------------------------------------------------------------------------------
--  This file is a part of the GRLIB VHDL IP LIBRARY
--  Copyright (C) 2012, Aeroflex Gaisler AB - all rights reserved.
--
-- ANY USE OR REDISTRIBUTION IN PART OR IN WHOLE MUST BE HANDLED IN 
-- ACCORDANCE WITH THE GAISLER LICENSE AGREEMENT AND MUST BE APPROVED 
-- IN ADVANCE IN WRITING. 
------------------------------------------------------------------------------

library ieee, stratixii;
use ieee.std_logic_1164.all;
use stratixii.stratixii_components.all;

library altera_mf;
use altera_mf.altera_mf_components.all;

entity grfpw_0_stratixii is
port(
  rst :  in std_logic;
  clk :  in std_logic;
  holdn :  in std_logic;
  cpi_flush :  in std_logic;
  cpi_exack :  in std_logic;
  cpi_a_rs1 : in std_logic_vector(4 downto 0);
  cpi_d_pc : in std_logic_vector(31 downto 0);
  cpi_d_inst : in std_logic_vector(31 downto 0);
  cpi_d_cnt : in std_logic_vector(1 downto 0);
  cpi_d_trap :  in std_logic;
  cpi_d_annul :  in std_logic;
  cpi_d_pv :  in std_logic;
  cpi_a_pc : in std_logic_vector(31 downto 0);
  cpi_a_inst : in std_logic_vector(31 downto 0);
  cpi_a_cnt : in std_logic_vector(1 downto 0);
  cpi_a_trap :  in std_logic;
  cpi_a_annul :  in std_logic;
  cpi_a_pv :  in std_logic;
  cpi_e_pc : in std_logic_vector(31 downto 0);
  cpi_e_inst : in std_logic_vector(31 downto 0);
  cpi_e_cnt : in std_logic_vector(1 downto 0);
  cpi_e_trap :  in std_logic;
  cpi_e_annul :  in std_logic;
  cpi_e_pv :  in std_logic;
  cpi_m_pc : in std_logic_vector(31 downto 0);
  cpi_m_inst : in std_logic_vector(31 downto 0);
  cpi_m_cnt : in std_logic_vector(1 downto 0);
  cpi_m_trap :  in std_logic;
  cpi_m_annul :  in std_logic;
  cpi_m_pv :  in std_logic;
  cpi_x_pc : in std_logic_vector(31 downto 0);
  cpi_x_inst : in std_logic_vector(31 downto 0);
  cpi_x_cnt : in std_logic_vector(1 downto 0);
  cpi_x_trap :  in std_logic;
  cpi_x_annul :  in std_logic;
  cpi_x_pv :  in std_logic;
  cpi_lddata : in std_logic_vector(31 downto 0);
  cpi_dbg_enable :  in std_logic;
  cpi_dbg_write :  in std_logic;
  cpi_dbg_fsr :  in std_logic;
  cpi_dbg_addr : in std_logic_vector(4 downto 0);
  cpi_dbg_data : in std_logic_vector(31 downto 0);
  cpo_data : out std_logic_vector(31 downto 0);
  cpo_exc :  out std_logic;
  cpo_cc : out std_logic_vector(1 downto 0);
  cpo_ccv :  out std_logic;
  cpo_ldlock :  out std_logic;
  cpo_holdn :  out std_logic;
  cpo_dbg_data : out std_logic_vector(31 downto 0);
  rfi1_rd1addr : out std_logic_vector(3 downto 0);
  rfi1_rd2addr : out std_logic_vector(3 downto 0);
  rfi1_wraddr : out std_logic_vector(3 downto 0);
  rfi1_wrdata : out std_logic_vector(31 downto 0);
  rfi1_ren1 :  out std_logic;
  rfi1_ren2 :  out std_logic;
  rfi1_wren :  out std_logic;
  rfi2_rd1addr : out std_logic_vector(3 downto 0);
  rfi2_rd2addr : out std_logic_vector(3 downto 0);
  rfi2_wraddr : out std_logic_vector(3 downto 0);
  rfi2_wrdata : out std_logic_vector(31 downto 0);
  rfi2_ren1 :  out std_logic;
  rfi2_ren2 :  out std_logic;
  rfi2_wren :  out std_logic;
  rfo1_data1 : in std_logic_vector(31 downto 0);
  rfo1_data2 : in std_logic_vector(31 downto 0);
  rfo2_data1 : in std_logic_vector(31 downto 0);
  rfo2_data2 : in std_logic_vector(31 downto 0));
end grfpw_0_stratixii;

architecture beh of grfpw_0_stratixii is
  signal devclrn : std_logic := '1';
  signal devpor : std_logic := '1';
  signal devoe : std_logic := '0';
  signal \FPO.RES\ : std_logic_vector(63 downto 0);
  signal \FPO.ALLOW\ : std_logic_vector(1 to 1);
  signal \FPO.CC\ : std_logic_vector(1 downto 0);
  signal \FPO.IDOUT\ : std_logic_vector(5 downto 0);
  signal \FPI.OP1\ : std_logic_vector(63 downto 0);
  signal \FPI.OP2\ : std_logic_vector(63 downto 0);
  signal \FPI.FLUSHID\ : std_logic_vector(5 downto 0);
  signal \FPI.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.DIVROMI\ : std_logic_vector(7 downto 0);
  signal \GRFPU0.MULO.MRES\ : std_logic_vector(120 downto 16);
  signal \GRFPU0.MULO.DRES_S\ : std_logic_vector(118 downto 65);
  signal \GRFPU0.MULO.DRES_1\ : std_logic_vector(121 downto 68);
  signal \GRFPU0.MULO.DRES_1S\ : std_logic_vector(118 downto 67);
  signal \GRFPU0.MULO.MRES_1\ : std_logic_vector(120 downto 69);
  signal \GRFPU0.MULO.MRES_1S\ : std_logic_vector(120 downto 68);
  signal \GRFPU0.DIVROM0.RADDR\ : std_logic_vector(7 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.DBUF\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.LZCNT\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.GUARDS\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPOP\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.R_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2\ : std_logic_vector(52 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES\ : std_logic_vector(55 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST2.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE1\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.RAW2\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.ID\ : std_logic_vector(5 downto 0);
  signal \FPI.OP1_RETO\ : std_logic_vector(28 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RAW1\ : std_logic_vector(63 downto 29);
  signal \GRFPU0.GRFPU_X0.ST2.DIFF\ : std_logic_vector(53 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.DIFFIN1\ : std_logic_vector(48 downto 29);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF1\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF2\ : std_logic_vector(43 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ND_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\ : std_logic_vector(52 downto 1);
  signal \GRFPU0.GRFPU_X0.ST2.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.UN8_C\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.C\ : std_logic_vector(11 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.REG\ : std_logic_vector(62 downto 2);
  signal \GRFPU0.GRFPU_X0.ST4.SGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.AEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MSGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_37\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\ : std_logic_vector(58 downto 23);
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\ : std_logic_vector(58 downto 23);
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP\ : std_logic_vector(52 downto 4);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP\ : std_logic_vector(52 downto 4);
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\ : std_logic_vector(56 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1\ : std_logic_vector(52 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\ : std_logic_vector(54 downto 49);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\ : std_logic_vector(41 downto 0);
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\ : std_logic_vector(55 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\ : std_logic_vector(7 downto 4);
  signal \GRFPU0.GRFPU_X0.UN1_INTO\ : std_logic_vector(31 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\ : std_logic_vector(7 downto 3);
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2\ : std_logic_vector(25 downto 1);
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1\ : std_logic_vector(28 downto 0);
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2\ : std_logic_vector(52 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1\ : std_logic_vector(53 downto 27);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\ : std_logic_vector(62 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\ : std_logic_vector(56 downto 20);
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX\ : std_logic_vector(22 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47\ : std_logic_vector(62 downto 32);
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3\ : std_logic_vector(23 downto 0);
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\ : std_logic_vector(7 downto 0);
  signal \GRFPU0.GRFPU_X0.VST2.EXC_8\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ITER.TZR\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.S3ADDI\ : std_logic_vector(51 downto 27);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\ : std_logic_vector(6 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\ : std_logic_vector(63 downto 32);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\ : std_logic_vector(28 downto 19);
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\ : std_logic_vector(22 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1\ : std_logic_vector(51 downto 29);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\ : std_logic_vector(50 downto 29);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\ : std_logic_vector(59 downto 8);
  signal \GRFPU0.GRFPU_X0.UN148_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN158_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_4_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.INST_0\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FIFO.INST_1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.EX.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.R.STATE\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.FOP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.MEM.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FIFO.VCNT_1\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.FIFO.VCNT_0\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.DIV.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.MEM.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.MEM.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR2.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.FIFO.WR\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR.CTRL.VCNT\ : std_logic_vector(0 to 0);
  signal \GRFPC0.RFA.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPR.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.FSR.AEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.TEM\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FIFO.PC_0\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FIFO.PC_1\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FPR.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.RFA2.RS2SEL\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\ : std_logic_vector(15 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.RS1SEL\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.DIV.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.MEM.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR2.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.R.FSR.FCC\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.D.LDLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.D.STDLCK\ : std_logic_vector(15 downto 0);
  signal \GRFPC0.DIV.RESULT\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.D.STLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.EX.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.STDATA\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.R.FSR.CEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.FTT\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.DIV.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR2.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.MEM.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.EX.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA.RS2\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FID_1\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.RFA.RS1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPRIN.ALLOW\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FPUSEL_1\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FPUSEL_6\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_146_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_370\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_266\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.WREN_17_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.WREN_17_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\ : std_logic_vector(59 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.FPMUL0.SX\ : std_logic_vector(121 downto 92);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\ : std_logic_vector(49 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\ : std_logic_vector(71 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\ : std_logic_vector(121 downto 16);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\ : std_logic_vector(47 downto 36);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1\ : std_logic_vector(26 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\ : std_logic_vector(48 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\ : std_logic_vector(97 downto 72);
  signal \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.DEP_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_9\ : std_logic_vector(1 to 1);
  signal \FPO.EXC\ : std_logic_vector(2 downto 0);
  signal \FPI.OPID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.V.STDATA_14\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\ : std_logic_vector(59 downto 8);
  signal \FPO.ALLOW_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\ : std_logic_vector(31 downto 11);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_268\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_17\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.RNDM_2\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\ : std_logic_vector(59 downto 33);
  signal \GRFPU0.GRFPU_X0.COMB.RMND_13\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\ : std_logic_vector(63 downto 33);
  signal \GRFPU0.GRFPU_X0.UN23_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN33_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_6\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_6\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_173\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\ : std_logic_vector(51 downto 3);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.TZI\ : std_logic_vector(23 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.UN108_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN113_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_13\ : std_logic_vector(4 downto 1);
  signal \GRFPU0.GRFPU_X0.L2_0_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L3_0_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L1_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN58_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\ : std_logic_vector(59 downto 8);
  signal \GRFPU0.GRFPU_X0.REST_1_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\ : std_logic_vector(63 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_33\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\ : std_logic_vector(63 downto 47);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.UN1_ITER.EXP\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.UN23_EXP\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\ : std_logic_vector(18 downto 17);
  signal \GRFPU0.GRFPU_X0.TZI2\ : std_logic_vector(21 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\ : std_logic_vector(55 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\ : std_logic_vector(57 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.UN48_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\ : std_logic_vector(21 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\ : std_logic_vector(62 downto 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\ : std_logic_vector(56 downto 20);
  signal \GRFPU0.GRFPU_X0.L1_6_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\ : std_logic_vector(59 downto 45);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.EXC_16\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.RNDM_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN68_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN53_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L2_0_5\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_7\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.L3_0_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.L3_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_2_3\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN238_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN228_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\ : std_logic_vector(3 downto 2);
  signal \GRFPU0.GRFPU_X0.L1_0_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\ : std_logic_vector(49 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\ : std_logic_vector(59 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\ : std_logic_vector(58 downto 7);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_3\ : std_logic_vector(24 downto 2);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_6\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\ : std_logic_vector(60 downto 29);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\ : std_logic_vector(60 downto 8);
  signal \GRFPU0.GRFPU_X0.L4_3\ : std_logic_vector(4 downto 3);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\ : std_logic_vector(2 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\ : std_logic_vector(5 downto 1);
  signal \GRFPU0.GRFPU_X0.UN83_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.FLOP4_1\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_283\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\ : std_logic_vector(57 downto 53);
  signal \GRFPU0.DIVAPPR\ : std_logic_vector(6 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.EXC_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.IEXC_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_3\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L4_2_2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.EXP_14\ : std_logic_vector(7 downto 5);
  signal \GRFPU0.GRFPU_X0.UN1_INCDP\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\ : std_logic_vector(31 downto 2);
  signal \GRFPU0.GRFPU_X0.RNDOP_32\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN253_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN258_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\ : std_logic_vector(56 downto 0);
  signal \GRFPU0.SQRTAPPR\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_INCSP\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47\ : std_logic_vector(56 downto 48);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\ : std_logic_vector(57 downto 37);
  signal \GRFPU0.GRFPU_X0.L2_0_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\ : std_logic_vector(40 to 40);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.UN73_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_2_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\ : std_logic_vector(47 downto 24);
  signal \GRFPU0.GRFPU_X0.L1_0\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.EXP_11\ : std_logic_vector(8 to 8);
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_126\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_129\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_148\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\ : std_logic_vector(58 downto 47);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\ : std_logic_vector(47 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\ : std_logic_vector(22 downto 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\ : std_logic_vector(52 downto 39);
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_I_M_1\ : std_logic_vector(28 to 28);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF1_I_M\ : std_logic_vector(28 to 28);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11_I_M\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.VITER.R_I_33_M\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.UN242_BCO_MSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\ : std_logic_vector(56 downto 39);
  signal \GRFPU0.GRFPU_X0.RNDOP_14\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_154\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.0.REGDEPX_78\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.1.REGDEPX_80\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_452\ : std_logic_vector(1 to 1);
  signal \FPI.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.INST\ : std_logic_vector(31 downto 5);
  signal \GRFPC0.FP_PIPELINE.RS1_6\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.VDIV.RD_1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_44\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_528\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_524\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_42\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.1.REGDEPX_44\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.1.REGDEPX_46\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_48\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_25_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_50\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FIFO.INST_0_I_M_2\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_246\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.1.REGDEPX_82\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_84\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX_66\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\ : std_logic_vector(15 downto 3);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_48\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_248\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FP_PIPELINE.WRDATA_3\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\ : std_logic_vector(2 downto 1);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.UN28_EXP\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FPUSEL_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_164\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FIFO.RD_I_M\ : std_logic_vector(0 to 0);
  signal \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\ : std_logic_vector(0 to 0);
  signal \GRFPC0.UN1_REN130\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_338\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_365\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_438\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_23_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX_264\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_616\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_384\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_604\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_608\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_8_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.0.REGDEPX_2_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.WR2SEL_1\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFAREG.R.STATE_4_M0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.UN4_CNTX\ : std_logic_vector(2 downto 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_372\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_13\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_289\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.10.0.REGDEPX_185\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_86\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_89\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.RS2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_9\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.0.REGDEPX_76\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_278\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_159\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_378\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_376\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_375\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_144\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_64\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX_106\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX_70\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.1.REGDEPX_262\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.0.REGDEPX_130\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_40\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX_250\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX_53\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_18\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_1_1_6_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_3_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_180_0_IV_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_0_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ\ : std_logic_vector(26 to 26);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_12_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A2_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_9_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_12_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_A3_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_9_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_I_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_I_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_8_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_14_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\ : std_logic_vector(38 to 38);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_35_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_6_1\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.L4_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\ : std_logic_vector(59 downto 37);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.WREN_17_IV_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.REN1_1_IV_0\ : std_logic_vector(2 downto 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_0_0\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_5_0_A2_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_8_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_202_0_IV_I_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.REST_1_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_1_2_IV_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_2_IV_1\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.REST_1_2_0\ : std_logic_vector(6 to 6);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L4_4_I_A2_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_6_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_3_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_5_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_0_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_0_10_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_1_1\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_4_0_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.V.STDATA_14_I_M_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_13\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_16\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_20\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_22\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L1_0_5_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0\ : std_logic_vector(61 downto 33);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_1\ : std_logic_vector(61 downto 33);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\ : std_logic_vector(59 downto 45);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\ : std_logic_vector(59 downto 45);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_0\ : std_logic_vector(35 to 35);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_1\ : std_logic_vector(35 to 35);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_5_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_0_O2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_O2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_A3_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_1\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_124_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\ : std_logic_vector(36 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\ : std_logic_vector(36 downto 4);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\ : std_logic_vector(11 to 11);
  signal \GRFPU0.GRFPU_X0.L2_0_7_0\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_0_7_1\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_0_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_0_0_1\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60_0_A5_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_402_0_IV_I_O2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_0\ : std_logic_vector(23 to 23);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_0\ : std_logic_vector(26 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3_1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX_230_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX_102_I_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_2\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_3_0\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_0\ : std_logic_vector(26 to 26);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_1\ : std_logic_vector(26 to 26);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\ : std_logic_vector(53 downto 25);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\ : std_logic_vector(55 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\ : std_logic_vector(53 to 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_1\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_4\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\ : std_logic_vector(55 downto 38);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_4_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_9\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_13\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_9_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\ : std_logic_vector(19 downto 5);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_O2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\ : std_logic_vector(24 to 24);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_1\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O3_10_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_335_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_8\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_18\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_20\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_22\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_27\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_29\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_13\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_4_1\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_3\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_44\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\ : std_logic_vector(18 to 18);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_10\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_13\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\ : std_logic_vector(35 downto 7);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\ : std_logic_vector(60 to 60);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\ : std_logic_vector(43 downto 32);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\ : std_logic_vector(44 downto 36);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_8_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VFIFO.VCNT_0_1_F1_0_O4_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_0\ : std_logic_vector(63 to 63);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A4_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_0\ : std_logic_vector(55 downto 53);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\ : std_logic_vector(55 to 55);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_O2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_O2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_A3_6_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_7\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\ : std_logic_vector(62 downto 58);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\ : std_logic_vector(62 downto 56);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_1\ : std_logic_vector(58 to 58);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_12\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_11\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\ : std_logic_vector(35 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\ : std_logic_vector(40 downto 9);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\ : std_logic_vector(40 downto 9);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\ : std_logic_vector(40 downto 9);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\ : std_logic_vector(30 downto 16);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_0\ : std_logic_vector(33 to 33);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_3\ : std_logic_vector(33 to 33);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_1\ : std_logic_vector(26 to 26);
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB_S_1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\ : std_logic_vector(40 downto 31);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\ : std_logic_vector(30 downto 9);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\ : std_logic_vector(51 downto 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\ : std_logic_vector(48 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\ : std_logic_vector(59 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\ : std_logic_vector(44 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\ : std_logic_vector(59 downto 38);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\ : std_logic_vector(34 to 34);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\ : std_logic_vector(59 downto 10);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\ : std_logic_vector(24 downto 13);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_2\ : std_logic_vector(24 downto 13);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\ : std_logic_vector(58 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\ : std_logic_vector(38 downto 11);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\ : std_logic_vector(11 to 11);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_A2_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_A2_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.STDEP_412_3_0_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_O3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_11_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_O3_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\ : std_logic_vector(54 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\ : std_logic_vector(58 downto 46);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\ : std_logic_vector(58 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\ : std_logic_vector(58 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_1\ : std_logic_vector(57 downto 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_5\ : std_logic_vector(40 to 40);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FPO_I_4_I_0\ : std_logic_vector(69 to 69);
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.V.STDATA_14_M_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.UN128_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN123_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_4_3\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.RNDOP_29_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L4_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_3_0\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_6\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_7_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.UN248_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_0_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_7\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_6_1\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_0_9_0_A3_5\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.L2_0_9_0_A3_1\ : std_logic_vector(4 to 4);
  signal \GRFPU0.MULO.DRES_S_RETI\ : std_logic_vector(91 downto 66);
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I\ : std_logic_vector(60 to 60);
  signal \GRFPU0.MULO.MRES_1_RETI\ : std_logic_vector(94 downto 69);
  signal \GRFPU0.MULO.MRES_1S_RETI\ : std_logic_vector(120 downto 69);
  signal \GRFPU0.MULO.MRES_RETI\ : std_logic_vector(101 downto 66);
  signal \GRFPU0.FPMUL0.UN1_SIN_2\ : std_logic_vector(56 downto 55);
  signal \GRFPU0.MULO.DRES_1_RETI\ : std_logic_vector(97 downto 68);
  signal \GRFPU0.FPMUL0.UN1_SIN_3\ : std_logic_vector(57 downto 56);
  signal \GRFPU0.MULO.DRES_1S_RETI\ : std_logic_vector(92 downto 67);
  signal \GRFPC0.FPUSEL_6_1_RETO\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.RAW2_RETO\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_RETO\ : std_logic_vector(63 to 63);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ITER.IDI\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB_RETI\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1_RETI\ : std_logic_vector(11 downto 10);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0_RETI\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ITER.RNDMODEI\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.TZI2_RETI\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.C_I\ : std_logic_vector(11 to 11);
  signal \GRFPC0.FIFO.INST_1_0\ : std_logic_vector(29 downto 6);
  signal \GRFPC0.FIFO.INST_0_0\ : std_logic_vector(29 downto 6);
  signal \GRFPC0.FIFO.RD_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.WR_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST3.FLOP_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\ : std_logic_vector(8 downto 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\ : std_logic_vector(5 to 5);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_0\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST3.REG_0\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.ST3.REG_1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0\ : std_logic_vector(12 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE_1\ : std_logic_vector(12 downto 0);
  signal \GRFPC0.DIV.RD_0\ : std_logic_vector(4 downto 3);
  signal \GRFPC0.RFA2.RS2SEL_0\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS2SEL_1\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS1SEL_0\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS1SEL_1\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.R.STATE_189\ : std_logic_vector(0 to 0);
  signal \GRFPC0.R.STATE_190\ : std_logic_vector(0 to 0);
  signal \GRFPC0.R.STATE_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.R.STATE_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_0\ : std_logic_vector(55 downto 54);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_1\ : std_logic_vector(55 downto 54);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_2\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_3\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES_4\ : std_logic_vector(55 to 55);
  signal \GRFPU0.GRFPU_X0.L4_4_0\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_4_1\ : std_logic_vector(3 downto 2);
  signal \GRFPU0.MULO.MRES_0\ : std_logic_vector(120 to 120);
  signal \FPI.FLOP_0\ : std_logic_vector(6 downto 1);
  signal \FPI.FLOP_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\ : std_logic_vector(0 to 0);
  signal \FPI.FLOP_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FIFO.RD_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.R.STATE_191\ : std_logic_vector(0 to 0);
  signal \GRFPC0.R.STATE_2\ : std_logic_vector(1 to 1);
  signal CPO_DATAZ : std_logic_vector(31 downto 0);
  signal CPO_CCZ : std_logic_vector(1 downto 0);
  signal CPO_DBG_DATAZ : std_logic_vector(31 downto 0);
  signal RFI1_WRDATAZ : std_logic_vector(31 downto 0);
  signal RFI2_RD1ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_RD2ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRDATAZ : std_logic_vector(31 downto 0);
  signal CLK_INTERNAL : std_logic ;
  signal CPI_FLUSH_INTERNAL : std_logic ;
  signal CPI_EXACK_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL_0 : std_logic ;
  signal CPI_A_RS1_INTERNAL_1 : std_logic ;
  signal CPI_A_RS1_INTERNAL_2 : std_logic ;
  signal CPI_A_RS1_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL : std_logic ;
  signal CPI_D_PC_INTERNAL_0 : std_logic ;
  signal CPI_D_PC_INTERNAL_1 : std_logic ;
  signal CPI_D_PC_INTERNAL_2 : std_logic ;
  signal CPI_D_PC_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL_4 : std_logic ;
  signal CPI_D_PC_INTERNAL_5 : std_logic ;
  signal CPI_D_PC_INTERNAL_6 : std_logic ;
  signal CPI_D_PC_INTERNAL_7 : std_logic ;
  signal CPI_D_PC_INTERNAL_8 : std_logic ;
  signal CPI_D_PC_INTERNAL_9 : std_logic ;
  signal CPI_D_PC_INTERNAL_10 : std_logic ;
  signal CPI_D_PC_INTERNAL_11 : std_logic ;
  signal CPI_D_PC_INTERNAL_12 : std_logic ;
  signal CPI_D_PC_INTERNAL_13 : std_logic ;
  signal CPI_D_PC_INTERNAL_14 : std_logic ;
  signal CPI_D_PC_INTERNAL_15 : std_logic ;
  signal CPI_D_PC_INTERNAL_16 : std_logic ;
  signal CPI_D_PC_INTERNAL_17 : std_logic ;
  signal CPI_D_PC_INTERNAL_18 : std_logic ;
  signal CPI_D_PC_INTERNAL_19 : std_logic ;
  signal CPI_D_PC_INTERNAL_20 : std_logic ;
  signal CPI_D_PC_INTERNAL_21 : std_logic ;
  signal CPI_D_PC_INTERNAL_22 : std_logic ;
  signal CPI_D_PC_INTERNAL_23 : std_logic ;
  signal CPI_D_PC_INTERNAL_24 : std_logic ;
  signal CPI_D_PC_INTERNAL_25 : std_logic ;
  signal CPI_D_PC_INTERNAL_26 : std_logic ;
  signal CPI_D_PC_INTERNAL_27 : std_logic ;
  signal CPI_D_PC_INTERNAL_28 : std_logic ;
  signal CPI_D_PC_INTERNAL_29 : std_logic ;
  signal CPI_D_PC_INTERNAL_30 : std_logic ;
  signal CPI_D_INST_INTERNAL : std_logic ;
  signal CPI_D_INST_INTERNAL_0 : std_logic ;
  signal CPI_D_INST_INTERNAL_1 : std_logic ;
  signal CPI_D_INST_INTERNAL_2 : std_logic ;
  signal CPI_D_INST_INTERNAL_3 : std_logic ;
  signal CPI_D_INST_INTERNAL_4 : std_logic ;
  signal CPI_D_INST_INTERNAL_5 : std_logic ;
  signal CPI_D_INST_INTERNAL_6 : std_logic ;
  signal CPI_D_INST_INTERNAL_7 : std_logic ;
  signal CPI_D_INST_INTERNAL_8 : std_logic ;
  signal CPI_D_INST_INTERNAL_9 : std_logic ;
  signal CPI_D_INST_INTERNAL_10 : std_logic ;
  signal CPI_D_INST_INTERNAL_11 : std_logic ;
  signal CPI_D_INST_INTERNAL_12 : std_logic ;
  signal CPI_D_INST_INTERNAL_13 : std_logic ;
  signal CPI_D_INST_INTERNAL_14 : std_logic ;
  signal CPI_D_INST_INTERNAL_15 : std_logic ;
  signal CPI_D_INST_INTERNAL_16 : std_logic ;
  signal CPI_D_INST_INTERNAL_17 : std_logic ;
  signal CPI_D_INST_INTERNAL_18 : std_logic ;
  signal CPI_D_INST_INTERNAL_19 : std_logic ;
  signal CPI_D_INST_INTERNAL_20 : std_logic ;
  signal CPI_D_INST_INTERNAL_21 : std_logic ;
  signal CPI_D_INST_INTERNAL_22 : std_logic ;
  signal CPI_D_INST_INTERNAL_23 : std_logic ;
  signal CPI_D_INST_INTERNAL_24 : std_logic ;
  signal CPI_D_INST_INTERNAL_25 : std_logic ;
  signal CPI_D_INST_INTERNAL_26 : std_logic ;
  signal CPI_D_INST_INTERNAL_27 : std_logic ;
  signal CPI_D_INST_INTERNAL_28 : std_logic ;
  signal CPI_D_INST_INTERNAL_29 : std_logic ;
  signal CPI_D_INST_INTERNAL_30 : std_logic ;
  signal CPI_D_CNT_INTERNAL : std_logic ;
  signal CPI_D_CNT_INTERNAL_0 : std_logic ;
  signal CPI_D_TRAP_INTERNAL : std_logic ;
  signal CPI_D_ANNUL_INTERNAL : std_logic ;
  signal CPI_D_PV_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL_0 : std_logic ;
  signal CPI_A_PC_INTERNAL_1 : std_logic ;
  signal CPI_A_PC_INTERNAL_2 : std_logic ;
  signal CPI_A_PC_INTERNAL_3 : std_logic ;
  signal CPI_A_PC_INTERNAL_4 : std_logic ;
  signal CPI_A_PC_INTERNAL_5 : std_logic ;
  signal CPI_A_PC_INTERNAL_6 : std_logic ;
  signal CPI_A_PC_INTERNAL_7 : std_logic ;
  signal CPI_A_PC_INTERNAL_8 : std_logic ;
  signal CPI_A_PC_INTERNAL_9 : std_logic ;
  signal CPI_A_PC_INTERNAL_10 : std_logic ;
  signal CPI_A_PC_INTERNAL_11 : std_logic ;
  signal CPI_A_PC_INTERNAL_12 : std_logic ;
  signal CPI_A_PC_INTERNAL_13 : std_logic ;
  signal CPI_A_PC_INTERNAL_14 : std_logic ;
  signal CPI_A_PC_INTERNAL_15 : std_logic ;
  signal CPI_A_PC_INTERNAL_16 : std_logic ;
  signal CPI_A_PC_INTERNAL_17 : std_logic ;
  signal CPI_A_PC_INTERNAL_18 : std_logic ;
  signal CPI_A_PC_INTERNAL_19 : std_logic ;
  signal CPI_A_PC_INTERNAL_20 : std_logic ;
  signal CPI_A_PC_INTERNAL_21 : std_logic ;
  signal CPI_A_PC_INTERNAL_22 : std_logic ;
  signal CPI_A_PC_INTERNAL_23 : std_logic ;
  signal CPI_A_PC_INTERNAL_24 : std_logic ;
  signal CPI_A_PC_INTERNAL_25 : std_logic ;
  signal CPI_A_PC_INTERNAL_26 : std_logic ;
  signal CPI_A_PC_INTERNAL_27 : std_logic ;
  signal CPI_A_PC_INTERNAL_28 : std_logic ;
  signal CPI_A_PC_INTERNAL_29 : std_logic ;
  signal CPI_A_PC_INTERNAL_30 : std_logic ;
  signal CPI_A_INST_INTERNAL : std_logic ;
  signal CPI_A_INST_INTERNAL_0 : std_logic ;
  signal CPI_A_INST_INTERNAL_1 : std_logic ;
  signal CPI_A_INST_INTERNAL_2 : std_logic ;
  signal CPI_A_INST_INTERNAL_3 : std_logic ;
  signal CPI_A_INST_INTERNAL_4 : std_logic ;
  signal CPI_A_INST_INTERNAL_5 : std_logic ;
  signal CPI_A_INST_INTERNAL_6 : std_logic ;
  signal CPI_A_INST_INTERNAL_7 : std_logic ;
  signal CPI_A_INST_INTERNAL_8 : std_logic ;
  signal CPI_A_INST_INTERNAL_9 : std_logic ;
  signal CPI_A_INST_INTERNAL_10 : std_logic ;
  signal CPI_A_INST_INTERNAL_11 : std_logic ;
  signal CPI_A_INST_INTERNAL_12 : std_logic ;
  signal CPI_A_INST_INTERNAL_13 : std_logic ;
  signal CPI_A_INST_INTERNAL_14 : std_logic ;
  signal CPI_A_INST_INTERNAL_15 : std_logic ;
  signal CPI_A_INST_INTERNAL_16 : std_logic ;
  signal CPI_A_INST_INTERNAL_17 : std_logic ;
  signal CPI_A_INST_INTERNAL_18 : std_logic ;
  signal CPI_A_INST_INTERNAL_19 : std_logic ;
  signal CPI_A_INST_INTERNAL_20 : std_logic ;
  signal CPI_A_INST_INTERNAL_21 : std_logic ;
  signal CPI_A_INST_INTERNAL_22 : std_logic ;
  signal CPI_A_INST_INTERNAL_23 : std_logic ;
  signal CPI_A_INST_INTERNAL_24 : std_logic ;
  signal CPI_A_INST_INTERNAL_25 : std_logic ;
  signal CPI_A_INST_INTERNAL_26 : std_logic ;
  signal CPI_A_INST_INTERNAL_27 : std_logic ;
  signal CPI_A_INST_INTERNAL_28 : std_logic ;
  signal CPI_A_INST_INTERNAL_29 : std_logic ;
  signal CPI_A_INST_INTERNAL_30 : std_logic ;
  signal CPI_A_CNT_INTERNAL : std_logic ;
  signal CPI_A_CNT_INTERNAL_0 : std_logic ;
  signal CPI_A_TRAP_INTERNAL : std_logic ;
  signal CPI_A_ANNUL_INTERNAL : std_logic ;
  signal CPI_A_PV_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL_0 : std_logic ;
  signal CPI_E_PC_INTERNAL_1 : std_logic ;
  signal CPI_E_PC_INTERNAL_2 : std_logic ;
  signal CPI_E_PC_INTERNAL_3 : std_logic ;
  signal CPI_E_PC_INTERNAL_4 : std_logic ;
  signal CPI_E_PC_INTERNAL_5 : std_logic ;
  signal CPI_E_PC_INTERNAL_6 : std_logic ;
  signal CPI_E_PC_INTERNAL_7 : std_logic ;
  signal CPI_E_PC_INTERNAL_8 : std_logic ;
  signal CPI_E_PC_INTERNAL_9 : std_logic ;
  signal CPI_E_PC_INTERNAL_10 : std_logic ;
  signal CPI_E_PC_INTERNAL_11 : std_logic ;
  signal CPI_E_PC_INTERNAL_12 : std_logic ;
  signal CPI_E_PC_INTERNAL_13 : std_logic ;
  signal CPI_E_PC_INTERNAL_14 : std_logic ;
  signal CPI_E_PC_INTERNAL_15 : std_logic ;
  signal CPI_E_PC_INTERNAL_16 : std_logic ;
  signal CPI_E_PC_INTERNAL_17 : std_logic ;
  signal CPI_E_PC_INTERNAL_18 : std_logic ;
  signal CPI_E_PC_INTERNAL_19 : std_logic ;
  signal CPI_E_PC_INTERNAL_20 : std_logic ;
  signal CPI_E_PC_INTERNAL_21 : std_logic ;
  signal CPI_E_PC_INTERNAL_22 : std_logic ;
  signal CPI_E_PC_INTERNAL_23 : std_logic ;
  signal CPI_E_PC_INTERNAL_24 : std_logic ;
  signal CPI_E_PC_INTERNAL_25 : std_logic ;
  signal CPI_E_PC_INTERNAL_26 : std_logic ;
  signal CPI_E_PC_INTERNAL_27 : std_logic ;
  signal CPI_E_PC_INTERNAL_28 : std_logic ;
  signal CPI_E_PC_INTERNAL_29 : std_logic ;
  signal CPI_E_PC_INTERNAL_30 : std_logic ;
  signal CPI_E_INST_INTERNAL : std_logic ;
  signal CPI_E_INST_INTERNAL_0 : std_logic ;
  signal CPI_E_INST_INTERNAL_1 : std_logic ;
  signal CPI_E_INST_INTERNAL_2 : std_logic ;
  signal CPI_E_INST_INTERNAL_3 : std_logic ;
  signal CPI_E_INST_INTERNAL_4 : std_logic ;
  signal CPI_E_INST_INTERNAL_5 : std_logic ;
  signal CPI_E_INST_INTERNAL_6 : std_logic ;
  signal CPI_E_INST_INTERNAL_7 : std_logic ;
  signal CPI_E_INST_INTERNAL_8 : std_logic ;
  signal CPI_E_INST_INTERNAL_9 : std_logic ;
  signal CPI_E_INST_INTERNAL_10 : std_logic ;
  signal CPI_E_INST_INTERNAL_11 : std_logic ;
  signal CPI_E_INST_INTERNAL_12 : std_logic ;
  signal CPI_E_INST_INTERNAL_13 : std_logic ;
  signal CPI_E_INST_INTERNAL_14 : std_logic ;
  signal CPI_E_INST_INTERNAL_15 : std_logic ;
  signal CPI_E_INST_INTERNAL_16 : std_logic ;
  signal CPI_E_INST_INTERNAL_17 : std_logic ;
  signal CPI_E_INST_INTERNAL_18 : std_logic ;
  signal CPI_E_INST_INTERNAL_19 : std_logic ;
  signal CPI_E_INST_INTERNAL_20 : std_logic ;
  signal CPI_E_INST_INTERNAL_21 : std_logic ;
  signal CPI_E_INST_INTERNAL_22 : std_logic ;
  signal CPI_E_INST_INTERNAL_23 : std_logic ;
  signal CPI_E_INST_INTERNAL_24 : std_logic ;
  signal CPI_E_INST_INTERNAL_25 : std_logic ;
  signal CPI_E_INST_INTERNAL_26 : std_logic ;
  signal CPI_E_INST_INTERNAL_27 : std_logic ;
  signal CPI_E_INST_INTERNAL_28 : std_logic ;
  signal CPI_E_INST_INTERNAL_29 : std_logic ;
  signal CPI_E_INST_INTERNAL_30 : std_logic ;
  signal CPI_E_CNT_INTERNAL : std_logic ;
  signal CPI_E_CNT_INTERNAL_0 : std_logic ;
  signal CPI_E_TRAP_INTERNAL : std_logic ;
  signal CPI_E_ANNUL_INTERNAL : std_logic ;
  signal CPI_E_PV_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL_0 : std_logic ;
  signal CPI_M_PC_INTERNAL_1 : std_logic ;
  signal CPI_M_PC_INTERNAL_2 : std_logic ;
  signal CPI_M_PC_INTERNAL_3 : std_logic ;
  signal CPI_M_PC_INTERNAL_4 : std_logic ;
  signal CPI_M_PC_INTERNAL_5 : std_logic ;
  signal CPI_M_PC_INTERNAL_6 : std_logic ;
  signal CPI_M_PC_INTERNAL_7 : std_logic ;
  signal CPI_M_PC_INTERNAL_8 : std_logic ;
  signal CPI_M_PC_INTERNAL_9 : std_logic ;
  signal CPI_M_PC_INTERNAL_10 : std_logic ;
  signal CPI_M_PC_INTERNAL_11 : std_logic ;
  signal CPI_M_PC_INTERNAL_12 : std_logic ;
  signal CPI_M_PC_INTERNAL_13 : std_logic ;
  signal CPI_M_PC_INTERNAL_14 : std_logic ;
  signal CPI_M_PC_INTERNAL_15 : std_logic ;
  signal CPI_M_PC_INTERNAL_16 : std_logic ;
  signal CPI_M_PC_INTERNAL_17 : std_logic ;
  signal CPI_M_PC_INTERNAL_18 : std_logic ;
  signal CPI_M_PC_INTERNAL_19 : std_logic ;
  signal CPI_M_PC_INTERNAL_20 : std_logic ;
  signal CPI_M_PC_INTERNAL_21 : std_logic ;
  signal CPI_M_PC_INTERNAL_22 : std_logic ;
  signal CPI_M_PC_INTERNAL_23 : std_logic ;
  signal CPI_M_PC_INTERNAL_24 : std_logic ;
  signal CPI_M_PC_INTERNAL_25 : std_logic ;
  signal CPI_M_PC_INTERNAL_26 : std_logic ;
  signal CPI_M_PC_INTERNAL_27 : std_logic ;
  signal CPI_M_PC_INTERNAL_28 : std_logic ;
  signal CPI_M_PC_INTERNAL_29 : std_logic ;
  signal CPI_M_PC_INTERNAL_30 : std_logic ;
  signal CPI_M_INST_INTERNAL : std_logic ;
  signal CPI_M_INST_INTERNAL_0 : std_logic ;
  signal CPI_M_INST_INTERNAL_1 : std_logic ;
  signal CPI_M_INST_INTERNAL_2 : std_logic ;
  signal CPI_M_INST_INTERNAL_3 : std_logic ;
  signal CPI_M_INST_INTERNAL_4 : std_logic ;
  signal CPI_M_INST_INTERNAL_5 : std_logic ;
  signal CPI_M_INST_INTERNAL_6 : std_logic ;
  signal CPI_M_INST_INTERNAL_7 : std_logic ;
  signal CPI_M_INST_INTERNAL_8 : std_logic ;
  signal CPI_M_INST_INTERNAL_9 : std_logic ;
  signal CPI_M_INST_INTERNAL_10 : std_logic ;
  signal CPI_M_INST_INTERNAL_11 : std_logic ;
  signal CPI_M_INST_INTERNAL_12 : std_logic ;
  signal CPI_M_INST_INTERNAL_13 : std_logic ;
  signal CPI_M_INST_INTERNAL_14 : std_logic ;
  signal CPI_M_INST_INTERNAL_15 : std_logic ;
  signal CPI_M_INST_INTERNAL_16 : std_logic ;
  signal CPI_M_INST_INTERNAL_17 : std_logic ;
  signal CPI_M_INST_INTERNAL_18 : std_logic ;
  signal CPI_M_INST_INTERNAL_19 : std_logic ;
  signal CPI_M_INST_INTERNAL_20 : std_logic ;
  signal CPI_M_INST_INTERNAL_21 : std_logic ;
  signal CPI_M_INST_INTERNAL_22 : std_logic ;
  signal CPI_M_INST_INTERNAL_23 : std_logic ;
  signal CPI_M_INST_INTERNAL_24 : std_logic ;
  signal CPI_M_INST_INTERNAL_25 : std_logic ;
  signal CPI_M_INST_INTERNAL_26 : std_logic ;
  signal CPI_M_INST_INTERNAL_27 : std_logic ;
  signal CPI_M_INST_INTERNAL_28 : std_logic ;
  signal CPI_M_INST_INTERNAL_29 : std_logic ;
  signal CPI_M_INST_INTERNAL_30 : std_logic ;
  signal CPI_M_CNT_INTERNAL : std_logic ;
  signal CPI_M_CNT_INTERNAL_0 : std_logic ;
  signal CPI_M_TRAP_INTERNAL : std_logic ;
  signal CPI_M_ANNUL_INTERNAL : std_logic ;
  signal CPI_M_PV_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL_0 : std_logic ;
  signal CPI_X_PC_INTERNAL_1 : std_logic ;
  signal CPI_X_PC_INTERNAL_2 : std_logic ;
  signal CPI_X_PC_INTERNAL_3 : std_logic ;
  signal CPI_X_PC_INTERNAL_4 : std_logic ;
  signal CPI_X_PC_INTERNAL_5 : std_logic ;
  signal CPI_X_PC_INTERNAL_6 : std_logic ;
  signal CPI_X_PC_INTERNAL_7 : std_logic ;
  signal CPI_X_PC_INTERNAL_8 : std_logic ;
  signal CPI_X_PC_INTERNAL_9 : std_logic ;
  signal CPI_X_PC_INTERNAL_10 : std_logic ;
  signal CPI_X_PC_INTERNAL_11 : std_logic ;
  signal CPI_X_PC_INTERNAL_12 : std_logic ;
  signal CPI_X_PC_INTERNAL_13 : std_logic ;
  signal CPI_X_PC_INTERNAL_14 : std_logic ;
  signal CPI_X_PC_INTERNAL_15 : std_logic ;
  signal CPI_X_PC_INTERNAL_16 : std_logic ;
  signal CPI_X_PC_INTERNAL_17 : std_logic ;
  signal CPI_X_PC_INTERNAL_18 : std_logic ;
  signal CPI_X_PC_INTERNAL_19 : std_logic ;
  signal CPI_X_PC_INTERNAL_20 : std_logic ;
  signal CPI_X_PC_INTERNAL_21 : std_logic ;
  signal CPI_X_PC_INTERNAL_22 : std_logic ;
  signal CPI_X_PC_INTERNAL_23 : std_logic ;
  signal CPI_X_PC_INTERNAL_24 : std_logic ;
  signal CPI_X_PC_INTERNAL_25 : std_logic ;
  signal CPI_X_PC_INTERNAL_26 : std_logic ;
  signal CPI_X_PC_INTERNAL_27 : std_logic ;
  signal CPI_X_PC_INTERNAL_28 : std_logic ;
  signal CPI_X_PC_INTERNAL_29 : std_logic ;
  signal CPI_X_PC_INTERNAL_30 : std_logic ;
  signal CPI_X_INST_INTERNAL : std_logic ;
  signal CPI_X_INST_INTERNAL_0 : std_logic ;
  signal CPI_X_INST_INTERNAL_1 : std_logic ;
  signal CPI_X_INST_INTERNAL_2 : std_logic ;
  signal CPI_X_INST_INTERNAL_3 : std_logic ;
  signal CPI_X_INST_INTERNAL_4 : std_logic ;
  signal CPI_X_INST_INTERNAL_5 : std_logic ;
  signal CPI_X_INST_INTERNAL_6 : std_logic ;
  signal CPI_X_INST_INTERNAL_7 : std_logic ;
  signal CPI_X_INST_INTERNAL_8 : std_logic ;
  signal CPI_X_INST_INTERNAL_9 : std_logic ;
  signal CPI_X_INST_INTERNAL_10 : std_logic ;
  signal CPI_X_INST_INTERNAL_11 : std_logic ;
  signal CPI_X_INST_INTERNAL_12 : std_logic ;
  signal CPI_X_INST_INTERNAL_13 : std_logic ;
  signal CPI_X_INST_INTERNAL_14 : std_logic ;
  signal CPI_X_INST_INTERNAL_15 : std_logic ;
  signal CPI_X_INST_INTERNAL_16 : std_logic ;
  signal CPI_X_INST_INTERNAL_17 : std_logic ;
  signal CPI_X_INST_INTERNAL_18 : std_logic ;
  signal CPI_X_INST_INTERNAL_19 : std_logic ;
  signal CPI_X_INST_INTERNAL_20 : std_logic ;
  signal CPI_X_INST_INTERNAL_21 : std_logic ;
  signal CPI_X_INST_INTERNAL_22 : std_logic ;
  signal CPI_X_INST_INTERNAL_23 : std_logic ;
  signal CPI_X_INST_INTERNAL_24 : std_logic ;
  signal CPI_X_INST_INTERNAL_25 : std_logic ;
  signal CPI_X_INST_INTERNAL_26 : std_logic ;
  signal CPI_X_INST_INTERNAL_27 : std_logic ;
  signal CPI_X_INST_INTERNAL_28 : std_logic ;
  signal CPI_X_INST_INTERNAL_29 : std_logic ;
  signal CPI_X_INST_INTERNAL_30 : std_logic ;
  signal CPI_X_CNT_INTERNAL : std_logic ;
  signal CPI_X_CNT_INTERNAL_0 : std_logic ;
  signal CPI_X_TRAP_INTERNAL : std_logic ;
  signal CPI_X_ANNUL_INTERNAL : std_logic ;
  signal CPI_X_PV_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL_0 : std_logic ;
  signal CPI_LDDATA_INTERNAL_1 : std_logic ;
  signal CPI_LDDATA_INTERNAL_2 : std_logic ;
  signal CPI_LDDATA_INTERNAL_3 : std_logic ;
  signal CPI_LDDATA_INTERNAL_4 : std_logic ;
  signal CPI_LDDATA_INTERNAL_5 : std_logic ;
  signal CPI_LDDATA_INTERNAL_6 : std_logic ;
  signal CPI_LDDATA_INTERNAL_7 : std_logic ;
  signal CPI_LDDATA_INTERNAL_8 : std_logic ;
  signal CPI_LDDATA_INTERNAL_9 : std_logic ;
  signal CPI_LDDATA_INTERNAL_10 : std_logic ;
  signal CPI_LDDATA_INTERNAL_11 : std_logic ;
  signal CPI_LDDATA_INTERNAL_12 : std_logic ;
  signal CPI_LDDATA_INTERNAL_13 : std_logic ;
  signal CPI_LDDATA_INTERNAL_14 : std_logic ;
  signal CPI_LDDATA_INTERNAL_15 : std_logic ;
  signal CPI_LDDATA_INTERNAL_16 : std_logic ;
  signal CPI_LDDATA_INTERNAL_17 : std_logic ;
  signal CPI_LDDATA_INTERNAL_18 : std_logic ;
  signal CPI_LDDATA_INTERNAL_19 : std_logic ;
  signal CPI_LDDATA_INTERNAL_20 : std_logic ;
  signal CPI_LDDATA_INTERNAL_21 : std_logic ;
  signal CPI_LDDATA_INTERNAL_22 : std_logic ;
  signal CPI_LDDATA_INTERNAL_23 : std_logic ;
  signal CPI_LDDATA_INTERNAL_24 : std_logic ;
  signal CPI_LDDATA_INTERNAL_25 : std_logic ;
  signal CPI_LDDATA_INTERNAL_26 : std_logic ;
  signal CPI_LDDATA_INTERNAL_27 : std_logic ;
  signal CPI_LDDATA_INTERNAL_28 : std_logic ;
  signal CPI_LDDATA_INTERNAL_29 : std_logic ;
  signal CPI_LDDATA_INTERNAL_30 : std_logic ;
  signal CPI_DBG_ENABLE_INTERNAL : std_logic ;
  signal CPI_DBG_WRITE_INTERNAL : std_logic ;
  signal CPI_DBG_FSR_INTERNAL : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_0 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_1 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_2 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_0 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_1 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_2 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_4 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_5 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_6 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_7 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_8 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_9 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_10 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_11 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_12 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_13 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_14 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_15 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_16 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_17 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_18 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_19 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_20 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_21 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_22 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_23 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_24 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_25 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_26 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_27 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_28 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_29 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_30 : std_logic ;
  signal RFO1_DATA1_INTERNAL : std_logic ;
  signal RFO1_DATA1_INTERNAL_0 : std_logic ;
  signal RFO1_DATA1_INTERNAL_1 : std_logic ;
  signal RFO1_DATA1_INTERNAL_2 : std_logic ;
  signal RFO1_DATA1_INTERNAL_3 : std_logic ;
  signal RFO1_DATA1_INTERNAL_4 : std_logic ;
  signal RFO1_DATA1_INTERNAL_5 : std_logic ;
  signal RFO1_DATA1_INTERNAL_6 : std_logic ;
  signal RFO1_DATA1_INTERNAL_7 : std_logic ;
  signal RFO1_DATA1_INTERNAL_8 : std_logic ;
  signal RFO1_DATA1_INTERNAL_9 : std_logic ;
  signal RFO1_DATA1_INTERNAL_10 : std_logic ;
  signal RFO1_DATA1_INTERNAL_11 : std_logic ;
  signal RFO1_DATA1_INTERNAL_12 : std_logic ;
  signal RFO1_DATA1_INTERNAL_13 : std_logic ;
  signal RFO1_DATA1_INTERNAL_14 : std_logic ;
  signal RFO1_DATA1_INTERNAL_15 : std_logic ;
  signal RFO1_DATA1_INTERNAL_16 : std_logic ;
  signal RFO1_DATA1_INTERNAL_17 : std_logic ;
  signal RFO1_DATA1_INTERNAL_18 : std_logic ;
  signal RFO1_DATA1_INTERNAL_19 : std_logic ;
  signal RFO1_DATA1_INTERNAL_20 : std_logic ;
  signal RFO1_DATA1_INTERNAL_21 : std_logic ;
  signal RFO1_DATA1_INTERNAL_22 : std_logic ;
  signal RFO1_DATA1_INTERNAL_23 : std_logic ;
  signal RFO1_DATA1_INTERNAL_24 : std_logic ;
  signal RFO1_DATA1_INTERNAL_25 : std_logic ;
  signal RFO1_DATA1_INTERNAL_26 : std_logic ;
  signal RFO1_DATA1_INTERNAL_27 : std_logic ;
  signal RFO1_DATA1_INTERNAL_28 : std_logic ;
  signal RFO1_DATA1_INTERNAL_29 : std_logic ;
  signal RFO1_DATA1_INTERNAL_30 : std_logic ;
  signal RFO1_DATA2_INTERNAL : std_logic ;
  signal RFO1_DATA2_INTERNAL_0 : std_logic ;
  signal RFO1_DATA2_INTERNAL_1 : std_logic ;
  signal RFO1_DATA2_INTERNAL_2 : std_logic ;
  signal RFO1_DATA2_INTERNAL_3 : std_logic ;
  signal RFO1_DATA2_INTERNAL_4 : std_logic ;
  signal RFO1_DATA2_INTERNAL_5 : std_logic ;
  signal RFO1_DATA2_INTERNAL_6 : std_logic ;
  signal RFO1_DATA2_INTERNAL_7 : std_logic ;
  signal RFO1_DATA2_INTERNAL_8 : std_logic ;
  signal RFO1_DATA2_INTERNAL_9 : std_logic ;
  signal RFO1_DATA2_INTERNAL_10 : std_logic ;
  signal RFO1_DATA2_INTERNAL_11 : std_logic ;
  signal RFO1_DATA2_INTERNAL_12 : std_logic ;
  signal RFO1_DATA2_INTERNAL_13 : std_logic ;
  signal RFO1_DATA2_INTERNAL_14 : std_logic ;
  signal RFO1_DATA2_INTERNAL_15 : std_logic ;
  signal RFO1_DATA2_INTERNAL_16 : std_logic ;
  signal RFO1_DATA2_INTERNAL_17 : std_logic ;
  signal RFO1_DATA2_INTERNAL_18 : std_logic ;
  signal RFO1_DATA2_INTERNAL_19 : std_logic ;
  signal RFO1_DATA2_INTERNAL_20 : std_logic ;
  signal RFO1_DATA2_INTERNAL_21 : std_logic ;
  signal RFO1_DATA2_INTERNAL_22 : std_logic ;
  signal RFO1_DATA2_INTERNAL_23 : std_logic ;
  signal RFO1_DATA2_INTERNAL_24 : std_logic ;
  signal RFO1_DATA2_INTERNAL_25 : std_logic ;
  signal RFO1_DATA2_INTERNAL_26 : std_logic ;
  signal RFO1_DATA2_INTERNAL_27 : std_logic ;
  signal RFO1_DATA2_INTERNAL_28 : std_logic ;
  signal RFO1_DATA2_INTERNAL_29 : std_logic ;
  signal RFO1_DATA2_INTERNAL_30 : std_logic ;
  signal RFO2_DATA1_INTERNAL : std_logic ;
  signal RFO2_DATA1_INTERNAL_0 : std_logic ;
  signal RFO2_DATA1_INTERNAL_1 : std_logic ;
  signal RFO2_DATA1_INTERNAL_2 : std_logic ;
  signal RFO2_DATA1_INTERNAL_3 : std_logic ;
  signal RFO2_DATA1_INTERNAL_4 : std_logic ;
  signal RFO2_DATA1_INTERNAL_5 : std_logic ;
  signal RFO2_DATA1_INTERNAL_6 : std_logic ;
  signal RFO2_DATA1_INTERNAL_7 : std_logic ;
  signal RFO2_DATA1_INTERNAL_8 : std_logic ;
  signal RFO2_DATA1_INTERNAL_9 : std_logic ;
  signal RFO2_DATA1_INTERNAL_10 : std_logic ;
  signal RFO2_DATA1_INTERNAL_11 : std_logic ;
  signal RFO2_DATA1_INTERNAL_12 : std_logic ;
  signal RFO2_DATA1_INTERNAL_13 : std_logic ;
  signal RFO2_DATA1_INTERNAL_14 : std_logic ;
  signal RFO2_DATA1_INTERNAL_15 : std_logic ;
  signal RFO2_DATA1_INTERNAL_16 : std_logic ;
  signal RFO2_DATA1_INTERNAL_17 : std_logic ;
  signal RFO2_DATA1_INTERNAL_18 : std_logic ;
  signal RFO2_DATA1_INTERNAL_19 : std_logic ;
  signal RFO2_DATA1_INTERNAL_20 : std_logic ;
  signal RFO2_DATA1_INTERNAL_21 : std_logic ;
  signal RFO2_DATA1_INTERNAL_22 : std_logic ;
  signal RFO2_DATA1_INTERNAL_23 : std_logic ;
  signal RFO2_DATA1_INTERNAL_24 : std_logic ;
  signal RFO2_DATA1_INTERNAL_25 : std_logic ;
  signal RFO2_DATA1_INTERNAL_26 : std_logic ;
  signal RFO2_DATA1_INTERNAL_27 : std_logic ;
  signal RFO2_DATA1_INTERNAL_28 : std_logic ;
  signal RFO2_DATA1_INTERNAL_29 : std_logic ;
  signal RFO2_DATA1_INTERNAL_30 : std_logic ;
  signal RFO2_DATA2_INTERNAL : std_logic ;
  signal RFO2_DATA2_INTERNAL_0 : std_logic ;
  signal RFO2_DATA2_INTERNAL_1 : std_logic ;
  signal RFO2_DATA2_INTERNAL_2 : std_logic ;
  signal RFO2_DATA2_INTERNAL_3 : std_logic ;
  signal RFO2_DATA2_INTERNAL_4 : std_logic ;
  signal RFO2_DATA2_INTERNAL_5 : std_logic ;
  signal RFO2_DATA2_INTERNAL_6 : std_logic ;
  signal RFO2_DATA2_INTERNAL_7 : std_logic ;
  signal RFO2_DATA2_INTERNAL_8 : std_logic ;
  signal RFO2_DATA2_INTERNAL_9 : std_logic ;
  signal RFO2_DATA2_INTERNAL_10 : std_logic ;
  signal RFO2_DATA2_INTERNAL_11 : std_logic ;
  signal RFO2_DATA2_INTERNAL_12 : std_logic ;
  signal RFO2_DATA2_INTERNAL_13 : std_logic ;
  signal RFO2_DATA2_INTERNAL_14 : std_logic ;
  signal RFO2_DATA2_INTERNAL_15 : std_logic ;
  signal RFO2_DATA2_INTERNAL_16 : std_logic ;
  signal RFO2_DATA2_INTERNAL_17 : std_logic ;
  signal RFO2_DATA2_INTERNAL_18 : std_logic ;
  signal RFO2_DATA2_INTERNAL_19 : std_logic ;
  signal RFO2_DATA2_INTERNAL_20 : std_logic ;
  signal RFO2_DATA2_INTERNAL_21 : std_logic ;
  signal RFO2_DATA2_INTERNAL_22 : std_logic ;
  signal RFO2_DATA2_INTERNAL_23 : std_logic ;
  signal RFO2_DATA2_INTERNAL_24 : std_logic ;
  signal RFO2_DATA2_INTERNAL_25 : std_logic ;
  signal RFO2_DATA2_INTERNAL_26 : std_logic ;
  signal RFO2_DATA2_INTERNAL_27 : std_logic ;
  signal RFO2_DATA2_INTERNAL_28 : std_logic ;
  signal RFO2_DATA2_INTERNAL_29 : std_logic ;
  signal RFO2_DATA2_INTERNAL_30 : std_logic ;
  signal \FPI.NONSTD\ : std_logic ;
  signal \FPI.FLUSH\ : std_logic ;
  signal GND : std_logic ;
  signal \GRFPU0.FPMUL0.CS_DP_R\ : std_logic ;
  signal \GRFPU0.N_439\ : std_logic ;
  signal \GRFPU0.N_440\ : std_logic ;
  signal \GRFPU0.N_441\ : std_logic ;
  signal \GRFPU0.N_442\ : std_logic ;
  signal \GRFPU0.N_443\ : std_logic ;
  signal \GRFPU0.N_444\ : std_logic ;
  signal \GRFPU0.N_445\ : std_logic ;
  signal \GRFPU0.N_446\ : std_logic ;
  signal \GRFPU0.N_447\ : std_logic ;
  signal \GRFPU0.N_448\ : std_logic ;
  signal \GRFPU0.N_449\ : std_logic ;
  signal \GRFPU0.N_450\ : std_logic ;
  signal \GRFPU0.N_451\ : std_logic ;
  signal \GRFPU0.N_452\ : std_logic ;
  signal \GRFPU0.N_453\ : std_logic ;
  signal \GRFPU0.N_454\ : std_logic ;
  signal \GRFPU0.N_455\ : std_logic ;
  signal \GRFPU0.N_456\ : std_logic ;
  signal \GRFPU0.N_457\ : std_logic ;
  signal \GRFPU0.N_458\ : std_logic ;
  signal \GRFPU0.N_459\ : std_logic ;
  signal \GRFPU0.N_460\ : std_logic ;
  signal \GRFPU0.N_461\ : std_logic ;
  signal \GRFPU0.N_462\ : std_logic ;
  signal \GRFPU0.N_463\ : std_logic ;
  signal \GRFPU0.N_464\ : std_logic ;
  signal \GRFPU0.N_465\ : std_logic ;
  signal \GRFPU0.N_466\ : std_logic ;
  signal \GRFPU0.N_467\ : std_logic ;
  signal \GRFPU0.N_468\ : std_logic ;
  signal \GRFPU0.N_469\ : std_logic ;
  signal \GRFPU0.N_470\ : std_logic ;
  signal \GRFPU0.N_471\ : std_logic ;
  signal \GRFPU0.N_472\ : std_logic ;
  signal \GRFPU0.N_473\ : std_logic ;
  signal \GRFPU0.N_474\ : std_logic ;
  signal \GRFPU0.N_475\ : std_logic ;
  signal \GRFPU0.N_476\ : std_logic ;
  signal \GRFPU0.N_477\ : std_logic ;
  signal \GRFPU0.N_478\ : std_logic ;
  signal \GRFPU0.N_479\ : std_logic ;
  signal \GRFPU0.N_480\ : std_logic ;
  signal \GRFPU0.N_481\ : std_logic ;
  signal \GRFPU0.N_482\ : std_logic ;
  signal \GRFPU0.N_483\ : std_logic ;
  signal \GRFPU0.N_484\ : std_logic ;
  signal \GRFPU0.N_485\ : std_logic ;
  signal \GRFPU0.N_486\ : std_logic ;
  signal \GRFPU0.N_487\ : std_logic ;
  signal \GRFPU0.N_488\ : std_logic ;
  signal \GRFPU0.N_489\ : std_logic ;
  signal \GRFPU0.N_490\ : std_logic ;
  signal \GRFPU0.N_491\ : std_logic ;
  signal \GRFPU0.N_492\ : std_logic ;
  signal \GRFPU0.N_493\ : std_logic ;
  signal \GRFPU0.N_494\ : std_logic ;
  signal \GRFPU0.N_495\ : std_logic ;
  signal \GRFPU0.N_496\ : std_logic ;
  signal \GRFPU0.N_497\ : std_logic ;
  signal \GRFPU0.N_498\ : std_logic ;
  signal \GRFPU0.N_499\ : std_logic ;
  signal \GRFPU0.N_500\ : std_logic ;
  signal \GRFPU0.N_501\ : std_logic ;
  signal \GRFPU0.N_502\ : std_logic ;
  signal \GRFPU0.N_503\ : std_logic ;
  signal \GRFPU0.N_504\ : std_logic ;
  signal \GRFPU0.N_505\ : std_logic ;
  signal \GRFPU0.N_506\ : std_logic ;
  signal \GRFPU0.N_507\ : std_logic ;
  signal \GRFPU0.N_508\ : std_logic ;
  signal \GRFPU0.N_509\ : std_logic ;
  signal \GRFPU0.N_510\ : std_logic ;
  signal \GRFPU0.N_511\ : std_logic ;
  signal \GRFPU0.N_512\ : std_logic ;
  signal \GRFPU0.N_513\ : std_logic ;
  signal \GRFPU0.N_514\ : std_logic ;
  signal \GRFPU0.N_515\ : std_logic ;
  signal \GRFPU0.N_516\ : std_logic ;
  signal \GRFPU0.N_517\ : std_logic ;
  signal \GRFPU0.N_518\ : std_logic ;
  signal \GRFPU0.N_519\ : std_logic ;
  signal \GRFPU0.N_520\ : std_logic ;
  signal \GRFPU0.N_521\ : std_logic ;
  signal \GRFPU0.N_522\ : std_logic ;
  signal \GRFPU0.N_523\ : std_logic ;
  signal \GRFPU0.N_524\ : std_logic ;
  signal \GRFPU0.N_525\ : std_logic ;
  signal \GRFPU0.N_526\ : std_logic ;
  signal \GRFPU0.N_527\ : std_logic ;
  signal \GRFPU0.N_528\ : std_logic ;
  signal \GRFPU0.N_529\ : std_logic ;
  signal \GRFPU0.N_530\ : std_logic ;
  signal \GRFPU0.N_531\ : std_logic ;
  signal \GRFPU0.N_532\ : std_logic ;
  signal \GRFPU0.N_533\ : std_logic ;
  signal \GRFPU0.N_534\ : std_logic ;
  signal \GRFPU0.N_535\ : std_logic ;
  signal \GRFPU0.N_536\ : std_logic ;
  signal \GRFPU0.N_537\ : std_logic ;
  signal \GRFPU0.N_538\ : std_logic ;
  signal \GRFPU0.N_539\ : std_logic ;
  signal \GRFPU0.N_540\ : std_logic ;
  signal \GRFPU0.N_541\ : std_logic ;
  signal \GRFPU0.N_542\ : std_logic ;
  signal \GRFPU0.N_543\ : std_logic ;
  signal \GRFPU0.N_544\ : std_logic ;
  signal \GRFPU0.N_545\ : std_logic ;
  signal \GRFPU0.N_546\ : std_logic ;
  signal \GRFPU0.N_547\ : std_logic ;
  signal \GRFPU0.N_548\ : std_logic ;
  signal \GRFPU0.N_549\ : std_logic ;
  signal \GRFPU0.N_550\ : std_logic ;
  signal \GRFPU0.N_551\ : std_logic ;
  signal \GRFPU0.N_552\ : std_logic ;
  signal \GRFPU0.N_553\ : std_logic ;
  signal \GRFPU0.N_554\ : std_logic ;
  signal \GRFPU0.N_555\ : std_logic ;
  signal \GRFPU0.N_556\ : std_logic ;
  signal \GRFPU0.N_557\ : std_logic ;
  signal \GRFPU0.N_558\ : std_logic ;
  signal \GRFPU0.N_559\ : std_logic ;
  signal \GRFPU0.N_560\ : std_logic ;
  signal \GRFPU0.N_267\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.ODDEXP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SGNFEQ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.LOB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ADD\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.IOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.MOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.ADDOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3207\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3209\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3210\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3211\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3212\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3215\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3216\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7143\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4226\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.INF_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3206\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6611\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6759\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5184\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11211\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11215\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11217\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11219\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11221\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11223\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11225\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11227\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11228\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11230\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11232\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11233\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11242\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11243\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11244\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11246\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11247\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11248\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11249\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11251\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11253\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11255\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11257\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11258\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11259\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11261\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11265\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11267\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11268\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11269\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11270\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11271\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11272\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11273\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11274\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11275\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11276\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11277\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11278\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11279\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11280\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11281\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11282\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11283\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11285\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11286\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11287\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11288\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11289\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11290\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11291\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11295\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11297\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11356\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11367\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17299\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17300\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17303\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17304\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17305\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17306\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17307\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17308\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17309\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17310\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17311\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17312\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17313\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17314\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17315\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17316\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17317\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17318\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17319\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17320\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17321\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17322\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17323\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17324\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17325\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17329\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17330\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17331\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17332\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17333\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17334\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17335\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17336\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17337\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17338\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17339\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17340\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17341\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17342\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17347\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17348\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17350\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17351\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17354\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17355\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17356\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17357\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17358\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17359\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17360\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17361\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17362\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17363\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17364\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17365\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17366\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17367\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17368\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17369\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17370\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17371\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17372\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17373\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17374\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17375\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17376\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17399\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17400\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19434\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19514\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19583\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19587\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19589\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19669\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19670\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19671\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19672\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19673\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19674\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19675\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19676\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19677\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19678\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19679\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19680\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19681\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19682\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19683\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19684\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19685\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19686\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19687\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19688\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19689\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20280\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20455\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20463\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20468\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20473\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20509\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20616\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20623\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20645\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20648\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20786\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21025\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_296\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19405_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7376\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19295\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21692\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.LD\ : std_logic ;
  signal \GRFPC0.N_131\ : std_logic ;
  signal \GRFPC0.FIFO.FULL\ : std_logic ;
  signal \GRFPC0.RFA.RS2D\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.EX.RREG.RESV\ : std_logic ;
  signal \GRFPC0.DIV.VALID\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.DIV.PEND\ : std_logic ;
  signal \GRFPC0.DIV.RDD\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.LD\ : std_logic ;
  signal \GRFPC0.EX.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD\ : std_logic ;
  signal \GRFPC0.RFA.ST\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.LD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.FPR.RDY\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR2.EXC\ : std_logic ;
  signal \GRFPC0.DIV.EXC\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.RFA.RS1D\ : std_logic ;
  signal \GRFPC0.RFA.LD\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP\ : std_logic ;
  signal \GRFPC0.RFA2.DIVLCK\ : std_logic ;
  signal \GRFPC0.DIV.EXEC\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.WR.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.FCC_VALID_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6990_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7019_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7047_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2399_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2580_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2945_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3023_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4857_REGDEPX2\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.RFA.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.DIV.RS1V\ : std_logic ;
  signal \GRFPC0.D.FSTLCK\ : std_logic ;
  signal \GRFPC0.D.FLDLCK\ : std_logic ;
  signal \GRFPC0.RFA.AFSR\ : std_logic ;
  signal \GRFPC0.RFA.RDWR\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_135\ : std_logic ;
  signal \GRFPC0.N_10165\ : std_logic ;
  signal \GRFPC0.N_10167\ : std_logic ;
  signal \GRFPC0.N_10169\ : std_logic ;
  signal \GRFPC0.N_10170\ : std_logic ;
  signal \GRFPC0.N_10172\ : std_logic ;
  signal \GRFPC0.N_10173\ : std_logic ;
  signal \GRFPC0.N_10175\ : std_logic ;
  signal \GRFPC0.N_10177\ : std_logic ;
  signal \GRFPC0.N_10179\ : std_logic ;
  signal \GRFPC0.N_10181\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\ : std_logic ;
  signal \GRFPC0.N_10185\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES\ : std_logic ;
  signal \GRFPC0.N_17302\ : std_logic ;
  signal \GRFPC0.N_17452\ : std_logic ;
  signal \GRFPC0.N_18752\ : std_logic ;
  signal \GRFPC0.N_18753\ : std_logic ;
  signal \GRFPC0.N_18754\ : std_logic ;
  signal \GRFPC0.N_18755\ : std_logic ;
  signal \GRFPC0.N_18756\ : std_logic ;
  signal \GRFPC0.N_18757\ : std_logic ;
  signal \GRFPC0.N_18758\ : std_logic ;
  signal \GRFPC0.N_18759\ : std_logic ;
  signal \GRFPC0.N_18760\ : std_logic ;
  signal \GRFPC0.N_18761\ : std_logic ;
  signal \GRFPC0.N_18762\ : std_logic ;
  signal \GRFPC0.N_18763\ : std_logic ;
  signal \GRFPC0.N_18764\ : std_logic ;
  signal \GRFPC0.N_18765\ : std_logic ;
  signal \GRFPC0.N_18766\ : std_logic ;
  signal \GRFPC0.N_18767\ : std_logic ;
  signal \GRFPC0.N_18768\ : std_logic ;
  signal \GRFPC0.N_18769\ : std_logic ;
  signal \GRFPC0.N_18770\ : std_logic ;
  signal \GRFPC0.N_18771\ : std_logic ;
  signal \GRFPC0.N_18772\ : std_logic ;
  signal \GRFPC0.N_18773\ : std_logic ;
  signal \GRFPC0.N_18775\ : std_logic ;
  signal \GRFPC0.N_18776\ : std_logic ;
  signal \GRFPC0.N_18777\ : std_logic ;
  signal \GRFPC0.N_18778\ : std_logic ;
  signal \GRFPC0.N_18779\ : std_logic ;
  signal \GRFPC0.N_18780\ : std_logic ;
  signal \GRFPC0.N_18781\ : std_logic ;
  signal \GRFPC0.N_18783\ : std_logic ;
  signal \GRFPC0.N_18784\ : std_logic ;
  signal \GRFPC0.N_18785\ : std_logic ;
  signal \GRFPC0.N_18786\ : std_logic ;
  signal \GRFPC0.N_18787\ : std_logic ;
  signal \GRFPC0.N_18788\ : std_logic ;
  signal \GRFPC0.N_18789\ : std_logic ;
  signal \GRFPC0.N_18790\ : std_logic ;
  signal \GRFPC0.N_18791\ : std_logic ;
  signal \GRFPC0.N_18792\ : std_logic ;
  signal \GRFPC0.N_18793\ : std_logic ;
  signal \GRFPC0.N_18794\ : std_logic ;
  signal \GRFPC0.N_18795\ : std_logic ;
  signal \GRFPC0.N_18796\ : std_logic ;
  signal \GRFPC0.N_18797\ : std_logic ;
  signal \GRFPC0.N_18798\ : std_logic ;
  signal \GRFPC0.N_18799\ : std_logic ;
  signal \GRFPC0.N_18800\ : std_logic ;
  signal \GRFPC0.N_18801\ : std_logic ;
  signal \GRFPC0.N_18802\ : std_logic ;
  signal \GRFPC0.N_18803\ : std_logic ;
  signal \GRFPC0.N_18804\ : std_logic ;
  signal \GRFPC0.N_18805\ : std_logic ;
  signal \GRFPC0.N_18807\ : std_logic ;
  signal \GRFPC0.N_18808\ : std_logic ;
  signal \GRFPC0.N_18809\ : std_logic ;
  signal \GRFPC0.N_18810\ : std_logic ;
  signal \GRFPC0.N_18811\ : std_logic ;
  signal \GRFPC0.N_18812\ : std_logic ;
  signal \GRFPC0.N_18813\ : std_logic ;
  signal \GRFPC0.N_18815\ : std_logic ;
  signal \GRFPC0.N_18817\ : std_logic ;
  signal \GRFPC0.N_18818\ : std_logic ;
  signal \GRFPC0.N_18819\ : std_logic ;
  signal \GRFPC0.N_18820\ : std_logic ;
  signal \GRFPC0.N_18821\ : std_logic ;
  signal \GRFPC0.N_18822\ : std_logic ;
  signal \GRFPC0.N_18823\ : std_logic ;
  signal \GRFPC0.N_18824\ : std_logic ;
  signal \GRFPC0.N_18825\ : std_logic ;
  signal \GRFPC0.N_18826\ : std_logic ;
  signal \GRFPC0.N_18827\ : std_logic ;
  signal \GRFPC0.N_18828\ : std_logic ;
  signal \GRFPC0.N_18829\ : std_logic ;
  signal \GRFPC0.N_18830\ : std_logic ;
  signal \GRFPC0.N_18831\ : std_logic ;
  signal \GRFPC0.N_18832\ : std_logic ;
  signal \GRFPC0.N_18833\ : std_logic ;
  signal \GRFPC0.N_18834\ : std_logic ;
  signal \GRFPC0.N_18835\ : std_logic ;
  signal \GRFPC0.N_18836\ : std_logic ;
  signal \GRFPC0.N_18837\ : std_logic ;
  signal \GRFPC0.N_18838\ : std_logic ;
  signal \GRFPC0.N_18839\ : std_logic ;
  signal \GRFPC0.N_18840\ : std_logic ;
  signal \GRFPC0.N_18841\ : std_logic ;
  signal \GRFPC0.N_18842\ : std_logic ;
  signal \GRFPC0.N_18843\ : std_logic ;
  signal \GRFPC0.N_18844\ : std_logic ;
  signal \GRFPC0.N_18845\ : std_logic ;
  signal \GRFPC0.N_18846\ : std_logic ;
  signal \GRFPC0.N_18848\ : std_logic ;
  signal \GRFPC0.N_18849\ : std_logic ;
  signal \GRFPC0.N_18850\ : std_logic ;
  signal \GRFPC0.N_18851\ : std_logic ;
  signal \GRFPC0.N_18852\ : std_logic ;
  signal \GRFPC0.N_18853\ : std_logic ;
  signal \GRFPC0.N_18854\ : std_logic ;
  signal \GRFPC0.N_18855\ : std_logic ;
  signal \GRFPC0.N_18856\ : std_logic ;
  signal \GRFPC0.N_18857\ : std_logic ;
  signal \GRFPC0.N_18858\ : std_logic ;
  signal \GRFPC0.N_18859\ : std_logic ;
  signal \GRFPC0.N_18860\ : std_logic ;
  signal \GRFPC0.N_18861\ : std_logic ;
  signal \GRFPC0.N_18862\ : std_logic ;
  signal \GRFPC0.N_18863\ : std_logic ;
  signal \GRFPC0.N_18864\ : std_logic ;
  signal \GRFPC0.N_18865\ : std_logic ;
  signal \GRFPC0.N_18866\ : std_logic ;
  signal \GRFPC0.N_18867\ : std_logic ;
  signal \GRFPC0.N_18868\ : std_logic ;
  signal \GRFPC0.N_18869\ : std_logic ;
  signal \GRFPC0.N_18870\ : std_logic ;
  signal \GRFPC0.N_18872\ : std_logic ;
  signal \GRFPC0.N_18873\ : std_logic ;
  signal \GRFPC0.N_18874\ : std_logic ;
  signal \GRFPC0.N_18875\ : std_logic ;
  signal \GRFPC0.N_18876\ : std_logic ;
  signal \GRFPC0.N_18877\ : std_logic ;
  signal \GRFPC0.N_18878\ : std_logic ;
  signal \GRFPC0.N_18880\ : std_logic ;
  signal \GRFPC0.N_20031\ : std_logic ;
  signal \GRFPC0.N_20032\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN859_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\ : std_logic ;
  signal \GRFPC0.N_61\ : std_logic ;
  signal \GRFPC0.N_62\ : std_logic ;
  signal \GRFPC0.N_77\ : std_logic ;
  signal \GRFPC0.N_83\ : std_logic ;
  signal \GRFPC0.N_100\ : std_logic ;
  signal \GRFPC0.N_21474\ : std_logic ;
  signal \GRFPC0.N_21860\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10\ : std_logic ;
  signal \GRFPC0.N_21998\ : std_logic ;
  signal \GRFPC0.N_22305\ : std_logic ;
  signal \GRFPC0.N_22455\ : std_logic ;
  signal \GRFPC0.N_22912\ : std_logic ;
  signal \GRFPC0.N_23044\ : std_logic ;
  signal \GRFPC0.N_23398\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\ : std_logic ;
  signal \GRFPC0.N_23584\ : std_logic ;
  signal \GRFPC0.N_23587\ : std_logic ;
  signal \GRFPC0.N_23588\ : std_logic ;
  signal \GRFPC0.N_23726\ : std_logic ;
  signal \GRFPC0.N_23728\ : std_logic ;
  signal \GRFPC0.N_23788\ : std_logic ;
  signal \GRFPC0.N_23817\ : std_logic ;
  signal \GRFPC0.N_23819\ : std_logic ;
  signal \GRFPC0.N_305\ : std_logic ;
  signal \GRFPC0.N_23937\ : std_logic ;
  signal \GRFPC0.N_23938\ : std_logic ;
  signal \GRFPC0.N_23956\ : std_logic ;
  signal \GRFPC0.N_23957\ : std_logic ;
  signal \GRFPC0.N_23999\ : std_logic ;
  signal \GRFPC0.N_24000\ : std_logic ;
  signal \GRFPC0.N_24001\ : std_logic ;
  signal \GRFPC0.N_24427\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_24554\ : std_logic ;
  signal \GRFPC0.N_24727\ : std_logic ;
  signal \GRFPC0.N_24867\ : std_logic ;
  signal \GRFPC0.N_25236\ : std_logic ;
  signal \GRFPC0.N_25312\ : std_logic ;
  signal \GRFPC0.N_25314\ : std_logic ;
  signal \GRFPC0.N_25317\ : std_logic ;
  signal \GRFPC0.N_25352\ : std_logic ;
  signal \GRFPC0.N_25361\ : std_logic ;
  signal \GRFPC0.N_25385\ : std_logic ;
  signal \GRFPC0.N_25457\ : std_logic ;
  signal \GRFPC0.N_25477\ : std_logic ;
  signal \GRFPC0.N_25485\ : std_logic ;
  signal \GRFPC0.N_25569\ : std_logic ;
  signal \GRFPC0.N_25594\ : std_logic ;
  signal \GRFPC0.N_25614\ : std_logic ;
  signal \GRFPC0.N_25621\ : std_logic ;
  signal \GRFPC0.N_25624\ : std_logic ;
  signal \GRFPC0.N_25657\ : std_logic ;
  signal \GRFPC0.N_25674\ : std_logic ;
  signal \GRFPC0.N_25677\ : std_logic ;
  signal \GRFPC0.N_25755\ : std_logic ;
  signal \GRFPC0.N_25757\ : std_logic ;
  signal \GRFPC0.N_25758\ : std_logic ;
  signal \GRFPC0.N_25759\ : std_logic ;
  signal \GRFPC0.N_25859\ : std_logic ;
  signal \GRFPC0.N_25179_1\ : std_logic ;
  signal \GRFPC0.N_24701_1\ : std_logic ;
  signal \GRFPC0.N_25433_1\ : std_logic ;
  signal \GRFPC0.N_22325_2\ : std_logic ;
  signal \GRFPC0.N_25646_2\ : std_logic ;
  signal \GRFPC0.N_234_1\ : std_logic ;
  signal \GRFPC0.N_24483_I\ : std_logic ;
  signal \GRFPC0.N_78_I_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_18116\ : std_logic ;
  signal \GRFPC0.N_18119\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\ : std_logic ;
  signal \GRFPC0.N_23608\ : std_logic ;
  signal \GRFPC0.N_23609\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1136_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2384_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_109\ : std_logic ;
  signal \GRFPC0.N_22924_1\ : std_logic ;
  signal \GRFPC0.N_22573_1\ : std_logic ;
  signal \GRFPC0.N_25173\ : std_logic ;
  signal \GRFPC0.N_21785\ : std_logic ;
  signal \GRFPC0.N_23443\ : std_logic ;
  signal \GRFPC0.N_21146\ : std_logic ;
  signal \GRFPC0.N_21468\ : std_logic ;
  signal \GRFPC0.N_21477\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_251\ : std_logic ;
  signal \GRFPC0.N_24633\ : std_logic ;
  signal \GRFPC0.N_25450_1\ : std_logic ;
  signal \GRFPC0.N_25087\ : std_logic ;
  signal \GRFPC0.N_25271\ : std_logic ;
  signal \GRFPC0.N_25378\ : std_logic ;
  signal \GRFPC0.N_25585\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23741\ : std_logic ;
  signal \GRFPC0.N_25389\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25779\ : std_logic ;
  signal \GRFPC0.N_25762\ : std_logic ;
  signal \GRFPC0.N_24712_2\ : std_logic ;
  signal \GRFPC0.N_24735_2\ : std_logic ;
  signal \GRFPC0.N_24490\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25491\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25436\ : std_logic ;
  signal \GRFPC0.N_25589\ : std_logic ;
  signal \GRFPC0.N_24112\ : std_logic ;
  signal \GRFPC0.N_18115\ : std_logic ;
  signal \GRFPC0.N_22006\ : std_logic ;
  signal \GRFPC0.N_24642\ : std_logic ;
  signal \GRFPC0.N_25164\ : std_logic ;
  signal \GRFPC0.N_24979_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24279\ : std_logic ;
  signal \GRFPC0.N_24442\ : std_logic ;
  signal N_6 : std_logic ;
  signal N_7 : std_logic ;
  signal N_8 : std_logic ;
  signal N_9 : std_logic ;
  signal N_10 : std_logic ;
  signal N_11 : std_logic ;
  signal N_12 : std_logic ;
  signal N_13 : std_logic ;
  signal N_14 : std_logic ;
  signal N_15 : std_logic ;
  signal N_16 : std_logic ;
  signal N_17 : std_logic ;
  signal N_18 : std_logic ;
  signal N_19 : std_logic ;
  signal N_20 : std_logic ;
  signal N_21 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15336_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15316_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20285_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20282_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19711_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19427_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_68_I\ : std_logic ;
  signal \GRFPC0.N_16912_I\ : std_logic ;
  signal N_29618 : std_logic ;
  signal N_29619 : std_logic ;
  signal N_29620 : std_logic ;
  signal N_29688 : std_logic ;
  signal N_29689 : std_logic ;
  signal N_29701 : std_logic ;
  signal N_29747 : std_logic ;
  signal N_29816 : std_logic ;
  signal N_29893 : std_logic ;
  signal N_29911 : std_logic ;
  signal N_29912 : std_logic ;
  signal N_29913 : std_logic ;
  signal N_29914 : std_logic ;
  signal N_29915 : std_logic ;
  signal N_29916 : std_logic ;
  signal N_30470 : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\ : std_logic ;
  signal N_30745 : std_logic ;
  signal N_30747 : std_logic ;
  signal N_30749 : std_logic ;
  signal N_30751 : std_logic ;
  signal N_30753 : std_logic ;
  signal N_30755 : std_logic ;
  signal N_30757 : std_logic ;
  signal N_30759 : std_logic ;
  signal N_30761 : std_logic ;
  signal N_30763 : std_logic ;
  signal N_30765 : std_logic ;
  signal N_30767 : std_logic ;
  signal N_30769 : std_logic ;
  signal N_30771 : std_logic ;
  signal N_30773 : std_logic ;
  signal N_30775 : std_logic ;
  signal N_30777 : std_logic ;
  signal N_30779 : std_logic ;
  signal N_30781 : std_logic ;
  signal N_30783 : std_logic ;
  signal N_30785 : std_logic ;
  signal N_30787 : std_logic ;
  signal N_30789 : std_logic ;
  signal N_30791 : std_logic ;
  signal N_30793 : std_logic ;
  signal N_30795 : std_logic ;
  signal N_30797 : std_logic ;
  signal N_30799 : std_logic ;
  signal N_30801 : std_logic ;
  signal N_30803 : std_logic ;
  signal N_30805 : std_logic ;
  signal N_30807 : std_logic ;
  signal N_30809 : std_logic ;
  signal N_30811 : std_logic ;
  signal N_30813 : std_logic ;
  signal N_30815 : std_logic ;
  signal N_30817 : std_logic ;
  signal N_30819 : std_logic ;
  signal N_30821 : std_logic ;
  signal N_30823 : std_logic ;
  signal N_30825 : std_logic ;
  signal N_30827 : std_logic ;
  signal N_30829 : std_logic ;
  signal N_30831 : std_logic ;
  signal N_30833 : std_logic ;
  signal N_30835 : std_logic ;
  signal N_30837 : std_logic ;
  signal N_30839 : std_logic ;
  signal N_30841 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\ : std_logic ;
  signal N_30847 : std_logic ;
  signal N_30849 : std_logic ;
  signal N_30851 : std_logic ;
  signal N_30853 : std_logic ;
  signal N_30855 : std_logic ;
  signal N_30857 : std_logic ;
  signal N_30859 : std_logic ;
  signal N_30861 : std_logic ;
  signal N_30863 : std_logic ;
  signal N_30865 : std_logic ;
  signal N_30867 : std_logic ;
  signal N_30869 : std_logic ;
  signal N_30871 : std_logic ;
  signal N_30873 : std_logic ;
  signal N_30875 : std_logic ;
  signal N_30877 : std_logic ;
  signal N_30879 : std_logic ;
  signal N_30881 : std_logic ;
  signal N_30883 : std_logic ;
  signal N_30885 : std_logic ;
  signal N_30887 : std_logic ;
  signal N_30889 : std_logic ;
  signal N_30891 : std_logic ;
  signal N_30893 : std_logic ;
  signal N_30895 : std_logic ;
  signal N_30897 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\ : std_logic ;
  signal N_30902 : std_logic ;
  signal N_30904 : std_logic ;
  signal N_30907 : std_logic ;
  signal N_30908 : std_logic ;
  signal N_30909 : std_logic ;
  signal N_30910 : std_logic ;
  signal N_30911 : std_logic ;
  signal N_30912 : std_logic ;
  signal N_30913 : std_logic ;
  signal N_30914 : std_logic ;
  signal N_30915 : std_logic ;
  signal N_30916 : std_logic ;
  signal N_30917 : std_logic ;
  signal N_30918 : std_logic ;
  signal N_30919 : std_logic ;
  signal N_30920 : std_logic ;
  signal N_30921 : std_logic ;
  signal N_30922 : std_logic ;
  signal N_30923 : std_logic ;
  signal N_30924 : std_logic ;
  signal N_30925 : std_logic ;
  signal N_30926 : std_logic ;
  signal N_30927 : std_logic ;
  signal N_30928 : std_logic ;
  signal N_30929 : std_logic ;
  signal N_30930 : std_logic ;
  signal N_30931 : std_logic ;
  signal N_30932 : std_logic ;
  signal N_30933 : std_logic ;
  signal N_30934 : std_logic ;
  signal N_30935 : std_logic ;
  signal N_30936 : std_logic ;
  signal N_30937 : std_logic ;
  signal N_30938 : std_logic ;
  signal N_30939 : std_logic ;
  signal N_30940 : std_logic ;
  signal N_30941 : std_logic ;
  signal N_30942 : std_logic ;
  signal N_30943 : std_logic ;
  signal N_30944 : std_logic ;
  signal N_30945 : std_logic ;
  signal N_30946 : std_logic ;
  signal N_30947 : std_logic ;
  signal N_30948 : std_logic ;
  signal N_30949 : std_logic ;
  signal N_30950 : std_logic ;
  signal N_30953 : std_logic ;
  signal N_30954 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\ : std_logic ;
  signal N_30959 : std_logic ;
  signal N_30961 : std_logic ;
  signal N_30963 : std_logic ;
  signal N_30965 : std_logic ;
  signal N_30967 : std_logic ;
  signal N_30969 : std_logic ;
  signal N_30971 : std_logic ;
  signal N_30973 : std_logic ;
  signal N_30975 : std_logic ;
  signal N_30977 : std_logic ;
  signal N_30979 : std_logic ;
  signal N_30981 : std_logic ;
  signal N_30983 : std_logic ;
  signal N_30985 : std_logic ;
  signal N_30987 : std_logic ;
  signal N_30989 : std_logic ;
  signal N_30991 : std_logic ;
  signal N_30993 : std_logic ;
  signal N_30995 : std_logic ;
  signal N_30997 : std_logic ;
  signal N_30999 : std_logic ;
  signal N_31001 : std_logic ;
  signal N_31003 : std_logic ;
  signal N_31005 : std_logic ;
  signal N_31007 : std_logic ;
  signal N_31009 : std_logic ;
  signal N_31011 : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\ : std_logic ;
  signal N_31016 : std_logic ;
  signal N_31018 : std_logic ;
  signal N_31019 : std_logic ;
  signal N_31020 : std_logic ;
  signal N_31021 : std_logic ;
  signal N_31022 : std_logic ;
  signal N_31023 : std_logic ;
  signal N_31024 : std_logic ;
  signal N_31025 : std_logic ;
  signal N_31026 : std_logic ;
  signal N_31027 : std_logic ;
  signal N_31028 : std_logic ;
  signal N_31029 : std_logic ;
  signal N_31030 : std_logic ;
  signal N_31031 : std_logic ;
  signal N_31032 : std_logic ;
  signal N_31033 : std_logic ;
  signal N_31034 : std_logic ;
  signal N_31035 : std_logic ;
  signal N_31036 : std_logic ;
  signal N_31037 : std_logic ;
  signal N_31038 : std_logic ;
  signal N_31039 : std_logic ;
  signal N_31040 : std_logic ;
  signal N_31041 : std_logic ;
  signal N_31042 : std_logic ;
  signal N_31043 : std_logic ;
  signal N_31044 : std_logic ;
  signal N_31045 : std_logic ;
  signal N_31046 : std_logic ;
  signal N_31047 : std_logic ;
  signal N_31048 : std_logic ;
  signal N_31049 : std_logic ;
  signal N_31050 : std_logic ;
  signal N_31051 : std_logic ;
  signal N_31052 : std_logic ;
  signal N_31053 : std_logic ;
  signal N_31054 : std_logic ;
  signal N_31055 : std_logic ;
  signal N_31056 : std_logic ;
  signal N_31057 : std_logic ;
  signal N_31058 : std_logic ;
  signal N_31059 : std_logic ;
  signal N_31060 : std_logic ;
  signal N_31061 : std_logic ;
  signal N_31062 : std_logic ;
  signal N_31063 : std_logic ;
  signal N_31064 : std_logic ;
  signal N_31065 : std_logic ;
  signal N_31066 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\ : std_logic ;
  signal N_31071 : std_logic ;
  signal N_31073 : std_logic ;
  signal N_31075 : std_logic ;
  signal N_31076 : std_logic ;
  signal N_31077 : std_logic ;
  signal N_31078 : std_logic ;
  signal N_31079 : std_logic ;
  signal N_31080 : std_logic ;
  signal N_31081 : std_logic ;
  signal N_31082 : std_logic ;
  signal N_31083 : std_logic ;
  signal N_31084 : std_logic ;
  signal N_31085 : std_logic ;
  signal N_31086 : std_logic ;
  signal N_31087 : std_logic ;
  signal N_31088 : std_logic ;
  signal N_31089 : std_logic ;
  signal N_31090 : std_logic ;
  signal N_31091 : std_logic ;
  signal N_31092 : std_logic ;
  signal N_31093 : std_logic ;
  signal N_31094 : std_logic ;
  signal N_31095 : std_logic ;
  signal N_31096 : std_logic ;
  signal N_31097 : std_logic ;
  signal N_31098 : std_logic ;
  signal N_31099 : std_logic ;
  signal N_31100 : std_logic ;
  signal N_31101 : std_logic ;
  signal N_31102 : std_logic ;
  signal N_31103 : std_logic ;
  signal N_31104 : std_logic ;
  signal N_31105 : std_logic ;
  signal N_31106 : std_logic ;
  signal N_31107 : std_logic ;
  signal N_31108 : std_logic ;
  signal N_31109 : std_logic ;
  signal N_31110 : std_logic ;
  signal N_31111 : std_logic ;
  signal N_31112 : std_logic ;
  signal N_31113 : std_logic ;
  signal N_31114 : std_logic ;
  signal N_31115 : std_logic ;
  signal N_31116 : std_logic ;
  signal N_31117 : std_logic ;
  signal N_31118 : std_logic ;
  signal N_31119 : std_logic ;
  signal N_31122 : std_logic ;
  signal N_31123 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\ : std_logic ;
  signal N_31125 : std_logic ;
  signal N_31127 : std_logic ;
  signal N_31129 : std_logic ;
  signal N_31131 : std_logic ;
  signal N_31133 : std_logic ;
  signal N_31135 : std_logic ;
  signal N_31137 : std_logic ;
  signal N_31139 : std_logic ;
  signal N_31141 : std_logic ;
  signal N_31143 : std_logic ;
  signal N_31145 : std_logic ;
  signal N_31147 : std_logic ;
  signal N_31149 : std_logic ;
  signal N_31151 : std_logic ;
  signal N_31153 : std_logic ;
  signal N_31155 : std_logic ;
  signal N_31157 : std_logic ;
  signal N_31159 : std_logic ;
  signal N_31161 : std_logic ;
  signal N_31163 : std_logic ;
  signal N_31165 : std_logic ;
  signal N_31167 : std_logic ;
  signal N_31169 : std_logic ;
  signal N_31171 : std_logic ;
  signal N_31173 : std_logic ;
  signal N_31175 : std_logic ;
  signal N_31177 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\ : std_logic ;
  signal N_31183 : std_logic ;
  signal N_31185 : std_logic ;
  signal N_31187 : std_logic ;
  signal N_31189 : std_logic ;
  signal N_31191 : std_logic ;
  signal N_31193 : std_logic ;
  signal N_31195 : std_logic ;
  signal N_31197 : std_logic ;
  signal N_31199 : std_logic ;
  signal N_31201 : std_logic ;
  signal N_31203 : std_logic ;
  signal N_31205 : std_logic ;
  signal N_31207 : std_logic ;
  signal N_31209 : std_logic ;
  signal N_31211 : std_logic ;
  signal N_31213 : std_logic ;
  signal N_31215 : std_logic ;
  signal N_31217 : std_logic ;
  signal N_31219 : std_logic ;
  signal N_31221 : std_logic ;
  signal N_31223 : std_logic ;
  signal N_31225 : std_logic ;
  signal N_31227 : std_logic ;
  signal N_31229 : std_logic ;
  signal N_31231 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\ : std_logic ;
  signal N_31236 : std_logic ;
  signal N_31238 : std_logic ;
  signal N_31240 : std_logic ;
  signal N_31242 : std_logic ;
  signal N_31244 : std_logic ;
  signal N_31246 : std_logic ;
  signal N_31248 : std_logic ;
  signal N_31250 : std_logic ;
  signal N_31252 : std_logic ;
  signal N_31254 : std_logic ;
  signal N_31256 : std_logic ;
  signal N_31258 : std_logic ;
  signal N_31260 : std_logic ;
  signal N_31262 : std_logic ;
  signal N_31264 : std_logic ;
  signal N_31266 : std_logic ;
  signal N_31268 : std_logic ;
  signal N_31270 : std_logic ;
  signal N_31272 : std_logic ;
  signal N_31274 : std_logic ;
  signal N_31276 : std_logic ;
  signal N_31278 : std_logic ;
  signal N_31280 : std_logic ;
  signal N_31282 : std_logic ;
  signal N_31284 : std_logic ;
  signal N_31286 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\ : std_logic ;
  signal N_31291 : std_logic ;
  signal N_31293 : std_logic ;
  signal N_31295 : std_logic ;
  signal N_31297 : std_logic ;
  signal N_31299 : std_logic ;
  signal N_31301 : std_logic ;
  signal N_31303 : std_logic ;
  signal N_31305 : std_logic ;
  signal N_31307 : std_logic ;
  signal N_31309 : std_logic ;
  signal N_31311 : std_logic ;
  signal N_31313 : std_logic ;
  signal N_31315 : std_logic ;
  signal N_31317 : std_logic ;
  signal N_31319 : std_logic ;
  signal N_31321 : std_logic ;
  signal N_31323 : std_logic ;
  signal N_31325 : std_logic ;
  signal N_31327 : std_logic ;
  signal N_31329 : std_logic ;
  signal N_31331 : std_logic ;
  signal N_31333 : std_logic ;
  signal N_31335 : std_logic ;
  signal N_31337 : std_logic ;
  signal N_31339 : std_logic ;
  signal N_31341 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\ : std_logic ;
  signal N_31346 : std_logic ;
  signal N_31348 : std_logic ;
  signal N_31350 : std_logic ;
  signal N_31352 : std_logic ;
  signal N_31354 : std_logic ;
  signal N_31356 : std_logic ;
  signal N_31358 : std_logic ;
  signal N_31360 : std_logic ;
  signal N_31362 : std_logic ;
  signal N_31364 : std_logic ;
  signal N_31366 : std_logic ;
  signal N_31368 : std_logic ;
  signal N_31370 : std_logic ;
  signal N_31372 : std_logic ;
  signal N_31374 : std_logic ;
  signal N_31376 : std_logic ;
  signal N_31378 : std_logic ;
  signal N_31380 : std_logic ;
  signal N_31382 : std_logic ;
  signal N_31384 : std_logic ;
  signal N_31386 : std_logic ;
  signal N_31388 : std_logic ;
  signal N_31390 : std_logic ;
  signal N_31392 : std_logic ;
  signal N_31394 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\ : std_logic ;
  signal N_31396 : std_logic ;
  signal N_31398 : std_logic ;
  signal N_31400 : std_logic ;
  signal N_31402 : std_logic ;
  signal N_31404 : std_logic ;
  signal N_31406 : std_logic ;
  signal N_31408 : std_logic ;
  signal N_31410 : std_logic ;
  signal N_31412 : std_logic ;
  signal N_31414 : std_logic ;
  signal N_31416 : std_logic ;
  signal N_31418 : std_logic ;
  signal N_31420 : std_logic ;
  signal N_31422 : std_logic ;
  signal N_31424 : std_logic ;
  signal N_31426 : std_logic ;
  signal N_31428 : std_logic ;
  signal N_31430 : std_logic ;
  signal N_31432 : std_logic ;
  signal N_31434 : std_logic ;
  signal N_31436 : std_logic ;
  signal N_31438 : std_logic ;
  signal N_31440 : std_logic ;
  signal N_31442 : std_logic ;
  signal N_31444 : std_logic ;
  signal N_31446 : std_logic ;
  signal N_31461 : std_logic ;
  signal N_31462 : std_logic ;
  signal N_31463 : std_logic ;
  signal N_31464 : std_logic ;
  signal N_31465 : std_logic ;
  signal N_31466 : std_logic ;
  signal N_31467 : std_logic ;
  signal N_31468 : std_logic ;
  signal N_31469 : std_logic ;
  signal N_31470 : std_logic ;
  signal N_31471 : std_logic ;
  signal N_31472 : std_logic ;
  signal N_31473 : std_logic ;
  signal N_31474 : std_logic ;
  signal N_31475 : std_logic ;
  signal N_31476 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\ : std_logic ;
  signal N_38025 : std_logic ;
  signal \GRFPC0.N_107\ : std_logic ;
  signal \GRFPC0.N_165_1\ : std_logic ;
  signal \GRFPC0.N_91_1\ : std_logic ;
  signal \GRFPC0.N_25217_1\ : std_logic ;
  signal \GRFPC0.N_23756_1\ : std_logic ;
  signal \GRFPC0.N_25708_2\ : std_logic ;
  signal \GRFPC0.N_25451_2\ : std_logic ;
  signal \GRFPC0.N_25367_I\ : std_logic ;
  signal \GRFPC0.N_21055_I\ : std_logic ;
  signal \GRFPC0.N_24372_1\ : std_logic ;
  signal \GRFPC0.N_25309_1\ : std_logic ;
  signal \GRFPC0.N_23783_1\ : std_logic ;
  signal \GRFPC0.N_25813_1\ : std_logic ;
  signal \GRFPC0.N_25703_3\ : std_logic ;
  signal \GRFPC0.N_25826_1\ : std_logic ;
  signal \GRFPC0.N_24299_1\ : std_logic ;
  signal \GRFPC0.N_25786_1\ : std_logic ;
  signal \GRFPC0.N_25722_1\ : std_logic ;
  signal \GRFPC0.N_24696_1\ : std_logic ;
  signal \GRFPC0.N_207_1\ : std_logic ;
  signal \GRFPC0.N_21911_3\ : std_logic ;
  signal \GRFPC0.N_23873_2\ : std_logic ;
  signal \GRFPC0.N_88_1_0\ : std_logic ;
  signal \GRFPC0.FPRIN.ALLOW_0_0__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_34__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_36__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_37__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_38__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_39__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_40__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_41__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_42__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_43__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_44__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_45__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_46__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_47__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_48__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1\ : std_logic ;
  signal \GRFPC0.RFA.RS1D_0_0_G1\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.FIFO.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.R.FSR.NONSTD_0_0_G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RS1V_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_3__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_4__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_5__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_3__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_4__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.EXCT_0_0_5__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_3__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_4__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_5__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_6__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_7__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_8__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_10__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_11__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_12__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_13__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_14__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_15__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_16__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_17__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_18__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_19__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_20__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_21__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_22__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_23__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_24__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_25__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_26__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_27__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_28__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_29__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_30__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_31__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_32__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_33__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_34__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_35__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_36__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_37__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_38__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_39__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_40__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_41__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_42__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_43__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_44__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_45__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_46__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_47__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_48__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_49__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_50__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_51__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_52__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_53__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_54__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_55__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_56__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_57__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_58__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_59__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_60__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_61__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_62__G2\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RES_0_0_63__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_3__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_4__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_5__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_6__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_7__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_8__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_10__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_11__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_12__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_13__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_14__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_15__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_16__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_17__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_18__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_19__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_20__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_21__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_22__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_23__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_24__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_25__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_26__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_27__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_28__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_29__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_30__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_31__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_32__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_33__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_34__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_35__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_36__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_37__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_38__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_39__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_40__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_41__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_42__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_43__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_44__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_45__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_46__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_47__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_48__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_49__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_50__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_51__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_52__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_53__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_54__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_55__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_56__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_57__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_58__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_59__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_60__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_61__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_62__G2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_63__G2\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_1__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__N_6\ : std_logic ;
  signal N_50070 : std_logic ;
  signal N_50084 : std_logic ;
  signal N_50098 : std_logic ;
  signal N_50123 : std_logic ;
  signal N_50192 : std_logic ;
  signal N_50271 : std_logic ;
  signal N_50328 : std_logic ;
  signal N_50340 : std_logic ;
  signal N_50358 : std_logic ;
  signal N_50359 : std_logic ;
  signal N_50374 : std_logic ;
  signal N_50387 : std_logic ;
  signal N_50395 : std_logic ;
  signal N_50405 : std_logic ;
  signal N_50421 : std_logic ;
  signal N_50438 : std_logic ;
  signal N_50456 : std_logic ;
  signal N_50471 : std_logic ;
  signal N_50487 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_0__G3\ : std_logic ;
  signal N_50527 : std_logic ;
  signal N_50528 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_1__G3\ : std_logic ;
  signal N_50554 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_2__G3\ : std_logic ;
  signal N_50580 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_3__G3\ : std_logic ;
  signal N_50606 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_4__G3\ : std_logic ;
  signal N_50632 : std_logic ;
  signal N_50656 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19283_I\ : std_logic ;
  signal N_52884 : std_logic ;
  signal N_52885 : std_logic ;
  signal N_52886 : std_logic ;
  signal N_52887 : std_logic ;
  signal N_52888 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_25_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_27_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_29_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_31_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_33_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19185_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19186_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_39_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_41_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_43_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20283_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20286_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20288_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20313_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_45_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20281_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20284_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_23_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19_I\ : std_logic ;
  signal N_52963 : std_logic ;
  signal N_52964 : std_logic ;
  signal N_52965 : std_logic ;
  signal N_52966 : std_logic ;
  signal N_52967 : std_logic ;
  signal N_52968 : std_logic ;
  signal N_52969 : std_logic ;
  signal N_52970 : std_logic ;
  signal N_52971 : std_logic ;
  signal N_52972 : std_logic ;
  signal N_52973 : std_logic ;
  signal N_52974 : std_logic ;
  signal N_52975 : std_logic ;
  signal N_52976 : std_logic ;
  signal N_52977 : std_logic ;
  signal N_52978 : std_logic ;
  signal N_52979 : std_logic ;
  signal N_52980 : std_logic ;
  signal N_52982 : std_logic ;
  signal N_52983 : std_logic ;
  signal N_52984 : std_logic ;
  signal N_52985 : std_logic ;
  signal N_52986 : std_logic ;
  signal N_52987 : std_logic ;
  signal N_52988 : std_logic ;
  signal N_52989 : std_logic ;
  signal N_52990 : std_logic ;
  signal N_52991 : std_logic ;
  signal N_52992 : std_logic ;
  signal N_52993 : std_logic ;
  signal N_52994 : std_logic ;
  signal N_52995 : std_logic ;
  signal N_52996 : std_logic ;
  signal N_52998 : std_logic ;
  signal N_52999 : std_logic ;
  signal N_53000 : std_logic ;
  signal N_53001 : std_logic ;
  signal N_53002 : std_logic ;
  signal N_53003 : std_logic ;
  signal N_53004 : std_logic ;
  signal N_53005 : std_logic ;
  signal N_53006 : std_logic ;
  signal N_53007 : std_logic ;
  signal N_53008 : std_logic ;
  signal N_53009 : std_logic ;
  signal N_53010 : std_logic ;
  signal N_53011 : std_logic ;
  signal N_53012 : std_logic ;
  signal N_53013 : std_logic ;
  signal N_53014 : std_logic ;
  signal N_53015 : std_logic ;
  signal N_53016 : std_logic ;
  signal N_53017 : std_logic ;
  signal N_53018 : std_logic ;
  signal N_53019 : std_logic ;
  signal N_53020 : std_logic ;
  signal N_53021 : std_logic ;
  signal N_53022 : std_logic ;
  signal N_53023 : std_logic ;
  signal N_53024 : std_logic ;
  signal N_53025 : std_logic ;
  signal N_53026 : std_logic ;
  signal N_53027 : std_logic ;
  signal N_53028 : std_logic ;
  signal N_53029 : std_logic ;
  signal N_53030 : std_logic ;
  signal N_53031 : std_logic ;
  signal N_53032 : std_logic ;
  signal N_53033 : std_logic ;
  signal N_53034 : std_logic ;
  signal N_53035 : std_logic ;
  signal N_53036 : std_logic ;
  signal N_53037 : std_logic ;
  signal N_53038 : std_logic ;
  signal N_53039 : std_logic ;
  signal N_53040 : std_logic ;
  signal N_53041 : std_logic ;
  signal N_53042 : std_logic ;
  signal N_53043 : std_logic ;
  signal N_53044 : std_logic ;
  signal N_53045 : std_logic ;
  signal N_53046 : std_logic ;
  signal N_53047 : std_logic ;
  signal N_53048 : std_logic ;
  signal N_53049 : std_logic ;
  signal N_53050 : std_logic ;
  signal N_53051 : std_logic ;
  signal N_53052 : std_logic ;
  signal N_53053 : std_logic ;
  signal N_53054 : std_logic ;
  signal N_53055 : std_logic ;
  signal N_53056 : std_logic ;
  signal N_53057 : std_logic ;
  signal N_53058 : std_logic ;
  signal N_53059 : std_logic ;
  signal N_53060 : std_logic ;
  signal N_53061 : std_logic ;
  signal N_53062 : std_logic ;
  signal N_53063 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20890_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20889_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20886_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20888_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20893_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20887_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20891_I\ : std_logic ;
  signal RST_INTERNAL : std_logic ;
  signal HOLDN_INTERNAL : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_5__G0\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_1__G0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_SM0\ : std_logic ;
  signal N_91835 : std_logic ;
  signal N_91836 : std_logic ;
  signal N_91837 : std_logic ;
  signal N_91838 : std_logic ;
  signal N_91839 : std_logic ;
  signal N_91840 : std_logic ;
  signal N_91841 : std_logic ;
  signal N_91842 : std_logic ;
  signal N_91843 : std_logic ;
  signal N_91844 : std_logic ;
  signal N_91845 : std_logic ;
  signal N_91846 : std_logic ;
  signal N_91847 : std_logic ;
  signal N_91848 : std_logic ;
  signal \GRFPC0.N_21882\ : std_logic ;
  signal \GRFPC0.N_84\ : std_logic ;
  signal \GRFPC0.N_25404\ : std_logic ;
  signal \GRFPC0.N_25401\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.MEMSEL4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.MEMEN10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\ : std_logic ;
  signal \GRFPC0.N_24602_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5430\ : std_logic ;
  signal \GRFPC0.N_25648_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19318_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD_2_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G3\ : std_logic ;
  signal \GRFPC0.N_121_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_2\ : std_logic ;
  signal \GRFPC0.UN1_WRENX10_1\ : std_logic ;
  signal \GRFPC0.N_80\ : std_logic ;
  signal \GRFPC0.N_22918_1\ : std_logic ;
  signal \GRFPC0.N_191\ : std_logic ;
  signal \GRFPC0.N_76\ : std_logic ;
  signal \GRFPC0.N_22001\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_51_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19899\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19517\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18154\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18144\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18155\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18153\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5299\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18151\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_228_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18089\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18079\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17602\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18090\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18088\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18086\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16770\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18093\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18158\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXP57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10484\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3346\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10489\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10526\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10521\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3313\ : std_logic ;
  signal \GRFPC0.N_25407\ : std_logic ;
  signal \GRFPC0.N_25110\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3886\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3923\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10896\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10920\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3853\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3883\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10907\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10901\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3306\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18141\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17659\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17663\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18076\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4227\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4369\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4373\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCV18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4458_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17152\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17909\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCV12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4284\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4205\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4285\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4313\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20803\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20843_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20848\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20849\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20881\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20876\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17158\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17915\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17169\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17861\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17167\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17859\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17895\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17202\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17894\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4233\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4355\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18396\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18426\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18411\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4260_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG88\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17783\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17918\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17161\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18279\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18280\ : std_logic ;
  signal N_50790 : std_logic ;
  signal N_50756 : std_logic ;
  signal N_51424 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19837\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19829\ : std_logic ;
  signal N_36192 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19798\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19836\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19791\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19794\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19800\ : std_logic ;
  signal N_36129 : std_logic ;
  signal N_35934 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19838\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19832\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19831\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19817\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19821_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19818_1\ : std_logic ;
  signal N_36102 : std_logic ;
  signal N_35944 : std_logic ;
  signal N_36139 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20985\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18050\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18115\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18126\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18117\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18061\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18052\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19361\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19364\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19370\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19388\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\ : std_logic ;
  signal \GRFPC0.N_21949\ : std_logic ;
  signal \GRFPC0.N_22053\ : std_logic ;
  signal \GRFPC0.N_21907\ : std_logic ;
  signal \GRFPC0.N_21904\ : std_logic ;
  signal \GRFPC0.N_20913\ : std_logic ;
  signal \GRFPC0.N_20968\ : std_logic ;
  signal \GRFPC0.N_20967\ : std_logic ;
  signal \GRFPC0.N_137\ : std_logic ;
  signal \GRFPC0.N_96\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18975\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19463\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5437\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6759_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3493\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17661\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16308\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6661\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7023\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7028\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7459\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7445\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7019\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6995\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7053\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6575_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6577\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6660\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7645\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6576_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7439\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6571\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6654\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19373\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19382\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19398\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\ : std_logic ;
  signal N_36015 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20969\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3406\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10409\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3386\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10410\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3383\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3513\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3836\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.GUARD_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19652\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21896\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19652_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19606\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7910\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20965\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3423\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3443\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3473\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20892\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3293\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3373\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.IEXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10728\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19482\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3653\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3633\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10717\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10722\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3623\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10741\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3643\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19483_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19473\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19480\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19481\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3336\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10583\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19299\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3533\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3503\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3413\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3523\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3363\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10570\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3483\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3393\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3366\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3463\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3433\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3763\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3913\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4013\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3873\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3743\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17631\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3783\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3753\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ODDEXP_2_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17200\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17892\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5188\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21036\ : std_logic ;
  signal \GRFPC0.N_24697_1\ : std_logic ;
  signal \GRFPC0.N_25620\ : std_logic ;
  signal \GRFPC0.N_25432\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6097\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6100\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4379\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6498\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4094\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7781\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17600\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15359\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9852\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8154\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9851\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7753\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7795\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7767\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7797\ : std_logic ;
  signal N_36172 : std_logic ;
  signal N_36167 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21152\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20608\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX_1_0_N_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7226\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_264\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18104\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18130\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.STATE_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18065\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18039\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.STATE_18_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19310\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19306\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19307\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6875\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18972\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7680\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4066_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4063\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.V_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16307\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19403\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4378\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8171_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7767_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7781_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7795_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19196\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19197\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6243_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_64\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19550\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5438\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4LT6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19367\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19379\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.N_25682\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17645\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20925\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17673\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_127\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_131\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_135\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_138\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20609\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6325\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_271\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16305\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3576\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3593\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.ZERO_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6639\ : std_logic ;
  signal N_36040 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15674\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15721\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15723\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15724\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15725\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15722\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19536\ : std_logic ;
  signal N_36109 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19553\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19552\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19547\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19546\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19545\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5192\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_244\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16772\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19264\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19484\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG_2_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19397\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18163\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18132\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18067\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G4\ : std_logic ;
  signal \GRFPC0.N_25403\ : std_logic ;
  signal \GRFPC0.N_20860\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G4\ : std_logic ;
  signal \GRFPC0.N_24278\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXP37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_77_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19272\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19270\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19554_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19259_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19551\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21042\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21058\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21049\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17906\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17199\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20647\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3256\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3253\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3266\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3263\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21048\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17176\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17868\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3283\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19549\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19804\ : std_logic ;
  signal N_36182 : std_logic ;
  signal N_36187 : std_logic ;
  signal N_36200 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17608\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18099\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_246\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18137\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18124\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18131\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18066\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18059\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18072\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19842\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19843\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19844\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19845\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19846\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19847\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19848\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20789\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20790\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20792\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21169\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19525\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19253_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19212\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21000_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15703\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15704\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15705\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15706\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15707\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15708\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15709\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15710\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15711\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15712\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15713\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15714\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15715\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15716\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15717\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15718\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15719\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15720\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16650\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_117\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_18\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_31\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_49\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_69\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_94\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_91\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_78\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_81\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_72\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_65\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_70\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_63\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_4\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_45\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_110\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_183\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_147\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_151\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_124\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_106\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_120\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_113\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_119\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_101\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_94\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_96\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_82\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_89\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_64\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_71\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_29\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_9\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_31\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_53\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_49\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_51\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_37\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_42\ : std_logic ;
  signal \GRFPU0.DIVROM0.DATA_1_6_0_.N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15702\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15701\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11478\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_SP_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17113\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17676\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17662\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17109\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20927\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17665\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17670\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18051\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17666\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18057\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18046\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18054\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18073\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18138\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18055\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17652\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17107\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16317\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16265\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17656\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18044\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16312\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16260\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3733\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3813\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16314\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16262\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3773\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17117\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17867\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17175\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.STICKY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19314\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16302\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16313\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16306\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16254\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17655\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17119\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19503\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19504\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16309\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16257\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16311\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16259\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16316\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16322\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16270\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16310\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20650\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.NXX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17891\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17877\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17185\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17917\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17160\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17913\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17156\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17911\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17154\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17912\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17155\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17862\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17170\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17203\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17883\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17870\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17178\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17210\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17857\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17165\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17881\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17189\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17872\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17180\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17866\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17174\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17863\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17171\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15567\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17875\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17183\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17858\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17166\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20773\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17865\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17173\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17889\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17197\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17897\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17205\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17888\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17196\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17882\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17190\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17916\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17159\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17905\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17914\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17157\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16266\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20620\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17664\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17671\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17675\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17677\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18058\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18064\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18063\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18047\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17672\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18062\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18053\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18048\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18049\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18056\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18084\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18149\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17667\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17669\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18161\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17605\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17878\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17186\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16304\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16252\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17904\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17212\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17115\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16315\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16321\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17876\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17184\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2LT6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18041\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18106\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18043\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18108\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18109\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18111\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18112\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18113\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18114\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18116\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18118\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18119\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18120\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18121\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18122\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18123\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18060\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18125\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18127\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18128\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18129\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G4\ : std_logic ;
  signal N_50994 : std_logic ;
  signal N_50722 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19385\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19376\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19352\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20957\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19342\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19340\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19557\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_25211\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_24711\ : std_logic ;
  signal \GRFPC0.N_25437\ : std_logic ;
  signal \GRFPC0.N_25617\ : std_logic ;
  signal \GRFPC0.N_25045\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_99\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_96\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20842\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21185\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20562_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21092\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3905_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20993\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5299_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19335\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_135\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6860\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19465\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19408\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20670\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19334\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3286\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20474\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20599\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20981\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20989\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19524\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19332\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_268\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_265\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20846\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20814\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20824\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20826\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19221\ : std_logic ;
  signal N_45083 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3566\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19803\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19808\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6485\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6484\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7229_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19199\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_89\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6661_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21876\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG108\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4325\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_23428\ : std_logic ;
  signal \GRFPC0.N_69_I\ : std_logic ;
  signal \GRFPC0.N_23430\ : std_logic ;
  signal \GRFPC0.N_24362\ : std_logic ;
  signal \GRFPC0.N_25887\ : std_logic ;
  signal \GRFPC0.N_25593\ : std_logic ;
  signal \GRFPC0.N_25591\ : std_logic ;
  signal \GRFPC0.N_25310\ : std_logic ;
  signal \GRFPC0.N_25703\ : std_logic ;
  signal \GRFPC0.N_25706\ : std_logic ;
  signal \GRFPC0.N_25702\ : std_logic ;
  signal \GRFPC0.N_25693_2\ : std_logic ;
  signal \GRFPC0.N_91\ : std_logic ;
  signal \GRFPC0.N_221\ : std_logic ;
  signal \GRFPC0.N_24517\ : std_logic ;
  signal \GRFPC0.N_25612\ : std_logic ;
  signal \GRFPC0.N_23812\ : std_logic ;
  signal \GRFPC0.N_24709\ : std_logic ;
  signal \GRFPC0.N_25697\ : std_logic ;
  signal \GRFPC0.N_25721\ : std_logic ;
  signal \GRFPC0.N_25481\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25586\ : std_logic ;
  signal \GRFPC0.N_25214\ : std_logic ;
  signal \GRFPC0.N_25730\ : std_logic ;
  signal \GRFPC0.N_25228\ : std_logic ;
  signal \GRFPC0.N_25227\ : std_logic ;
  signal \GRFPC0.N_22914\ : std_logic ;
  signal \GRFPC0.N_22913\ : std_logic ;
  signal \GRFPC0.N_23813\ : std_logic ;
  signal \GRFPC0.N_25169\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3235_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20863\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20816_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_79\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6863\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7913_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20488\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20478\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20779\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19823\ : std_logic ;
  signal \GRFPC0.N_23797\ : std_logic ;
  signal \GRFPC0.N_23810\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_2\ : std_logic ;
  signal \GRFPC0.FID_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.ID_1\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_1_CO1\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_1_CO0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\ : std_logic ;
  signal \GRFPC0.VDIV.VALID_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_21157\ : std_logic ;
  signal \GRFPC0.N_21137_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH\ : std_logic ;
  signal N_50097 : std_logic ;
  signal N_50070_3 : std_logic ;
  signal N_52984_2 : std_logic ;
  signal N_51763 : std_logic ;
  signal N_51770 : std_logic ;
  signal N_52987_2 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.N_19626\ : std_logic ;
  signal \GRFPC0.N_19560\ : std_logic ;
  signal \GRFPC0.N_19889\ : std_logic ;
  signal \GRFPC0.N_19910\ : std_logic ;
  signal \GRFPC0.N_19647\ : std_logic ;
  signal \GRFPC0.N_19581\ : std_logic ;
  signal \GRFPC0.N_24997\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2623_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24193\ : std_logic ;
  signal \GRFPC0.N_23809\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24964\ : std_logic ;
  signal \GRFPC0.N_23822\ : std_logic ;
  signal \GRFPC0.N_25012\ : std_logic ;
  signal \GRFPC0.N_24939\ : std_logic ;
  signal \GRFPC0.N_24938\ : std_logic ;
  signal \GRFPC0.N_24930\ : std_logic ;
  signal \GRFPC0.N_25175\ : std_logic ;
  signal \GRFPC0.N_25175_1\ : std_logic ;
  signal \GRFPC0.N_24962\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1712_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25174_1\ : std_logic ;
  signal \GRFPC0.N_24330\ : std_logic ;
  signal \GRFPC0.N_25135\ : std_logic ;
  signal \GRFPC0.N_24327\ : std_logic ;
  signal \GRFPC0.N_25117\ : std_logic ;
  signal \GRFPC0.N_25754\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6549_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_21461\ : std_logic ;
  signal \GRFPC0.N_21460\ : std_logic ;
  signal \GRFPC0.N_20995\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_112_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_101\ : std_logic ;
  signal \GRFPC0.N_24443\ : std_logic ;
  signal \GRFPC0.N_24433\ : std_logic ;
  signal \GRFPC0.N_21956_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_92_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22743_1\ : std_logic ;
  signal \GRFPC0.N_24606_2\ : std_logic ;
  signal \GRFPC0.N_21749\ : std_logic ;
  signal \GRFPC0.N_22690\ : std_logic ;
  signal \GRFPC0.N_22689\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\ : std_logic ;
  signal N_38026 : std_logic ;
  signal \GRFPC0.N_21471\ : std_logic ;
  signal \GRFPC0.N_22664\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1344_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22737_2\ : std_logic ;
  signal \GRFPC0.N_22674\ : std_logic ;
  signal \GRFPC0.N_22146\ : std_logic ;
  signal \GRFPC0.N_22418_1\ : std_logic ;
  signal \GRFPC0.N_24408\ : std_logic ;
  signal \GRFPC0.N_20975\ : std_logic ;
  signal \GRFPC0.N_46\ : std_logic ;
  signal \GRFPC0.N_58\ : std_logic ;
  signal \GRFPC0.N_56\ : std_logic ;
  signal \GRFPC0.N_21921\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_96\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_93\ : std_logic ;
  signal \GRFPC0.N_21896\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_21001\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_21942\ : std_logic ;
  signal \GRFPC0.N_22039\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDD_1\ : std_logic ;
  signal \GRFPC0.N_45\ : std_logic ;
  signal \GRFPC0.N_16924\ : std_logic ;
  signal \GRFPC0.N_22045\ : std_logic ;
  signal \GRFPC0.N_177\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22457\ : std_logic ;
  signal \GRFPC0.N_55_LI\ : std_logic ;
  signal \GRFPC0.N_22483\ : std_logic ;
  signal \GRFPC0.N_22497\ : std_logic ;
  signal \GRFPC0.N_22\ : std_logic ;
  signal \GRFPC0.N_21710\ : std_logic ;
  signal \GRFPC0.N_22439\ : std_logic ;
  signal \GRFPC0.N_94\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_90\ : std_logic ;
  signal \GRFPC0.N_21010\ : std_logic ;
  signal \GRFPC0.N_21015\ : std_logic ;
  signal \GRFPC0.N_22719\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_124\ : std_logic ;
  signal \GRFPC0.N_21012\ : std_logic ;
  signal \GRFPC0.N_24881\ : std_logic ;
  signal \GRFPC0.N_24205\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_24115\ : std_logic ;
  signal N_50724 : std_logic ;
  signal N_50792 : std_logic ;
  signal \GRFPC0.N_24749\ : std_logic ;
  signal \GRFPC0.N_24798\ : std_logic ;
  signal \GRFPC0.N_24127_1\ : std_logic ;
  signal \GRFPC0.N_24791\ : std_logic ;
  signal \GRFPC0.N_24944_1\ : std_logic ;
  signal \GRFPC0.N_24950\ : std_logic ;
  signal \GRFPC0.N_24133\ : std_logic ;
  signal \GRFPC0.N_24126\ : std_logic ;
  signal N_51300 : std_logic ;
  signal N_51492 : std_logic ;
  signal N_51797 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25540_1\ : std_logic ;
  signal \GRFPC0.N_25508\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25208\ : std_logic ;
  signal \GRFPC0.N_24242_2\ : std_logic ;
  signal N_51460 : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_5\ : std_logic ;
  signal N_50926 : std_logic ;
  signal N_50960 : std_logic ;
  signal N_52337 : std_logic ;
  signal \GRFPC0.FIFO_INC_5_SQMUXA\ : std_logic ;
  signal \GRFPC0.VDIV.EXC_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN108_HOLDN\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_1\ : std_logic ;
  signal N_50654 : std_logic ;
  signal N_50892 : std_logic ;
  signal N_51062 : std_logic ;
  signal N_51362 : std_logic ;
  signal N_51560 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_2_LI\ : std_logic ;
  signal \GRFPC0.N_24707\ : std_logic ;
  signal \GRFPC0.N_24628\ : std_logic ;
  signal \GRFPC0.N_23711_LI\ : std_logic ;
  signal \GRFPC0.N_302\ : std_logic ;
  signal N_50824 : std_logic ;
  signal N_51458 : std_logic ;
  signal N_52445 : std_logic ;
  signal N_52733 : std_logic ;
  signal \GRFPC0.N_22077\ : std_logic ;
  signal \GRFPC0.N_21319\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_23175\ : std_logic ;
  signal \GRFPC0.N_21291_1\ : std_logic ;
  signal \GRFPC0.N_21317\ : std_logic ;
  signal \GRFPC0.N_21252\ : std_logic ;
  signal \GRFPC0.N_17857_1\ : std_logic ;
  signal \GRFPC0.N_21268\ : std_logic ;
  signal \GRFPC0.N_21553\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\ : std_logic ;
  signal \GRFPC0.N_23243\ : std_logic ;
  signal \GRFPC0.UN1_STDEP2530\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_108\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.RD\ : std_logic ;
  signal \GRFPC0.N_90\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_138\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3304_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_101\ : std_logic ;
  signal \GRFPC0.N_103\ : std_logic ;
  signal \GRFPC0.N_163\ : std_logic ;
  signal \GRFPC0.N_59\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_82\ : std_logic ;
  signal \GRFPC0.N_130\ : std_logic ;
  signal \GRFPC0.N_23572\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_88\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_21046_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_12_7\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_129_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.N_23611\ : std_logic ;
  signal \GRFPC0.N_23610\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_1_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12\ : std_logic ;
  signal \GRFPC0.N_17842_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_12_8\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_142\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_117_I_1\ : std_logic ;
  signal \GRFPC0.N_23148\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP\ : std_logic ;
  signal \GRFPC0.N_22494\ : std_logic ;
  signal \GRFPC0.N_20852\ : std_logic ;
  signal \GRFPC0.N_22448\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP\ : std_logic ;
  signal \GRFPC0.N_23178\ : std_logic ;
  signal \GRFPC0.N_162\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_20833\ : std_logic ;
  signal \GRFPC0.N_20880\ : std_logic ;
  signal \GRFPC0.N_20866\ : std_logic ;
  signal \GRFPC0.N_22226\ : std_logic ;
  signal \GRFPC0.N_22225\ : std_logic ;
  signal \GRFPC0.N_112\ : std_logic ;
  signal \GRFPC0.N_132\ : std_logic ;
  signal \GRFPC0.N_22179\ : std_logic ;
  signal \GRFPC0.N_20847\ : std_logic ;
  signal \GRFPC0.N_21386\ : std_logic ;
  signal \GRFPC0.N_21409\ : std_logic ;
  signal \GRFPC0.N_21382\ : std_logic ;
  signal \GRFPC0.N_22542\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1903_DEP\ : std_logic ;
  signal \GRFPC0.N_22452_1\ : std_logic ;
  signal \GRFPC0.N_21775\ : std_logic ;
  signal \GRFPC0.N_21141\ : std_logic ;
  signal \GRFPC0.N_22981\ : std_logic ;
  signal \GRFPC0.N_172\ : std_logic ;
  signal \GRFPC0.N_159\ : std_logic ;
  signal \GRFPC0.N_158\ : std_logic ;
  signal \GRFPC0.N_194\ : std_logic ;
  signal \GRFPC0.N_180\ : std_logic ;
  signal \GRFPC0.N_22998\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4199_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\ : std_logic ;
  signal \GRFPC0.N_193\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN4_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\ : std_logic ;
  signal \GRFPC0.N_21029\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\ : std_logic ;
  signal \GRFPC0.N_21703\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN676_DEP\ : std_logic ;
  signal \GRFPC0.N_23571\ : std_logic ;
  signal \GRFPC0.N_21339\ : std_logic ;
  signal \GRFPC0.N_21353\ : std_logic ;
  signal \GRFPC0.N_21341\ : std_logic ;
  signal \GRFPC0.N_21338\ : std_logic ;
  signal \GRFPC0.N_23535_1\ : std_logic ;
  signal \GRFPC0.N_21054\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\ : std_logic ;
  signal \GRFPC0.N_17935\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_83\ : std_logic ;
  signal \GRFPC0.N_127\ : std_logic ;
  signal \GRFPC0.N_17073\ : std_logic ;
  signal \GRFPC0.N_17107\ : std_logic ;
  signal \GRFPC0.N_17183\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_131\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL0\ : std_logic ;
  signal \GRFPC0.N_22778\ : std_logic ;
  signal \GRFPC0.N_116\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\ : std_logic ;
  signal \GRFPC0.N_21000\ : std_logic ;
  signal \GRFPC0.N_22766\ : std_logic ;
  signal \GRFPC0.N_22709\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\ : std_logic ;
  signal \GRFPC0.N_17057\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\ : std_logic ;
  signal \GRFPC0.N_17422\ : std_logic ;
  signal \GRFPC0.N_20976\ : std_logic ;
  signal \GRFPC0.N_21016_1\ : std_logic ;
  signal \GRFPC0.N_17424\ : std_logic ;
  signal N_38008 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\ : std_logic ;
  signal \GRFPC0.N_22721\ : std_logic ;
  signal \GRFPC0.N_22757\ : std_logic ;
  signal \GRFPC0.N_22289\ : std_logic ;
  signal \GRFPC0.N_21556\ : std_logic ;
  signal \GRFPC0.N_21543\ : std_logic ;
  signal \GRFPC0.N_21542\ : std_logic ;
  signal \GRFPC0.N_21544\ : std_logic ;
  signal \GRFPC0.N_21612\ : std_logic ;
  signal \GRFPC0.N_22324\ : std_logic ;
  signal \GRFPC0.N_21540\ : std_logic ;
  signal \GRFPC0.N_21549\ : std_logic ;
  signal \GRFPC0.N_22421\ : std_logic ;
  signal \GRFPC0.N_22422\ : std_logic ;
  signal \GRFPC0.N_22313\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\ : std_logic ;
  signal \GRFPC0.N_21541\ : std_logic ;
  signal \GRFPC0.N_21600\ : std_logic ;
  signal \GRFPC0.N_22364\ : std_logic ;
  signal \GRFPC0.N_22309\ : std_logic ;
  signal \GRFPC0.N_21716\ : std_logic ;
  signal \GRFPC0.N_21683_1\ : std_logic ;
  signal \GRFPC0.N_21598\ : std_logic ;
  signal \GRFPC0.N_22288\ : std_logic ;
  signal \GRFPC0.N_21545\ : std_logic ;
  signal \GRFPC0.N_22310\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4302_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP172\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\ : std_logic ;
  signal \GRFPC0.N_17905_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_125\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\ : std_logic ;
  signal \GRFPC0.UN1_FIFO.INST_0_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_21044\ : std_logic ;
  signal \GRFPC0.N_23282\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_92\ : std_logic ;
  signal \GRFPC0.N_23322\ : std_logic ;
  signal \GRFPC0.N_23365\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22626\ : std_logic ;
  signal \GRFPC0.N_23304\ : std_logic ;
  signal \GRFPC0.N_23195_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_167_1\ : std_logic ;
  signal \GRFPC0.N_22749_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22925_1\ : std_logic ;
  signal \GRFPC0.N_23310\ : std_logic ;
  signal \GRFPC0.N_23302\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22473_1\ : std_logic ;
  signal \GRFPC0.N_22333_1\ : std_logic ;
  signal \GRFPC0.N_20965\ : std_logic ;
  signal \GRFPC0.N_23412\ : std_logic ;
  signal \GRFPC0.N_22899\ : std_logic ;
  signal \GRFPC0.N_21128\ : std_logic ;
  signal \GRFPC0.N_23064\ : std_logic ;
  signal \GRFPC0.N_21121\ : std_logic ;
  signal \GRFPC0.N_22600\ : std_logic ;
  signal \GRFPC0.N_22565\ : std_logic ;
  signal \GRFPC0.N_22111_1\ : std_logic ;
  signal \GRFPC0.N_21794\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_89_1\ : std_logic ;
  signal \GRFPC0.N_24287_2\ : std_logic ;
  signal \GRFPC0.N_22782\ : std_logic ;
  signal \GRFPC0.N_22440\ : std_logic ;
  signal \GRFPC0.N_22443\ : std_logic ;
  signal \GRFPC0.N_24280\ : std_logic ;
  signal \GRFPC0.N_22473_2\ : std_logic ;
  signal \GRFPC0.N_22466_2\ : std_logic ;
  signal \GRFPC0.N_23401\ : std_logic ;
  signal \GRFPC0.N_24367\ : std_logic ;
  signal \GRFPC0.N_24448\ : std_logic ;
  signal \GRFPC0.N_23613_I_0\ : std_logic ;
  signal \GRFPC0.N_23116\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23291\ : std_logic ;
  signal \GRFPC0.N_23029\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4880_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23463_1\ : std_logic ;
  signal \GRFPC0.N_24368\ : std_logic ;
  signal \GRFPC0.N_22014\ : std_logic ;
  signal \GRFPC0.N_22015\ : std_logic ;
  signal \GRFPC0.N_22021\ : std_logic ;
  signal \GRFPC0.N_22022\ : std_logic ;
  signal \GRFPC0.N_23268\ : std_logic ;
  signal \GRFPC0.N_21043\ : std_logic ;
  signal \GRFPC0.N_23107\ : std_logic ;
  signal \GRFPC0.N_23452\ : std_logic ;
  signal \GRFPC0.N_150\ : std_logic ;
  signal \GRFPC0.N_17173\ : std_logic ;
  signal \GRFPC0.N_20985\ : std_logic ;
  signal \GRFPC0.N_20974\ : std_logic ;
  signal N_38007 : std_logic ;
  signal \GRFPC0.N_24606_1\ : std_logic ;
  signal \GRFPC0.N_22183\ : std_logic ;
  signal \GRFPC0.N_22207\ : std_logic ;
  signal \GRFPC0.N_22698\ : std_logic ;
  signal \GRFPC0.N_22249\ : std_logic ;
  signal \GRFPC0.N_23309_1\ : std_logic ;
  signal \GRFPC0.N_20925\ : std_logic ;
  signal \GRFPC0.N_23420\ : std_logic ;
  signal \GRFPC0.N_23423\ : std_logic ;
  signal \GRFPC0.N_23403\ : std_logic ;
  signal \GRFPC0.N_23381\ : std_logic ;
  signal \GRFPC0.N_20908\ : std_logic ;
  signal \GRFPC0.N_23474\ : std_logic ;
  signal \GRFPC0.N_23453\ : std_logic ;
  signal \GRFPC0.N_23449\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.STDEP2026\ : std_logic ;
  signal \GRFPC0.N_22597\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\ : std_logic ;
  signal \GRFPC0.N_22614\ : std_logic ;
  signal \GRFPC0.N_21327\ : std_logic ;
  signal \GRFPC0.N_22598\ : std_logic ;
  signal \GRFPC0.N_22612\ : std_logic ;
  signal \GRFPC0.N_21372\ : std_logic ;
  signal \GRFPC0.N_21666\ : std_logic ;
  signal \GRFPC0.N_21629\ : std_logic ;
  signal \GRFPC0.N_21668\ : std_logic ;
  signal \GRFPC0.N_21669\ : std_logic ;
  signal \GRFPC0.N_22124\ : std_logic ;
  signal \GRFPC0.N_21817\ : std_logic ;
  signal \GRFPC0.N_25877\ : std_logic ;
  signal \GRFPC0.N_22982\ : std_logic ;
  signal \GRFPC0.N_22231_1\ : std_logic ;
  signal \GRFPC0.N_21253\ : std_logic ;
  signal \GRFPC0.N_21683\ : std_logic ;
  signal \GRFPC0.N_21275\ : std_logic ;
  signal \GRFPC0.N_22819\ : std_logic ;
  signal \GRFPC0.N_20832\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_105\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\ : std_logic ;
  signal \GRFPC0.N_21336\ : std_logic ;
  signal \GRFPC0.N_20893\ : std_logic ;
  signal \GRFPC0.N_20838\ : std_logic ;
  signal \GRFPC0.N_20834\ : std_logic ;
  signal \GRFPC0.N_20884\ : std_logic ;
  signal \GRFPC0.N_21416_2\ : std_logic ;
  signal \GRFPC0.N_21414\ : std_logic ;
  signal \GRFPC0.N_21443\ : std_logic ;
  signal \GRFPC0.N_22307\ : std_logic ;
  signal \GRFPC0.N_22329_1\ : std_logic ;
  signal \GRFPC0.N_21472\ : std_logic ;
  signal \GRFPC0.N_21467\ : std_logic ;
  signal \GRFPC0.N_22013\ : std_logic ;
  signal \GRFPC0.N_99\ : std_logic ;
  signal \GRFPC0.N_21337\ : std_logic ;
  signal \GRFPC0.N_23172\ : std_logic ;
  signal \GRFPC0.N_23238\ : std_logic ;
  signal \GRFPC0.N_20961_2\ : std_logic ;
  signal \GRFPC0.N_21177\ : std_logic ;
  signal \GRFPC0.N_21182\ : std_logic ;
  signal \GRFPC0.N_24252\ : std_logic ;
  signal \GRFPC0.N_24218\ : std_logic ;
  signal \GRFPC0.N_21997\ : std_logic ;
  signal \GRFPC0.N_22847\ : std_logic ;
  signal \GRFPC0.N_22809\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_87\ : std_logic ;
  signal \GRFPC0.N_22850\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22858\ : std_logic ;
  signal \GRFPC0.N_22851\ : std_logic ;
  signal \GRFPC0.N_22807\ : std_logic ;
  signal \GRFPC0.N_23556\ : std_logic ;
  signal \GRFPC0.N_23557\ : std_logic ;
  signal \GRFPC0.N_23544\ : std_logic ;
  signal \GRFPC0.N_22804\ : std_logic ;
  signal \GRFPC0.N_22806\ : std_logic ;
  signal \GRFPC0.N_24221\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_21981\ : std_logic ;
  signal \GRFPC0.N_23257\ : std_logic ;
  signal \GRFPC0.N_21996\ : std_logic ;
  signal \GRFPC0.N_22774\ : std_logic ;
  signal \GRFPC0.N_22760\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_128\ : std_logic ;
  signal \GRFPC0.N_23540\ : std_logic ;
  signal \GRFPC0.N_21254\ : std_logic ;
  signal \GRFPC0.N_24226\ : std_logic ;
  signal \GRFPC0.N_21783\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\ : std_logic ;
  signal \GRFPC0.N_22513\ : std_logic ;
  signal \GRFPC0.N_17965\ : std_logic ;
  signal \GRFPC0.N_21763\ : std_logic ;
  signal \GRFPC0.N_21704\ : std_logic ;
  signal \GRFPC0.N_21760\ : std_logic ;
  signal \GRFPC0.N_21746\ : std_logic ;
  signal \GRFPC0.N_25876\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.STDEP1018\ : std_logic ;
  signal \GRFPC0.N_17377\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\ : std_logic ;
  signal \GRFPC0.N_21791\ : std_logic ;
  signal \GRFPC0.N_22896\ : std_logic ;
  signal \GRFPC0.N_22943\ : std_logic ;
  signal \GRFPC0.N_22920\ : std_logic ;
  signal \GRFPC0.N_22921\ : std_logic ;
  signal \GRFPC0.N_24409\ : std_logic ;
  signal \GRFPC0.N_23417_2\ : std_logic ;
  signal \GRFPC0.N_24360\ : std_logic ;
  signal \GRFPC0.N_22922\ : std_logic ;
  signal \GRFPC0.N_21957_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2904_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_22902\ : std_logic ;
  signal \GRFPC0.N_22900\ : std_logic ;
  signal \GRFPC0.N_21821\ : std_logic ;
  signal \GRFPC0.N_22942\ : std_logic ;
  signal \GRFPC0.N_22939\ : std_logic ;
  signal \GRFPC0.N_22901\ : std_logic ;
  signal \GRFPC0.N_22891\ : std_logic ;
  signal \GRFPC0.N_22964\ : std_logic ;
  signal \GRFPC0.N_21789\ : std_logic ;
  signal \GRFPC0.N_21793\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_21178\ : std_logic ;
  signal \GRFPC0.N_21172\ : std_logic ;
  signal \GRFPC0.N_40\ : std_logic ;
  signal \GRFPC0.N_21170\ : std_logic ;
  signal \GRFPC0.N_110\ : std_logic ;
  signal \GRFPC0.N_22495\ : std_logic ;
  signal \GRFPC0.N_22878\ : std_logic ;
  signal \GRFPC0.N_22865\ : std_logic ;
  signal \GRFPC0.N_22477\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP173\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP160\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP156\ : std_logic ;
  signal \GRFPC0.N_21711\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST4\ : std_logic ;
  signal \GRFPC0.N_21193\ : std_logic ;
  signal \GRFPC0.N_21174\ : std_logic ;
  signal \GRFPC0.N_22839\ : std_logic ;
  signal \GRFPC0.N_22835\ : std_logic ;
  signal \GRFPC0.N_23550\ : std_logic ;
  signal \GRFPC0.N_23549\ : std_logic ;
  signal \GRFPC0.N_17250\ : std_logic ;
  signal \GRFPC0.N_21695_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE6\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\ : std_logic ;
  signal \GRFPC0.V.FSR.AEXC_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_4_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.WREN_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.FCC_VALID_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20296\ : std_logic ;
  signal \GRFPC0.N_65\ : std_logic ;
  signal \GRFPC0.N_19050\ : std_logic ;
  signal N_58190 : std_logic ;
  signal \GRFPC0.N_19884\ : std_logic ;
  signal \GRFPC0.N_19621\ : std_logic ;
  signal \GRFPC0.N_19555\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_389\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19767\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20291\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8197\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_219\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19768\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_126_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20317\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_194\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_331\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_335\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_388_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\ : std_logic ;
  signal N_36249 : std_logic ;
  signal N_36244 : std_logic ;
  signal N_36304 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_221\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19767_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19767_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8127_M_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20295\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19722\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16177\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_125_I\ : std_logic ;
  signal \GRFPC0.N_19171\ : std_logic ;
  signal \GRFPC0.N_19236\ : std_logic ;
  signal \GRFPC0.N_19302\ : std_logic ;
  signal \GRFPC0.N_19235\ : std_logic ;
  signal \GRFPC0.N_19170\ : std_logic ;
  signal \GRFPC0.N_19301\ : std_logic ;
  signal \GRFPC0.N_22538\ : std_logic ;
  signal \GRFPC0.N_22560\ : std_logic ;
  signal \GRFPC0.N_22619_2\ : std_logic ;
  signal \GRFPC0.N_22619_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_22558\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24422\ : std_logic ;
  signal \GRFPC0.N_24437\ : std_logic ;
  signal \GRFPC0.N_22603\ : std_logic ;
  signal \GRFPC0.N_22582\ : std_logic ;
  signal \GRFPC0.N_22622\ : std_logic ;
  signal \GRFPC0.N_23240\ : std_logic ;
  signal \GRFPC0.N_23337\ : std_logic ;
  signal \GRFPC0.N_17115\ : std_logic ;
  signal \GRFPC0.N_23053\ : std_logic ;
  signal \GRFPC0.N_23004\ : std_logic ;
  signal \GRFPC0.N_23046\ : std_logic ;
  signal \GRFPC0.N_23010\ : std_logic ;
  signal \GRFPC0.N_31\ : std_logic ;
  signal \GRFPC0.N_22697\ : std_logic ;
  signal \GRFPC0.N_23358\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\ : std_logic ;
  signal \GRFPC0.N_21104\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\ : std_logic ;
  signal \GRFPC0.N_155_2\ : std_logic ;
  signal \GRFPC0.N_144\ : std_logic ;
  signal \GRFPC0.N_21052\ : std_logic ;
  signal \GRFPC0.N_21039\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP74\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_100\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_182\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_114_2\ : std_logic ;
  signal \GRFPC0.N_21092\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\ : std_logic ;
  signal \GRFPC0.UN1_STDEP682\ : std_logic ;
  signal \GRFPC0.N_21168_3\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.RD10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD10\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.FIFO.RD_0_0_0__G3\ : std_logic ;
  signal N_51232 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN42_HOLDN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\ : std_logic ;
  signal N_52826 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_1_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDBL_1_1\ : std_logic ;
  signal \GRFPC0.REN1_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RS1V.TMP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1D\ : std_logic ;
  signal \GRFPC0.N_20683\ : std_logic ;
  signal \GRFPC0.N_20672\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_24352\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22745\ : std_logic ;
  signal \GRFPC0.N_20668\ : std_logic ;
  signal \GRFPC0.N_20667_I\ : std_logic ;
  signal \GRFPC0.N_22735\ : std_logic ;
  signal \GRFPC0.N_22750_1\ : std_logic ;
  signal \GRFPC0.N_21974\ : std_logic ;
  signal \GRFPC0.N_21967\ : std_logic ;
  signal \GRFPC0.N_21939\ : std_logic ;
  signal \GRFPC0.N_20674\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA_6\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\ : std_logic ;
  signal \GRFPC0.N_21076_1\ : std_logic ;
  signal \GRFPC0.N_21036\ : std_logic ;
  signal \GRFPC0.N_21076\ : std_logic ;
  signal \GRFPC0.N_21090\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.N_303\ : std_logic ;
  signal \GRFPC0.N_250\ : std_logic ;
  signal \GRFPC0.N_25091\ : std_logic ;
  signal \GRFPC0.N_25098\ : std_logic ;
  signal \GRFPC0.N_25092\ : std_logic ;
  signal \GRFPC0.N_25522_2\ : std_logic ;
  signal \GRFPC0.N_23717\ : std_logic ;
  signal \GRFPC0.N_23719\ : std_logic ;
  signal \GRFPC0.N_24207\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN133_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25549\ : std_logic ;
  signal \GRFPC0.N_25495_2\ : std_logic ;
  signal \GRFPC0.N_24079\ : std_logic ;
  signal \GRFPC0.N_24081\ : std_logic ;
  signal \GRFPC0.N_23712\ : std_logic ;
  signal \GRFPC0.N_24493\ : std_logic ;
  signal \GRFPC0.N_25538\ : std_logic ;
  signal \GRFPC0.N_23867\ : std_logic ;
  signal \GRFPC0.N_25074\ : std_logic ;
  signal \GRFPC0.N_25077\ : std_logic ;
  signal \GRFPC0.N_25745_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23658\ : std_logic ;
  signal \GRFPC0.N_25530\ : std_logic ;
  signal \GRFPC0.N_23709\ : std_logic ;
  signal \GRFPC0.N_24088\ : std_logic ;
  signal \GRFPC0.N_25747_I\ : std_logic ;
  signal \GRFPC0.N_24701\ : std_logic ;
  signal \GRFPC0.N_24662\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN63_HOLDN\ : std_logic ;
  signal \GRFPC0.N_24713\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.N_24567\ : std_logic ;
  signal N_51725 : std_logic ;
  signal N_52562 : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\ : std_logic ;
  signal N_52229 : std_logic ;
  signal N_52015 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN50_HOLDN\ : std_logic ;
  signal \GRFPC0.FPEXC_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_25325_1\ : std_logic ;
  signal \GRFPC0.N_24487\ : std_logic ;
  signal \GRFPC0.N_25452\ : std_logic ;
  signal \GRFPC0.N_25454\ : std_logic ;
  signal \GRFPC0.N_25222_1\ : std_logic ;
  signal \GRFPC0.N_25756\ : std_logic ;
  signal \GRFPC0.N_25223_2\ : std_logic ;
  signal \GRFPC0.N_25781\ : std_logic ;
  signal \GRFPC0.N_25782\ : std_logic ;
  signal \GRFPC0.N_25303\ : std_logic ;
  signal N_52804 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3932_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25417\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2\ : std_logic ;
  signal N_52829 : std_logic ;
  signal \GRFPC0.N_20796\ : std_logic ;
  signal \GRFPC0.N_25296_1\ : std_logic ;
  signal \GRFPC0.N_25308\ : std_logic ;
  signal \GRFPC0.N_25308_2\ : std_logic ;
  signal \GRFPC0.N_25785\ : std_logic ;
  signal \GRFPC0.N_24095\ : std_logic ;
  signal \GRFPC0.N_22620\ : std_logic ;
  signal \GRFPC0.N_24209\ : std_logic ;
  signal \GRFPC0.N_24542_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_24909\ : std_logic ;
  signal \GRFPC0.N_23662\ : std_logic ;
  signal \GRFPC0.N_24090\ : std_logic ;
  signal \GRFPC0.N_25203_1\ : std_logic ;
  signal \GRFPC0.N_24948_1\ : std_logic ;
  signal \GRFPC0.N_24087\ : std_logic ;
  signal \GRFPC0.N_24942\ : std_logic ;
  signal \GRFPC0.N_24122\ : std_logic ;
  signal N_51096 : std_logic ;
  signal \GRFPC0.N_23661\ : std_logic ;
  signal \GRFPC0.N_23391\ : std_logic ;
  signal \GRFPC0.N_23462_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_24605\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25845\ : std_logic ;
  signal \GRFPC0.N_24981\ : std_logic ;
  signal \GRFPC0.N_25090\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25664\ : std_logic ;
  signal \GRFPC0.N_25854\ : std_logic ;
  signal \GRFPC0.N_25388\ : std_logic ;
  signal \GRFPC0.N_25384\ : std_logic ;
  signal \GRFPC0.N_25058_1\ : std_logic ;
  signal \GRFPC0.N_25518\ : std_logic ;
  signal \GRFPC0.N_25795_2\ : std_logic ;
  signal \GRFPC0.N_24970\ : std_logic ;
  signal \GRFPC0.N_24946\ : std_logic ;
  signal \GRFPC0.N_24971\ : std_logic ;
  signal \GRFPC0.N_24637\ : std_logic ;
  signal \GRFPC0.N_25694\ : std_logic ;
  signal \GRFPC0.N_25512\ : std_logic ;
  signal \GRFPC0.N_25500\ : std_logic ;
  signal \GRFPC0.N_24502\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24649\ : std_logic ;
  signal \GRFPC0.N_24656\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50\ : std_logic ;
  signal \GRFPC0.N_70\ : std_logic ;
  signal \GRFPC0.N_25179\ : std_logic ;
  signal \GRFPC0.N_25786_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25695\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_24731\ : std_logic ;
  signal \GRFPC0.N_25222\ : std_logic ;
  signal \GRFPC0.N_25223\ : std_logic ;
  signal \GRFPC0.N_24535\ : std_logic ;
  signal \GRFPC0.N_24653\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN816_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_24671\ : std_logic ;
  signal \GRFPC0.N_25724\ : std_logic ;
  signal \GRFPC0.N_24113\ : std_logic ;
  signal \GRFPC0.N_24694\ : std_logic ;
  signal \GRFPC0.N_24668\ : std_logic ;
  signal \GRFPC0.N_24644\ : std_logic ;
  signal \GRFPC0.N_25416\ : std_logic ;
  signal \GRFPC0.N_25465\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3768_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25715_2\ : std_logic ;
  signal \GRFPC0.N_24119\ : std_logic ;
  signal \GRFPC0.N_24832\ : std_logic ;
  signal \GRFPC0.N_24645\ : std_logic ;
  signal \GRFPC0.N_25421\ : std_logic ;
  signal \GRFPC0.N_25420\ : std_logic ;
  signal \GRFPC0.N_24693\ : std_logic ;
  signal N_51943 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_218\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_I\ : std_logic ;
  signal N_51941 : std_logic ;
  signal N_52193 : std_logic ;
  signal N_52373 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.QNE2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\ : std_logic ;
  signal \GRFPC0.N_25192\ : std_logic ;
  signal \GRFPC0.N_25190\ : std_logic ;
  signal \GRFPC0.N_25442\ : std_logic ;
  signal \GRFPC0.N_24635\ : std_logic ;
  signal \GRFPC0.N_24030\ : std_logic ;
  signal \GRFPC0.N_23216\ : std_logic ;
  signal \GRFPC0.N_23217\ : std_logic ;
  signal \GRFPC0.N_24795_2\ : std_logic ;
  signal \GRFPC0.N_25379\ : std_logic ;
  signal \GRFPC0.N_16955\ : std_logic ;
  signal \GRFPC0.N_16961\ : std_logic ;
  signal \GRFPC0.N_16975\ : std_logic ;
  signal \GRFPC0.N_24276\ : std_logic ;
  signal \GRFPC0.N_23009\ : std_logic ;
  signal \GRFPC0.N_21420\ : std_logic ;
  signal \GRFPC0.N_25186\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN8_OP_7_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_76\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN17_OP_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN14_OP_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN15_OP_1\ : std_logic ;
  signal N_51364 : std_logic ;
  signal N_51426 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_FPEXC\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.N_18401\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118\ : std_logic ;
  signal N_36269 : std_logic ;
  signal N_36264 : std_logic ;
  signal N_36274 : std_logic ;
  signal N_36217 : std_logic ;
  signal \GRFPC0.N_19737\ : std_logic ;
  signal \GRFPC0.N_19876\ : std_logic ;
  signal \GRFPC0.N_19745\ : std_logic ;
  signal \GRFPC0.N_19810\ : std_logic ;
  signal \GRFPC0.N_19872\ : std_logic ;
  signal \GRFPC0.N_19741\ : std_logic ;
  signal \GRFPC0.N_19806\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_223\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_83\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_86\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_88\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_156\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_157\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_268\ : std_logic ;
  signal \GRFPC0.N_25532\ : std_logic ;
  signal \GRFPC0.N_23649\ : std_logic ;
  signal \GRFPC0.N_24503\ : std_logic ;
  signal \GRFPC0.N_23445\ : std_logic ;
  signal \GRFPC0.N_24965\ : std_logic ;
  signal \GRFPC0.N_24977\ : std_logic ;
  signal \GRFPC0.N_24973_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_23446\ : std_logic ;
  signal \GRFPC0.N_24655_1\ : std_logic ;
  signal \GRFPC0.N_24952\ : std_logic ;
  signal \GRFPC0.N_24967\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25710\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25713\ : std_logic ;
  signal \GRFPC0.N_25711\ : std_logic ;
  signal \GRFPC0.N_25514\ : std_logic ;
  signal \GRFPC0.N_25225\ : std_logic ;
  signal \GRFPC0.N_25580\ : std_logic ;
  signal \GRFPC0.N_24869\ : std_logic ;
  signal \GRFPC0.N_25685\ : std_logic ;
  signal \GRFPC0.N_25655\ : std_logic ;
  signal \GRFPC0.N_24789\ : std_logic ;
  signal \GRFPC0.N_24841\ : std_logic ;
  signal \GRFPC0.N_23708\ : std_logic ;
  signal \GRFPC0.N_24538\ : std_logic ;
  signal \GRFPC0.N_23783\ : std_logic ;
  signal \GRFPC0.N_24538_2\ : std_logic ;
  signal \GRFPC0.N_24688\ : std_logic ;
  signal \GRFPC0.N_25129\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP30\ : std_logic ;
  signal \GRFPC0.UN1_RDWR_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18\ : std_logic ;
  signal \GRFPC0.N_25527\ : std_logic ;
  signal \GRFPC0.N_25544\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4650_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24228\ : std_logic ;
  signal \GRFPC0.N_25529\ : std_logic ;
  signal \GRFPC0.N_22607\ : std_logic ;
  signal \GRFPC0.N_24753\ : std_logic ;
  signal \GRFPC0.N_24161\ : std_logic ;
  signal \GRFPC0.N_24794\ : std_logic ;
  signal \GRFPC0.N_25165\ : std_logic ;
  signal \GRFPC0.N_23872\ : std_logic ;
  signal \GRFPC0.N_25234\ : std_logic ;
  signal \GRFPC0.N_23737\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP14\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\ : std_logic ;
  signal \GRFPC0.N_21694\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_S3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_1_1_S4\ : std_logic ;
  signal \GRFPC0.N_10173_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP146\ : std_logic ;
  signal \GRFPC0.N_21133\ : std_logic ;
  signal \GRFPC0.N_21123\ : std_logic ;
  signal \GRFPC0.N_175\ : std_logic ;
  signal \GRFPC0.N_22992\ : std_logic ;
  signal \GRFPC0.N_23069\ : std_logic ;
  signal \GRFPC0.N_25426\ : std_logic ;
  signal \GRFPC0.N_25425\ : std_logic ;
  signal \GRFPC0.N_25639\ : std_logic ;
  signal \GRFPC0.N_23066\ : std_logic ;
  signal \GRFPC0.N_23070\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9745\ : std_logic ;
  signal \GRFPC0.N_19006\ : std_logic ;
  signal \GRFPC0.N_19072\ : std_logic ;
  signal \GRFPC0.N_19335\ : std_logic ;
  signal \GRFPC0.N_19577\ : std_logic ;
  signal \GRFPC0.N_19643\ : std_logic ;
  signal \GRFPC0.N_19906\ : std_logic ;
  signal \GRFPC0.N_19571\ : std_logic ;
  signal \GRFPC0.N_19637\ : std_logic ;
  signal \GRFPC0.N_19900\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\ : std_logic ;
  signal \GRFPC0.N_248\ : std_logic ;
  signal \GRFPC0.N_25314_1\ : std_logic ;
  signal \GRFPC0.N_25304\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25277\ : std_logic ;
  signal \GRFPC0.N_23821\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_4\ : std_logic ;
  signal \GRFPC0.WREN_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_24302\ : std_logic ;
  signal \GRFPC0.N_23870\ : std_logic ;
  signal \GRFPC0.N_207\ : std_logic ;
  signal \GRFPC0.N_23648\ : std_logic ;
  signal \GRFPC0.N_19003\ : std_logic ;
  signal \GRFPC0.N_19229\ : std_logic ;
  signal \GRFPC0.N_19000\ : std_logic ;
  signal \GRFPC0.N_19066\ : std_logic ;
  signal \GRFPC0.N_19329\ : std_logic ;
  signal \GRFPC0.N_19574\ : std_logic ;
  signal \GRFPC0.N_19051\ : std_logic ;
  signal \GRFPC0.N_18985\ : std_logic ;
  signal \GRFPC0.N_19314\ : std_logic ;
  signal \GRFPC0.N_19022\ : std_logic ;
  signal \GRFPC0.N_19088\ : std_logic ;
  signal \GRFPC0.N_19351\ : std_logic ;
  signal \GRFPC0.N_19593\ : std_logic ;
  signal \GRFPC0.N_19627\ : std_logic ;
  signal \GRFPC0.N_19659\ : std_logic ;
  signal \GRFPC0.N_19011\ : std_logic ;
  signal \GRFPC0.N_19077\ : std_logic ;
  signal \GRFPC0.N_19306\ : std_logic ;
  signal \GRFPC0.N_19340\ : std_logic ;
  signal \GRFPC0.N_19582\ : std_logic ;
  signal \GRFPC0.N_19648\ : std_logic ;
  signal \GRFPC0.N_19811\ : std_logic ;
  signal \GRFPC0.N_19911\ : std_logic ;
  signal \GRFPC0.N_23185\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP\ : std_logic ;
  signal \GRFPC0.N_18990\ : std_logic ;
  signal \GRFPC0.N_19056\ : std_logic ;
  signal \GRFPC0.N_19319\ : std_logic ;
  signal \GRFPC0.N_19004\ : std_logic ;
  signal \GRFPC0.N_19070\ : std_logic ;
  signal \GRFPC0.N_19333\ : std_logic ;
  signal \GRFPC0.N_19014\ : std_logic ;
  signal \GRFPC0.N_19080\ : std_logic ;
  signal \GRFPC0.N_19343\ : std_logic ;
  signal \GRFPC0.N_19074\ : std_logic ;
  signal \GRFPC0.N_19743\ : std_logic ;
  signal \GRFPC0.N_19808\ : std_logic ;
  signal \GRFPC0.N_19579\ : std_logic ;
  signal \GRFPC0.N_19645\ : std_logic ;
  signal \GRFPC0.N_19908\ : std_logic ;
  signal \GRFPC0.N_19570\ : std_logic ;
  signal \GRFPC0.N_19636\ : std_logic ;
  signal \GRFPC0.N_19899\ : std_logic ;
  signal \GRFPC0.N_18999\ : std_logic ;
  signal \GRFPC0.N_19065\ : std_logic ;
  signal \GRFPC0.N_19328\ : std_logic ;
  signal \GRFPC0.N_19799\ : std_logic ;
  signal \GRFPC0.N_18998\ : std_logic ;
  signal \GRFPC0.N_19064\ : std_logic ;
  signal \GRFPC0.N_19327\ : std_logic ;
  signal \GRFPC0.N_19569\ : std_logic ;
  signal \GRFPC0.N_19635\ : std_logic ;
  signal \GRFPC0.N_19898\ : std_logic ;
  signal \GRFPC0.N_19223\ : std_logic ;
  signal \GRFPC0.N_18994\ : std_logic ;
  signal \GRFPC0.N_19060\ : std_logic ;
  signal \GRFPC0.N_19323\ : std_logic ;
  signal \GRFPC0.N_19565\ : std_logic ;
  signal \GRFPC0.N_19631\ : std_logic ;
  signal \GRFPC0.N_19894\ : std_logic ;
  signal \GRFPC0.N_18993\ : std_logic ;
  signal \GRFPC0.N_19059\ : std_logic ;
  signal \GRFPC0.N_19322\ : std_logic ;
  signal \GRFPC0.N_18987\ : std_logic ;
  signal \GRFPC0.N_19053\ : std_logic ;
  signal \GRFPC0.N_19316\ : std_logic ;
  signal \GRFPC0.N_19576\ : std_logic ;
  signal \GRFPC0.N_19642\ : std_logic ;
  signal \GRFPC0.N_19905\ : std_logic ;
  signal \GRFPC0.N_23994\ : std_logic ;
  signal \GRFPC0.N_19303\ : std_logic ;
  signal \GRFPC0.N_19172\ : std_logic ;
  signal \GRFPC0.N_19237\ : std_logic ;
  signal \GRFPC0.N_19589\ : std_logic ;
  signal \GRFPC0.N_19655\ : std_logic ;
  signal \GRFPC0.N_19918\ : std_logic ;
  signal \GRFPC0.N_19299\ : std_logic ;
  signal \GRFPC0.N_19168\ : std_logic ;
  signal \GRFPC0.N_19233\ : std_logic ;
  signal \GRFPC0.N_19739\ : std_logic ;
  signal \GRFPC0.N_19870\ : std_logic ;
  signal \GRFPC0.N_19804\ : std_logic ;
  signal \GRFPC0.N_19364\ : std_logic ;
  signal \GRFPC0.N_19069\ : std_logic ;
  signal \GRFPC0.N_19332\ : std_logic ;
  signal \GRFPC0.N_19035\ : std_logic ;
  signal \GRFPC0.N_19101\ : std_logic ;
  signal \GRFPC0.N_19869\ : std_logic ;
  signal \GRFPC0.N_19738\ : std_logic ;
  signal \GRFPC0.N_19803\ : std_logic ;
  signal \GRFPC0.N_19297\ : std_logic ;
  signal \GRFPC0.N_19166\ : std_logic ;
  signal \GRFPC0.N_19231\ : std_logic ;
  signal \GRFPC0.N_19868\ : std_logic ;
  signal \GRFPC0.N_19802\ : std_logic ;
  signal \GRFPC0.N_19362\ : std_logic ;
  signal \GRFPC0.N_19033\ : std_logic ;
  signal \GRFPC0.N_19099\ : std_logic ;
  signal \GRFPC0.N_19604\ : std_logic ;
  signal \GRFPC0.N_19670\ : std_logic ;
  signal \GRFPC0.N_19933\ : std_logic ;
  signal \GRFPC0.N_19360\ : std_logic ;
  signal \GRFPC0.N_19157\ : std_logic ;
  signal \GRFPC0.N_19222\ : std_logic ;
  signal \GRFPC0.N_19288\ : std_logic ;
  signal \GRFPC0.N_19031\ : std_logic ;
  signal \GRFPC0.N_19097\ : std_logic ;
  signal \GRFPC0.N_19734\ : std_logic ;
  signal \GRFPC0.N_19865\ : std_logic ;
  signal \GRFPC0.N_19359\ : std_logic ;
  signal \GRFPC0.N_19030\ : std_logic ;
  signal \GRFPC0.N_19096\ : std_logic ;
  signal \GRFPC0.N_19601\ : std_logic ;
  signal \GRFPC0.N_19667\ : std_logic ;
  signal \GRFPC0.N_19930\ : std_logic ;
  signal \GRFPC0.N_19358\ : std_logic ;
  signal \GRFPC0.N_19029\ : std_logic ;
  signal \GRFPC0.N_19095\ : std_logic ;
  signal \GRFPC0.N_19732\ : std_logic ;
  signal \GRFPC0.N_19797\ : std_logic ;
  signal \GRFPC0.N_19863\ : std_logic ;
  signal \GRFPC0.N_19356\ : std_logic ;
  signal \GRFPC0.N_19027\ : std_logic ;
  signal \GRFPC0.N_19093\ : std_logic ;
  signal \GRFPC0.N_19598\ : std_logic ;
  signal \GRFPC0.N_19664\ : std_logic ;
  signal \GRFPC0.N_19927\ : std_logic ;
  signal \GRFPC0.N_19349\ : std_logic ;
  signal \GRFPC0.N_19020\ : std_logic ;
  signal \GRFPC0.N_19086\ : std_logic ;
  signal \GRFPC0.N_19591\ : std_logic ;
  signal \GRFPC0.N_19657\ : std_logic ;
  signal \GRFPC0.N_19920\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\ : std_logic ;
  signal \GRFPC0.N_19307\ : std_logic ;
  signal \GRFPC0.N_19241\ : std_logic ;
  signal \GRFPC0.N_19874\ : std_logic ;
  signal \GRFPC0.N_19747\ : std_logic ;
  signal \GRFPC0.N_19878\ : std_logic ;
  signal \GRFPC0.N_19812\ : std_logic ;
  signal \GRFPC0.N_19176\ : std_logic ;
  signal \GRFPC0.N_19015\ : std_logic ;
  signal \GRFPC0.N_19081\ : std_logic ;
  signal \GRFPC0.N_19344\ : std_logic ;
  signal \GRFPC0.N_19586\ : std_logic ;
  signal \GRFPC0.N_19652\ : std_logic ;
  signal \GRFPC0.N_19915\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.N_19010\ : std_logic ;
  signal \GRFPC0.N_19076\ : std_logic ;
  signal \GRFPC0.N_19339\ : std_logic ;
  signal \GRFPC0.N_19742\ : std_logic ;
  signal \GRFPC0.N_19807\ : std_logic ;
  signal \GRFPC0.N_19873\ : std_logic ;
  signal \GRFPC0.N_24006\ : std_logic ;
  signal \GRFPC0.N_18399\ : std_logic ;
  signal \GRFPC0.N_23984\ : std_logic ;
  signal \GRFPC0.N_24010\ : std_logic ;
  signal \GRFPC0.N_23993\ : std_logic ;
  signal \GRFPC0.N_23989\ : std_logic ;
  signal \GRFPC0.N_23990\ : std_logic ;
  signal \GRFPC0.N_24008\ : std_logic ;
  signal \GRFPC0.N_19002\ : std_logic ;
  signal \GRFPC0.N_19068\ : std_logic ;
  signal \GRFPC0.N_19331\ : std_logic ;
  signal \GRFPC0.N_19573\ : std_logic ;
  signal \GRFPC0.N_19639\ : std_logic ;
  signal \GRFPC0.N_19902\ : std_logic ;
  signal \GRFPC0.N_19345\ : std_logic ;
  signal \GRFPC0.N_19016\ : std_logic ;
  signal \GRFPC0.N_19082\ : std_logic ;
  signal \GRFPC0.N_19001\ : std_logic ;
  signal \GRFPC0.N_19067\ : std_logic ;
  signal \GRFPC0.N_19330\ : std_logic ;
  signal \GRFPC0.N_19572\ : std_logic ;
  signal \GRFPC0.N_19638\ : std_logic ;
  signal \GRFPC0.N_19901\ : std_logic ;
  signal \GRFPC0.N_18997\ : std_logic ;
  signal \GRFPC0.N_19568\ : std_logic ;
  signal \GRFPC0.N_19634\ : std_logic ;
  signal \GRFPC0.N_19897\ : std_logic ;
  signal \GRFPC0.N_19567\ : std_logic ;
  signal \GRFPC0.N_19633\ : std_logic ;
  signal \GRFPC0.N_19896\ : std_logic ;
  signal \GRFPC0.N_18996\ : std_logic ;
  signal \GRFPC0.N_19062\ : std_logic ;
  signal \GRFPC0.N_19325\ : std_logic ;
  signal \GRFPC0.N_18995\ : std_logic ;
  signal \GRFPC0.N_19061\ : std_logic ;
  signal \GRFPC0.N_19324\ : std_logic ;
  signal \GRFPC0.N_19566\ : std_logic ;
  signal \GRFPC0.N_19632\ : std_logic ;
  signal \GRFPC0.N_19895\ : std_logic ;
  signal \GRFPC0.N_19564\ : std_logic ;
  signal \GRFPC0.N_19630\ : std_logic ;
  signal \GRFPC0.N_19893\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPRDY_1_1\ : std_logic ;
  signal \GRFPC0.N_18992\ : std_logic ;
  signal \GRFPC0.N_19058\ : std_logic ;
  signal \GRFPC0.N_19321\ : std_logic ;
  signal \GRFPC0.N_19563\ : std_logic ;
  signal \GRFPC0.N_19629\ : std_logic ;
  signal \GRFPC0.N_19892\ : std_logic ;
  signal \GRFPC0.N_18402\ : std_logic ;
  signal \GRFPC0.N_18403\ : std_logic ;
  signal \GRFPC0.N_18410\ : std_logic ;
  signal \GRFPC0.N_18406\ : std_logic ;
  signal \GRFPC0.N_18400\ : std_logic ;
  signal \GRFPC0.N_18407\ : std_logic ;
  signal \GRFPC0.N_18991\ : std_logic ;
  signal \GRFPC0.N_19057\ : std_logic ;
  signal \GRFPC0.N_19320\ : std_logic ;
  signal \GRFPC0.N_19628\ : std_logic ;
  signal \GRFPC0.N_18408\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\ : std_logic ;
  signal \GRFPC0.N_19350\ : std_logic ;
  signal \GRFPC0.N_18989\ : std_logic ;
  signal \GRFPC0.N_19021\ : std_logic ;
  signal \GRFPC0.N_19087\ : std_logic ;
  signal \GRFPC0.N_19592\ : std_logic ;
  signal \GRFPC0.N_19658\ : std_logic ;
  signal \GRFPC0.N_19921\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20956\ : std_logic ;
  signal \GRFPC0.N_19007\ : std_logic ;
  signal \GRFPC0.N_19304\ : std_logic ;
  signal \GRFPC0.N_19173\ : std_logic ;
  signal \GRFPC0.N_19238\ : std_logic ;
  signal \GRFPC0.N_19875\ : std_logic ;
  signal \GRFPC0.N_19744\ : std_logic ;
  signal \GRFPC0.N_19809\ : std_logic ;
  signal \GRFPC0.FIFO_INC_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\ : std_logic ;
  signal N_36314 : std_logic ;
  signal \GRFPC0.VMEM.CTRL.PEND_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_207\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_73\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_87\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.MEMEN2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.STDFQ_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FIFOV2\ : std_logic ;
  signal N_50421_2 : std_logic ;
  signal \GRFPC0.N_23498\ : std_logic ;
  signal \GRFPC0.N_23486\ : std_logic ;
  signal \GRFPC0.N_23489\ : std_logic ;
  signal N_50421_11 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.ORV.TMP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2SEL4\ : std_logic ;
  signal \GRFPC0.N_201_2\ : std_logic ;
  signal \GRFPC0.N_19559\ : std_logic ;
  signal \GRFPC0.N_19625\ : std_logic ;
  signal \GRFPC0.N_19888\ : std_logic ;
  signal \GRFPC0.N_18988\ : std_logic ;
  signal \GRFPC0.N_19054\ : std_logic ;
  signal \GRFPC0.N_19317\ : std_logic ;
  signal \GRFPC0.N_21803\ : std_logic ;
  signal \GRFPC0.N_21841\ : std_logic ;
  signal \GRFPC0.N_21622\ : std_logic ;
  signal \GRFPC0.N_21620\ : std_logic ;
  signal \GRFPC0.N_21626\ : std_logic ;
  signal \GRFPC0.N_21631\ : std_logic ;
  signal \GRFPC0.N_21663\ : std_logic ;
  signal \GRFPC0.N_22985\ : std_logic ;
  signal \GRFPC0.N_17407\ : std_logic ;
  signal \GRFPC0.N_21635\ : std_logic ;
  signal \GRFPC0.N_21627\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_22180\ : std_logic ;
  signal \GRFPC0.N_25502\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_24282\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_220\ : std_logic ;
  signal \GRFPC0.N_257\ : std_logic ;
  signal \GRFPC0.N_24323\ : std_logic ;
  signal \GRFPC0.N_21917\ : std_logic ;
  signal \GRFPC0.N_22096\ : std_logic ;
  signal \GRFPC0.N_22074\ : std_logic ;
  signal \GRFPC0.N_93\ : std_logic ;
  signal \GRFPC0.N_25295_1\ : std_logic ;
  signal \GRFPC0.N_167\ : std_logic ;
  signal \GRFPC0.N_24361\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_16972\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_117_1\ : std_logic ;
  signal \GRFPC0.N_24446\ : std_logic ;
  signal \GRFPC0.N_22972_I\ : std_logic ;
  signal \GRFPC0.N_23030\ : std_logic ;
  signal \GRFPC0.N_23137\ : std_logic ;
  signal \GRFPC0.N_21404\ : std_logic ;
  signal \GRFPC0.N_21423\ : std_logic ;
  signal \GRFPC0.N_21425\ : std_logic ;
  signal \GRFPC0.N_21361_1\ : std_logic ;
  signal \GRFPC0.N_20960\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22083\ : std_logic ;
  signal \GRFPC0.N_22076\ : std_logic ;
  signal \GRFPC0.N_22113\ : std_logic ;
  signal \GRFPC0.N_20839\ : std_logic ;
  signal \GRFPC0.N_24287\ : std_logic ;
  signal \GRFPC0.N_21919\ : std_logic ;
  signal \GRFPC0.N_24285\ : std_logic ;
  signal \GRFPC0.N_20837\ : std_logic ;
  signal \GRFPC0.N_22115\ : std_logic ;
  signal \GRFPC0.N_22123\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_22075\ : std_logic ;
  signal \GRFPC0.N_21973\ : std_logic ;
  signal \GRFPC0.N_21525\ : std_logic ;
  signal \GRFPC0.N_21459\ : std_logic ;
  signal \GRFPC0.N_21891\ : std_logic ;
  signal \GRFPC0.N_21963\ : std_logic ;
  signal N_52013 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_OP\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_I0_I_1\ : std_logic ;
  signal N_50375 : std_logic ;
  signal N_50374_4 : std_logic ;
  signal N_50421_9 : std_logic ;
  signal \FPI.START_1\ : std_logic ;
  signal \GRFPC0.N_23533\ : std_logic ;
  signal \GRFPC0.N_290\ : std_logic ;
  signal \GRFPC0.CCWR_0_SQMUXA_2_0\ : std_logic ;
  signal N_49468_I : std_logic ;
  signal N_50504_3 : std_logic ;
  signal N_50504_4 : std_logic ;
  signal \GRFPC0.N_24181\ : std_logic ;
  signal \GRFPC0.N_25505_2\ : std_logic ;
  signal \GRFPC0.N_24128\ : std_logic ;
  signal N_51164 : std_logic ;
  signal N_52049 : std_logic ;
  signal N_52157 : std_logic ;
  signal \GRFPC0.N_24358\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\ : std_logic ;
  signal N_52879 : std_logic ;
  signal N_52831 : std_logic ;
  signal N_52880_2 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\ : std_logic ;
  signal \GRFPC0.N_18409\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_N_4\ : std_logic ;
  signal N_52981 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16176\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16178\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16180\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16184\ : std_logic ;
  signal N_51871 : std_logic ;
  signal N_51799 : std_logic ;
  signal N_52708 : std_logic ;
  signal N_52706 : std_logic ;
  signal N_52672 : std_logic ;
  signal N_52670 : std_logic ;
  signal N_52636 : std_logic ;
  signal N_52634 : std_logic ;
  signal N_52598 : std_logic ;
  signal N_52528 : std_logic ;
  signal N_52490 : std_logic ;
  signal N_52312 : std_logic ;
  signal N_52204 : std_logic ;
  signal N_52168 : std_logic ;
  signal N_52132 : std_logic ;
  signal N_52096 : std_logic ;
  signal N_51988 : std_logic ;
  signal N_51916 : std_logic ;
  signal N_51844 : std_logic ;
  signal \GRFPC0.N_25259\ : std_logic ;
  signal \GRFPC0.N_24272\ : std_logic ;
  signal \GRFPC0.N_24289\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_A2_2_4__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_388\ : std_logic ;
  signal \GRFPC0.N_19877\ : std_logic ;
  signal \GRFPC0.N_23948\ : std_logic ;
  signal \GRFPC0.N_23953\ : std_logic ;
  signal \GRFPC0.N_19155\ : std_logic ;
  signal \GRFPC0.N_19220\ : std_logic ;
  signal \GRFPC0.N_19286\ : std_logic ;
  signal \GRFPC0.N_19904\ : std_logic ;
  signal \GRFPC0.N_19641\ : std_logic ;
  signal \GRFPC0.N_19575\ : std_logic ;
  signal \GRFPC0.N_24011\ : std_logic ;
  signal \GRFPC0.N_24003\ : std_logic ;
  signal \GRFPC0.N_19909\ : std_logic ;
  signal \GRFPC0.N_19646\ : std_logic ;
  signal \GRFPC0.N_19580\ : std_logic ;
  signal \GRFPC0.N_19851\ : std_logic ;
  signal \GRFPC0.N_19720\ : std_logic ;
  signal \GRFPC0.N_19785\ : std_logic ;
  signal \GRFPC0.N_19919\ : std_logic ;
  signal \GRFPC0.N_19656\ : std_logic ;
  signal \GRFPC0.N_19590\ : std_logic ;
  signal \GRFPC0.N_19282\ : std_logic ;
  signal \GRFPC0.N_19923\ : std_logic ;
  signal \GRFPC0.N_19660\ : std_logic ;
  signal \GRFPC0.N_19594\ : std_logic ;
  signal \GRFPC0.N_19926\ : std_logic ;
  signal \GRFPC0.N_19663\ : std_logic ;
  signal \GRFPC0.N_19597\ : std_logic ;
  signal \GRFPC0.N_19862\ : std_logic ;
  signal \GRFPC0.N_19731\ : std_logic ;
  signal \GRFPC0.N_19796\ : std_logic ;
  signal \GRFPC0.N_19866\ : std_logic ;
  signal \GRFPC0.N_19735\ : std_logic ;
  signal \GRFPC0.N_19800\ : std_logic ;
  signal \GRFPC0.N_19164\ : std_logic ;
  signal \GRFPC0.N_19295\ : std_logic ;
  signal \GRFPC0.N_19916\ : std_logic ;
  signal \GRFPC0.N_19653\ : std_logic ;
  signal \GRFPC0.N_19587\ : std_logic ;
  signal \GRFPC0.N_19149\ : std_logic ;
  signal \GRFPC0.N_19214\ : std_logic ;
  signal \GRFPC0.N_19280\ : std_logic ;
  signal \GRFPC0.N_19887\ : std_logic ;
  signal \GRFPC0.N_19624\ : std_logic ;
  signal \GRFPC0.N_19558\ : std_logic ;
  signal \GRFPC0.N_19924\ : std_logic ;
  signal \GRFPC0.N_19661\ : std_logic ;
  signal \GRFPC0.N_19595\ : std_logic ;
  signal \GRFPC0.N_19925\ : std_logic ;
  signal \GRFPC0.N_19662\ : std_logic ;
  signal \GRFPC0.N_19596\ : std_logic ;
  signal \GRFPC0.N_19903\ : std_logic ;
  signal \GRFPC0.N_19640\ : std_logic ;
  signal \GRFPC0.N_23950\ : std_logic ;
  signal \GRFPC0.N_23954\ : std_logic ;
  signal \GRFPC0.N_23917\ : std_logic ;
  signal \GRFPC0.N_23916\ : std_logic ;
  signal \GRFPC0.N_23925\ : std_logic ;
  signal \GRFPC0.N_23924\ : std_logic ;
  signal \GRFPC0.N_19883\ : std_logic ;
  signal \GRFPC0.N_19620\ : std_logic ;
  signal \GRFPC0.N_19554\ : std_logic ;
  signal \GRFPC0.N_19150\ : std_logic ;
  signal \GRFPC0.N_19215\ : std_logic ;
  signal \GRFPC0.N_19281\ : std_logic ;
  signal \GRFPC0.N_19315\ : std_logic ;
  signal \GRFPC0.N_19052\ : std_logic ;
  signal \GRFPC0.N_18986\ : std_logic ;
  signal \GRFPC0.N_11185\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_1\ : std_logic ;
  signal \GRFPC0.N_19886\ : std_logic ;
  signal \GRFPC0.N_19623\ : std_logic ;
  signal \GRFPC0.N_19557\ : std_logic ;
  signal \GRFPC0.N_19158\ : std_logic ;
  signal \GRFPC0.N_19289\ : std_logic ;
  signal \GRFPC0.N_19907\ : std_logic ;
  signal \GRFPC0.N_19644\ : std_logic ;
  signal \GRFPC0.N_19578\ : std_logic ;
  signal \GRFPC0.N_19338\ : std_logic ;
  signal \GRFPC0.N_19075\ : std_logic ;
  signal \GRFPC0.N_19009\ : std_logic ;
  signal \GRFPC0.N_19175\ : std_logic ;
  signal \GRFPC0.N_19240\ : std_logic ;
  signal \GRFPC0.N_23929\ : std_logic ;
  signal \GRFPC0.N_23928\ : std_logic ;
  signal \GRFPC0.N_19880\ : std_logic ;
  signal \GRFPC0.N_19749\ : std_logic ;
  signal \GRFPC0.N_19814\ : std_logic ;
  signal \GRFPC0.N_19178\ : std_logic ;
  signal \GRFPC0.N_19243\ : std_logic ;
  signal \GRFPC0.N_19309\ : std_logic ;
  signal \GRFPC0.N_19312\ : std_logic ;
  signal \GRFPC0.N_19049\ : std_logic ;
  signal \GRFPC0.N_18983\ : std_logic ;
  signal \GRFPC0.N_19313\ : std_logic ;
  signal \GRFPC0.N_18984\ : std_logic ;
  signal \GRFPC0.N_19151\ : std_logic ;
  signal \GRFPC0.N_19216\ : std_logic ;
  signal \GRFPC0.N_19922\ : std_logic ;
  signal \GRFPC0.N_19890\ : std_logic ;
  signal \GRFPC0.N_19561\ : std_logic ;
  signal \GRFPC0.N_19891\ : std_logic ;
  signal \GRFPC0.N_19562\ : std_logic ;
  signal \GRFPC0.N_19156\ : std_logic ;
  signal \GRFPC0.N_19221\ : std_logic ;
  signal \GRFPC0.N_19287\ : std_logic ;
  signal \GRFPC0.N_19160\ : std_logic ;
  signal \GRFPC0.N_19225\ : std_logic ;
  signal \GRFPC0.N_19291\ : std_logic ;
  signal \GRFPC0.N_19326\ : std_logic ;
  signal \GRFPC0.N_19063\ : std_logic ;
  signal \GRFPC0.N_19336\ : std_logic ;
  signal \GRFPC0.N_19174\ : std_logic ;
  signal \GRFPC0.N_19239\ : std_logic ;
  signal \GRFPC0.N_19305\ : std_logic ;
  signal \GRFPC0.N_19746\ : std_logic ;
  signal \GRFPC0.N_19341\ : std_logic ;
  signal \GRFPC0.N_19078\ : std_logic ;
  signal \GRFPC0.N_19012\ : std_logic ;
  signal \GRFPC0.N_19073\ : std_logic ;
  signal \GRFPC0.N_19337\ : std_logic ;
  signal \GRFPC0.N_19008\ : std_logic ;
  signal \GRFPC0.N_23913\ : std_logic ;
  signal \GRFPC0.N_23932\ : std_logic ;
  signal \GRFPC0.N_23923\ : std_logic ;
  signal \GRFPC0.N_23922\ : std_logic ;
  signal \GRFPC0.N_19885\ : std_logic ;
  signal \GRFPC0.N_19622\ : std_logic ;
  signal \GRFPC0.N_19556\ : std_logic ;
  signal \GRFPC0.N_19318\ : std_logic ;
  signal \GRFPC0.N_19055\ : std_logic ;
  signal \GRFPC0.N_19912\ : std_logic ;
  signal \GRFPC0.N_19649\ : std_logic ;
  signal \GRFPC0.N_19583\ : std_logic ;
  signal \GRFPC0.N_19914\ : std_logic ;
  signal \GRFPC0.N_19651\ : std_logic ;
  signal \GRFPC0.N_19585\ : std_logic ;
  signal \GRFPC0.N_19516\ : std_logic ;
  signal \GRFPC0.N_19515\ : std_logic ;
  signal \GRFPC0.N_23511\ : std_logic ;
  signal \GRFPC0.N_23514\ : std_logic ;
  signal \GRFPC0.N_19501\ : std_logic ;
  signal \GRFPC0.N_23506\ : std_logic ;
  signal \GRFPC0.N_23508\ : std_logic ;
  signal \GRFPC0.N_23500\ : std_logic ;
  signal \GRFPC0.N_23503\ : std_logic ;
  signal \GRFPC0.N_184\ : std_logic ;
  signal \GRFPC0.N_23518\ : std_logic ;
  signal \GRFPC0.N_23515\ : std_logic ;
  signal \GRFPC0.N_23516\ : std_logic ;
  signal \GRFPC0.N_23493\ : std_logic ;
  signal \GRFPC0.N_23496\ : std_logic ;
  signal \GRFPC0.N_24\ : std_logic ;
  signal \GRFPC0.N_23607\ : std_logic ;
  signal \GRFPC0.N_23602\ : std_logic ;
  signal \GRFPC0.N_23605\ : std_logic ;
  signal \GRFPC0.N_23595\ : std_logic ;
  signal \GRFPC0.N_23598\ : std_logic ;
  signal \GRFPC0.N_22020\ : std_logic ;
  signal \GRFPC0.N_22027\ : std_logic ;
  signal \GRFPC0.N_22026\ : std_logic ;
  signal \GRFPC0.N_22017\ : std_logic ;
  signal \GRFPC0.N_22018\ : std_logic ;
  signal \GRFPC0.N_16962\ : std_logic ;
  signal \GRFPC0.N_16968\ : std_logic ;
  signal \GRFPC0.N_16974\ : std_logic ;
  signal \GRFPC0.N_16954\ : std_logic ;
  signal \GRFPC0.N_16956\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G3\ : std_logic ;
  signal \GRFPC0.N_24402\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.STATE_14_SQMUXA\ : std_logic ;
  signal N_52769 : std_logic ;
  signal N_52517 : std_logic ;
  signal N_52409 : std_logic ;
  signal N_52301 : std_logic ;
  signal N_52265 : std_logic ;
  signal N_52121 : std_logic ;
  signal N_52085 : std_logic ;
  signal N_51977 : std_logic ;
  signal N_51905 : std_logic ;
  signal N_51869 : std_logic ;
  signal N_51833 : std_logic ;
  signal N_51690 : std_logic ;
  signal N_51628 : std_logic ;
  signal N_51594 : std_logic ;
  signal N_51526 : std_logic ;
  signal N_51266 : std_logic ;
  signal N_51198 : std_logic ;
  signal N_51130 : std_logic ;
  signal N_51028 : std_logic ;
  signal N_50858 : std_logic ;
  signal N_50688 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_2_4__N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\ : std_logic ;
  signal \GRFPC0.N_23392\ : std_logic ;
  signal \GRFPC0.N_23387\ : std_logic ;
  signal \GRFPC0.N_24376\ : std_logic ;
  signal \GRFPC0.N_24958\ : std_logic ;
  signal \GRFPC0.N_23803\ : std_logic ;
  signal \GRFPC0.N_25824\ : std_logic ;
  signal \GRFPC0.N_25763\ : std_logic ;
  signal \GRFPC0.N_25823\ : std_logic ;
  signal \GRFPC0.N_21205\ : std_logic ;
  signal \GRFPC0.N_21176\ : std_logic ;
  signal \GRFPC0.N_25163\ : std_logic ;
  signal \GRFPC0.N_25289\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25290\ : std_logic ;
  signal \GRFPC0.N_25448\ : std_logic ;
  signal \GRFPC0.N_25360\ : std_logic ;
  signal \GRFPC0.N_25350\ : std_logic ;
  signal \GRFPC0.N_25443\ : std_logic ;
  signal \GRFPC0.N_25059\ : std_logic ;
  signal \GRFPC0.N_25445\ : std_logic ;
  signal \GRFPC0.N_24123\ : std_logic ;
  signal \GRFPC0.N_23639\ : std_logic ;
  signal \GRFPC0.N_23617\ : std_logic ;
  signal \GRFPC0.N_24715\ : std_logic ;
  signal \GRFPC0.N_25546\ : std_logic ;
  signal \GRFPC0.N_24959\ : std_logic ;
  signal \GRFPC0.N_24843\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24016\ : std_logic ;
  signal \GRFPC0.N_24135\ : std_logic ;
  signal \GRFPC0.N_23865\ : std_logic ;
  signal \GRFPC0.N_25330\ : std_logic ;
  signal \GRFPC0.N_21523\ : std_logic ;
  signal \GRFPC0.N_24413\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20316\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_307\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_327\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20304\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20299\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20953\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21005\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_388_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_333\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20294\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_343_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN5_SHARE\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_SHARE\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25306\ : std_logic ;
  signal \GRFPC0.N_25618\ : std_logic ;
  signal \GRFPC0.N_22332\ : std_logic ;
  signal \GRFPC0.N_22373\ : std_logic ;
  signal \GRFPC0.N_22372\ : std_logic ;
  signal \GRFPC0.N_22463\ : std_logic ;
  signal \GRFPC0.N_22461\ : std_logic ;
  signal \GRFPC0.N_24348\ : std_logic ;
  signal \GRFPC0.N_24356\ : std_logic ;
  signal \GRFPC0.N_24363\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V8_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V6\ : std_logic ;
  signal \GRFPC0.N_24438\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_8_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_196\ : std_logic ;
  signal \GRFPC0.N_23479\ : std_logic ;
  signal \GRFPC0.N_23482\ : std_logic ;
  signal \GRFPC0.N_198\ : std_logic ;
  signal \GRFPC0.N_25303_1\ : std_logic ;
  signal \GRFPC0.N_25328\ : std_logic ;
  signal \GRFPC0.N_23811_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24602\ : std_logic ;
  signal \GRFPC0.N_25184\ : std_logic ;
  signal \GRFPC0.N_25777\ : std_logic ;
  signal \GRFPC0.N_24601\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\ : std_logic ;
  signal \GRFPC0.N_24926\ : std_logic ;
  signal \GRFPC0.N_25808_2\ : std_logic ;
  signal \GRFPC0.N_23621\ : std_logic ;
  signal \GRFPC0.N_23758\ : std_logic ;
  signal \GRFPC0.N_25128\ : std_logic ;
  signal \GRFPC0.N_25519\ : std_logic ;
  signal \GRFPC0.N_25127\ : std_logic ;
  signal \GRFPC0.N_24822\ : std_logic ;
  signal \GRFPC0.N_24850\ : std_logic ;
  signal \GRFPC0.N_25566\ : std_logic ;
  signal \GRFPC0.N_24823\ : std_logic ;
  signal \GRFPC0.N_24719\ : std_logic ;
  signal \GRFPC0.N_25819\ : std_logic ;
  signal \GRFPC0.N_237\ : std_logic ;
  signal \GRFPC0.N_24533\ : std_logic ;
  signal \GRFPC0.N_24703\ : std_logic ;
  signal \GRFPC0.N_24706\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23643\ : std_logic ;
  signal \GRFPC0.N_23816_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_23746\ : std_logic ;
  signal \GRFPC0.N_218\ : std_logic ;
  signal \GRFPC0.N_23748\ : std_logic ;
  signal \GRFPC0.N_23745\ : std_logic ;
  signal \GRFPC0.N_24807\ : std_logic ;
  signal \GRFPC0.N_24837\ : std_logic ;
  signal \GRFPC0.N_25028\ : std_logic ;
  signal \GRFPC0.N_25029\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25326\ : std_logic ;
  signal \GRFPC0.N_25446\ : std_logic ;
  signal \GRFPC0.N_25276\ : std_logic ;
  signal \GRFPC0.N_21204\ : std_logic ;
  signal \GRFPC0.N_22100\ : std_logic ;
  signal \GRFPC0.N_22575\ : std_logic ;
  signal \GRFPC0.N_24664\ : std_logic ;
  signal \GRFPC0.N_25540\ : std_logic ;
  signal \GRFPC0.N_25787\ : std_logic ;
  signal \GRFPC0.N_25811\ : std_logic ;
  signal \GRFPC0.N_25816\ : std_logic ;
  signal \GRFPC0.N_21832\ : std_logic ;
  signal \GRFPC0.N_23414\ : std_logic ;
  signal \GRFPC0.N_227\ : std_logic ;
  signal \GRFPC0.N_25365\ : std_logic ;
  signal \GRFPC0.N_24297\ : std_logic ;
  signal \GRFPC0.N_24845\ : std_logic ;
  signal \GRFPC0.N_24848\ : std_logic ;
  signal \GRFPC0.N_24957\ : std_logic ;
  signal \GRFPC0.N_25156_2\ : std_logic ;
  signal \GRFPC0.N_24767\ : std_logic ;
  signal \GRFPC0.N_25177\ : std_logic ;
  signal \GRFPC0.N_25412\ : std_logic ;
  signal \GRFPC0.N_25715\ : std_logic ;
  signal \GRFPC0.N_24364\ : std_logic ;
  signal \GRFPC0.N_22472\ : std_logic ;
  signal \GRFPC0.N_22470\ : std_logic ;
  signal \GRFPC0.N_22468\ : std_logic ;
  signal \GRFPC0.N_22467\ : std_logic ;
  signal \GRFPC0.N_22829\ : std_logic ;
  signal \GRFPC0.N_23756\ : std_logic ;
  signal \GRFPC0.N_23754\ : std_logic ;
  signal \GRFPC0.N_23761\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP104\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_11_7\ : std_logic ;
  signal \GRFPC0.N_22253\ : std_logic ;
  signal \GRFPC0.N_25835_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3903_REGDEPX2\ : std_logic ;
  signal N_36329 : std_logic ;
  signal N_36324 : std_logic ;
  signal N_36319 : std_logic ;
  signal N_36259 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19778_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_380\ : std_logic ;
  signal \GRFPC0.N_24347\ : std_logic ;
  signal \GRFPC0.N_22082\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24444\ : std_logic ;
  signal \GRFPC0.N_252\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN416_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23612\ : std_logic ;
  signal \GRFPC0.N_25161\ : std_logic ;
  signal \GRFPC0.N_23735\ : std_logic ;
  signal \GRFPC0.N_24897\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24761\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN317_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_PENDEXC_2\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP119\ : std_logic ;
  signal N_100078 : std_logic ;
  signal N_100153 : std_logic ;
  signal N_100260 : std_logic ;
  signal N_100290 : std_logic ;
  signal N_100325 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15295\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_TZ_TZ\ : std_logic ;
  signal N_100066_TZ : std_logic ;
  signal N_100069_TZ : std_logic ;
  signal N_100071_TZ : std_logic ;
  signal N_100074_TZ : std_logic ;
  signal N_100296_TZ : std_logic ;
  signal N_100346_TZ : std_logic ;
  signal N_100350_TZ : std_logic ;
  signal N_100355_TZ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_2_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_3_TZ\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_3_TZ\ : std_logic ;
  signal \GRFPC0.N_24997_TZ_TZ\ : std_logic ;
  signal \GRFPC0.N_25259_TZ_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270TT_1_N_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_N_11\ : std_logic ;
  signal N_4 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G0_0_1\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19243_2\ : std_logic ;
  signal N_108254 : std_logic ;
  signal N_108255 : std_logic ;
  signal N_108257 : std_logic ;
  signal N_108258 : std_logic ;
  signal N_108260 : std_logic ;
  signal N_108261 : std_logic ;
  signal N_108265 : std_logic ;
  signal N_108266 : std_logic ;
  signal N_108267 : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_5_TZ\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19491\ : std_logic ;
  signal \GRFPC0.N_25338\ : std_logic ;
  signal \GRFPC0.N_25553\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_21703_2\ : std_logic ;
  signal \GRFPC0.N_260\ : std_logic ;
  signal \GRFPC0.N_25438_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3806\ : std_logic ;
  signal \GRFPC0.N_25565\ : std_logic ;
  signal \GRFPC0.N_23813_1\ : std_logic ;
  signal \GRFPC0.N_25834\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6453\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3846\ : std_logic ;
  signal \GRFPC0.N_185_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3506\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3526\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3496\ : std_logic ;
  signal \GRFPC0.N_25264_I\ : std_logic ;
  signal \GRFPC0.N_24030_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6659\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3356\ : std_logic ;
  signal \GRFPC0.N_25648_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_672_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ADDI3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3226\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_0\ : std_logic ;
  signal \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_7_7_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_1__G0_3_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_1__G0_0\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_1__G0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62_0\ : std_logic ;
  signal \GRFPC0.N_22486_1\ : std_logic ;
  signal \GRFPC0.N_22485_1\ : std_logic ;
  signal N_122890 : std_logic ;
  signal N_122891 : std_logic ;
  signal N_122892 : std_logic ;
  signal N_122893 : std_logic ;
  signal N_122894 : std_logic ;
  signal N_122895 : std_logic ;
  signal N_122902 : std_logic ;
  signal N_122903 : std_logic ;
  signal N_122904 : std_logic ;
  signal N_122905 : std_logic ;
  signal N_122908 : std_logic ;
  signal N_122909 : std_logic ;
  signal N_122916 : std_logic ;
  signal N_122917 : std_logic ;
  signal N_122918 : std_logic ;
  signal N_122919 : std_logic ;
  signal N_122920 : std_logic ;
  signal N_122921 : std_logic ;
  signal N_122922 : std_logic ;
  signal N_122923 : std_logic ;
  signal N_122924 : std_logic ;
  signal N_122925 : std_logic ;
  signal N_122928 : std_logic ;
  signal N_122934 : std_logic ;
  signal N_122935 : std_logic ;
  signal N_122945 : std_logic ;
  signal N_122946 : std_logic ;
  signal N_122957 : std_logic ;
  signal N_122958 : std_logic ;
  signal N_122964 : std_logic ;
  signal N_122965 : std_logic ;
  signal N_122973 : std_logic ;
  signal N_122974 : std_logic ;
  signal N_122979 : std_logic ;
  signal N_122980 : std_logic ;
  signal N_122985 : std_logic ;
  signal N_122986 : std_logic ;
  signal N_122992 : std_logic ;
  signal N_122993 : std_logic ;
  signal N_123002 : std_logic ;
  signal N_123003 : std_logic ;
  signal N_123012 : std_logic ;
  signal N_123013 : std_logic ;
  signal N_123022 : std_logic ;
  signal N_123023 : std_logic ;
  signal N_123031 : std_logic ;
  signal N_123032 : std_logic ;
  signal N_123283 : std_logic ;
  signal N_123284 : std_logic ;
  signal N_123286 : std_logic ;
  signal N_123287 : std_logic ;
  signal N_123290 : std_logic ;
  signal N_123366 : std_logic ;
  signal N_123417 : std_logic ;
  signal N_123418 : std_logic ;
  signal N_123422 : std_logic ;
  signal N_123423 : std_logic ;
  signal N_123426 : std_logic ;
  signal N_123427 : std_logic ;
  signal N_123430 : std_logic ;
  signal N_123431 : std_logic ;
  signal N_123434 : std_logic ;
  signal N_123435 : std_logic ;
  signal N_123438 : std_logic ;
  signal N_123439 : std_logic ;
  signal N_123442 : std_logic ;
  signal N_123443 : std_logic ;
  signal N_123446 : std_logic ;
  signal N_123447 : std_logic ;
  signal N_123450 : std_logic ;
  signal N_123451 : std_logic ;
  signal N_123454 : std_logic ;
  signal N_123455 : std_logic ;
  signal N_123458 : std_logic ;
  signal N_123459 : std_logic ;
  signal N_123462 : std_logic ;
  signal N_123463 : std_logic ;
  signal N_123465 : std_logic ;
  signal N_123526 : std_logic ;
  signal N_123527 : std_logic ;
  signal N_123528 : std_logic ;
  signal N_123529 : std_logic ;
  signal N_123530 : std_logic ;
  signal N_123531 : std_logic ;
  signal N_123532 : std_logic ;
  signal N_123533 : std_logic ;
  signal N_123534 : std_logic ;
  signal N_123535 : std_logic ;
  signal N_123536 : std_logic ;
  signal N_123537 : std_logic ;
  signal N_123538 : std_logic ;
  signal N_123539 : std_logic ;
  signal N_123540 : std_logic ;
  signal N_123541 : std_logic ;
  signal N_123542 : std_logic ;
  signal N_123543 : std_logic ;
  signal N_123544 : std_logic ;
  signal N_123545 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19510_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMAX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4045\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\ : std_logic ;
  signal N_50149 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN105_HOLDN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.CNTX14\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\ : std_logic ;
  signal N_50233 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_231\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19777\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\ : std_logic ;
  signal \GRFPC0.DIV.EXC_1_0_G0_I\ : std_logic ;
  signal \GRFPC0.N_23290_I\ : std_logic ;
  signal \GRFPC0.N_22192_I\ : std_logic ;
  signal \GRFPU0.SQRTROM0.DATA_1_6_0_.N_60_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19607_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19596_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19595_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19594_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19593_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19592_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19586_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_N_4_0_I\ : std_logic ;
  signal N_124803 : std_logic ;
  signal N_124806 : std_logic ;
  signal N_124807 : std_logic ;
  signal N_124815 : std_logic ;
  signal N_124816 : std_logic ;
  signal N_124817 : std_logic ;
  signal N_124818 : std_logic ;
  signal N_124819 : std_logic ;
  signal N_124820 : std_logic ;
  signal N_124821 : std_logic ;
  signal N_124823 : std_logic ;
  signal N_124825 : std_logic ;
  signal N_124826 : std_logic ;
  signal N_124828 : std_logic ;
  signal N_124829 : std_logic ;
  signal N_124830 : std_logic ;
  signal N_124836 : std_logic ;
  signal N_124837 : std_logic ;
  signal N_124838 : std_logic ;
  signal N_124841 : std_logic ;
  signal N_124842 : std_logic ;
  signal N_124845 : std_logic ;
  signal N_124846 : std_logic ;
  signal N_124847 : std_logic ;
  signal N_124850 : std_logic ;
  signal N_124852 : std_logic ;
  signal N_124860 : std_logic ;
  signal N_124864 : std_logic ;
  signal N_124865 : std_logic ;
  signal N_124866 : std_logic ;
  signal N_124867 : std_logic ;
  signal N_124868 : std_logic ;
  signal N_124869 : std_logic ;
  signal N_124870 : std_logic ;
  signal N_124871 : std_logic ;
  signal N_124872 : std_logic ;
  signal N_124873 : std_logic ;
  signal N_124875 : std_logic ;
  signal N_124878 : std_logic ;
  signal N_124879 : std_logic ;
  signal N_124882 : std_logic ;
  signal N_124885 : std_logic ;
  signal N_124886 : std_logic ;
  signal N_124889 : std_logic ;
  signal N_124890 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20910_I\ : std_logic ;
  signal N_124895 : std_logic ;
  signal N_124896 : std_logic ;
  signal N_124901 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16749_I\ : std_logic ;
  signal N_124905 : std_logic ;
  signal N_124907 : std_logic ;
  signal N_125011 : std_logic ;
  signal N_125070 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6659_TZ\ : std_logic ;
  signal N_138072 : std_logic ;
  signal N_138073 : std_logic ;
  signal N_138075 : std_logic ;
  signal N_138076 : std_logic ;
  signal N_138078 : std_logic ;
  signal N_138079 : std_logic ;
  signal N_138080 : std_logic ;
  signal N_138081 : std_logic ;
  signal N_138094 : std_logic ;
  signal N_138095 : std_logic ;
  signal N_138110 : std_logic ;
  signal N_138111 : std_logic ;
  signal N_138114 : std_logic ;
  signal N_138115 : std_logic ;
  signal N_138118 : std_logic ;
  signal N_138119 : std_logic ;
  signal N_138122 : std_logic ;
  signal N_138123 : std_logic ;
  signal N_138130 : std_logic ;
  signal N_138131 : std_logic ;
  signal N_138138 : std_logic ;
  signal N_138139 : std_logic ;
  signal N_138140 : std_logic ;
  signal N_138141 : std_logic ;
  signal N_138142 : std_logic ;
  signal N_138220 : std_logic ;
  signal N_138228 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_169_1\ : std_logic ;
  signal \GRFPC0.WREN_2_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST7_0\ : std_logic ;
  signal \GRFPC0.N_22942_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_O3_I_A2_I_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_0_A4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19432\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_O2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_3_I_O5_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_31_I_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES4_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG16_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG16_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G1_E_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_25\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_5_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_0_SQMUXA_S1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_A4_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0_O4_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_BCO_LSB_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN43_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN43_BCO_LSB_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.BIAS15_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3826\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_3\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_OP_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN14_OP_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN17_OP_7_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_1_2\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17757_M_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17757_M_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_21\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_32__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_32__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_62__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_62__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_39__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_39__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_42__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_42__G3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_O2_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_106_I_I_A2_0_A4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1\ : std_logic ;
  signal \GRFPC0.INST_1387_I_O3_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_SEL1_0_A3_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_6414_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1934_I_A5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_A2_0_G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_10__G1_0_4697_I_O4_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G0_0_A4_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_A5_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.SEL6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_2\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_4_M7_3\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_4_M7_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_3\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_4\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_5\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_O2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_1\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_G0_0_A3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_8_4_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_2_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_I_I_0_0__G0_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_0_1__G0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5_0_2\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_A4_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_2_5877_I_A4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A3_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_A2_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.STDEP178_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_19\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_5\ : std_logic ;
  signal \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_7\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_6\ : std_logic ;
  signal \GRFPC0.DIV.PEND_1_0_G0_I_O4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__G2_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_3\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_2497_A2_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1_3\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3_0_0\ : std_logic ;
  signal \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_2__G1_0_4289_I_A4_1_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_30__G1_0_5717_I_A4_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_0_18__G0_0_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_9\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_11\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_12\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_0_15\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_7\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_11\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0_14\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V6_0\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_3\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_4\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_3\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP146_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP104_0\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_2475_A2_1\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_2421_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_66_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1_4\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_1__G0_3_0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82_2\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_30\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1_3\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_1\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF_0\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_2289_A2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_17__G3_0_1575_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_18__G3_0_1601_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_7__G3_0_1445_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_39__G3_0_1757_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_42__G3_0_1783_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_22__G3_0_1627_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_27__G3_0_1679_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_44__G3_0_1835_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_47__G3_0_1887_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_15__G3_0_1523_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_16__G3_0_1549_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_31__G3_0_1705_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_25__G3_0_1653_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_14__G3_0_1497_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_2\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_1__G4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_68_I_0_G0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_1__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_1__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_5__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_5__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_3__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_3__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_2__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_2__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_4__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_4__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0__G0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1_U_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ALLOW_0_1__G0_1_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_33__G3_0_1731_I_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1_6\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP172_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP172_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_168_0_A2_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_2\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_3\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_7\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_8\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_11\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_12\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_14\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_133_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_3_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP2_I_M_0_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_8_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_8_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_6_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A2_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_3_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_6\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP90_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP90_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_I_S_4_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_1\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP47_1\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP47_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_6\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.MEMEN2_0_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_6\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_8\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_2\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_0\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP_0_0_G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\ : std_logic ;
  signal \GRFPC0.N_25458\ : std_logic ;
  signal N_174581 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19600_I_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\ : std_logic ;
  signal N_52981_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19713\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20287\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19431\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10716\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\ : std_logic ;
  signal N_52020 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_80\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\ : std_logic ;
  signal \GRFPC0.V.STDATA_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21425_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21434_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19903_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21424_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21433_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21438_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21423_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_67_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21437_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21426_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21432_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21436_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21429_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21444_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_63_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21428_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20333_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21431_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21427_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21430_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21441_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21435_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21440_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21443_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19990_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21439_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21442_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19274_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8_I_0\ : std_logic ;
  signal N_174627 : std_logic ;
  signal N_174628 : std_logic ;
  signal \GRFPC0.PENDEXC_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\ : std_logic ;
  signal \GRFPC0.N_24306_1\ : std_logic ;
  signal N_49627 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\ : std_logic ;
  signal \GRFPC0.N_18417\ : std_logic ;
  signal \GRFPC0.N_24324\ : std_logic ;
  signal N_52992_1 : std_logic ;
  signal \GRFPC0.N_23787\ : std_logic ;
  signal \GRFPC0.STDATA_SN_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_430\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_431\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_429\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19712\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1\ : std_logic ;
  signal \GRFPC0.N_23623\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_2\ : std_logic ;
  signal \GRFPC0.N_23660\ : std_logic ;
  signal \GRFPC0.OP1_4\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_5\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_9\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SS0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21448\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_427\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_428\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_SS0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN45_WREN\ : std_logic ;
  signal \GRFPC0.VEX.RREG.RESV_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEBUG_UNIT\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_6_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.NONSTD_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_21181\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN\ : std_logic ;
  signal N_49622 : std_logic ;
  signal \GRFPC0.N_23347\ : std_logic ;
  signal \GRFPC0.N_22811\ : std_logic ;
  signal \GRFPC0.N_22649\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_1\ : std_logic ;
  signal \GRFPC0.N_228\ : std_logic ;
  signal \GRFPC0.N_22354\ : std_logic ;
  signal \GRFPC0.N_22718\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.INST_SN_N_2\ : std_logic ;
  signal \GRFPC0.INST_0\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_9\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_6\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_5\ : std_logic ;
  signal \GRFPC0.OP2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_299\ : std_logic ;
  signal \GRFPC0.N_21137\ : std_logic ;
  signal \GRFPC0.N_16912_I_0_I1_I_3\ : std_logic ;
  signal \GRFPC0.FID_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20479\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20480\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20485\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20487\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20484\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21034\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19404_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10715\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19472\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10765\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8376\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5221\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19339\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7458\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19840\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19853\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPINC_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4997\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4296\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21039\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20766\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4352\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20764\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_242\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4961\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5193\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19279_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10895\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10894\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10889\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19502\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19495_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19526_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10569\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10519\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10558\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10514\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19513_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19292_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20635\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15508\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19293_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21179\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7942\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19890\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19499\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6328\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19496\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7654\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13127_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\ : std_logic ;
  signal N_174806 : std_logic ;
  signal N_174807 : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17_I\ : std_logic ;
  signal N_50653_I : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.PENDEXC_3\ : std_logic ;
  signal \GRFPC0.DIV.PC_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\ : std_logic ;
  signal N_174882 : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10710\ : std_logic ;
  signal \GRFPC0.N_168_1\ : std_logic ;
  signal \GRFPC0.N_89_1_0\ : std_logic ;
  signal \GRFPC0.N_24910\ : std_logic ;
  signal N_50667_1 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\ : std_logic ;
  signal N_174890 : std_logic ;
  signal N_174891 : std_logic ;
  signal N_174892 : std_logic ;
  signal N_174895 : std_logic ;
  signal N_174896 : std_logic ;
  signal N_174897 : std_logic ;
  signal N_174898 : std_logic ;
  signal N_174900 : std_logic ;
  signal N_174901 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_1\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0\ : std_logic ;
  signal \GRFPC0.RFA.RS2D_0_0_G1\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN\ : std_logic ;
  signal \GRFPC0.VEX.RREG.RES_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7370\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7365\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19405\ : std_logic ;
  signal N_174933 : std_logic ;
  signal N_174934 : std_logic ;
  signal N_174935 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6809\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7297\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6466\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1\ : std_logic ;
  signal N_174945 : std_logic ;
  signal N_184293 : std_logic ;
  signal N_184323 : std_logic ;
  signal N_184333 : std_logic ;
  signal N_184337 : std_logic ;
  signal N_184347 : std_logic ;
  signal N_184373 : std_logic ;
  signal N_184375 : std_logic ;
  signal N_184377 : std_logic ;
  signal N_184379 : std_logic ;
  signal N_184387 : std_logic ;
  signal N_184389 : std_logic ;
  signal N_184391 : std_logic ;
  signal N_184395 : std_logic ;
  signal N_184405 : std_logic ;
  signal N_184413 : std_logic ;
  signal N_184425 : std_logic ;
  signal N_184429 : std_logic ;
  signal N_184431 : std_logic ;
  signal N_184433 : std_logic ;
  signal N_184434 : std_logic ;
  signal N_184435 : std_logic ;
  signal N_184436 : std_logic ;
  signal N_184437 : std_logic ;
  signal N_184438 : std_logic ;
  signal N_184439 : std_logic ;
  signal N_184440 : std_logic ;
  signal N_184441 : std_logic ;
  signal N_184442 : std_logic ;
  signal N_184443 : std_logic ;
  signal N_184444 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9\ : std_logic ;
  signal N_184477 : std_logic ;
  signal N_184495 : std_logic ;
  signal N_184505 : std_logic ;
  signal N_184521 : std_logic ;
  signal N_184523 : std_logic ;
  signal N_184567 : std_logic ;
  signal N_184569 : std_logic ;
  signal N_184575 : std_logic ;
  signal N_184577 : std_logic ;
  signal N_184585 : std_logic ;
  signal N_184609 : std_logic ;
  signal N_184623 : std_logic ;
  signal N_184631 : std_logic ;
  signal N_184641 : std_logic ;
  signal N_184643 : std_logic ;
  signal N_184645 : std_logic ;
  signal N_184647 : std_logic ;
  signal N_184679 : std_logic ;
  signal N_184753 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_6_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_7_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20521\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4126_1\ : std_logic ;
  signal N_124898 : std_logic ;
  signal N_124877 : std_logic ;
  signal N_124855 : std_logic ;
  signal N_124876 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3233\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15343\ : std_logic ;
  signal N_124856 : std_logic ;
  signal N_185265 : std_logic ;
  signal N_185266 : std_logic ;
  signal N_185267 : std_logic ;
  signal N_185268 : std_logic ;
  signal N_185269 : std_logic ;
  signal N_185270 : std_logic ;
  signal N_185271 : std_logic ;
  signal N_185272 : std_logic ;
  signal N_185273 : std_logic ;
  signal N_185274 : std_logic ;
  signal N_185275 : std_logic ;
  signal N_185276 : std_logic ;
  signal N_185277 : std_logic ;
  signal N_185278 : std_logic ;
  signal N_185279 : std_logic ;
  signal N_185280 : std_logic ;
  signal N_185281 : std_logic ;
  signal N_185282 : std_logic ;
  signal N_185283 : std_logic ;
  signal N_185284 : std_logic ;
  signal N_185285 : std_logic ;
  signal N_185286 : std_logic ;
  signal N_185287 : std_logic ;
  signal N_185288 : std_logic ;
  signal N_185289 : std_logic ;
  signal N_185290 : std_logic ;
  signal N_185291 : std_logic ;
  signal N_185292 : std_logic ;
  signal N_185293 : std_logic ;
  signal N_185294 : std_logic ;
  signal N_185295 : std_logic ;
  signal N_185296 : std_logic ;
  signal N_185297 : std_logic ;
  signal N_185298 : std_logic ;
  signal N_185299 : std_logic ;
  signal N_185300 : std_logic ;
  signal N_185301 : std_logic ;
  signal N_185302 : std_logic ;
  signal N_185303 : std_logic ;
  signal N_185304 : std_logic ;
  signal N_185305 : std_logic ;
  signal N_185306 : std_logic ;
  signal N_185307 : std_logic ;
  signal N_185308 : std_logic ;
  signal N_185309 : std_logic ;
  signal N_185310 : std_logic ;
  signal N_185311 : std_logic ;
  signal N_185312 : std_logic ;
  signal N_185313 : std_logic ;
  signal N_185314 : std_logic ;
  signal N_185315 : std_logic ;
  signal N_185316 : std_logic ;
  signal N_185317 : std_logic ;
  signal N_185318 : std_logic ;
  signal N_185319 : std_logic ;
  signal N_185320 : std_logic ;
  signal N_185321 : std_logic ;
  signal N_185322 : std_logic ;
  signal N_185323 : std_logic ;
  signal N_185324 : std_logic ;
  signal N_185325 : std_logic ;
  signal N_185326 : std_logic ;
  signal N_185327 : std_logic ;
  signal N_185328 : std_logic ;
  signal N_185329 : std_logic ;
  signal N_185330 : std_logic ;
  signal N_185331 : std_logic ;
  signal N_185332 : std_logic ;
  signal N_185333 : std_logic ;
  signal N_185334 : std_logic ;
  signal N_185335 : std_logic ;
  signal N_185336 : std_logic ;
  signal N_185337 : std_logic ;
  signal N_185338 : std_logic ;
  signal N_185339 : std_logic ;
  signal N_185340 : std_logic ;
  signal N_185341 : std_logic ;
  signal N_185342 : std_logic ;
  signal N_185343 : std_logic ;
  signal N_185344 : std_logic ;
  signal N_185345 : std_logic ;
  signal N_185346 : std_logic ;
  signal N_185347 : std_logic ;
  signal N_185348 : std_logic ;
  signal N_185349 : std_logic ;
  signal N_185350 : std_logic ;
  signal N_185351 : std_logic ;
  signal N_185352 : std_logic ;
  signal N_185353 : std_logic ;
  signal N_185354 : std_logic ;
  signal N_185355 : std_logic ;
  signal N_185356 : std_logic ;
  signal N_185357 : std_logic ;
  signal N_185358 : std_logic ;
  signal N_185359 : std_logic ;
  signal N_185360 : std_logic ;
  signal N_185361 : std_logic ;
  signal N_185362 : std_logic ;
  signal N_185363 : std_logic ;
  signal N_185364 : std_logic ;
  signal N_185365 : std_logic ;
  signal N_185366 : std_logic ;
  signal N_185367 : std_logic ;
  signal N_185368 : std_logic ;
  signal N_185369 : std_logic ;
  signal N_185370 : std_logic ;
  signal N_185371 : std_logic ;
  signal N_185372 : std_logic ;
  signal N_185373 : std_logic ;
  signal N_185374 : std_logic ;
  signal N_185375 : std_logic ;
  signal N_185376 : std_logic ;
  signal N_185377 : std_logic ;
  signal N_185378 : std_logic ;
  signal N_185379 : std_logic ;
  signal N_185380 : std_logic ;
  signal N_185381 : std_logic ;
  signal N_185382 : std_logic ;
  signal N_185383 : std_logic ;
  signal N_185384 : std_logic ;
  signal N_185385 : std_logic ;
  signal N_185386 : std_logic ;
  signal N_185387 : std_logic ;
  signal N_185388 : std_logic ;
  signal N_185389 : std_logic ;
  signal N_185390 : std_logic ;
  signal N_185391 : std_logic ;
  signal N_185392 : std_logic ;
  signal N_185393 : std_logic ;
  signal N_185394 : std_logic ;
  signal N_185395 : std_logic ;
  signal N_185396 : std_logic ;
  signal N_185397 : std_logic ;
  signal N_185398 : std_logic ;
  signal N_185399 : std_logic ;
  signal N_185400 : std_logic ;
  signal N_185401 : std_logic ;
  signal N_185402 : std_logic ;
  signal N_185403 : std_logic ;
  signal N_185404 : std_logic ;
  signal N_185405 : std_logic ;
  signal N_185406 : std_logic ;
  signal N_185407 : std_logic ;
  signal N_185408 : std_logic ;
  signal N_185409 : std_logic ;
  signal N_185410 : std_logic ;
  signal N_185411 : std_logic ;
  signal N_185412 : std_logic ;
  signal N_185413 : std_logic ;
  signal N_185414 : std_logic ;
  signal N_185415 : std_logic ;
  signal N_185416 : std_logic ;
  signal N_185417 : std_logic ;
  signal N_185418 : std_logic ;
  signal N_185419 : std_logic ;
  signal N_185420 : std_logic ;
  signal N_185421 : std_logic ;
  signal N_185422 : std_logic ;
  signal N_185423 : std_logic ;
  signal N_185424 : std_logic ;
  signal N_185425 : std_logic ;
  signal N_185426 : std_logic ;
  signal N_185427 : std_logic ;
  signal N_185428 : std_logic ;
  signal N_185429 : std_logic ;
  signal N_185430 : std_logic ;
  signal N_185431 : std_logic ;
  signal N_185432 : std_logic ;
  signal N_185433 : std_logic ;
  signal N_185434 : std_logic ;
  signal N_185435 : std_logic ;
  signal N_185436 : std_logic ;
  signal N_185437 : std_logic ;
  signal N_185438 : std_logic ;
  signal N_185439 : std_logic ;
  signal N_185440 : std_logic ;
  signal N_185441 : std_logic ;
  signal N_185442 : std_logic ;
  signal N_185443 : std_logic ;
  signal N_185444 : std_logic ;
  signal N_185445 : std_logic ;
  signal N_185446 : std_logic ;
  signal N_185447 : std_logic ;
  signal N_185448 : std_logic ;
  signal N_185449 : std_logic ;
  signal N_185450 : std_logic ;
  signal N_185451 : std_logic ;
  signal N_185452 : std_logic ;
  signal N_185453 : std_logic ;
  signal N_185454 : std_logic ;
  signal N_185455 : std_logic ;
  signal N_185456 : std_logic ;
  signal N_185457 : std_logic ;
  signal N_185458 : std_logic ;
  signal N_185459 : std_logic ;
  signal N_185460 : std_logic ;
  signal N_185461 : std_logic ;
  signal N_185462 : std_logic ;
  signal N_185463 : std_logic ;
  signal N_185464 : std_logic ;
  signal N_185465 : std_logic ;
  signal N_185466 : std_logic ;
  signal N_185467 : std_logic ;
  signal N_185468 : std_logic ;
  signal N_185469 : std_logic ;
  signal N_185470 : std_logic ;
  signal N_185471 : std_logic ;
  signal N_185472 : std_logic ;
  signal N_185473 : std_logic ;
  signal N_185474 : std_logic ;
  signal N_185475 : std_logic ;
  signal N_185476 : std_logic ;
  signal N_185477 : std_logic ;
  signal N_185478 : std_logic ;
  signal N_185479 : std_logic ;
  signal N_185480 : std_logic ;
  signal N_185481 : std_logic ;
  signal N_185482 : std_logic ;
  signal N_185483 : std_logic ;
  signal N_185484 : std_logic ;
  signal N_185485 : std_logic ;
  signal N_185486 : std_logic ;
  signal N_185487 : std_logic ;
  signal N_185488 : std_logic ;
  signal N_185489 : std_logic ;
  signal N_185490 : std_logic ;
  signal N_185491 : std_logic ;
  signal N_185492 : std_logic ;
  signal N_185493 : std_logic ;
  signal N_185494 : std_logic ;
  signal N_185495 : std_logic ;
  signal N_185496 : std_logic ;
  signal N_185497 : std_logic ;
  signal N_185498 : std_logic ;
  signal N_185499 : std_logic ;
  signal N_185500 : std_logic ;
  signal N_185501 : std_logic ;
  signal N_185502 : std_logic ;
  signal N_185503 : std_logic ;
  signal N_185504 : std_logic ;
  signal N_185505 : std_logic ;
  signal N_185506 : std_logic ;
  signal N_185507 : std_logic ;
  signal N_185508 : std_logic ;
  signal N_185509 : std_logic ;
  signal N_185510 : std_logic ;
  signal N_185511 : std_logic ;
  signal N_185512 : std_logic ;
  signal N_185513 : std_logic ;
  signal N_122899 : std_logic ;
  signal N_122898 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26_RETI\ : std_logic ;
  signal N_122913 : std_logic ;
  signal N_122912 : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\ : std_logic ;
  signal N_31120 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\ : std_logic ;
  signal N_31122_RETI : std_logic ;
  signal N_31118_RETI : std_logic ;
  signal N_31116_RETI : std_logic ;
  signal N_31114_RETI : std_logic ;
  signal N_31112_RETI : std_logic ;
  signal N_31110_RETI : std_logic ;
  signal N_31108_RETI : std_logic ;
  signal N_31106_RETI : std_logic ;
  signal N_31104_RETI : std_logic ;
  signal N_31102_RETI : std_logic ;
  signal N_31100_RETI : std_logic ;
  signal N_31098_RETI : std_logic ;
  signal N_31096_RETI : std_logic ;
  signal N_31094_RETI : std_logic ;
  signal N_31092_RETI : std_logic ;
  signal N_31090_RETI : std_logic ;
  signal N_31088_RETI : std_logic ;
  signal N_31086_RETI : std_logic ;
  signal N_31084_RETI : std_logic ;
  signal N_31082_RETI : std_logic ;
  signal N_31080_RETI : std_logic ;
  signal N_31078_RETI : std_logic ;
  signal N_31076_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\ : std_logic ;
  signal N_31121 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\ : std_logic ;
  signal N_31123_RETI : std_logic ;
  signal N_31119_RETI : std_logic ;
  signal N_31117_RETI : std_logic ;
  signal N_31115_RETI : std_logic ;
  signal N_31113_RETI : std_logic ;
  signal N_31111_RETI : std_logic ;
  signal N_31109_RETI : std_logic ;
  signal N_31107_RETI : std_logic ;
  signal N_31105_RETI : std_logic ;
  signal N_31103_RETI : std_logic ;
  signal N_31101_RETI : std_logic ;
  signal N_31099_RETI : std_logic ;
  signal N_31097_RETI : std_logic ;
  signal N_31095_RETI : std_logic ;
  signal N_31093_RETI : std_logic ;
  signal N_31091_RETI : std_logic ;
  signal N_31089_RETI : std_logic ;
  signal N_31087_RETI : std_logic ;
  signal N_31085_RETI : std_logic ;
  signal N_31083_RETI : std_logic ;
  signal N_31081_RETI : std_logic ;
  signal N_31079_RETI : std_logic ;
  signal N_31077_RETI : std_logic ;
  signal N_31071_RETI : std_logic ;
  signal N_31073_RETI : std_logic ;
  signal N_31075_RETI : std_logic ;
  signal N_122915 : std_logic ;
  signal N_122914 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\ : std_logic ;
  signal N_122897 : std_logic ;
  signal N_122896 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0_RETI\ : std_logic ;
  signal N_122911 : std_logic ;
  signal N_122910 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\ : std_logic ;
  signal N_21_0 : std_logic ;
  signal N_22 : std_logic ;
  signal N_23 : std_logic ;
  signal N_24 : std_logic ;
  signal N_25 : std_logic ;
  signal N_26 : std_logic ;
  signal N_27 : std_logic ;
  signal N_28 : std_logic ;
  signal N_29 : std_logic ;
  signal N_30 : std_logic ;
  signal N_31 : std_logic ;
  signal N_32 : std_logic ;
  signal N_33 : std_logic ;
  signal N_34 : std_logic ;
  signal N_35 : std_logic ;
  signal N_36 : std_logic ;
  signal N_37 : std_logic ;
  signal N_38 : std_logic ;
  signal N_39 : std_logic ;
  signal N_40 : std_logic ;
  signal N_41 : std_logic ;
  signal N_42 : std_logic ;
  signal N_43 : std_logic ;
  signal N_44 : std_logic ;
  signal N_45 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_RETI\ : std_logic ;
  signal N_46 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\ : std_logic ;
  signal N_31011_RETI : std_logic ;
  signal N_31009_RETI : std_logic ;
  signal N_31007_RETI : std_logic ;
  signal N_31005_RETI : std_logic ;
  signal N_31003_RETI : std_logic ;
  signal N_31001_RETI : std_logic ;
  signal N_30999_RETI : std_logic ;
  signal N_30997_RETI : std_logic ;
  signal N_30995_RETI : std_logic ;
  signal N_30993_RETI : std_logic ;
  signal N_30991_RETI : std_logic ;
  signal N_30989_RETI : std_logic ;
  signal N_30987_RETI : std_logic ;
  signal N_30985_RETI : std_logic ;
  signal N_30983_RETI : std_logic ;
  signal N_30981_RETI : std_logic ;
  signal N_30979_RETI : std_logic ;
  signal N_30977_RETI : std_logic ;
  signal N_30975_RETI : std_logic ;
  signal N_30973_RETI : std_logic ;
  signal N_30971_RETI : std_logic ;
  signal N_30969_RETI : std_logic ;
  signal N_30967_RETI : std_logic ;
  signal N_30965_RETI : std_logic ;
  signal N_30963_RETI : std_logic ;
  signal N_30961_RETI : std_logic ;
  signal N_30959_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\ : std_logic ;
  signal N_30952 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\ : std_logic ;
  signal N_30954_RETI : std_logic ;
  signal N_30950_RETI : std_logic ;
  signal N_30948_RETI : std_logic ;
  signal N_30946_RETI : std_logic ;
  signal N_30944_RETI : std_logic ;
  signal N_30942_RETI : std_logic ;
  signal N_30940_RETI : std_logic ;
  signal N_30938_RETI : std_logic ;
  signal N_30936_RETI : std_logic ;
  signal N_30934_RETI : std_logic ;
  signal N_30932_RETI : std_logic ;
  signal N_30930_RETI : std_logic ;
  signal N_30928_RETI : std_logic ;
  signal N_30926_RETI : std_logic ;
  signal N_30924_RETI : std_logic ;
  signal N_30922_RETI : std_logic ;
  signal N_30920_RETI : std_logic ;
  signal N_30918_RETI : std_logic ;
  signal N_30916_RETI : std_logic ;
  signal N_30914_RETI : std_logic ;
  signal N_30912_RETI : std_logic ;
  signal N_30910_RETI : std_logic ;
  signal N_30908_RETI : std_logic ;
  signal N_30902_RETI : std_logic ;
  signal N_30904_RETI : std_logic ;
  signal N_30906_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\ : std_logic ;
  signal N_30951 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\ : std_logic ;
  signal N_30953_RETI : std_logic ;
  signal N_30949_RETI : std_logic ;
  signal N_30947_RETI : std_logic ;
  signal N_30945_RETI : std_logic ;
  signal N_30943_RETI : std_logic ;
  signal N_30941_RETI : std_logic ;
  signal N_30939_RETI : std_logic ;
  signal N_30937_RETI : std_logic ;
  signal N_30935_RETI : std_logic ;
  signal N_30933_RETI : std_logic ;
  signal N_30931_RETI : std_logic ;
  signal N_30929_RETI : std_logic ;
  signal N_30927_RETI : std_logic ;
  signal N_30925_RETI : std_logic ;
  signal N_30923_RETI : std_logic ;
  signal N_30921_RETI : std_logic ;
  signal N_30919_RETI : std_logic ;
  signal N_30917_RETI : std_logic ;
  signal N_30915_RETI : std_logic ;
  signal N_30913_RETI : std_logic ;
  signal N_30911_RETI : std_logic ;
  signal N_30909_RETI : std_logic ;
  signal N_30907_RETI : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\ : std_logic ;
  signal HOLDN_RETO : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2SEL4_RETO\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV_RETO\ : std_logic ;
  signal N_1 : std_logic ;
  signal \GRFPC0.N_25715_2_RETI\ : std_logic ;
  signal \GRFPC0.DIV.VALID_RETO\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_5_RETO\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_1_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\ : std_logic ;
  signal N_1_0 : std_logic ;
  signal \GRFPC0.N_131I\ : std_logic ;
  signal \GRFPC0.N_24119_RETI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2_RETI\ : std_logic ;
  signal \GRFPC0.N_24711_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5_RETI\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RS1VI\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_6_RETI\ : std_logic ;
  signal N_5 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4296_RETO\ : std_logic ;
  signal N_1_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11284_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21036_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_14_RETI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2_RETI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2_RETI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11269_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14_RETI\ : std_logic ;
  signal \GRFPC0.N_25566_RETI\ : std_logic ;
  signal N_13_0 : std_logic ;
  signal \GRFPC0.N_24487_RETI\ : std_logic ;
  signal \GRFPC0.N_252_RETI\ : std_logic ;
  signal \GRFPC0.N_24727_RETI\ : std_logic ;
  signal \GRFPC0.N_25553_RETI\ : std_logic ;
  signal \GRFPC0.N_25532_RETI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_RETI\ : std_logic ;
  signal \GRFPC0.N_23587_RETI\ : std_logic ;
  signal N_184434_RETI : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDDI\ : std_logic ;
  signal \GRFPC0.N_24981_RETI\ : std_logic ;
  signal \GRFPC0.N_24957_RETI\ : std_logic ;
  signal \GRFPC0.N_25384_RETI\ : std_logic ;
  signal \GRFPC0.N_25091_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DPI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3406_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19404_I_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19279_I_RETI\ : std_logic ;
  signal N_174945_RETI : std_logic ;
  signal \GRFPC0.N_25585_RETI\ : std_logic ;
  signal \GRFPC0.N_25586_RETI\ : std_logic ;
  signal \GRFPC0.N_25090_RETI\ : std_logic ;
  signal \GRFPC0.N_25854_RETI\ : std_logic ;
  signal \GRFPC0.N_25664_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19713_RETO\ : std_logic ;
  signal N_1_2 : std_logic ;
  signal N_1_3 : std_logic ;
  signal N_1_4 : std_logic ;
  signal N_1_5 : std_logic ;
  signal N_1_6 : std_logic ;
  signal N_1_7 : std_logic ;
  signal N_1_8 : std_logic ;
  signal N_1_9 : std_logic ;
  signal N_1_10 : std_logic ;
  signal N_1_11 : std_logic ;
  signal N_1_12 : std_logic ;
  signal N_1_13 : std_logic ;
  signal N_1_14 : std_logic ;
  signal N_1_15 : std_logic ;
  signal N_1_16 : std_logic ;
  signal N_1_17 : std_logic ;
  signal N_1_18 : std_logic ;
  signal N_1_19 : std_logic ;
  signal N_1_20 : std_logic ;
  signal N_1_21 : std_logic ;
  signal N_1_22 : std_logic ;
  signal N_1_23 : std_logic ;
  signal N_1_24 : std_logic ;
  signal N_1_25 : std_logic ;
  signal N_1_26 : std_logic ;
  signal N_1_27 : std_logic ;
  signal N_1_28 : std_logic ;
  signal N_1_29 : std_logic ;
  signal N_1_30 : std_logic ;
  signal \GRFPC0.MEM.CTRL.RS1VI\ : std_logic ;
  signal \GRFPC0.N_24642_RETI\ : std_logic ;
  signal \GRFPC0.N_24719_RETI\ : std_logic ;
  signal N_1_31 : std_logic ;
  signal N_2 : std_logic ;
  signal N_3 : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10_RETI\ : std_logic ;
  signal N_4_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5193_RETI\ : std_logic ;
  signal \GRFPC0.N_24633_RETI\ : std_logic ;
  signal N_186128 : std_logic ;
  signal N_186140 : std_logic ;
  signal N_186142 : std_logic ;
  signal N_186166 : std_logic ;
  signal N_186168 : std_logic ;
  signal N_186170 : std_logic ;
  signal N_186172 : std_logic ;
  signal N_186174 : std_logic ;
  signal N_186176 : std_logic ;
  signal N_186182 : std_logic ;
  signal N_186184 : std_logic ;
  signal N_186186 : std_logic ;
  signal N_186188 : std_logic ;
  signal N_186190 : std_logic ;
  signal N_186196 : std_logic ;
  signal N_186200 : std_logic ;
  signal N_186212 : std_logic ;
  signal N_186214 : std_logic ;
  signal N_186216 : std_logic ;
  signal N_186232 : std_logic ;
  signal N_186236 : std_logic ;
  signal N_186238 : std_logic ;
  signal N_186242 : std_logic ;
  signal N_186254 : std_logic ;
  signal N_186256 : std_logic ;
  signal N_186266 : std_logic ;
  signal N_186268 : std_logic ;
  signal N_186272 : std_logic ;
  signal N_186278 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_N_6\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_11\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_0_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_11\ : std_logic ;
  signal N_186704 : std_logic ;
  signal N_186808 : std_logic ;
  signal N_186810 : std_logic ;
  signal N_186812 : std_logic ;
  signal N_186814 : std_logic ;
  signal N_186816 : std_logic ;
  signal N_186818 : std_logic ;
  signal N_186820 : std_logic ;
  signal N_186880 : std_logic ;
  signal N_186882 : std_logic ;
  signal N_186892 : std_logic ;
  signal N_186900 : std_logic ;
  signal N_186902 : std_logic ;
  signal N_186904 : std_logic ;
  signal N_186906 : std_logic ;
  signal N_186910 : std_logic ;
  signal N_186912 : std_logic ;
  signal N_186918 : std_logic ;
  signal N_186932 : std_logic ;
  signal N_186940 : std_logic ;
  signal N_186944 : std_logic ;
  signal N_186946 : std_logic ;
  signal N_186950 : std_logic ;
  signal N_186962 : std_logic ;
  signal N_186976 : std_logic ;
  signal N_186980 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_10_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_9\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0_N_8\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_10\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G3_N_7\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G3_N_9\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G3_N_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_7\ : std_logic ;
  signal N_187395 : std_logic ;
  signal N_187397 : std_logic ;
  signal N_187399 : std_logic ;
  signal N_187401 : std_logic ;
  signal N_187403 : std_logic ;
  signal N_187409 : std_logic ;
  signal N_187513 : std_logic ;
  signal N_187533 : std_logic ;
  signal N_187537 : std_logic ;
  signal N_187551 : std_logic ;
  signal N_187561 : std_logic ;
  signal N_187563 : std_logic ;
  signal N_187567 : std_logic ;
  signal N_187587 : std_logic ;
  signal N_187621 : std_logic ;
  signal N_187623 : std_logic ;
  signal N_187627 : std_logic ;
  signal N_187629 : std_logic ;
  signal N_187631 : std_logic ;
  signal N_187635 : std_logic ;
  signal N_187733 : std_logic ;
  signal N_187785 : std_logic ;
  signal N_187787 : std_logic ;
  signal N_187789 : std_logic ;
  signal N_187791 : std_logic ;
  signal N_187793 : std_logic ;
  signal N_187795 : std_logic ;
  signal N_187797 : std_logic ;
  signal N_187799 : std_logic ;
  signal N_187801 : std_logic ;
  signal N_187803 : std_logic ;
  signal N_187805 : std_logic ;
  signal N_187807 : std_logic ;
  signal N_187809 : std_logic ;
  signal N_187811 : std_logic ;
  signal N_187813 : std_logic ;
  signal N_187815 : std_logic ;
  signal N_187817 : std_logic ;
  signal N_187819 : std_logic ;
  signal N_187829 : std_logic ;
  signal N_187831 : std_logic ;
  signal N_187833 : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0_N_5\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0_N_7\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9_0\ : std_logic ;
  signal N_188345 : std_logic ;
  signal N_188346 : std_logic ;
  signal N_188347 : std_logic ;
  signal N_188348 : std_logic ;
  signal N_188349 : std_logic ;
  signal N_188350 : std_logic ;
  signal N_188351 : std_logic ;
  signal N_188352 : std_logic ;
  signal N_188353 : std_logic ;
  signal N_188354 : std_logic ;
  signal N_188355 : std_logic ;
  signal N_188356 : std_logic ;
  signal N_188357 : std_logic ;
  signal N_188358 : std_logic ;
  signal N_189350 : std_logic ;
  signal N_189351 : std_logic ;
  signal N_189352 : std_logic ;
  signal N_189353 : std_logic ;
  signal N_189354 : std_logic ;
  signal N_189355 : std_logic ;
  signal N_189356 : std_logic ;
  signal N_189357 : std_logic ;
  signal N_189358 : std_logic ;
  signal N_189359 : std_logic ;
  signal N_189360 : std_logic ;
  signal N_189361 : std_logic ;
  signal N_189362 : std_logic ;
  signal N_189363 : std_logic ;
  signal N_189364 : std_logic ;
  signal N_189365 : std_logic ;
  signal N_189366 : std_logic ;
  signal N_189367 : std_logic ;
  signal N_189368 : std_logic ;
  signal N_189369 : std_logic ;
  signal N_189370 : std_logic ;
  signal N_189371 : std_logic ;
  signal N_189372 : std_logic ;
  signal N_189373 : std_logic ;
  signal N_189374 : std_logic ;
  signal N_189375 : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\ : std_logic ;
  signal RST_I : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_80_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_0_1_0\ : std_logic ;
  signal HOLDN_I : std_logic ;
  signal N_174882_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2_0\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFV_0\ : std_logic ;
  signal \GRFPC0.RFA.LD_0\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD_0\ : std_logic ;
  signal \GRFPC0.RFA.ST_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_1\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_2\ : std_logic ;
  signal \GRFPC0.DIV.RDD_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_2\ : std_logic ;
  signal \GRFPC0.N_131_0\ : std_logic ;
  signal \GRFPC0.N_131_1\ : std_logic ;
  signal \GRFPC0.N_131_2\ : std_logic ;
  signal \GRFPC0.N_131_3\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_0\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_5\ : std_logic ;
  signal \GRFPC0.N_78_I_I_0\ : std_logic ;
  signal \GRFPC0.N_78_I_I_1\ : std_logic ;
  signal \GRFPC0.N_78_I_I_2\ : std_logic ;
  signal N_50656_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4227_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20764_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\ : std_logic ;
  signal \GRFPC0.N_65_0\ : std_logic ;
  signal \GRFPC0.N_65_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10710_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19502_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19502_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19840_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20635_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE10_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_218_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_218_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_80_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_427_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_428_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_431_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21448_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21448_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_299_0\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_6_0\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_6_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4961_0\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_9_0\ : std_logic ;
  signal \GRFPC0.OP1_SN_N_9_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_9_0\ : std_logic ;
  signal \GRFPC0.OP2_SN_N_9_1\ : std_logic ;
  signal N_49622_0 : std_logic ;
  signal N_49622_1 : std_logic ;
  signal N_49622_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4352_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19292_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19499_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19513_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19513_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15508_0\ : std_logic ;
  signal \GRFPC0.OP1_4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19496_0\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\ : std_logic ;
  signal \GRFPC0.DIV.PC_0_0_9__G2_0\ : std_logic ;
  signal \GRFPC0.DIV.PC_0_0_9__G2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5221_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5221_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19293_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19293_I_1\ : std_logic ;
  signal \GRFPC0.OP2_4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19600_I_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19600_I_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19600_I_I_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.PENDEXC_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.PENDEXC_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.PENDEXC_3_2\ : std_logic ;
  signal N_52020_1 : std_logic ;
  signal N_52020_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20287_0\ : std_logic ;
  signal \GRFPC0.N_21137_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19712_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.SEQERR_0\ : std_logic ;
  signal \GRFPC0.DIV.VALID_0\ : std_logic ;
  signal N_174935_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_270\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_390\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_393\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_490\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_491\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1_E0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1_U0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1_U1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.L2_0_30_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_031\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_032\ : std_logic ;
  signal VCC : std_logic ;
  signal N_47 : std_logic ;
  signal N_48 : std_logic ;
  signal N_49 : std_logic ;
  signal N_50 : std_logic ;
  signal N_51 : std_logic ;
  signal N_52 : std_logic ;
  signal N_53 : std_logic ;
  signal N_54 : std_logic ;
  signal N_55 : std_logic ;
  signal N_56 : std_logic ;
  signal N_57 : std_logic ;
  signal N_58 : std_logic ;
  signal N_59 : std_logic ;
  signal N_60 : std_logic ;
  signal N_61 : std_logic ;
  signal N_62 : std_logic ;
  signal N_63 : std_logic ;
  signal N_64 : std_logic ;
  signal N_65 : std_logic ;
  signal N_66 : std_logic ;
  signal N_67 : std_logic ;
  signal N_68 : std_logic ;
  signal N_69 : std_logic ;
  signal N_70 : std_logic ;
  signal N_71 : std_logic ;
  signal N_72 : std_logic ;
  signal N_73 : std_logic ;
  signal N_74 : std_logic ;
  signal N_75 : std_logic ;
  signal N_76 : std_logic ;
  signal N_77 : std_logic ;
  signal N_78 : std_logic ;
  signal N_79 : std_logic ;
  signal N_80 : std_logic ;
  signal N_81 : std_logic ;
  signal N_82 : std_logic ;
  signal N_83 : std_logic ;
  signal N_84 : std_logic ;
  signal N_85 : std_logic ;
  signal N_86 : std_logic ;
  signal N_87 : std_logic ;
  signal N_88 : std_logic ;
  signal N_89 : std_logic ;
  signal N_90 : std_logic ;
  signal N_91 : std_logic ;
  signal N_92 : std_logic ;
  signal N_93 : std_logic ;
  signal N_94 : std_logic ;
  signal N_95 : std_logic ;
  signal N_96 : std_logic ;
  signal N_97 : std_logic ;
  signal N_98 : std_logic ;
  signal N_99 : std_logic ;
  signal N_100 : std_logic ;
  signal N_101 : std_logic ;
  signal N_102 : std_logic ;
  signal N_103 : std_logic ;
  signal N_104 : std_logic ;
  signal N_105 : std_logic ;
  signal N_106 : std_logic ;
  signal N_107 : std_logic ;
  signal N_108 : std_logic ;
  signal N_109 : std_logic ;
  signal N_110 : std_logic ;
  signal N_111 : std_logic ;
  signal N_112 : std_logic ;
  signal N_113 : std_logic ;
  signal N_114 : std_logic ;
  signal N_115 : std_logic ;
  signal N_116 : std_logic ;
  signal N_117 : std_logic ;
  signal N_118 : std_logic ;
  signal N_119 : std_logic ;
  signal N_120 : std_logic ;
  signal N_121 : std_logic ;
  signal N_122 : std_logic ;
  signal N_123 : std_logic ;
  signal N_124 : std_logic ;
  signal N_125 : std_logic ;
  signal N_126 : std_logic ;
  signal N_127 : std_logic ;
  signal N_128 : std_logic ;
  signal N_129 : std_logic ;
  signal N_130 : std_logic ;
  signal N_131 : std_logic ;
  signal N_132 : std_logic ;
  signal N_133 : std_logic ;
  signal N_134 : std_logic ;
  signal N_135 : std_logic ;
  signal N_136 : std_logic ;
  signal N_137 : std_logic ;
  signal N_138 : std_logic ;
  signal N_139 : std_logic ;
  signal N_140 : std_logic ;
  signal N_141 : std_logic ;
  signal N_142 : std_logic ;
  signal N_143 : std_logic ;
  signal N_144 : std_logic ;
  signal N_145 : std_logic ;
  signal N_146 : std_logic ;
  signal N_147 : std_logic ;
  signal N_148 : std_logic ;
  signal N_149 : std_logic ;
  signal N_150 : std_logic ;
  signal N_151 : std_logic ;
  signal N_152 : std_logic ;
  signal N_153 : std_logic ;
  signal N_154 : std_logic ;
  signal N_155 : std_logic ;
  signal N_156 : std_logic ;
  signal N_157 : std_logic ;
  signal N_158 : std_logic ;
  signal N_159 : std_logic ;
  signal N_160 : std_logic ;
  signal N_161 : std_logic ;
  signal N_162 : std_logic ;
  signal N_163 : std_logic ;
  signal N_164 : std_logic ;
  signal N_165 : std_logic ;
  signal N_166 : std_logic ;
  signal N_167 : std_logic ;
  signal N_168 : std_logic ;
  signal N_169 : std_logic ;
  signal N_170 : std_logic ;
  signal N_171 : std_logic ;
  signal N_172 : std_logic ;
  signal N_173 : std_logic ;
  signal N_174 : std_logic ;
  signal N_175 : std_logic ;
  signal N_176 : std_logic ;
  signal N_177 : std_logic ;
  signal N_178 : std_logic ;
  signal N_179 : std_logic ;
  signal N_180 : std_logic ;
  signal N_181 : std_logic ;
  signal N_182 : std_logic ;
  signal N_183 : std_logic ;
  signal N_184 : std_logic ;
  signal N_185 : std_logic ;
  signal N_186 : std_logic ;
  signal N_187 : std_logic ;
  signal N_188 : std_logic ;
  signal N_189 : std_logic ;
  signal N_190 : std_logic ;
  signal N_191 : std_logic ;
  signal N_192 : std_logic ;
  signal N_193 : std_logic ;
  signal N_194 : std_logic ;
  signal N_195 : std_logic ;
  signal N_196 : std_logic ;
  signal N_197 : std_logic ;
  signal N_198 : std_logic ;
  signal N_199 : std_logic ;
  signal N_200 : std_logic ;
  signal N_201 : std_logic ;
  signal N_202 : std_logic ;
  signal N_203 : std_logic ;
  signal N_204 : std_logic ;
  signal N_205 : std_logic ;
  signal N_206 : std_logic ;
  signal N_207 : std_logic ;
  signal N_208 : std_logic ;
  signal N_209 : std_logic ;
  signal N_210 : std_logic ;
  signal N_211 : std_logic ;
  signal N_212 : std_logic ;
  signal N_213 : std_logic ;
  signal N_214 : std_logic ;
  signal N_215 : std_logic ;
  signal N_216 : std_logic ;
  signal N_217 : std_logic ;
  signal N_218 : std_logic ;
  signal N_219 : std_logic ;
  signal N_220 : std_logic ;
  signal N_221 : std_logic ;
  signal N_222 : std_logic ;
  signal N_223 : std_logic ;
  signal N_224 : std_logic ;
  signal N_225 : std_logic ;
  signal N_226 : std_logic ;
  signal N_227 : std_logic ;
  signal N_228 : std_logic ;
  signal N_229 : std_logic ;
  signal N_230 : std_logic ;
  signal N_231 : std_logic ;
  signal N_232 : std_logic ;
  signal N_233 : std_logic ;
  signal N_234 : std_logic ;
  signal N_235 : std_logic ;
  signal N_236 : std_logic ;
  signal N_237 : std_logic ;
  signal N_238 : std_logic ;
  signal N_239 : std_logic ;
  signal N_240 : std_logic ;
  signal N_241 : std_logic ;
  signal N_242 : std_logic ;
  signal N_243 : std_logic ;
  signal N_244 : std_logic ;
  signal N_245 : std_logic ;
  signal N_246 : std_logic ;
  signal N_247 : std_logic ;
  signal N_248 : std_logic ;
  signal N_249 : std_logic ;
  signal N_250 : std_logic ;
  signal N_251 : std_logic ;
  signal N_252 : std_logic ;
  signal N_253 : std_logic ;
  signal N_254 : std_logic ;
  signal N_255 : std_logic ;
  signal N_256 : std_logic ;
  signal N_257 : std_logic ;
  signal N_258 : std_logic ;
  signal N_259 : std_logic ;
  signal N_260 : std_logic ;
  signal N_261 : std_logic ;
  signal N_262 : std_logic ;
  signal N_263 : std_logic ;
  signal N_264 : std_logic ;
  signal N_265 : std_logic ;
  signal N_266 : std_logic ;
  signal N_267 : std_logic ;
  signal N_268 : std_logic ;
  signal N_269 : std_logic ;
  signal N_270 : std_logic ;
  signal N_271 : std_logic ;
  signal N_272 : std_logic ;
  signal N_273 : std_logic ;
  signal N_274 : std_logic ;
  signal N_275 : std_logic ;
  signal N_276 : std_logic ;
  signal N_277 : std_logic ;
  signal N_278 : std_logic ;
  signal N_279 : std_logic ;
  signal N_280 : std_logic ;
  signal N_281 : std_logic ;
  signal N_282 : std_logic ;
  signal N_283 : std_logic ;
  signal N_284 : std_logic ;
  signal N_285 : std_logic ;
  signal N_286 : std_logic ;
  signal N_287 : std_logic ;
  signal N_288 : std_logic ;
  signal N_289 : std_logic ;
  signal N_290 : std_logic ;
  signal N_291 : std_logic ;
  signal N_292 : std_logic ;
  signal N_293 : std_logic ;
  signal N_294 : std_logic ;
  signal N_295 : std_logic ;
  signal N_296 : std_logic ;
  signal N_297 : std_logic ;
  signal N_298 : std_logic ;
  signal N_299 : std_logic ;
  signal N_300 : std_logic ;
  signal N_301 : std_logic ;
  signal N_302 : std_logic ;
  signal N_303 : std_logic ;
  signal N_304 : std_logic ;
  signal N_305 : std_logic ;
  signal N_306 : std_logic ;
  signal N_307 : std_logic ;
  signal N_308 : std_logic ;
  signal N_309 : std_logic ;
  signal N_310 : std_logic ;
  signal N_311 : std_logic ;
  signal N_312 : std_logic ;
  signal N_313 : std_logic ;
  signal N_314 : std_logic ;
  signal N_315 : std_logic ;
  signal N_316 : std_logic ;
  signal N_317 : std_logic ;
  signal N_318 : std_logic ;
  signal N_319 : std_logic ;
  signal N_320 : std_logic ;
  signal N_321 : std_logic ;
  signal N_322 : std_logic ;
  signal N_323 : std_logic ;
  signal N_324 : std_logic ;
  signal N_325 : std_logic ;
  signal N_326 : std_logic ;
  signal N_327 : std_logic ;
  signal N_328 : std_logic ;
  signal N_329 : std_logic ;
  signal N_330 : std_logic ;
  signal N_331 : std_logic ;
  signal N_332 : std_logic ;
  signal N_333 : std_logic ;
  signal N_334 : std_logic ;
  signal N_335 : std_logic ;
  signal N_336 : std_logic ;
  signal N_337 : std_logic ;
  signal N_338 : std_logic ;
  signal N_339 : std_logic ;
  signal N_340 : std_logic ;
  signal N_341 : std_logic ;
  signal N_342 : std_logic ;
  signal N_343 : std_logic ;
  signal N_344 : std_logic ;
  signal N_345 : std_logic ;
  signal N_346 : std_logic ;
  signal N_347 : std_logic ;
  signal N_348 : std_logic ;
  signal N_349 : std_logic ;
  signal N_350 : std_logic ;
  signal N_351 : std_logic ;
  signal N_352 : std_logic ;
  signal N_353 : std_logic ;
  signal N_354 : std_logic ;
  signal N_355 : std_logic ;
  signal N_356 : std_logic ;
  signal N_357 : std_logic ;
  signal N_358 : std_logic ;
  signal N_359 : std_logic ;
  signal N_360 : std_logic ;
  signal N_361 : std_logic ;
  signal N_362 : std_logic ;
  signal N_363 : std_logic ;
  signal N_364 : std_logic ;
  signal N_365 : std_logic ;
  signal N_366 : std_logic ;
  signal N_367 : std_logic ;
  signal N_368 : std_logic ;
  signal N_369 : std_logic ;
  signal N_370 : std_logic ;
  signal N_371 : std_logic ;
  signal N_372 : std_logic ;
  signal N_373 : std_logic ;
  signal N_374 : std_logic ;
  signal N_375 : std_logic ;
  signal N_376 : std_logic ;
  signal N_377 : std_logic ;
  signal N_378 : std_logic ;
  signal N_379 : std_logic ;
  signal N_380 : std_logic ;
  signal N_381 : std_logic ;
  signal N_382 : std_logic ;
  signal N_383 : std_logic ;
  signal N_384 : std_logic ;
  signal N_385 : std_logic ;
  signal N_386 : std_logic ;
  signal N_387 : std_logic ;
  signal N_388 : std_logic ;
  signal N_389 : std_logic ;
  signal N_390 : std_logic ;
  signal N_391 : std_logic ;
  signal N_392 : std_logic ;
  signal N_393 : std_logic ;
  signal N_394 : std_logic ;
  signal N_395 : std_logic ;
  signal N_396 : std_logic ;
  signal N_397 : std_logic ;
  signal N_398 : std_logic ;
  signal N_399 : std_logic ;
  signal N_400 : std_logic ;
  signal N_401 : std_logic ;
  signal N_402 : std_logic ;
  signal N_403 : std_logic ;
  signal N_404 : std_logic ;
  signal N_405 : std_logic ;
  signal N_406 : std_logic ;
  signal N_407 : std_logic ;
  signal N_408 : std_logic ;
  signal N_409 : std_logic ;
  signal N_410 : std_logic ;
  signal N_411 : std_logic ;
  signal N_412 : std_logic ;
  signal N_413 : std_logic ;
  signal N_414 : std_logic ;
  signal N_415 : std_logic ;
  signal N_416 : std_logic ;
  signal N_417 : std_logic ;
  signal N_418 : std_logic ;
  signal N_419 : std_logic ;
  signal N_420 : std_logic ;
  signal N_421 : std_logic ;
  signal N_422 : std_logic ;
  signal N_423 : std_logic ;
  signal N_424 : std_logic ;
  signal N_425 : std_logic ;
  signal N_426 : std_logic ;
  signal N_427 : std_logic ;
  signal N_428 : std_logic ;
  signal N_429 : std_logic ;
  signal N_430 : std_logic ;
  signal N_431 : std_logic ;
  signal N_432 : std_logic ;
  signal N_433 : std_logic ;
  signal N_434 : std_logic ;
  signal N_435 : std_logic ;
  signal N_436 : std_logic ;
  signal N_437 : std_logic ;
  signal N_438 : std_logic ;
  signal N_439 : std_logic ;
  signal N_440 : std_logic ;
  signal N_441 : std_logic ;
  signal N_442 : std_logic ;
  signal N_443 : std_logic ;
  signal N_444 : std_logic ;
  signal N_445 : std_logic ;
  signal N_446 : std_logic ;
  signal N_447 : std_logic ;
  signal N_448 : std_logic ;
  signal N_449 : std_logic ;
  signal N_450 : std_logic ;
  signal N_451 : std_logic ;
  signal N_452 : std_logic ;
  signal N_453 : std_logic ;
  signal N_454 : std_logic ;
  signal N_455 : std_logic ;
  signal N_456 : std_logic ;
  signal N_457 : std_logic ;
  signal N_458 : std_logic ;
  signal N_459 : std_logic ;
  signal N_460 : std_logic ;
  signal N_461 : std_logic ;
  signal N_462 : std_logic ;
  signal N_463 : std_logic ;
  signal N_464 : std_logic ;
  signal N_465 : std_logic ;
  signal N_466 : std_logic ;
  signal N_467 : std_logic ;
  signal N_468 : std_logic ;
  signal N_469 : std_logic ;
  signal N_470 : std_logic ;
  signal N_471 : std_logic ;
  signal N_472 : std_logic ;
  signal N_473 : std_logic ;
  signal N_474 : std_logic ;
  signal N_475 : std_logic ;
  signal N_476 : std_logic ;
  signal N_477 : std_logic ;
  signal N_478 : std_logic ;
  signal N_479 : std_logic ;
  signal N_480 : std_logic ;
  signal N_481 : std_logic ;
  signal N_482 : std_logic ;
  signal N_483 : std_logic ;
  signal N_484 : std_logic ;
  signal N_485 : std_logic ;
  signal N_486 : std_logic ;
  signal N_487 : std_logic ;
  signal N_0 : std_logic ;
  signal N_1_32 : std_logic ;
  signal N_2_0 : std_logic ;
  signal N_3_0 : std_logic ;
  signal N_4_1 : std_logic ;
  signal N_5_0 : std_logic ;
  signal N_6_0 : std_logic ;
  signal N_7_0 : std_logic ;
  signal N_8_0 : std_logic ;
  signal N_9_0 : std_logic ;
  signal N_10_0 : std_logic ;
  signal N_11_0 : std_logic ;
  signal N_12_0 : std_logic ;
  signal N_13_1 : std_logic ;
  signal N_14_0 : std_logic ;
  signal N_15_0 : std_logic ;
  signal N_16_0 : std_logic ;
  signal N_17_0 : std_logic ;
  signal N_18_0 : std_logic ;
  signal N_19_0 : std_logic ;
  signal N_20_0 : std_logic ;
  signal N_21_1 : std_logic ;
  signal N_22_0 : std_logic ;
  signal N_23_0 : std_logic ;
  signal N_24_0 : std_logic ;
  signal N_25_0 : std_logic ;
  signal N_26_0 : std_logic ;
  signal N_27_0 : std_logic ;
  signal N_28_0 : std_logic ;
  signal N_29_0 : std_logic ;
  signal N_30_0 : std_logic ;
  signal N_31_0 : std_logic ;
  signal N_32_0 : std_logic ;
  signal N_33_0 : std_logic ;
  signal N_34_0 : std_logic ;
  signal N_35_0 : std_logic ;
  signal N_36_0 : std_logic ;
  signal N_37_0 : std_logic ;
  signal N_38_0 : std_logic ;
  signal N_39_0 : std_logic ;
  signal N_40_0 : std_logic ;
  signal N_41_0 : std_logic ;
  signal N_42_0 : std_logic ;
  signal N_43_0 : std_logic ;
  signal N_44_0 : std_logic ;
  signal N_45_0 : std_logic ;
  signal N_46_0 : std_logic ;
  signal N_47_0 : std_logic ;
  signal N_48_0 : std_logic ;
  signal N_49_0 : std_logic ;
  signal N_50_0 : std_logic ;
  signal N_51_0 : std_logic ;
  signal N_52_0 : std_logic ;
  signal N_53_0 : std_logic ;
  signal N_54_0 : std_logic ;
  signal N_55_0 : std_logic ;
  signal N_56_0 : std_logic ;
  signal N_57_0 : std_logic ;
  signal N_58_0 : std_logic ;
  signal N_59_0 : std_logic ;
  signal N_60_0 : std_logic ;
  signal N_61_0 : std_logic ;
  signal N_62_0 : std_logic ;
  signal N_63_0 : std_logic ;
  signal N_64_0 : std_logic ;
  signal N_65_0 : std_logic ;
  signal N_66_0 : std_logic ;
  signal N_67_0 : std_logic ;
  signal N_68_0 : std_logic ;
  signal N_69_0 : std_logic ;
  signal N_70_0 : std_logic ;
  signal N_71_0 : std_logic ;
  signal N_72_0 : std_logic ;
  signal N_73_0 : std_logic ;
  signal N_74_0 : std_logic ;
  signal N_75_0 : std_logic ;
  signal N_76_0 : std_logic ;
  signal N_77_0 : std_logic ;
  signal N_78_0 : std_logic ;
  signal N_79_0 : std_logic ;
  signal N_80_0 : std_logic ;
  signal N_81_0 : std_logic ;
  signal N_82_0 : std_logic ;
  signal N_83_0 : std_logic ;
  signal N_84_0 : std_logic ;
  signal N_85_0 : std_logic ;
  signal N_86_0 : std_logic ;
  signal N_87_0 : std_logic ;
  signal N_88_0 : std_logic ;
  signal N_89_0 : std_logic ;
  signal N_90_0 : std_logic ;
  signal N_91_0 : std_logic ;
  signal N_92_0 : std_logic ;
  signal N_93_0 : std_logic ;
  signal N_94_0 : std_logic ;
  signal N_95_0 : std_logic ;
  signal N_96_0 : std_logic ;
  signal N_97_0 : std_logic ;
  signal N_98_0 : std_logic ;
  signal N_99_0 : std_logic ;
  signal N_100_0 : std_logic ;
  signal N_101_0 : std_logic ;
  signal N_102_0 : std_logic ;
  signal N_103_0 : std_logic ;
  signal N_104_0 : std_logic ;
  signal N_105_0 : std_logic ;
  signal N_106_0 : std_logic ;
  signal N_107_0 : std_logic ;
  signal N_108_0 : std_logic ;
  signal N_109_0 : std_logic ;
  signal N_110_0 : std_logic ;
  signal N_111_0 : std_logic ;
  signal N_112_0 : std_logic ;
  signal N_113_0 : std_logic ;
  signal N_114_0 : std_logic ;
  signal N_115_0 : std_logic ;
  signal N_116_0 : std_logic ;
  signal N_117_0 : std_logic ;
  signal N_118_0 : std_logic ;
  signal N_119_0 : std_logic ;
  signal N_120_0 : std_logic ;
  signal N_121_0 : std_logic ;
  signal N_122_0 : std_logic ;
  signal N_123_0 : std_logic ;
  signal N_124_0 : std_logic ;
  signal N_125_0 : std_logic ;
  signal N_126_0 : std_logic ;
  signal N_127_0 : std_logic ;
  signal N_128_0 : std_logic ;
  signal N_129_0 : std_logic ;
  signal N_130_0 : std_logic ;
  signal N_131_0 : std_logic ;
  signal N_132_0 : std_logic ;
  signal N_133_0 : std_logic ;
  signal N_134_0 : std_logic ;
  signal N_135_0 : std_logic ;
  signal N_136_0 : std_logic ;
  signal N_137_0 : std_logic ;
  signal N_138_0 : std_logic ;
  signal N_139_0 : std_logic ;
  signal N_140_0 : std_logic ;
  signal N_141_0 : std_logic ;
  signal N_142_0 : std_logic ;
  signal N_143_0 : std_logic ;
  signal N_144_0 : std_logic ;
  signal N_145_0 : std_logic ;
  signal N_146_0 : std_logic ;
  signal N_147_0 : std_logic ;
  signal N_148_0 : std_logic ;
  signal N_149_0 : std_logic ;
  signal N_150_0 : std_logic ;
  signal N_151_0 : std_logic ;
  signal N_152_0 : std_logic ;
  signal N_153_0 : std_logic ;
  signal N_154_0 : std_logic ;
  signal N_155_0 : std_logic ;
  signal N_156_0 : std_logic ;
  signal N_157_0 : std_logic ;
  signal N_158_0 : std_logic ;
  signal N_159_0 : std_logic ;
  signal N_160_0 : std_logic ;
  signal N_161_0 : std_logic ;
  signal N_162_0 : std_logic ;
  signal N_163_0 : std_logic ;
  signal N_652 : std_logic ;
  signal N_653 : std_logic ;
  signal N_654 : std_logic ;
  signal N_655 : std_logic ;
  signal N_656 : std_logic ;
  signal N_657 : std_logic ;
  signal N_658 : std_logic ;
  signal N_659 : std_logic ;
  signal N_660 : std_logic ;
  signal N_661 : std_logic ;
  signal N_662 : std_logic ;
  signal N_663 : std_logic ;
  signal N_664 : std_logic ;
  signal N_665 : std_logic ;
  signal N_666 : std_logic ;
  signal N_667 : std_logic ;
  signal N_668 : std_logic ;
  signal N_669 : std_logic ;
  signal N_670 : std_logic ;
  signal N_671 : std_logic ;
  signal N_672 : std_logic ;
  signal N_673 : std_logic ;
  signal N_674 : std_logic ;
  signal N_675 : std_logic ;
  signal N_676 : std_logic ;
  signal N_677 : std_logic ;
  signal N_678 : std_logic ;
  signal N_679 : std_logic ;
  signal N_680 : std_logic ;
  signal N_681 : std_logic ;
  signal N_682 : std_logic ;
  signal N_683 : std_logic ;
  signal N_684 : std_logic ;
  signal N_685 : std_logic ;
  signal N_686 : std_logic ;
  signal N_687 : std_logic ;
  signal N_688 : std_logic ;
  signal N_689 : std_logic ;
  signal N_690 : std_logic ;
  signal N_691 : std_logic ;
  signal N_692 : std_logic ;
  signal N_693 : std_logic ;
  signal N_694 : std_logic ;
  signal N_695 : std_logic ;
  signal N_696 : std_logic ;
  signal N_697 : std_logic ;
  signal N_698 : std_logic ;
  signal N_699 : std_logic ;
  signal N_700 : std_logic ;
  signal N_701 : std_logic ;
  signal N_702 : std_logic ;
  signal N_703 : std_logic ;
  signal N_704 : std_logic ;
  signal N_705 : std_logic ;
  signal N_706 : std_logic ;
  signal N_707 : std_logic ;
  signal N_708 : std_logic ;
  signal N_709 : std_logic ;
  signal N_710 : std_logic ;
  signal N_711 : std_logic ;
  signal N_712 : std_logic ;
  signal N_713 : std_logic ;
  signal N_714 : std_logic ;
  signal N_715 : std_logic ;
  signal N_716 : std_logic ;
  signal N_717 : std_logic ;
  signal N_718 : std_logic ;
  signal N_719 : std_logic ;
  signal N_720 : std_logic ;
  signal N_721 : std_logic ;
  signal N_722 : std_logic ;
  signal N_723 : std_logic ;
  signal N_724 : std_logic ;
  signal N_725 : std_logic ;
  signal N_726 : std_logic ;
  signal N_727 : std_logic ;
  signal N_728 : std_logic ;
  signal N_729 : std_logic ;
  signal N_730 : std_logic ;
  signal N_731 : std_logic ;
  signal N_732 : std_logic ;
  signal N_733 : std_logic ;
  signal N_734 : std_logic ;
  signal N_735 : std_logic ;
  signal N_736 : std_logic ;
  signal N_737 : std_logic ;
  signal N_738 : std_logic ;
  signal N_739 : std_logic ;
  signal N_740 : std_logic ;
  signal N_741 : std_logic ;
  signal N_742 : std_logic ;
  signal N_743 : std_logic ;
  signal N_744 : std_logic ;
  signal N_745 : std_logic ;
  signal N_746 : std_logic ;
  signal N_747 : std_logic ;
  signal N_748 : std_logic ;
  signal N_749 : std_logic ;
  signal N_750 : std_logic ;
  signal N_751 : std_logic ;
  signal N_752 : std_logic ;
  signal N_753 : std_logic ;
  signal N_754 : std_logic ;
  signal N_755 : std_logic ;
  signal N_756 : std_logic ;
  signal N_757 : std_logic ;
  signal N_758 : std_logic ;
  signal N_759 : std_logic ;
  signal N_760 : std_logic ;
  signal N_761 : std_logic ;
  signal N_762 : std_logic ;
  signal N_763 : std_logic ;
  signal N_764 : std_logic ;
  signal N_765 : std_logic ;
  signal N_766 : std_logic ;
  signal N_767 : std_logic ;
  signal N_768 : std_logic ;
  signal N_769 : std_logic ;
  signal N_770 : std_logic ;
  signal N_771 : std_logic ;
  signal N_772 : std_logic ;
  signal N_773 : std_logic ;
  signal N_774 : std_logic ;
  signal N_775 : std_logic ;
  signal N_776 : std_logic ;
  signal N_777 : std_logic ;
  signal N_778 : std_logic ;
  signal N_779 : std_logic ;
  signal CPO_EXCZ : std_logic ;
  signal CPO_CCVZ : std_logic ;
  signal CPO_LDLOCKZ : std_logic ;
  signal RFI1_REN1Z : std_logic ;
  signal RFI1_REN2Z : std_logic ;
  signal RFI1_WRENZ : std_logic ;
  signal RFI2_REN1Z : std_logic ;
  signal RFI2_REN2Z : std_logic ;
  signal RFI2_WRENZ : std_logic ;
begin
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datad => \FPI.OP1_RETO\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => GND);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datad => \FPI.OP1_RETO\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datad => \FPI.OP1_RETO\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datad => \FPI.OP1_RETO\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datad => \FPI.OP1_RETO\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datad => \FPI.OP1_RETO\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datad => \FPI.OP1_RETO\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datad => \FPI.OP1_RETO\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datad => \FPI.OP1_RETO\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datad => \FPI.OP1_RETO\(9),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datad => \FPI.OP1_RETO\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datad => \FPI.OP1_RETO\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datad => \FPI.OP1_RETO\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datad => \FPI.OP1_RETO\(13),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datad => \FPI.OP1_RETO\(14),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datad => \FPI.OP1_RETO\(15),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datad => \FPI.OP1_RETO\(16),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datad => \FPI.OP1_RETO\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datad => \FPI.OP1_RETO\(18),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datad => \FPI.OP1_RETO\(19),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datad => \FPI.OP1_RETO\(20),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datad => \FPI.OP1_RETO\(21),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datad => \FPI.OP1_RETO\(22),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datad => \FPI.OP1_RETO\(23),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datad => \FPI.OP1_RETO\(24),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datad => \FPI.OP1_RETO\(25),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datad => \FPI.OP1_RETO\(26),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datad => \FPI.OP1_RETO\(27),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datad => \FPI.OP1_RETO\(28),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_48: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_49: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_50: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_53: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_54: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_55: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_56: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_57: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_58: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_59: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_60: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_61: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_62: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\,
cout => N_122924,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\);
VCC <= '1';
GND <= '0';
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI088L2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.N_15674\,
datad => N_125070,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI6PBD3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\,
datad => N_123417,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIEAF54_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\,
datad => N_123418,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIORIT4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\,
datad => N_123422,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI4DML5_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\,
datad => N_123423,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIIUPD6_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\,
datad => N_123426,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI2GT57_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\,
datad => N_123427,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIRUCU7_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\,
datad => N_123430,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIMHSM8_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\,
datad => N_123431,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIJ8CF9_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\,
datad => N_123434,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIP42HA_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\,
datad => N_123435,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI19OIB_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\,
datad => N_123438,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIBLEKC_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\,
datad => N_123439,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIN95MD_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\,
datad => N_123442,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI56SNE_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\,
datad => N_123443,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNILAJPF_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\,
datad => N_123446,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI7NARG_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\,
datad => N_123447,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNII31TH_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\,
datad => N_123450,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIVNNUI_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\,
datad => N_123451,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIEKE0K_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\,
datad => N_123454,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIMG42L_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\,
datad => N_123455,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI0LQ3M_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\,
datad => N_123458,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIC1H5N_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\,
datad => N_123459,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIRL77O_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\,
datad => N_123462,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNICIU8P_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\,
datad => N_123463,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIVMLAQ_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\,
datad => N_123465,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIK3DCR_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
cout => N_122922,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => N_123366,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI5RAQ2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => N_31236,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datad => \GRFPU0.GRFPU_X0.N_15701\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIUMAH3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31238,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.N_15703\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIGI984_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31240,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.N_15704\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI4M8V4_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31242,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.N_15705\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIQ18M5_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31244,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.N_15706\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIIL7D6_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31246,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.N_15707\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICH747_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31248,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.N_15708\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI8L7R7_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31250,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.N_15709\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI618I8_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31252,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.N_15710\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNITC799_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31254,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.N_15711\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIM070A_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31256,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.N_15712\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIHS6NA_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31258,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.N_15713\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI5O5EB_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31260,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.N_15714\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIRR45C_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31262,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.N_15715\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIJ74SC_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31264,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.N_15716\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIDR3JD_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31266,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.N_15717\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI9N3AE_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31268,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.N_15718\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI7R31F_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31270,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.N_15719\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI774OF_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31272,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.N_15720\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI0J3FG_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31274,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.N_15721\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIS636H_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31276,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.N_15722\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIQ23TH_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31278,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.N_15723\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIHU1KI_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31280,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.N_15724\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIE4F0J_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31282,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.N_15725\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIE4F0J_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31284,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\,
datad => VCC,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIE4F0J_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => N_31286,
cout => N_47,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_RNIQPK51_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fc000000ff00")
port map (
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.N_15567\,
datad => VCC,
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
cin => GND);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_RNIL1I33_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(1),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_0\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIEPCV6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(2),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI895PC_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(3),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI6PRGK_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(4),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIBHG6U_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(5),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNIGEVR91_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(6),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI0DTGN1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(7),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIUKA572_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(8),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNINLMQO2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(9),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI7EOIC3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIL0FK24_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(11),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI4HQVQ4_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(12),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIN3RKL5_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(13),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIHSGJI6_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(14),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNILVRRH7_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(15),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNI69R5J8_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(16),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI75GPM9_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(17),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_I_M2_1_RNI8C4FSA_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(18),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_RNIQ8O34C_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(19),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIUV0QDD_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(20),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI7PUPPE_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(21),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIOOH38G_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(22),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIKQOEOH_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(23),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIU2KRAJ_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(24),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIPL3AVK_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(25),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI2AINLM_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
cout => N_122920,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(26),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI5BTBQ3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => N_31291,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1\(28),
datad => N_31125,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(0),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => GND);
\GRFPU0_GRFPU_X0_DIFFIN1_RNI254GT5_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31293,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_2\,
datad => N_31129,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(2),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIP39448_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31295,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_3\,
datad => N_31131,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(3),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_2\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNI2NC8EA_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31297,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_4\,
datad => N_31133,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(4),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_3\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNIEVS8RC_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31299,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_5\,
datad => N_31135,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(5),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_4\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIJF8RBF_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31301,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_6\,
datad => N_31137,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(6),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_5\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIN7FVVH_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31303,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_7\,
datad => N_31139,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(7),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_6\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNI5EPPNK_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31305,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_8\,
datad => N_31141,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(8),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_7\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNIEAHGIN_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31307,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_9\,
datad => N_31143,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(9),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_8\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI8F4PGQ_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31309,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_10\,
datad => N_31145,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(10),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_9\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIPSIJIT_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31311,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_11\,
datad => N_31147,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(11),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_10\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI7JSVN01_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31313,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_12\,
datad => N_31149,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(12),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_11\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIAQ1U041_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31315,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_13\,
datad => N_31151,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(13),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_12\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIC13ED71_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31317,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_14\,
datad => N_31153,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(14),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_13\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIJ80GTA1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31319,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_15\,
datad => N_31155,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(15),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_14\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIAM18HE1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31321,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_16\,
datad => N_31157,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(16),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_15\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_RNIL13G8I1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31323,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_17\,
datad => N_31159,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(17),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_16\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNIP78A2M1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31325,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_18\,
datad => N_31161,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(18),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_17\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIHO3AVP1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31327,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_19\,
datad => N_31163,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(19),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_18\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI27HHVT1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31329,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_20\,
datad => N_31165,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(20),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_19\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNINPO4322_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31331,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_21\,
datad => N_31167,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(21),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_20\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIHAIV962_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31333,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_22\,
datad => N_31169,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(22),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_21\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI81U1KA2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31335,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_23\,
datad => N_31171,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(23),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_22\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIK5SB1F2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31337,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_24\,
datad => N_31173,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(24),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_23\);
\GRFPU0_GRFPU_X0_ST1_SGNF1_RNIO6MNHJ2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31339,
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_25\,
datad => N_31175,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(25),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_24\);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31341,
cout => N_48,
datad => N_31177,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26),
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_0_CARRY_25\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITF02_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(52),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => VCC,
cin => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRV04_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI15DD_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI8EPM_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIGR501_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIPCI91_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI32VI1_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIERBS1_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIQOO52_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI7Q5F2_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNILVIO2_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI49023_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIBECB3_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIJNOK3_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIS45U3_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI6MH74_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIHBUG4_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIT4BQ4_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIA2O35_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIO35D5_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI79IM5_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNINIVV5_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIVNB96_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI81OI6_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIIE4S6_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITVG57_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
cout => N_122918,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIPEPI_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_31346,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
cin => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI7C6S_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31348,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIMDJ51_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31350,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_2\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI6J0F1_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31352,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_3\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNINSDO1_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31354,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_4\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI02Q12_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31356,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_5\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIAB6B2_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31358,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_6\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNILOIK2_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31360,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_7\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI1AVT2_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31362,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_8\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIEVB73_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31364,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_9\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNISOOG3_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31366,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_10\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIBM5Q3_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31368,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_11\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRNI34_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31370,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_12\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNICTVC4_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31372,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_13\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIU6DM4_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31374,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_14\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI8CPV4_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31376,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_15\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIJL595_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31378,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_16\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIV2II5_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31380,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_17\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNICKUR5_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31382,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_18\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIQ9B56_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31384,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_19\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI93OE6_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31386,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_20\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIP05O6_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31388,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_21\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIA2I17_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31390,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_22\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIS7VA7_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31392,
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_23\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_RNO_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31394,
cout => N_49,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_0_CARRY_24\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITF02_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(52),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => VCC,
cin => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRV04_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI15DD_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI8EPM_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIGR501_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIPCI91_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI32VI1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIERBS1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIQOO52_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI7Q5F2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNILVIO2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI49023_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIBECB3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIJNOK3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIS45U3_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI6MH74_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIHBUG4_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIT4BQ4_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIA2O35_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIO35D5_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI79IM5_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNINIVV5_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIVNB96_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI81OI6_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIIE4S6_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITVG57_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000cccc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
cout => N_122916,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNICLC9_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31396,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => VCC,
cin => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIPEPI_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31398,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI7C6S_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31400,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIMDJ51_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31402,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI6J0F1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31404,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNINSDO1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31406,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI02Q12_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31408,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIAB6B2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31410,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNILOIK2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31412,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI1AVT2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31414,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIEVB73_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31416,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNISOOG3_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31418,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIBM5Q3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31420,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRNI34_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31422,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNICTVC4_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31424,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIU6DM4_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31426,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI8CPV4_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31428,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIJL595_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31430,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIV2II5_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31432,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNICKUR5_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31434,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIQ9B56_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31436,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNI93OE6_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31438,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIP05O6_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31440,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIA2I17_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31442,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22_0\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIS7VA7_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31444,
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => N_31446,
cout => N_50,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24_0\);
GRFPU0_FPMUL0_CS_DP_R_RNI1GS8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_31019,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3_0\,
dataf => \GRFPU0.FPMUL0.SX\(97),
datad => \GRFPU0.FPMUL0.SX\(98),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNICCMC_99_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31021,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4_0\,
datad => \GRFPU0.FPMUL0.SX\(99),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISUAO_100_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31023,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5_0\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDHV31_101_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31025,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6_0\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIV3KF1_102_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31027,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7_0\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIIM8R1_103_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31029,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8_0\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI69T62_104_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31031,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9_0\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIRRHI2_105_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31033,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10_0\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHE6U2_106_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31035,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11_0\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI81R93_107_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31037,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12_0\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0KFL3_108_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31039,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13_0\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIP6414_109_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31041,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14_0\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNICTOC4_110_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31043,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15_0\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0KDO4_111_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31045,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16_0\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNILA245_112_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31047,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17_0\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIB1NF5_113_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31049,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18_0\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2OBR5_114_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31051,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19_0\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIQE076_115_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31053,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20_0\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJ5LI6_116_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31055,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21_0\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIDS9U6_117_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31057,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22_0\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8JU97_118_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31059,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23_0\,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI4AJL7_119_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31061,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24_0\,
datad => \GRFPU0.FPMUL0.SX\(119),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIQ4818_120_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25_0\,
datad => \GRFPU0.FPMUL0.SX\(120),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHVSC8_121_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31065,
datad => \GRFPU0.FPMUL0.SX\(121),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25_0\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIFSI7_95_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_31016,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.SX\(96),
datad => \GRFPU0.FPMUL0.SX\(95),
cin => GND);
GRFPU0_FPMUL0_CS_DP_R_RNI6KLC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => N_31018,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.SX\(97),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_1\);
GRFPU0_FPMUL0_CS_DP_R_RNI74IL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_31020,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_3\,
dataf => \GRFPU0.FPMUL0.SX\(97),
datad => \GRFPU0.FPMUL0.SX\(98),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_2\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNII0CP_99_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31022,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.SX\(99),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_3\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2J051_100_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31024,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_4\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJ5LG1_101_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31026,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_5\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5O9S1_102_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31028,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_6\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOAU72_103_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31030,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_7\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNICTIJ2_104_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31032,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_8\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1G7V2_105_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31034,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_9\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIN2SA3_106_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31036,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_10\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIELGM3_107_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31038,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_11\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI68524_108_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31040,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_12\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIVQPD4_109_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31042,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_13\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIIHEP4_110_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31044,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_14\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI68355_111_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31046,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_15\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIRUNG5_112_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31048,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_16\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHLCS5_113_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31050,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_17\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI8C186_114_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31052,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_18\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI03MJ6_115_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31054,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_19\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIPPAV6_116_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31056,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_20\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJGVA7_117_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31058,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_21\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIE7KM7_118_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31060,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_22\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAU828_119_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31062,
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.SX\(119),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_23\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI0PTD8_120_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.SX\(120),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_24\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNINJIP8_121_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31066,
datad => \GRFPU0.FPMUL0.SX\(121),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_0_CARRY_25\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIR7TT1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(1),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\,
dataf => N_123526,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => GND);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIPNQR3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(2),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\,
dataf => N_123527,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIQFOP5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(3),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\,
dataf => N_123528,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIUFMN7_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(4),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\,
dataf => N_123529,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI5OKL9_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(5),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\,
dataf => N_123530,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI5TELB_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(6),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\,
dataf => N_123531,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIGUTKD_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(7),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\,
dataf => N_123532,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIU7DKF_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(8),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\,
dataf => N_123533,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIP0CLH_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(9),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.N_20623\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIGO1OJ_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(10),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\,
dataf => N_123534,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIEIM1M_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(11),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\,
dataf => N_123535,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIFGBBO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(12),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\,
dataf => N_123536,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIJI0LQ_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(13),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\,
dataf => N_123537,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIQOLUS_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(14),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\,
dataf => N_123538,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI43B8V_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(15),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\,
dataf => N_123539,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIH9V911_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(16),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.N_20616\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI1SKJ31_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(17),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\,
dataf => N_123540,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_I_M2_1_RNI17KL51_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(18),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\,
dataf => N_123541,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_RNIISJK71_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(19),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\,
dataf => N_123542,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNI4N8M91_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(20),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.N_20468\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI9PTVB1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(21),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\,
dataf => N_123543,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIHVI9E1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(22),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\,
dataf => N_123544,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIS17BG1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(23),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.N_20455\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIA8RCI1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(24),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.N_20473\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_RNIRIFEK1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(25),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.N_20463\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI9KEDM1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(26),
cout => N_122908,
dataf => N_123545,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIM1582_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31125,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datad => N_122928,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => GND);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIF7AG4_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31127,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => N_122934,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_0\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNINIBB6_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31129,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(29),
datad => N_122935,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNI4LA38_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31131,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.N_20648\,
datad => N_122945,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_2\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIDV9R9_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31133,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.N_20645\,
datad => N_122946,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_3\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNIT1G9B_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => N_31135,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => N_122957,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_4\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIODD2D_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31137,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datad => N_122958,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_5\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIMPARE_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31139,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datad => N_122964,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_6\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIRGCMG_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31141,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(35),
datad => N_122965,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_7\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNIN3J4I_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => N_31143,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => N_122973,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_8\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIUFGTJ_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31145,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datad => N_122974,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_9\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI8SDML_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31147,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datad => N_122979,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_10\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIL8BFN_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31149,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datad => N_122980,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_11\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIUO88P_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31151,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datad => N_122985,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_12\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNISG61R_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31153,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datad => N_122986,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_13\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIT84QS_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31155,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datad => N_122992,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_14\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNI5C6LU_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31157,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(43),
datad => N_122993,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_15\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_RNIVA6D01_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31159,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.N_20509\,
datad => N_123002,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_16\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNIA08M11_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => N_31161,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => N_123003,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_17\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIK53931_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31163,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.N_20786\,
datad => N_123012,
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_18\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIFSRS41_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => N_31165,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => N_123013,
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_19\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIHUOI61_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => N_31167,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(48),
datad => N_123022,
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_20\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIILH681_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31169,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datad => N_123023,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_21\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIFGAQ91_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31171,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datad => N_123031,
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_22\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI8F3EB1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => N_31173,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datad => N_123032,
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_23\);
\GRFPU0_GRFPU_X0_ST1_SGNF1_RNIKD1VC1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f00000003")
port map (
sumout => N_31175,
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_25\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_24\);
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNIPOSMD1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000fff0")
port map (
sumout => N_31177,
cout => N_51,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_0_CARRY_25\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIPH582_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(0),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_122928,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
cin => N_188357);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIL7BG4_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(1),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_122934,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_0\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNITICB6_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(2),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(29),
datad => N_122935,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_1\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIALB38_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(3),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.N_20648\,
datad => N_122945,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_2\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIJVAR9_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(4),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.N_20645\,
datad => N_122946,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_3\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNI6IH9B_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(5),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datad => N_122957,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_4\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI4EF2D_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(6),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datad => N_122958,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_5\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI5ADRE_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(7),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_122964,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_6\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIA1FMG_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(8),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(35),
datad => N_122965,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_7\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI94M4I_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(9),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datad => N_122973,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_8\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIJ0KTJ_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(10),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datad => N_122974,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_9\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI0THML_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(11),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datad => N_122979,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_10\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIGPFFN_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(12),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datad => N_122980,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_11\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNISPD8P_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(13),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datad => N_122985,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_12\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIT1C1R_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(14),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datad => N_122986,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_13\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI1AAQS_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(15),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_122992,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_14\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNI9DCLU_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(16),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(43),
datad => N_122993,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_15\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_RNI3CCD01_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(17),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.N_20509\,
datad => N_123002,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_16\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_RNIHHEM11_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(18),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_123003,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_17\);
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIRM9931_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(19),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.N_20786\,
datad => N_123012,
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_18\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIPT2T41_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(20),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_123013,
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_19\);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIRVVI61_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff03")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(21),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.DIFFIN1\(48),
datad => N_123022,
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_20\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIV6P681_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(22),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datad => N_123023,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_21\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIVHIQ91_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(23),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datad => N_123031,
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_22\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIR0CEB1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(24),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datad => N_123032,
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_23\);
\GRFPU0_GRFPU_X0_ST1_SGNF1_RNI7V9VC1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f00000003")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(25),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_25\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_24\);
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNICA5ND1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000fcfc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26),
cout => N_52,
dataf => VCC,
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_1_CARRY_25\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNISCI92_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\,
dataf => N_123417,
datad => N_125070,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI7UL13_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\,
datad => N_123418,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIDDB44_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\,
datad => N_123422,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNILS075_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\,
datad => N_123423,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIVBM96_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\,
datad => N_123426,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIBRBC7_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\,
datad => N_123427,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI08DF8_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\,
datad => N_123430,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNINOEI9_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\,
datad => N_123431,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIGDGLA_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\,
datad => N_123434,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNII7O1C_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\,
datad => N_123435,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIM90ED_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\,
datad => N_123438,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNISJ8QE_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\,
datad => N_123439,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI46H6G_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\,
datad => N_123442,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIE0QIH_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\,
datad => N_123443,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIQ23VI_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\,
datad => N_123446,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI8DCBK_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\,
datad => N_123447,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIFNKNL_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\,
datad => N_123450,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIO9T3N_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\,
datad => N_123451,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI346GO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\,
datad => N_123454,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI7UDSP_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\,
datad => N_123455,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNID0M8R_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\,
datad => N_123458,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNILAUKS_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\,
datad => N_123459,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIVS61U_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\,
datad => N_123462,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIBNFDV_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\,
datad => N_123463,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIPPOP01_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
cout => N_122904,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => N_123465,
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIDO353_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.S3ADDI\(27),
datad => N_123366,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI8C3S3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.N_15702\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI583J4_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31187,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.N_15703\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIR32A5_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31189,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.N_15704\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIJ7116_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31191,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.N_15705\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIDJ0O6_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31193,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.N_15706\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI970F7_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31195,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.N_15707\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI73068_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31197,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.N_15708\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI770T8_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31199,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.N_15709\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI9J0K9_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31201,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.N_15710\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI4VVAA_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31203,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.N_15711\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI1JV1B_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31205,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.N_15712\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI0FVOB_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31207,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.N_15713\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIOAUFC_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31209,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.N_15714\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIIET6D_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31211,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.N_15715\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIEQSTD_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31213,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.N_15716\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICESKE_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31215,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.N_15717\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICASBF_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31217,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.N_15718\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIEES2G_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31219,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.N_15719\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIIQSPG_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31221,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.N_15720\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIF6SGH_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31223,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.N_15721\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIEQR7I_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31225,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.N_15722\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIFMRUI_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31227,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.N_15723\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI9IQLJ_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_31229,
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.N_15724\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_23\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => N_31231,
cout => N_53,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.N_15725\,
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_1_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(36),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(36),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(0),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(37),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(37),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(38),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(38),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(39),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(39),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(40),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(40),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(41),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(41),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(42),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(42),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(43),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(43),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(44),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(44),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(45),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(45),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(46),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(46),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(47),
cout => N_122902,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(47),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30745,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(12),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(48),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30747,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(13),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30749,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(14),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30751,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(15),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30753,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(16),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30755,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_5\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(17),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30757,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_6\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(18),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30759,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_7\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(19),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30761,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_8\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(20),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30763,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_9\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(21),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30765,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_10\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(22),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30767,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_11\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(23),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30769,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_12\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(24),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30771,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_13\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(25),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(61),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30773,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_14\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(26),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(62),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30775,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_15\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(27),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(63),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30777,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_16\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(28),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(64),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30779,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_17\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(29),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(65),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30781,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_18\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(30),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(66),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30783,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_19\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(31),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(67),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30785,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_20\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(32),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(68),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30787,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_21\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(33),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(69),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30789,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_22\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(34),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(70),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30791,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_23\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(35),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(71),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30793,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(36),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30795,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30797,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30799,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_27\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30801,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_28\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30803,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_29\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30805,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_30\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30807,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_31\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30809,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_32\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30811,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_33\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30813,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_34\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30815,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_35\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30817,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_36\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30819,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_37\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30821,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_38\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30823,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_39\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30825,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_40\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30827,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_41\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30829,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_42\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30831,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_43\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30833,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_44\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30835,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_45\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30837,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_46\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30839,
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_47\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30841,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_0_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(0),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(48),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(12),
cin => N_188355);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(1),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(49),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(2),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(50),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(3),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(51),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(4),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(52),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(5),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_5\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(53),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(6),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_6\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(7),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_7\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(55),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(8),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_8\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(56),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(9),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_9\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(57),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(10),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_10\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(58),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(11),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_11\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(59),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(12),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_12\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(60),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(13),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_13\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(61),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(14),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_14\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(62),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(15),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_15\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(63),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(16),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_16\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(64),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(17),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_17\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(65),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(18),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_18\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(66),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(19),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_19\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(67),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(20),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_20\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(68),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(21),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_21\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(69),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(22),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_22\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(70),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(23),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_23\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(71),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(24),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_24\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(36),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(25),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_25\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(26),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_26\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(27),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_27\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(28),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_28\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(29),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_29\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(30),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(31),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_31\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(32),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_32\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(33),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_33\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(34),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_34\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(35),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_35\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(36),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(37),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(38),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(39),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(40),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(41),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(42),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(43),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(44),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(45),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(46),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(47),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_48: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(48),
cout => N_54,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1_CARRY_47\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI94I7_92_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30847,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.SX\(93),
datad => \GRFPU0.FPMUL0.SX\(92),
cin => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIFCBB_94_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30849,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.SX\(94),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_1\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMO4F_95_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30851,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_3\,
datad => \GRFPU0.FPMUL0.SX\(95),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_2\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIU8UI_96_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30853,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.SX\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_3\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI7TNM_97_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30855,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.SX\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_4\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIHLHQ_98_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30857,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.SX\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_5\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNISHBU_99_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30859,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.SX\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_6\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIC40A1_100_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30861,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_7\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITMKL1_101_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30863,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_8\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIF9912_102_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30865,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_9\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2STC2_103_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30867,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_10\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIMEIO2_104_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30869,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_11\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIB1743_105_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30871,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_12\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI1KRF3_106_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30873,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_13\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIO6GR3_107_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30875,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_14\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGP474_108_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30877,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_15\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI9CPI4_109_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30879,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_16\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIS2EU4_110_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30881,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_17\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGP2A5_111_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30883,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_18\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI5GNL5_112_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30885,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_19\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIR6C16_113_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30887,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_20\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIIT0D6_114_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30889,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_21\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIAKLO6_115_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30891,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_22\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI3BA47_116_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30893,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_23\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIT1VF7_117_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30895,
cout => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_24\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIOOJR7_118_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30897,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNIT92ES: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(72),
datad => N_30793,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(24),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNIAQT4P1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(73),
datad => N_30795,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(25),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNI7HI4M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(74),
datad => N_30797,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(26),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNIKE0DJ3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(75),
datad => N_30799,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(27),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIHI7UG4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\,
dataf => N_30801,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(76),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(28),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNIUS7OE5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\,
dataf => N_30803,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(77),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(29),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNI9L1RC6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\,
dataf => N_30805,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(78),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(30),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNI4KK6B7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\,
dataf => N_30807,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(79),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(31),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNIFP0R98: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\,
dataf => N_30809,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(80),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNIA56O89: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\,
dataf => N_30811,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(81),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(33),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNILN4U7A: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\,
dataf => N_30813,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(82),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(34),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNIGGSC7B: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\,
dataf => N_30815,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(83),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(35),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNIRFD47C: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\,
dataf => N_30817,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(84),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(36),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNIMLN47D: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\,
dataf => N_30819,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(85),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(37),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNI12RD7E: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\,
dataf => N_30821,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(86),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(38),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNISKNV7F: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\,
dataf => N_30823,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(87),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(39),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNILLDQ8G: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\,
dataf => N_30825,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(88),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(40),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNIUSST9H: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\,
dataf => N_30827,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(89),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(41),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNINA5ABI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\,
dataf => N_30829,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(90),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(42),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNI0V6VCJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\,
dataf => N_30831,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(91),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(43),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44_RNIPP1TEK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\,
dataf => N_30833,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(92),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(44),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNI2RL3HL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\,
dataf => N_30835,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(93),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(45),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_46_RNIR23JJM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\,
dataf => N_30837,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(94),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(46),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_47_RNI4H9BMN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\,
dataf => N_30839,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(95),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(47),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIT59CPO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f330000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(96),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(48),
datab => N_30841,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI4UGIRP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIB1TMRP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNII49RRP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIP7LVRP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI0B14SP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI7ED8SP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIEHPCSP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNILK5HSP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNISNHLSP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI3RTPSP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIAU9USP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIH1M2TP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(36),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIO427TP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIV7EBTP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI6BQFTP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIDE6KTP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIKHIOTP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIRKUSTP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI2OA1UP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI9RM5UP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIGU2AUP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIN1FEUP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIU4RIUP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI587NUP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNICBJRUP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_36_RNI35T6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(36),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(36),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_37_RNI7AQD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(37),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_38_RNICFNK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(38),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_39_RNIIKKR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(39),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_40_RNIGTH21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(40),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_41_RNIF6F91: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(41),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_42_RNIFFCG1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(42),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_43_RNIGO9N1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(43),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_44_RNII17U1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(44),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_45_RNILA452: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(45),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_46_RNIPJ1C2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(46),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_47_RNIUSUI2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(47),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_N\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_0_RNI60VF3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(48),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
datad => N_30745,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(0),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_1_RNIG3VC4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(49),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
datad => N_30747,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(1),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_2_RNIS6V95: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(50),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
datad => N_30749,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(2),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_3_RNIAAV66: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(51),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
datad => N_30751,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(3),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_4_RNIQDV37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(52),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
datad => N_30753,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(4),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_5_RNICHV08: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(53),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
datad => N_30755,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(5),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_6_RNI0LVT8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(54),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(18),
datad => N_30757,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(6),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_7_RNIMOVQ9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(55),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(19),
datad => N_30759,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(7),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_8_RNIESVNA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(56),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(20),
datad => N_30761,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(8),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_9_RNI800LB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(57),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(21),
datad => N_30763,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(9),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_10_RNIIAGOC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(58),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(22),
datad => N_30765,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(10),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_11_RNIUK0SD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(59),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(23),
datad => N_30767,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(11),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_12_RNICVGVE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(60),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(24),
datad => N_30769,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(12),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_13_RNIS913G: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(61),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(25),
datad => N_30771,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(13),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_14_RNIEKH6H: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(62),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(26),
datad => N_30773,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(14),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_15_RNI2V1AI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(63),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(27),
datad => N_30775,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(15),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_16_RNIO9IDJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(64),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(28),
datad => N_30777,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(16),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_17_RNIGK2HK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(29),
datad => N_30779,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(17),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18_RNIAVIKL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(30),
datad => N_30781,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(18),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNI6A3OM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(31),
datad => N_30783,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(19),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20_RNIISJRN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(32),
datad => N_30785,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(20),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNI0F4VO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(33),
datad => N_30787,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(21),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNIG1L2Q: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(34),
datad => N_30789,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(22),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI2K56R: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(35),
datad => N_30791,
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_1\(23),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIGQUER: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(72),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(36),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIU0ONR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(73),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(37),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIC7H0S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(74),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(38),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIQDA9S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(75),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(39),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI8K3IS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(76),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(40),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIMQSQS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(77),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(41),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI41M3T: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(78),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(42),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNII7FCT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(79),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(43),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI0E8LT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(80),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(44),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIEK1UT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(81),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(45),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNISQQ6U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(82),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(46),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIA1KFU: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(83),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(47),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIO7DOU: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(84),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(48),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI6E61V: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(49),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIKKV9V: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(50),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI2ROIV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(51),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIG1IRV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(52),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIU7B401: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(53),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNICE4D01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIQKTL01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(55),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI8RMU01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(56),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIM1G711: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(57),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI489G11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(58),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIIE2P11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(59),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI0LR121: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(96),
cout => N_122894,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(60),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(56),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY\,
datad => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(55),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(54),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(53),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(52),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(51),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(50),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(49),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(48),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(47),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(46),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(45),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(44),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(43),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(42),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(41),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(40),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(39),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(38),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(37),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(36),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(35),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(34),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(33),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(32),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(31),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(30),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(29),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(28),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(27),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(26),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(25),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(24),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(23),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(22),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(21),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(20),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(19),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(18),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(17),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(16),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(15),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(14),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(13),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(12),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(11),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_48: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_49: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_50: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_53: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_54: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_55: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003333")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(1),
cout => N_55,
datab => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(11),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => VCC,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(58),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000030000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\,
dataf => N_123290,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.N_7645\,
datab => \GRFPU0.GRFPU_X0.N_6661\,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000030000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.N_7645\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.N_6661\,
datab => N_123290,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000030000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.N_7645\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.N_6661\,
datab => N_123290,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(1),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0c300000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\,
dataf => N_123287,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
datab => N_123286,
cin => GND);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
cout => N_56,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datac => N_123284,
datab => N_123283,
cin => GND);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(30),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(31),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(32),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(33),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(34),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(35),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(36),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(38),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(39),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(41),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(42),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(43),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(44),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(45),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(46),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(47),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(48),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(49),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(50),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
cout => N_122892,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\,
dataf => N_125011,
datad => \GRFPU0.GRFPU_X0.N_15703\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => GND);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.N_15704\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.N_15705\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.N_15706\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.N_15707\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.N_15708\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.N_15709\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.N_15710\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.N_15711\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.N_15712\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.N_15713\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.N_15714\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.N_15715\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.N_15716\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.N_15717\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.N_15718\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.N_15719\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.N_15720\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.N_15721\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.N_15722\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.N_15723\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.N_15724\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.N_15725\,
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(23),
cout => N_122890,
datad => VCC,
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(1),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(2),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(3),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(4),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(5),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(6),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(7),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(8),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(9),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(10),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datad => N_174627,
datac => N_174628,
datab => \GRFPU0.GRFPU_X0.N_4094\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000fc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(11),
cout => N_57,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datad => \GRFPU0.GRFPU_X0.N_4094\,
datac => N_174627,
datab => N_174628,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
cin => N_188353);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(54),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
cin => GND);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
cout => N_58,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(10),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(9),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(8),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(7),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(6),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(5),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.N_6097\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(4),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datad => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.N_6097\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(3),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(2),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(1),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(1),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datad => N_174581,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000fc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(11),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => N_174581,
datab => \GRFPU0.GRFPU_X0.COMB.EXP37\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(0),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_188351);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(1),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(2),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(3),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(4),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(5),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(6),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(7),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(8),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(9),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(10),
cout => N_59,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\);
GRFPU0_GRFPU_X0_C_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(0),
cout => \GRFPU0.GRFPU_X0.C_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_188349);
GRFPU0_GRFPU_X0_C_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(1),
cout => \GRFPU0.GRFPU_X0.C_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.C_CARRY_0\);
GRFPU0_GRFPU_X0_C_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(2),
cout => \GRFPU0.GRFPU_X0.C_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.C_CARRY_1\);
GRFPU0_GRFPU_X0_C_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(3),
cout => \GRFPU0.GRFPU_X0.C_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.C_CARRY_2\);
GRFPU0_GRFPU_X0_C_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(4),
cout => \GRFPU0.GRFPU_X0.C_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.C_CARRY_3\);
GRFPU0_GRFPU_X0_C_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(5),
cout => \GRFPU0.GRFPU_X0.C_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.C_CARRY_4\);
GRFPU0_GRFPU_X0_C_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(6),
cout => \GRFPU0.GRFPU_X0.C_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
cin => \GRFPU0.GRFPU_X0.C_CARRY_5\);
GRFPU0_GRFPU_X0_C_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(7),
cout => \GRFPU0.GRFPU_X0.C_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
cin => \GRFPU0.GRFPU_X0.C_CARRY_6\);
GRFPU0_GRFPU_X0_C_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(8),
cout => \GRFPU0.GRFPU_X0.C_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
cin => \GRFPU0.GRFPU_X0.C_CARRY_7\);
GRFPU0_GRFPU_X0_C_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(9),
cout => \GRFPU0.GRFPU_X0.C_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
cin => \GRFPU0.GRFPU_X0.C_CARRY_8\);
GRFPU0_GRFPU_X0_C_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(10),
cout => \GRFPU0.GRFPU_X0.C_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_9\);
GRFPU0_GRFPU_X0_C_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(11),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_10\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_188347);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_188345);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(0),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => GND);
GRFPU0_GRFPU_X0_UN8_C_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(1),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(2),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(3),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(4),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(5),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(6),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(7),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(8),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(9),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000f0f0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(10),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000f0f0")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
cout => N_60,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_23_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\,
cin => N_122890);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_22_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
cin => N_122892);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI0LR121_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
cin => N_122894);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_CARRY_47_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_0_CARRY_47\,
cin => N_122902);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIPPOP01_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
cin => N_122904);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI9KEDM1_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
cin => N_122908);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITVG57_2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
cin => N_122916);
\GRFPU0_GRFPU_X0_ITER_R_I_RNITVG57_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
cin => N_122918);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI2AINLM_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
cin => N_122920);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIK3DCR_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
cin => N_122922);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2\,
cin => N_122924);
GRFPC0_FP_PIPELINE_DEPMUX_RES_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cfd08fc0cec4c")
port map (
combout => \GRFPC0.N_11185\,
dataf => N_128,
datae => \GRFPC0.INST_SN_N_2\,
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(1),
datac => \GRFPC0.FIFO.INST_1\(25),
datab => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(0),
dataa => \GRFPC0.INST_0\,
datag => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FPUSEL_6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"c0003200c0000000")
port map (
combout => \GRFPC0.FPUSEL_6\(3),
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2\,
datae => N_63,
datad => \GRFPC0.N_21694\,
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.0.MEMEN2\,
dataa => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datag => \GRFPC0.FP_PIPELINE.0.MEMSEL4\);
\GRFPC0_RFA2_RS2SEL_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"2220101022200000")
port map (
combout => \GRFPC0.FPUSEL_1\(4),
dataf => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datae => N_63,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datac => \GRFPC0.FP_PIPELINE.0.WR2SEL4\,
datab => \GRFPC0.UN1_WRENX10_1\,
dataa => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datag => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_RFA2_RS2SEL_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00000000f00000e0")
port map (
combout => \GRFPC0.FPUSEL_1\(3),
dataf => \GRFPC0.FP_PIPELINE.1.EXEN7\,
datae => N_63,
datad => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
datac => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
dataa => \GRFPC0.WR.RREG.RESV\,
datag => \GRFPC0.FP_PIPELINE.0.MEMSEL4\);
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"55575f7f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_68_I\,
dataf => \GRFPU0.GRFPU_X0.N_68_I_0_G0_1\,
datae => \FPI.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.N_221\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.N_87\,
dataa => \GRFPU0.GRFPU_X0.N_8127_M_I\,
datag => N_100296_TZ);
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_O3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"1100150415049900")
port map (
combout => \GRFPC0.N_20672\,
dataf => \GRFPC0.INST\(8),
datae => \GRFPC0.INST\(7),
datad => \GRFPC0.N_20667_I\,
datac => \GRFPC0.INST\(6),
datab => \GRFPC0.INST\(12),
dataa => \GRFPC0.INST\(9),
datag => \GRFPC0.INST\(5));
\GRFPC0_D_STLCK_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc00fc00fd00fd00")
port map (
combout => \GRFPC0.N_21939\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.N_21981\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
datac => \GRFPC0.FP_PIPELINE.11.STDEP_452\(1),
datab => \GRFPC0.N_21967\,
dataa => \GRFPC0.N_94\,
datag => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\);
\GRFPC0_FP_PIPELINE_RS2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"faccfacc50cc50cc")
port map (
combout => RFI2_RD2ADDRZ(1),
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.INST_0\,
datad => N_63,
datac => N_105,
datab => \GRFPC0.RFA.RS2\(2),
dataa => \GRFPC0.INST_SN_N_2\,
datag => \GRFPC0.FIFO.INST_1\(2));
\GRFPC0_FP_PIPELINE_RS2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"faccfacc50cc50cc")
port map (
combout => RFI2_RD2ADDRZ(0),
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.INST_0\,
datad => N_63,
datac => N_104,
datab => \GRFPC0.RFA.RS2\(1),
dataa => \GRFPC0.INST_SN_N_2\,
datag => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPC0.N_23609\,
dataf => N_119,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => N_130);
\GRFPC0_FP_PIPELINE_RS1_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPC0.N_18115\,
dataf => N_117,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => N_128);
\GRFPC0_FP_PIPELINE_RS2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"faccfacc50cc50cc")
port map (
combout => RFI2_RD2ADDRZ(2),
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.INST_0\,
datad => N_63,
datac => N_106,
datab => \GRFPC0.RFA.RS2\(3),
dataa => \GRFPC0.INST_SN_N_2\,
datag => \GRFPC0.FIFO.INST_1\(3));
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPC0.N_23608\,
dataf => N_120,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => N_131);
\GRFPC0_FP_PIPELINE_RS1_6_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPC0.N_18119\,
dataf => N_121,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => N_132);
\GRFPC0_FP_PIPELINE_RS2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fd31f0f0ec20f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.RS2_1\(0),
dataf => N_103,
datae => N_63,
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.RFA.RS2\(0),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_RS1_6_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPC0.N_18116\,
dataf => N_118,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.INST_SN_N_2\,
dataa => \GRFPC0.INST_0\,
datag => N_129);
\GRFPC0_FP_PIPELINE_RS2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"faccfacc50cc50cc")
port map (
combout => RFI2_RD2ADDRZ(3),
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.INST_0\,
datad => N_63,
datac => N_107,
datab => \GRFPC0.RFA.RS2\(4),
dataa => \GRFPC0.INST_SN_N_2\,
datag => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O3_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fbbbfbfbaaaaaaaa")
port map (
combout => \GRFPC0.N_22422\,
dataf => \GRFPC0.N_22289\,
datae => \GRFPC0.N_21545\,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
datac => \GRFPC0.N_21794\,
datab => \GRFPC0.N_21556\,
dataa => \GRFPC0.N_22421\,
datag => N_38025);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5afff2ff5aff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(55),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(8),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datag => N_36015);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5afff2ff5aff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(56),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datag => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0ffff2ff0fff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(61),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datag => N_36040);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0fff2fff0ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(57),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datag => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0ffff2ff0fff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(60),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datag => N_36040);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"05af272700000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(53),
dataf => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datae => \GRFPU0.MULO.MRES_1\(120),
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.DRES_1S\(112),
datab => \GRFPU0.MULO.MRES\(112),
dataa => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datag => \GRFPU0.MULO.DRES_1\(113));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"05af272700000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(55),
dataf => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datae => \GRFPU0.MULO.MRES_1\(120),
datad => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.MULO.DRES_1S\(114),
datab => \GRFPU0.MULO.MRES\(114),
dataa => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datag => \GRFPU0.MULO.DRES_1\(115));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0fff2fff0ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(58),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_7458\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datag => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffff0a220a22")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(37),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datag => \GRFPU0.MULO.MRES\(97));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fcfcffccfcfcdcdc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(52),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(11),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
dataa => \GRFPU0.GRFPU_X0.N_7458\,
datag => \GRFPU0.GRFPU_X0.ST2.REG\(49));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_O2_8_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"40000f0fe0000f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_8_0\,
dataf => \GRFPC0.N_130\,
datae => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datad => \GRFPC0.N_21137_0\,
datac => \GRFPC0.N_131_0\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datag => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\);
\GRFPC0_RFA_RS2_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f0f0fac8f5c4")
port map (
combout => N_52885,
dataf => N_49627,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => N_49468_I,
datac => \GRFPC0.FIFO.INST_0\(1),
datab => N_104,
dataa => \GRFPC0.FIFO.WR\(0),
datag => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_RFA_RS2_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f0f0fac8f5c4")
port map (
combout => N_52886,
dataf => N_49627,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => N_49468_I,
datac => \GRFPC0.FIFO.INST_0\(2),
datab => N_105,
dataa => \GRFPC0.FIFO.WR\(0),
datag => \GRFPC0.FIFO.INST_1\(2));
\GRFPC0_RFA_RS2_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f0f0fac8f5c4")
port map (
combout => N_52884,
dataf => N_49627,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => N_49468_I,
datac => \GRFPC0.FIFO.INST_0\(0),
datab => N_103,
dataa => \GRFPC0.FIFO.WR\(0),
datag => \GRFPC0.FIFO.INST_1\(0));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3cf05f5f3cf0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(5),
dataf => \FPI.OP1\(60),
datae => \FPI.FLOP_1_0\(1),
datad => N_36249,
datac => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datab => \FPI.OP1\(56),
dataa => \FPI.OP1\(59),
datag => \FPI.OP1\(57));
\GRFPC0_RFA_RS2_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f0f0fac8f5c4")
port map (
combout => N_52887,
dataf => N_49627,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => N_49468_I,
datac => \GRFPC0.FIFO.INST_0\(3),
datab => N_106,
dataa => \GRFPC0.FIFO.WR\(0),
datag => \GRFPC0.FIFO.INST_1\(3));
\GRFPC0_RFA_RS2_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f0f0fac8f5c4")
port map (
combout => N_52888,
dataf => N_49627,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => N_49468_I,
datac => \GRFPC0.FIFO.INST_0\(4),
datab => N_107,
dataa => \GRFPC0.FIFO.WR\(0),
datag => \GRFPC0.FIFO.INST_1\(4));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000800000000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_A2_2_4__N_4\,
dataf => \FPI.OP2\(54),
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_221\,
datac => \GRFPU0.GRFPU_X0.N_20304\,
datab => \FPI.OP2\(52),
dataa => \FPI.OP2\(53),
datag => \FPI.OP2\(51));
\GRFPC0_R_FSR_FTT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"1030002210300020")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_0__G1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.PENDEXC_0_SQMUXA\,
datab => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
dataa => N_61,
datag => \GRFPC0.R.FSR.FTT\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00a0808055f5d5d5")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_131_0\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL0_1\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
dataa => N_174897,
datag => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffffafbffafb")
port map (
combout => \GRFPC0.N_21104\,
dataf => \GRFPC0.N_21044\,
datae => \GRFPC0.N_21046_I\,
datad => \GRFPC0.N_78_I_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.EX.CTRL.RD\(0),
dataa => \GRFPC0.N_21043\,
datag => \GRFPC0.EX.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3ccc5a5a3ccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_80_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(56),
datab => \FPI.OP2\(53),
dataa => \FPI.OP2\(55),
datag => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"a0f0a0f0d844d844")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datae => \GRFPU0.GRFPU_X0.N_7942\,
datad => \GRFPU0.GRFPU_X0.N_13127_I\,
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.COMB.SIGN_1\,
dataa => \GRFPU0.GRFPU_X0.N_19890\,
datag => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffff0ace0f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_2\(1),
dataf => \GRFPC0.N_21001\,
datae => \GRFPC0.N_20975\,
datad => \GRFPC0.N_20985\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datab => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
dataa => \GRFPC0.N_131_1\,
datag => \GRFPC0.N_20976\);
GRFPU0_GRFPU_X0_VALLOW_3_SQMUXA_5_RNI4M7E9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"030f33ff030f135f")
port map (
combout => \GRFPU0.GRFPU_X0.ALLOW_0_1__G0_1_0\,
dataf => N_174933,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
datab => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datag => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_I_M_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"20a820a8028a028a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11_I_M\(2),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO1\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.L2_0\(2),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
dataa => \GRFPU0.GRFPU_X0.N_19526_1\,
datag => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ccafccafcc50cc50")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(3),
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.L2_0\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
dataa => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO1\,
datag => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15));
\GRFPC0_STDATA_I_M2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(13),
dataf => \GRFPC0.FP_PIPELINE.QNE2\,
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(45),
datac => \GRFPC0.R.STDATA\(13),
datab => \GRFPC0.EX.RREG.RES\(13),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(8),
datae => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => N_174945,
dataa => \GRFPU0.MULO.MRES\(69),
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(56),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datae => \GRFPU0.MULO.MRES\(116),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(56),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => N_174945,
dataa => \GRFPU0.MULO.MRES\(117),
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPC0_D_STDLCK_RNO_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ff7fff7f7f7f7f7f")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_2\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datae => \GRFPC0.N_21541\,
datad => \GRFPC0.N_24408\,
datac => \GRFPC0.N_78_I_I_0\,
datab => \GRFPC0.N_22313\,
dataa => \GRFPC0.N_22324\,
datag => \GRFPC0.N_21543\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00f3a0a000c0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.N_19398\,
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3f30f5f53f30a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.C\(0),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datag => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3f30f5f53f30a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(1),
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datab => \GRFPU0.GRFPU_X0.UN23_EXP\(1),
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datag => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(50),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datae => \GRFPU0.MULO.MRES\(110),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(50),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => N_174945,
dataa => \GRFPU0.MULO.MRES\(111),
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(51),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datae => \GRFPU0.MULO.MRES\(111),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(51),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => N_174945,
dataa => \GRFPU0.MULO.MRES\(112),
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(48),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => N_174945,
dataa => \GRFPU0.MULO.MRES\(109),
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"72d8f5f572d8a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
dataf => \GRFPU0.MULO.DRES_1\(93),
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.FPMUL0.SX\(92),
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
dataa => \GRFPU0.GRFPU_X0.N_19499_0\,
datag => \GRFPU0.MULO.DRES_1S\(92));
\GRFPC0_OP2_6_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0bbf0bbf088f088")
port map (
combout => \GRFPC0.N_19901\,
dataf => \GRFPC0.WR.RREG.RES\(18),
datae => \GRFPC0.OP2_4\,
datad => \GRFPC0.RFA2.RS2SEL_1\(7),
datac => N_766,
datab => \GRFPC0.RFA2.RS2SEL_1\(1),
dataa => \GRFPC0.EX.RREG.RES\(18),
datag => N_702);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4fff4f4f4f4f4")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(58),
dataf => N_174945,
datae => \GRFPU0.MULO.MRES\(118),
datad => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
datag => \GRFPU0.GRFPU_X0.N_19279_I\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO9_RNIV53K1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5d5d555ddddddddd")
port map (
combout => \GRFPU0.GRFPU_X0.N_6576_1\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datad => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_2_0\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
dataa => \GRFPU0.GRFPU_X0.N_6995\,
datag => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT10\);
\GRFPU0_GRFPU_X0_L3_0_6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(2),
dataf => \GRFPU0.GRFPU_X0.N_10583\,
datae => \GRFPU0.GRFPU_X0.N_10558\,
datad => \GRFPU0.GRFPU_X0.N_10526\,
datac => \GRFPU0.GRFPU_X0.N_10570\,
datab => \GRFPU0.GRFPU_X0.N_10521\,
dataa => \GRFPU0.GRFPU_X0.N_10569\,
datag => \GRFPU0.GRFPU_X0.N_10519\);
\GRFPC0_DIV_EXCT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f00003aaaaaaaa")
port map (
combout => N_29816,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datac => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.IOF\,
dataa => \GRFPC0.DIV.EXCT\(2),
datag => \GRFPU0.GRFPU_X0.ST4.EXC\(2));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(5),
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.C\(5),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datag => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\);
\GRFPC0_D_STDLCK_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffdfffdfffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_3\,
dataf => \GRFPC0.N_21891\,
datae => \GRFPC0.N_21467\,
datad => \GRFPC0.STDDEP_0_SQMUXA_96\,
datac => \GRFPC0.N_78_I_I_0\,
datab => \GRFPC0.STDDEP_0_SQMUXA_93\,
dataa => \GRFPC0.N_21896\,
datag => \GRFPC0.N_21460\);
\GRFPC0_OP2_6_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19889\,
dataf => \GRFPC0.WR.RREG.RES\(6),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_754,
datac => \GRFPC0.EX.RREG.RES\(6),
datab => N_690,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17906\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datag => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17867\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17875\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20));
\GRFPC0_OP2_6_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0bbf0bbf088f088")
port map (
combout => \GRFPC0.N_19927\,
dataf => \GRFPC0.WR.RREG.RES\(44),
datae => \GRFPC0.OP2_SN_N_5\,
datad => \GRFPC0.RFA2.RS2SEL\(7),
datac => N_696,
datab => \GRFPC0.RFA2.RS2SEL\(1),
dataa => \GRFPC0.EX.RREG.RES\(44),
datag => N_760);
\GRFPC0_OP2_6_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0bbf0bbf088f088")
port map (
combout => \GRFPC0.N_19930\,
dataf => \GRFPC0.WR.RREG.RES\(47),
datae => \GRFPC0.OP2_SN_N_5\,
datad => \GRFPC0.RFA2.RS2SEL\(7),
datac => N_699,
datab => \GRFPC0.RFA2.RS2SEL\(1),
dataa => \GRFPC0.EX.RREG.RES\(47),
datag => N_763);
\GRFPC0_OP1_6_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19319\,
dataf => \GRFPC0.WR.RREG.RES\(7),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_723,
datac => \GRFPC0.EX.RREG.RES\(7),
datab => N_659,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17891\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36));
\GRFPC0_OP1_6_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19339\,
dataf => \GRFPC0.WR.RREG.RES\(27),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_743,
datac => \GRFPC0.EX.RREG.RES\(27),
datab => N_679,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fcf0fcf0fefafefa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(13),
dataf => \GRFPU0.MULO.MRES\(74),
datae => \GRFPU0.MULO.MRES\(73),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(13),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
dataa => N_174945,
datag => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPC0_OP1_5_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19303\,
dataf => \GRFPC0.DIV.RESULT\(57),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21433_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RES\(57),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19307\,
dataf => \GRFPC0.DIV.RESULT\(61),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21425_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.WR2.RREG.RES\(61),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19899\,
dataf => \GRFPC0.WR.RREG.RES\(16),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_764,
datac => \GRFPC0.EX.RREG.RES\(16),
datab => N_700,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19330\,
dataf => \GRFPC0.WR.RREG.RES\(18),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_734,
datac => \GRFPC0.EX.RREG.RES\(18),
datab => N_670,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_5_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19865\,
dataf => \GRFPC0.DIV.RESULT\(48),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21444_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(48),
datab => \GRFPC0.WR2.RREG.RES\(48),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19884\,
dataf => \GRFPC0.WR.RREG.RES\(1),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_749,
datac => \GRFPC0.EX.RREG.RES\(1),
datab => N_685,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19324\,
dataf => \GRFPC0.WR.RREG.RES\(12),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_728,
datac => \GRFPC0.EX.RREG.RES\(12),
datab => N_664,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_21049\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17868\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
\GRFPC0_OP1_6_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19340\,
dataf => \GRFPC0.WR.RREG.RES\(28),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_744,
datac => \GRFPC0.EX.RREG.RES\(28),
datab => N_680,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17905\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datag => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPC0_OP2_6_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0bbf0bbf088f088")
port map (
combout => \GRFPC0.N_19920\,
dataf => \GRFPC0.WR.RREG.RES\(37),
datae => \GRFPC0.OP2_SN_N_5\,
datad => \GRFPC0.RFA2.RS2SEL_1\(7),
datac => N_689,
datab => \GRFPC0.RFA2.RS2SEL\(1),
dataa => \GRFPC0.EX.RREG.RES\(37),
datag => N_753);
\GRFPC0_OP1_6_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19341\,
dataf => \GRFPC0.WR.RREG.RES\(29),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_745,
datac => \GRFPC0.EX.RREG.RES\(29),
datab => N_681,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17857\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPC0_OP1_5_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19287\,
dataf => \GRFPC0.DIV.RESULT\(41),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21430_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(41),
datab => \GRFPC0.WR2.RREG.RES\(41),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19885\,
dataf => \GRFPC0.WR.RREG.RES\(2),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_750,
datac => \GRFPC0.EX.RREG.RES\(2),
datab => N_686,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP2_5_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19874\,
dataf => \GRFPC0.DIV.RESULT\(57),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21433_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RES\(57),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_6_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19338\,
dataf => \GRFPC0.WR.RREG.RES\(26),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_742,
datac => \GRFPC0.EX.RREG.RES\(26),
datab => N_678,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5060506000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_33_M\(7),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
datag => \GRFPU0.MULO.DRES_S\(66));
\GRFPC0_OP2_5_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19868\,
dataf => \GRFPC0.DIV.RESULT\(51),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21432_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.WR2.RREG.RES\(51),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_6_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19891\,
dataf => \GRFPC0.WR.RREG.RES\(8),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_756,
datac => \GRFPC0.EX.RREG.RES\(8),
datab => N_692,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17917\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
\GRFPC0_OP1_I_M4_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_23954\,
dataf => \GRFPC0.WR.RREG.RES\(30),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_746,
datac => \GRFPC0.EX.RREG.RES\(30),
datab => N_682,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19911\,
dataf => \GRFPC0.WR.RREG.RES\(28),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_776,
datac => \GRFPC0.EX.RREG.RES\(28),
datab => N_712,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19337\,
dataf => \GRFPC0.WR.RREG.RES\(25),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_741,
datac => \GRFPC0.EX.RREG.RES\(25),
datab => N_677,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_5_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19878\,
dataf => \GRFPC0.DIV.RESULT\(61),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21425_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.WR2.RREG.RES\(61),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_5_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19863\,
dataf => \GRFPC0.DIV.RESULT\(46),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21428_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(46),
datab => \GRFPC0.WR2.RREG.RES\(46),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_5_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19869\,
dataf => \GRFPC0.DIV.RESULT\(52),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21426_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.WR2.RREG.RES\(52),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19886\,
dataf => \GRFPC0.WR.RREG.RES\(3),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_751,
datac => \GRFPC0.EX.RREG.RES\(3),
datab => N_687,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_I_M2_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_24010\,
dataf => \GRFPC0.DIV.RESULT\(54),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.WR2.RREG.RES\(54),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17911\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(4));
\GRFPC0_OP2_6_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19895\,
dataf => \GRFPC0.WR.RREG.RES\(12),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_760,
datac => \GRFPC0.EX.RREG.RES\(12),
datab => N_696,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19315\,
dataf => \GRFPC0.WR.RREG.RES\(3),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_719,
datac => \GRFPC0.EX.RREG.RES\(3),
datab => N_655,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17877\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17866\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPC0_OP2_5_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19875\,
dataf => \GRFPC0.DIV.RESULT\(58),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21424_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.WR2.RREG.RES\(58),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_6_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19364\,
dataf => N_672,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(52),
dataa => \GRFPC0.EX.RREG.RES\(52),
datag => N_736);
\GRFPC0_OP1_6_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19321\,
dataf => \GRFPC0.WR.RREG.RES\(9),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_725,
datac => \GRFPC0.EX.RREG.RES\(9),
datab => N_661,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP2_6_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19912\,
dataf => \GRFPC0.WR.RREG.RES\(29),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_777,
datac => \GRFPC0.EX.RREG.RES\(29),
datab => N_713,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19349\,
dataf => N_657,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(37),
dataa => \GRFPC0.EX.RREG.RES\(37),
datag => N_721);
\GRFPC0_OP1_6_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19336\,
dataf => \GRFPC0.WR.RREG.RES\(24),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_740,
datac => \GRFPC0.EX.RREG.RES\(24),
datab => N_676,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19924\,
dataf => N_693,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(41),
dataa => \GRFPC0.EX.RREG.RES\(41),
datag => N_757);
\GRFPU0_DIVROM0_DATA_1_6_0__M146\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ce573b3bce570808")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_147\,
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_69\,
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_110\,
datac => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datag => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_4\);
\GRFPC0_OP2_5_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19872\,
dataf => \GRFPC0.DIV.RESULT\(55),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21423_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.WR2.RREG.RES\(55),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19316\,
dataf => \GRFPC0.WR.RREG.RES\(4),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_720,
datac => \GRFPC0.EX.RREG.RES\(4),
datab => N_656,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP1_I_M4_0_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_23953\,
dataf => \GRFPC0.DIV.RESULT\(62),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \FPO.RES\(62),
datac => \GRFPC0.MEM.RREG.RES\(62),
datab => \GRFPC0.WR2.RREG.RES\(62),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19900\,
dataf => \GRFPC0.WR.RREG.RES\(17),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_765,
datac => \GRFPC0.EX.RREG.RES\(17),
datab => N_701,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19892\,
dataf => \GRFPC0.WR.RREG.RES\(9),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_757,
datac => \GRFPC0.EX.RREG.RES\(9),
datab => N_693,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19327\,
dataf => \GRFPC0.WR.RREG.RES\(15),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_731,
datac => \GRFPC0.EX.RREG.RES\(15),
datab => N_667,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17882\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17912\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(5));
\GRFPC0_OP1_6_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19332\,
dataf => \GRFPC0.WR.RREG.RES\(20),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_736,
datac => \GRFPC0.EX.RREG.RES\(20),
datab => N_672,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17865\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17863\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
\GRFPC0_OP2_5_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19851\,
dataf => \GRFPC0.DIV.RESULT\(34),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21439_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.WR2.RREG.RES\(34),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_6_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19909\,
dataf => \GRFPC0.WR.RREG.RES\(26),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_774,
datac => \GRFPC0.EX.RREG.RES\(26),
datab => N_710,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_5_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19286\,
dataf => \GRFPC0.DIV.RESULT\(40),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21441_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(40),
datab => \GRFPC0.WR2.RREG.RES\(40),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_L3_0_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(2),
dataf => \GRFPU0.GRFPU_X0.N_10722\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.N_10715\,
datac => \GRFPU0.GRFPU_X0.N_10765\,
datab => \GRFPU0.GRFPU_X0.N_10741\,
dataa => \GRFPU0.GRFPU_X0.N_10728\,
datag => \GRFPU0.GRFPU_X0.N_10717\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17892\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17883\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPC0_OP1_5_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19301\,
dataf => \GRFPC0.DIV.RESULT\(55),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21423_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.WR2.RREG.RES\(55),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_6_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19358\,
dataf => N_666,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(46),
dataa => \GRFPC0.EX.RREG.RES\(46),
datag => N_730);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17876\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPC0_OP2_5_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19870\,
dataf => \GRFPC0.DIV.RESULT\(53),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21437_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.WR2.RREG.RES\(53),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_5_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19873\,
dataf => \GRFPC0.DIV.RESULT\(56),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21438_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.WR2.RREG.RES\(56),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_5_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19877\,
dataf => \GRFPC0.DIV.RESULT\(60),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21434_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.WR2.RREG.RES\(60),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17916\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(9));
\GRFPC0_OP1_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19312\,
dataf => \GRFPC0.WR.RREG.RES\(0),
datae => \GRFPC0.RFA2.RS1SEL_0\(7),
datad => N_716,
datac => \GRFPC0.EX.RREG.RES\(0),
datab => N_652,
dataa => \GRFPC0.RFA2.RS1SEL_0\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP2_6_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19903\,
dataf => \GRFPC0.WR.RREG.RES\(20),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_768,
datac => \GRFPC0.EX.RREG.RES\(20),
datab => N_704,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_5_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19297\,
dataf => \GRFPC0.DIV.RESULT\(51),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21432_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.WR2.RREG.RES\(51),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19893\,
dataf => \GRFPC0.WR.RREG.RES\(10),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_758,
datac => \GRFPC0.EX.RREG.RES\(10),
datab => N_694,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_5_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19280\,
dataf => \GRFPC0.DIV.RESULT\(34),
datae => \GRFPC0.OP1_SN_N_6_1\,
datad => \GRFPU0.GRFPU_X0.N_21439_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.WR2.RREG.RES\(34),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL_1\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17881\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPC0_OP2_6_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19910\,
dataf => \GRFPC0.WR.RREG.RES\(27),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_775,
datac => \GRFPC0.EX.RREG.RES\(27),
datab => N_711,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_5_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19306\,
dataf => \GRFPC0.DIV.RESULT\(60),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21434_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.WR2.RREG.RES\(60),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19289\,
dataf => \GRFPC0.DIV.RESULT\(43),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21427_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(43),
datab => \GRFPC0.WR2.RREG.RES\(43),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17862\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
\GRFPC0_OP2_6_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19898\,
dataf => \GRFPC0.WR.RREG.RES\(15),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_763,
datac => \GRFPC0.EX.RREG.RES\(15),
datab => N_699,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP2_6_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19897\,
dataf => \GRFPC0.WR.RREG.RES\(14),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_762,
datac => \GRFPC0.EX.RREG.RES\(14),
datab => N_698,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19351\,
dataf => N_659,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(39),
dataa => \GRFPC0.EX.RREG.RES\(39),
datag => N_723);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17913\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(6));
\GRFPC0_OP1_5_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19288\,
dataf => \GRFPC0.DIV.RESULT\(42),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \FPO.RES\(42),
datac => \GRFPC0.MEM.RREG.RES\(42),
datab => \GRFPC0.WR2.RREG.RES\(42),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_6_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19328\,
dataf => \GRFPC0.WR.RREG.RES\(16),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_732,
datac => \GRFPC0.EX.RREG.RES\(16),
datab => N_668,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP1_6_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19360\,
dataf => N_668,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(48),
dataa => \GRFPC0.EX.RREG.RES\(48),
datag => N_732);
\GRFPC0_OP1_6_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19350\,
dataf => N_658,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(38),
dataa => \GRFPC0.EX.RREG.RES\(38),
datag => N_722);
\GRFPC0_OP1_6_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19344\,
dataf => N_652,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(32),
dataa => \GRFPC0.EX.RREG.RES\(32),
datag => N_716);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff0eeee0000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\(18),
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17915\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(8));
\GRFPC0_OP1_6_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19333\,
dataf => \GRFPC0.WR.RREG.RES\(21),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_737,
datac => \GRFPC0.EX.RREG.RES\(21),
datab => N_673,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_5_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19282\,
dataf => \GRFPC0.DIV.RESULT\(36),
datae => \GRFPC0.OP1_SN_N_6_1\,
datad => \GRFPU0.GRFPU_X0.N_21443_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(36),
datab => \GRFPC0.WR2.RREG.RES\(36),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL_1\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17870\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
\GRFPC0_OP2_6_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19921\,
dataf => N_690,
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(38),
dataa => \GRFPC0.EX.RREG.RES\(38),
datag => N_754);
\GRFPC0_OP1_6_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19317\,
dataf => \GRFPC0.WR.RREG.RES\(5),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_721,
datac => \GRFPC0.EX.RREG.RES\(5),
datab => N_657,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP1_5_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19302\,
dataf => \GRFPC0.DIV.RESULT\(56),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21438_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.WR2.RREG.RES\(56),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19915\,
dataf => N_684,
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(32),
dataa => \GRFPC0.EX.RREG.RES\(32),
datag => N_748);
\GRFPC0_OP2_6_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19904\,
dataf => \GRFPC0.WR.RREG.RES\(21),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_769,
datac => \GRFPC0.EX.RREG.RES\(21),
datab => N_705,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19887\,
dataf => \GRFPC0.WR.RREG.RES\(4),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_752,
datac => \GRFPC0.EX.RREG.RES\(4),
datab => N_688,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP2_6_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19906\,
dataf => \GRFPC0.WR.RREG.RES\(23),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_771,
datac => \GRFPC0.EX.RREG.RES\(23),
datab => N_707,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19362\,
dataf => N_670,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(50),
dataa => \GRFPC0.EX.RREG.RES\(50),
datag => N_734);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17861\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17897\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17872\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17909\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(2));
\GRFPU0_DIVROM0_DATA_1_6_0__M157\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3333002210107f7f")
port map (
combout => \GRFPU0.DIVAPPR\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(6),
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
datac => N_124803,
datab => \GRFPU0.DIVROM0.RADDR\(7),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datag => \GRFPU0.DIVROM0.DATA_1_6_0_.N_110\);
\GRFPU0_GRFPU_X0_L4_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000facac0000acac")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2\(2),
dataf => \GRFPU0.GRFPU_X0.N_3886\,
datae => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datac => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datab => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
dataa => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datag => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPC0_OP1_6_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19356\,
dataf => N_664,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(44),
dataa => \GRFPC0.EX.RREG.RES\(44),
datag => N_728);
\GRFPC0_OP1_6_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19331\,
dataf => \GRFPC0.WR.RREG.RES\(19),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_735,
datac => \GRFPC0.EX.RREG.RES\(19),
datab => N_671,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19918\,
dataf => N_687,
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(35),
dataa => \GRFPC0.EX.RREG.RES\(35),
datag => N_751);
\GRFPC0_OP2_5_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19876\,
dataf => \GRFPC0.DIV.RESULT\(59),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_19903_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.WR2.RREG.RES\(59),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19314\,
dataf => \GRFPC0.WR.RREG.RES\(2),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_718,
datac => \GRFPC0.EX.RREG.RES\(2),
datab => N_654,
dataa => \GRFPC0.RFA2.RS1SEL_0\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17858\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPC0_OP1_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19313\,
dataf => \GRFPC0.WR.RREG.RES\(1),
datae => \GRFPC0.RFA2.RS1SEL_0\(7),
datad => N_717,
datac => \GRFPC0.EX.RREG.RES\(1),
datab => N_653,
dataa => \GRFPC0.RFA2.RS1SEL_0\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17888\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17859\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
\GRFPC0_OP1_6_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19325\,
dataf => \GRFPC0.WR.RREG.RES\(13),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_729,
datac => \GRFPC0.EX.RREG.RES\(13),
datab => N_665,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP1_6_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19323\,
dataf => \GRFPC0.WR.RREG.RES\(11),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_727,
datac => \GRFPC0.EX.RREG.RES\(11),
datab => N_663,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP1_5_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19305\,
dataf => \GRFPC0.DIV.RESULT\(59),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_19903_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.WR2.RREG.RES\(59),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_6_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19345\,
dataf => N_653,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(33),
dataa => \GRFPC0.EX.RREG.RES\(33),
datag => N_717);
\GRFPC0_OP1_6_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19318\,
dataf => \GRFPC0.WR.RREG.RES\(6),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_722,
datac => \GRFPC0.EX.RREG.RES\(6),
datab => N_658,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP2_I_M2_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_24008\,
dataf => \GRFPC0.DIV.RESULT\(54),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_67_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.WR2.RREG.RES\(54),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19883\,
dataf => \GRFPC0.WR.RREG.RES\(0),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_748,
datac => \GRFPC0.EX.RREG.RES\(0),
datab => N_684,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"058d50d850d850d8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.N_6328\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(1),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datag => \GRFPU0.GRFPU_X0.ITER.EXP\(0));
\GRFPC0_OP2_6_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19905\,
dataf => \GRFPC0.WR.RREG.RES\(22),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_770,
datac => \GRFPC0.EX.RREG.RES\(22),
datab => N_706,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19914\,
dataf => \GRFPC0.WR.RREG.RES\(31),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_779,
datac => \GRFPC0.EX.RREG.RES\(31),
datab => N_715,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19359\,
dataf => N_667,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_SN_N_5\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(47),
dataa => \GRFPC0.EX.RREG.RES\(47),
datag => N_731);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17889\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17878\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961_0\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPC0_OP2_6_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19907\,
dataf => \GRFPC0.WR.RREG.RES\(24),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_772,
datac => \GRFPC0.EX.RREG.RES\(24),
datab => N_708,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17914\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(7));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_6_RNIUKFF4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0800800000008000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7797\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.N_7942\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_1\,
dataa => \GRFPU0.GRFPU_X0.N_7781_6\,
datag => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
\GRFPC0_OP1_5_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19291\,
dataf => \GRFPC0.DIV.RESULT\(45),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_20333_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.WR2.RREG.RES\(45),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19281\,
dataf => \GRFPC0.DIV.RESULT\(35),
datae => \GRFPC0.OP1_SN_N_6_1\,
datad => \GRFPU0.GRFPU_X0.N_19990_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(35),
datab => \GRFPC0.WR2.RREG.RES\(35),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffccfafaf0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datag => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\);
\GRFPC0_OP2_6_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19902\,
dataf => \GRFPC0.WR.RREG.RES\(19),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_767,
datac => \GRFPC0.EX.RREG.RES\(19),
datab => N_703,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19916\,
dataf => N_685,
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(33),
dataa => \GRFPC0.EX.RREG.RES\(33),
datag => N_749);
\GRFPC0_OP2_5_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19862\,
dataf => \GRFPC0.DIV.RESULT\(45),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_20333_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.WR2.RREG.RES\(45),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_6_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19322\,
dataf => \GRFPC0.WR.RREG.RES\(10),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_726,
datac => \GRFPC0.EX.RREG.RES\(10),
datab => N_662,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP2_6_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19888\,
dataf => \GRFPC0.WR.RREG.RES\(5),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_753,
datac => \GRFPC0.EX.RREG.RES\(5),
datab => N_689,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_5_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19304\,
dataf => \GRFPC0.DIV.RESULT\(58),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21424_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.WR2.RREG.RES\(58),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19908\,
dataf => \GRFPC0.WR.RREG.RES\(25),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_773,
datac => \GRFPC0.EX.RREG.RES\(25),
datab => N_709,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_5_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19299\,
dataf => \GRFPC0.DIV.RESULT\(53),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21437_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.WR2.RREG.RES\(53),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19933\,
dataf => N_702,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(50),
dataa => \GRFPC0.EX.RREG.RES\(50),
datag => N_766);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17895\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40));
\GRFPC0_OP2_6_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19926\,
dataf => N_695,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(43),
dataa => \GRFPC0.EX.RREG.RES\(43),
datag => N_759);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17894\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39));
\GRFPC0_OP2_6_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19922\,
dataf => N_691,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(39),
dataa => \GRFPC0.EX.RREG.RES\(39),
datag => N_755);
\GRFPC0_OP2_6_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19925\,
dataf => N_694,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.OP2_SN_N_5\,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(42),
dataa => \GRFPC0.EX.RREG.RES\(42),
datag => N_758);
\GRFPC0_OP1_6_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19329\,
dataf => \GRFPC0.WR.RREG.RES\(17),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_733,
datac => \GRFPC0.EX.RREG.RES\(17),
datab => N_669,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19894\,
dataf => \GRFPC0.WR.RREG.RES\(11),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_759,
datac => \GRFPC0.EX.RREG.RES\(11),
datab => N_695,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17904\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datag => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPC0_OP1_I_M2_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_24011\,
dataf => \GRFPC0.WR.RREG.RES\(22),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_738,
datac => \GRFPC0.EX.RREG.RES\(22),
datab => N_674,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_5_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19866\,
dataf => \GRFPC0.DIV.RESULT\(49),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21429_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(49),
datab => \GRFPC0.WR2.RREG.RES\(49),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_5_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19295\,
dataf => \GRFPC0.DIV.RESULT\(49),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_21429_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(49),
datab => \GRFPC0.WR2.RREG.RES\(49),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_6_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19890\,
dataf => \GRFPC0.WR.RREG.RES\(7),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_755,
datac => \GRFPC0.EX.RREG.RES\(7),
datab => N_691,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19343\,
dataf => \GRFPC0.WR.RREG.RES\(31),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_747,
datac => \GRFPC0.EX.RREG.RES\(31),
datab => N_683,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_I_M4_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_23950\,
dataf => \GRFPC0.WR.RREG.RES\(30),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_778,
datac => \GRFPC0.EX.RREG.RES\(30),
datab => N_714,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19326\,
dataf => \GRFPC0.WR.RREG.RES\(14),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_730,
datac => \GRFPC0.EX.RREG.RES\(14),
datab => N_666,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPC0_OP2_6_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19896\,
dataf => \GRFPC0.WR.RREG.RES\(13),
datae => \GRFPC0.RFA2.RS2SEL_0\(7),
datad => N_761,
datac => \GRFPC0.EX.RREG.RES\(13),
datab => N_697,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4_0\);
\GRFPC0_OP1_6_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19335\,
dataf => \GRFPC0.WR.RREG.RES\(23),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_739,
datac => \GRFPC0.EX.RREG.RES\(23),
datab => N_675,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19320\,
dataf => \GRFPC0.WR.RREG.RES\(8),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_724,
datac => \GRFPC0.EX.RREG.RES\(8),
datab => N_660,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4_0\);
\GRFPU0_GRFPU_X0_TZI_RNI51G72_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000000000020002")
port map (
combout => \GRFPU0.GRFPU_X0.N_10519\,
dataf => \GRFPU0.GRFPU_X0.TZI\(20),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.TZI\(22),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datab => \GRFPU0.GRFPU_X0.TZI\(23),
dataa => \GRFPU0.GRFPU_X0.N_10526\,
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPU0_GRFPU_X0_L1_4_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffa8a8aaa0a8a8")
port map (
combout => N_124841,
dataf => \GRFPU0.GRFPU_X0.N_3306\,
datae => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_L1_0_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5055515150505050")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.N_19299\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
dataa => \GRFPU0.GRFPU_X0.TZI\(0),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
GRFPC0_FP_PIPELINE_FCC_VALID_9_I_M4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0ec20f0f0fd31")
port map (
combout => \GRFPC0.N_16924\,
dataf => \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.AFSR\,
datae => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RESV_1_0\,
datab => \GRFPC0.WR.CTRL.CCWR\,
dataa => \GRFPC0.WR2.CTRL.CCWR\,
datag => \GRFPC0.MEM.RREG.RESV\);
\GRFPU0_SQRTROM0_DATA_1_6_0__M30\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"4f4bd5d5d2f42a2a")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_31\,
dataf => \GRFPU0.DIVROM0.RADDR\(2),
datae => \GRFPU0.DIVROM0.RADDR\(6),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_117\,
datab => \GRFPU0.DIVROM0.RADDR\(3),
dataa => \GRFPU0.DIVROM0.RADDR\(1),
datag => \GRFPU0.DIVROM0.RADDR\(4));
\GRFPU0_GRFPU_X0_L1_0_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fffffffff0f5f1f1")
port map (
combout => \GRFPU0.GRFPU_X0.N_3533\,
dataf => \GRFPU0.GRFPU_X0.TZI\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
dataa => \GRFPU0.GRFPU_X0.N_19299\,
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPC0_OP2_I_M4_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_23948\,
dataf => \GRFPC0.WR.RREG.RES\(62),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_714,
datac => \GRFPC0.EX.RREG.RES\(62),
datab => N_778,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_SN_N_5\);
\GRFPC0_STDATA_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => CPO_DATAZ(4),
dataf => \GRFPC0.EX.RREG.RES\(36),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datab => \GRFPC0.R.FSR.CEXC\(4),
dataa => \GRFPC0.R.STDATA\(4),
datag => \GRFPC0.EX.RREG.RES\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_11_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f3a2a0a0c080a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(53),
dataf => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4227_0\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
dataa => \GRFPU0.GRFPU_X0.N_4352_0\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
\GRFPU0_SQRTROM0_DATA_1_6_0__M90\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00001155efef8c8c")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_91\,
dataf => \GRFPU0.DIVROM0.RADDR\(6),
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => N_124803,
datac => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
datab => \GRFPU0.DIVROM0.RADDR\(7),
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datag => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_2\);
\GRFPU0_GRFPU_X0_L1_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0f0000000f00f2f2")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datae => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datag => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
\GRFPC0_STDATA_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => CPO_DATAZ(8),
dataf => \GRFPC0.EX.RREG.RES\(40),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datab => \GRFPC0.R.FSR.AEXC\(3),
dataa => \GRFPC0.R.STDATA\(8),
datag => \GRFPC0.EX.RREG.RES\(8));
\GRFPU0_GRFPU_X0_L1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffccfafaffcffafa")
port map (
combout => N_124818,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datae => \GRFPU0.GRFPU_X0.N_10901\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datag => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPC0_OP2_6_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19919\,
dataf => \GRFPC0.WR.RREG.RES\(36),
datae => \GRFPC0.RFA2.RS2SEL_1\(7),
datad => N_688,
datac => \GRFPC0.EX.RREG.RES\(36),
datab => N_752,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_SN_N_5\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000002000200020")
port map (
combout => \GRFPU0.GRFPU_X0.N_7753\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.N_7942\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datab => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(5),
dataa => \GRFPU0.GRFPU_X0.N_7767_6\,
datag => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_L1_3_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
dataa => \GRFPU0.GRFPU_X0.N_21048\,
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7));
\GRFPU0_GRFPU_X0_L1_2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000f0000000f0e0e")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_6\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datae => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datag => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPC0_OP2_6_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19923\,
dataf => \GRFPC0.WR.RREG.RES\(40),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_692,
datac => \GRFPC0.EX.RREG.RES\(40),
datab => N_756,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => \GRFPC0.OP2_SN_N_5\);
\GRFPU0_GRFPU_X0_L1_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000f1111000f1010")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6\(1),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datae => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datag => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
\GRFPC0_STDATA_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(5),
dataf => \GRFPC0.R.FSR.AEXC\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(37),
datac => \GRFPC0.R.STDATA\(5),
datab => \GRFPC0.EX.RREG.RES\(5),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_OP2_5_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19880\,
dataf => \GRFPC0.DIV.RESULT\(63),
datae => \GRFPC0.OP2_SN_N_6\,
datad => \FPO.RES\(63),
datac => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPC0.WR2.RREG.RES\(63),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_STDATA_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(11),
dataf => \GRFPC0.R.FSR.FCC\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(43),
datac => \GRFPC0.R.STDATA\(11),
datab => \GRFPC0.EX.RREG.RES\(11),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_OP1_5_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19309\,
dataf => \GRFPC0.DIV.RESULT\(63),
datae => \GRFPC0.OP1_SN_N_6\,
datad => \FPO.RES\(63),
datac => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPC0.WR2.RREG.RES\(63),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_STDATA_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(10),
dataf => \GRFPC0.R.FSR.FCC\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(42),
datac => \GRFPC0.R.STDATA\(10),
datab => \GRFPC0.EX.RREG.RES\(10),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(26),
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(58),
datac => \GRFPC0.R.STDATA\(26),
datab => \GRFPC0.EX.RREG.RES\(26),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(24),
dataf => \GRFPC0.R.FSR.TEM\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(56),
datac => \GRFPC0.R.STDATA\(24),
datab => \GRFPC0.EX.RREG.RES\(24),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(2),
dataf => \GRFPC0.R.FSR.CEXC\(2),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(34),
datac => \GRFPC0.R.STDATA\(2),
datab => \GRFPC0.EX.RREG.RES\(2),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_L1_0_1_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffdcdcf0f0dcdc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_6\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30));
\GRFPU0_GRFPU_X0_L1_2_1_4_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffdcdcf0f0dcdc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_BCO_MSB_1_7_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cf0fdc50cc00dc50")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_7\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.N_3235_1\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27));
\GRFPU0_GRFPU_X0_BCO_MSB_4_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_5\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(2),
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3));
\GRFPU0_DIVROM0_DATA_1_6_0__M134\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5050abaf5050afaf")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_135\,
dataf => \GRFPU0.DIVROM0.RADDR\(0),
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5),
datag => N_124803);
\GRFPC0_STDATA_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(14),
dataf => \GRFPC0.R.FSR.FTT\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(46),
datac => \GRFPC0.R.STDATA\(14),
datab => \GRFPC0.EX.RREG.RES\(14),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(1),
dataf => \GRFPC0.R.FSR.CEXC\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(33),
datac => \GRFPC0.R.STDATA\(1),
datab => \GRFPC0.EX.RREG.RES\(1),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(0),
dataf => \GRFPC0.R.FSR.CEXC\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(32),
datac => \GRFPC0.R.STDATA\(0),
datab => \GRFPC0.EX.RREG.RES\(0),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(30),
dataf => \FPI.RNDMODE\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(62),
datac => \GRFPC0.R.STDATA\(30),
datab => \GRFPC0.EX.RREG.RES\(30),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"eeeeeeaeeeeaeeae")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_O3_I_A2_I_0\,
dataf => N_114,
datae => N_111,
datad => N_113,
datac => N_115,
datab => N_109,
dataa => N_133,
datag => N_110);
\GRFPC0_STDATA_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(6),
dataf => \GRFPC0.R.FSR.AEXC\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(38),
datac => \GRFPC0.R.STDATA\(6),
datab => \GRFPC0.EX.RREG.RES\(6),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(27),
dataf => \GRFPC0.R.FSR.TEM\(4),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(59),
datac => \GRFPC0.R.STDATA\(27),
datab => \GRFPC0.EX.RREG.RES\(27),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(16),
dataf => \GRFPC0.R.FSR.FTT\(2),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(48),
datac => \GRFPC0.R.STDATA\(16),
datab => \GRFPC0.EX.RREG.RES\(16),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(23),
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(55),
datac => \GRFPC0.R.STDATA\(23),
datab => \GRFPC0.EX.RREG.RES\(23),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(25),
dataf => \GRFPC0.R.FSR.TEM\(2),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(57),
datac => \GRFPC0.R.STDATA\(25),
datab => \GRFPC0.EX.RREG.RES\(25),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
GRFPU0_GRFPU_X0_INC_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0300323203000000")
port map (
combout => N_123287,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_16\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datab => \GRFPU0.GRFPU_X0.COMB.RNDM_1\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datag => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
GRFPC0_FP_PIPELINE_UN1_FIFO_VCNT_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00000101000f0101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
dataf => \GRFPC0.FIFO.VCNT_0\(0),
datae => \GRFPC0.FIFO.WR_0\(0),
datad => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_1\(2),
dataa => \GRFPC0.FIFO.VCNT_1\(1),
datag => \GRFPC0.FIFO.VCNT_0\(1));
GRFPU0_GRFPU_X0_UN2_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000000100030001")
port map (
combout => \GRFPU0.GRFPU_X0.N_10583\,
dataf => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.N_19299\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.TZI\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPC0_STDATA_I_M2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(22),
dataf => \FPI.NONSTD\,
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(54),
datac => \GRFPC0.R.STDATA\(22),
datab => \GRFPC0.EX.RREG.RES\(22),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3303331033003310")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_7\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17));
\GRFPC0_STDATA_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(9),
dataf => \GRFPC0.R.FSR.AEXC\(4),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(41),
datac => \GRFPC0.R.STDATA\(9),
datab => \GRFPC0.EX.RREG.RES\(9),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffdcdcf0f0dcdc")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPC0_STDATA_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(15),
dataf => \GRFPC0.R.FSR.FTT\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(47),
datac => \GRFPC0.R.STDATA\(15),
datab => \GRFPC0.EX.RREG.RES\(15),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_L1_0_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3303331033003310")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.TZI2\(1),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.TZI2\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPU0_DIVROM0_DATA_1_6_0__M70\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"55e6556a55e66aad")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_71\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(2),
datag => \GRFPU0.DIVROM0.DATA_1_6_0_.N_183\);
\GRFPC0_STDATA_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(31),
dataf => \FPI.RNDMODE\(1),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(63),
datac => \GRFPC0.R.STDATA\(31),
datab => \GRFPC0.EX.RREG.RES\(31),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(7),
dataf => \GRFPC0.R.FSR.AEXC\(2),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(39),
datac => \GRFPC0.R.STDATA\(7),
datab => \GRFPC0.EX.RREG.RES\(7),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_L1_1_1_5_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffdcdcf0f0dcdc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPC0_STDATA_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(3),
dataf => \GRFPC0.R.FSR.CEXC\(3),
datae => \GRFPC0.STDATA_SN_N_3\,
datad => \GRFPC0.EX.RREG.RES\(35),
datac => \GRFPC0.R.STDATA\(3),
datab => \GRFPC0.EX.RREG.RES\(3),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff8fff8ff88ff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(8),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(8),
datac => \GRFPU0.MULO.DRES_1\(68),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datag => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17205\,
dataf => \GRFPU0.GRFPU_X0.N_17897\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17189\,
dataf => \GRFPU0.GRFPU_X0.N_17881\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
dataa => \FPI.OP1_RETO\(26),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17159\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17916\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17158\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17915\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17166\,
dataf => \GRFPU0.GRFPU_X0.N_17858\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
dataa => \FPI.OP1_RETO\(3),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17190\,
dataf => \GRFPU0.GRFPU_X0.N_17882\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
dataa => \FPI.OP1_RETO\(27),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17165\,
dataf => \GRFPU0.GRFPU_X0.N_17857\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
dataa => \FPI.OP1_RETO\(2),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17196\,
dataf => \GRFPU0.GRFPU_X0.N_17888\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17202\,
dataf => \GRFPU0.GRFPU_X0.N_17894\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17174\,
dataf => \GRFPU0.GRFPU_X0.N_17866\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
dataa => \FPI.OP1_RETO\(11),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17175\,
dataf => \GRFPU0.GRFPU_X0.N_17867\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
dataa => \FPI.OP1_RETO\(12),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17173\,
dataf => \GRFPU0.GRFPU_X0.N_17865\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
dataa => \FPI.OP1_RETO\(10),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17191\,
dataf => \GRFPU0.GRFPU_X0.N_17883\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
dataa => \FPI.OP1_RETO\(28),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17199\,
dataf => \GRFPU0.GRFPU_X0.N_17891\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17171\,
dataf => \GRFPU0.GRFPU_X0.N_17863\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
dataa => \FPI.OP1_RETO\(8),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17213\,
dataf => \GRFPU0.GRFPU_X0.N_17905\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17180\,
dataf => \GRFPU0.GRFPU_X0.N_17872\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
dataa => \FPI.OP1_RETO\(17),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17170\,
dataf => \GRFPU0.GRFPU_X0.N_17862\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
dataa => \FPI.OP1_RETO\(7),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17157\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17914\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17154\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17911\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17186\,
dataf => \GRFPU0.GRFPU_X0.N_17878\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
dataa => \FPI.OP1_RETO\(23),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17152\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17909\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17200\,
dataf => \GRFPU0.GRFPU_X0.N_17892\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17178\,
dataf => \GRFPU0.GRFPU_X0.N_17870\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
dataa => \FPI.OP1_RETO\(15),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17155\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17912\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17167\,
dataf => \GRFPU0.GRFPU_X0.N_17859\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
dataa => \FPI.OP1_RETO\(4),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17184\,
dataf => \GRFPU0.GRFPU_X0.N_17876\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
dataa => \FPI.OP1_RETO\(21),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17212\,
dataf => \GRFPU0.GRFPU_X0.N_17904\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17197\,
dataf => \GRFPU0.GRFPU_X0.N_17889\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17176\,
dataf => \GRFPU0.GRFPU_X0.N_17868\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
dataa => \FPI.OP1_RETO\(13),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17203\,
dataf => \GRFPU0.GRFPU_X0.N_17895\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fd31f0f0ec20f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17183\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_17875\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \FPI.OP1_RETO\(20));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17214\,
dataf => \GRFPU0.GRFPU_X0.N_17906\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17185\,
dataf => \GRFPU0.GRFPU_X0.N_17877\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
dataa => \FPI.OP1_RETO\(22),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17160\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17917\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0fd31f0f0ec20")
port map (
combout => \GRFPU0.GRFPU_X0.N_17156\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_17913\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataa => \GRFPU0.GRFPU_X0.N_21039\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafccaca0a0ccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_17169\,
dataf => \GRFPU0.GRFPU_X0.N_17861\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
dataa => \FPI.OP1_RETO\(6),
datag => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\);
GRFPC0_FP_PIPELINE_FCC_VALID_1_U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0070007070707070")
port map (
combout => CPO_CCVZ,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.EX.CTRL.CCWR\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_16924\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
dataa => \GRFPC0.FIFO.INST_0\(19),
datag => \GRFPC0.EX.RREG.RESV\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(57),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datad => \GRFPU0.GRFPU_X0.N_17155\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(59),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datad => \GRFPU0.GRFPU_X0.N_17157\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(58),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datad => \GRFPU0.GRFPU_X0.N_17156\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(62),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_17160\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(61),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_17159\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(60),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_17158\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(54),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datad => \GRFPU0.GRFPU_X0.N_17152\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datab => \GRFPU0.GRFPU_X0.N_20764\,
dataa => \GRFPU0.GRFPU_X0.N_242\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afefafafaaeaafaf")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_452\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_21461\,
datad => \GRFPC0.N_21474\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datab => N_38026,
dataa => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_0\(1),
datag => \GRFPC0.N_21471\);
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"efafafafeaaaafaf")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_372\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_21626\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datab => N_38026,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0\(1),
datag => \GRFPC0.N_21635\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ff004040f0f05050")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(38),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
datab => \GRFPU0.GRFPU_X0.N_21185\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datag => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000c0008000c004c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(45),
dataf => \GRFPU0.GRFPU_X0.N_16311\,
datae => \GRFPU0.GRFPU_X0.N_19502_0\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datac => \GRFPU0.GRFPU_X0.N_16259\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
dataa => \GRFPU0.GRFPU_X0.N_19499_0\,
datag => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_IV_0_A2_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00c000c400c00080")
port map (
combout => \GRFPU0.GRFPU_X0.N_19525\,
dataf => \GRFPU0.GRFPU_X0.N_19503\,
datae => \GRFPU0.GRFPU_X0.N_19502_0\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datac => \GRFPU0.GRFPU_X0.N_19504\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
dataa => \GRFPU0.GRFPU_X0.N_19499_0\,
datag => \GRFPU0.GRFPU_X0.ITER.DBUF\(53));
GRFPU0_GRFPU_X0_RDY_F0_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"d77df5f5d77d0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19283_I\,
dataf => \GRFPU0.GRFPU_X0.N_6466\,
datae => \GRFPU0.GRFPU_X0.ST3.V\,
datad => \FPI.FLUSHID\(5),
datac => \GRFPU0.GRFPU_X0.N_19307\,
datab => \GRFPU0.GRFPU_X0.ST3.ID\(5),
dataa => \FPI.FLUSH\,
datag => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f001fff0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
dataf => \GRFPU0.DIVROM0.RADDR\(6),
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datad => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => N_124803,
dataa => \GRFPU0.DIVROM0.RADDR\(4),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_DIVROM0_DATA_1_6_0__M130\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0515f0f0faeaaaaa")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_131\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
datab => \GRFPU0.DIVROM0.RADDR\(0),
dataa => \GRFPU0.DIVROM0.RADDR\(3),
datag => \GRFPU0.DIVROM0.RADDR\(2));
GRFPU0_FPMUL0_R2_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26_RETI\,
cin => N_122898);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNIBIMU9B2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(91),
cout => N_122898,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNIBJFVSN1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNIK8ALH51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNIMBDN7K: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNI1MVSU3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNI518TMK3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNI4VCFF63: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNIE9LA8P2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNIJP761D2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNI39BPP12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNIEH6RHN1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNI4C039E1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNILIV7V51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNIHUA1KU: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNI89967O: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIAC1EOI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNIPPPF7E: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNI5BP2KA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNIUP6UT7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNIKV8P46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNINL6B85: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNIL115D4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNI50C2J3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_17_RNI3BTQL_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
datad => \GRFPU0.GRFPU_X0.N_15316_I\,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18_RNIDAGFB1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(66),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNIJKJ722: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20_RNI5H73Q2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\);
GRFPU0_FPMUL0_CS_DP_R_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26_RETI\,
cin => N_122912);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_46_RNI5JSB3A: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(94),
cout => N_122912,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNIAGPOFJ3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(93),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44_RNI8L3LUT2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(92),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNIFR1OF92: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(91),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNIFSQO2M1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(90),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNIOHLEN31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(89),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNIQKOGDI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(88),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNI5VAM42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(87),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNI9AJMSI3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(86),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNI88O8L43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(85),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNIII04EN2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(84),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNIN2JV6B2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(83),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNI7IMIVV1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(82),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNIIQHKNL1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(81),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNI8LBSEC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(80),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNIPRA1541: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(79),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNIL7MQPS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(78),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNICIKVCM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(77),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIELC7UG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(76),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNIT259DC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(75),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNI9K4SP8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(74),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNI23IN36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(73),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNIO8KIA4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(72),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIRUH4E3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(71),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNIPACUI2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(70),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNI99NRO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1_RETI\(69),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20_RNI9QISV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
datad => \GRFPU0.GRFPU_X0.N_15336_I\,
cin => GND);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(120),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_50: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(119),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_49: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(118),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_48: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(117),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_47: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(116),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_46: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(115),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(114),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(113),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(112),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(111),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(110),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(109),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(108),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(107),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(106),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(105),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(104),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(103),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(102),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(101),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(100),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(99),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(98),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(97),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(96),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(95),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(94),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(93),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(92),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(91),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(90),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(89),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(88),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(87),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(86),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(85),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(84),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(83),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(82),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(81),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(80),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(79),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(78),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(77),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(76),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(75),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(74),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(73),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(72),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(71),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(70),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S_RETI\(69),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.N_15336_I\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31122_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\);
GRFPU0_FPMUL0_CS_DP_R_RET_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIT18OVI2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31118_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI60P91P1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31116_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIM1MV2V: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31114_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNID6VP45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31112_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIBEKO6B3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31110_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIGPLR8H2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31108_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIS733BN1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31106_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIFPSEDT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31104_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI9E2VF3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31102_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIA6KJI93: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31100_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNII1ICLF2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31098_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI10S9OL1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31096_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIN1IBRR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31094_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIK6KHU1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31092_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIOE2S183: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31090_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI3QSA5E2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31088_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIL83U8K1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31086_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIEQLLCQ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31084_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIEFKHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31082_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIL7VHK63: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31080_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI33MMOC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31078_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIO1PVSI1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_31076_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
cin => GND);
GRFPU0_FPMUL0_R2_RET_78_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31123_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\);
GRFPU0_FPMUL0_R2_RET_78_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIIKI7SF1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31119_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIRI3PTL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31117_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIBK0FVR3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31115_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI2P99123: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31113_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI01V7382: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31111_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI5C0B5E1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31109_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIHQDI7K: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31107_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI4C7U9Q3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31105_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIU0DEC03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31103_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIVOU2F62: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31101_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI7KSRHC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31099_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIMI6PKI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31097_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNICKSQNO3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31095_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI9PU0RU2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31093_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNID1DBU42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31091_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIOC7Q1B1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31089_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIARDD5H: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31087_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI3D059N3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31085_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI32V0DT2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31083_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIAQ91H32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31081_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIOL06L91: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31079_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIDK3FPF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f30000ff00")
port map (
sumout => N_31077_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNITTOM4C1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_31071_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_47_RNI1F22R32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31073_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNILIAFSS2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000c3c3")
port map (
sumout => N_31075_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\,
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNIMIBELK3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
cin => N_122914);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNIMIBELK3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(93),
cout => N_122914,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44_RNIKNLA4V2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(92),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNIRTJDLA2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNIRUCE8N1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNI4K74T41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNI6NA6JJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNIH1TBA3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNILC5C2K3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNIKAAUQ53: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNIUKIPJO2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNI355LCC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNIJK88512: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNIUS3ATM1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNIKNTHKD1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNI5USMA51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNI1A8GVT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNIOK6LIN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIQNUS3I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNI95NUID: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNILMMHV9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNIE54D97: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNI4B68G5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI714QJ4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNI5DUJO3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNILB9HU2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20_RNILS4I52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNI30HMD1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18_RNITLDUM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(66),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
datad => \GRFPU0.GRFPU_X0.N_15316_I\,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNIMATBTL3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0_RETI\,
cin => N_122896);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_45_RNIMATBTL3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(93),
cout => N_122896,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44_RNIKF78C03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(92),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNIRL5BTB2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNIRMUBGO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNI4CP1561: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNI6FS3RK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNIHPE9I4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNIL4N9AL3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNIK2SR273: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNIUC4NRP2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNI3TMIKD2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNIJCQ5D22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNIUKL75O1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNIKFFFSE1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNI5MEKI61: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNI12QD7V: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNIOCOIQO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIQFGQBJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNI9T8SQE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNILE8F7B: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNIETLAH8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNI43O5O6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNI7PLNR5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNI55GH05: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNIL3RE64: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000c0c0")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18_RNITLDUM_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
datad => \GRFPU0.GRFPU_X0.N_15316_I\,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNI30HMD1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_20_RNICQ3JD2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003c3c")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\,
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\);
GRFPU0_FPMUL0_R2_RET_131_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_RETI\,
cin => N_122910);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_44_RNIOHPLV03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(92),
cout => N_122910,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_43_RNIVNNOGC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_42_RNIVOGP3P1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_41_RNI8EBFO61: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_40_RNIAHEHEL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_39_RNILR0N55: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_38_RNIP69NTL3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_37_RNIO4E9M73: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_36_RNI2FM4FQ2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_35_RNI7V808E2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_34_RNINECJ032: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_33_RNI2N7LOO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_32_RNIOH1TFF1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_31_RNI9O02671: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_30_RNI54CRQV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_29_RNISEA0EP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_28_RNIUH28VJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_27_RNIDVQ9EF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_26_RNIPGQSQB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_25_RNIIV7O49: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_24_RNI85AJB7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_23_RNIBR75F6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_22_RNI972VJ5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_21_RNIP5DSP4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNIPM8T04: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000c0c0")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_17_RNI3BTQL: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
datad => \GRFPU0.GRFPU_X0.N_15316_I\,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_18_RNIDAGFB1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_19_RNIAII8A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003c3c")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\,
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\);
GRFPU0_FPMUL0_R2_RET_158_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31011_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI85OVUK1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31009_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI3TG80R: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31007_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI5OLL11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31005_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIEM67373: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31003_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIUN3T4D2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_31001_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNILSCN6J1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30999_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIJ42M8P: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30997_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIOF3PAV3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30995_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI4UG0D53: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30993_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNINFACFB2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30991_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIH4GSHH1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30989_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIIS1HKN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30987_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIQNV9NT3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30985_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI9M97Q33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30983_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIVNV8T92: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30981_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNISS1F0G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30979_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI05GP3M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30977_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIBGA87S3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30975_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNITUGRA23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30973_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIMG3JE82: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30971_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIM52FIE1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30969_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNITTCFMK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30967_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIBP3KQQ3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30965_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI0O6TU03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30963_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNISPLA372: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30961_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_47_RNIVJCU9E1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30959_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => GND);
GRFPU0_FPMUL0_R2_RET_185_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30954_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\);
GRFPU0_FPMUL0_R2_RET_185_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNILMVSBL1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30950_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNINH4ADR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30948_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI0GLRE1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30946_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIGHIHG73: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30944_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI7MRBID2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30942_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI5UGAKJ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30940_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIA9IDMP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30938_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIMNVKOV3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30936_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI99P0R53: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30934_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI3UUGTB2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30932_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI4MG50I1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30930_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNICHEU2O: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30928_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIRFOR5U3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30926_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIHHET843: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30924_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIEMG3CA2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30922_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIIUUDFG1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30920_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIT9PSIM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30918_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIFOVFMS3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30916_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI8AI7Q23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30914_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI8VG3U82: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30912_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIFNR32F1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30910_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNITII86L: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f30000ff00")
port map (
sumout => N_30908_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_47_RNIVJCU9E1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_30902_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNISPLA372_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30904_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNINL5U613: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000c3c3")
port map (
sumout => N_30906_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\,
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\);
GRFPU0_FPMUL0_CS_DP_R_RET_49_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30953_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\);
GRFPU0_FPMUL0_CS_DP_R_RET_49_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIU0QU4K2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30949_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI0SUB6Q1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30947_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI9QFT701: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30945_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIPRCJ96: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30943_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIG0MDBC3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30941_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIE8BCDI2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30939_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIJJCFFO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30937_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIV1QMHU: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30935_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIIJJ2K4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30933_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIC8PIMA3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30931_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNID0B7PG2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30929_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNILR80SM1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30927_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI4QITUS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30925_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIQR8V13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30923_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIN0B5593: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30921_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIR8PF8F2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30919_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI6KJUBL1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30917_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIO2QHFR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30915_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIHKC9J1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30913_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIH9B5N73: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30911_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNIO1M5RD2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_30909_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_0_CARRY_48_RNI6TCAVJ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_30907_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datac => \GRFPU0.GRFPU_X0.N_15336_I\,
cin => GND);
GRFPC0_RFA2_RS1SEL_RET_1_RNIUI7B2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"aaa0000000008080")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(4),
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\,
datae => HOLDN_RETO,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.WR2SEL4_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.FPUSEL_6_1_RETO\(7),
datag => \GRFPC0.WR.RREG.RESV_RETO\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MULADD_0_49_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  50,
 width_b =>  25,
 width_a =>  25,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(49),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(24) => \GRFPU0.GRFPU_X0.N_19514\,
  clock0 => N_62);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_MULADD_0_60_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  61,
 width_b =>  25,
 width_a =>  36,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(60),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(24) => \GRFPU0.GRFPU_X0.N_19514\,
  clock0 => N_62);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_MU_MULADD_0_60_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  61,
 width_b =>  36,
 width_a =>  25,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(60),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_62);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_ML_MULADD_0_71_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  72,
 width_b =>  36,
 width_a =>  36,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(60),
  result(61) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(61),
  result(62) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(62),
  result(63) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(63),
  result(64) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(64),
  result(65) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(65),
  result(66) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(66),
  result(67) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(67),
  result(68) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(68),
  result(69) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(69),
  result(70) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(70),
  result(71) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(71),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_62);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188345,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188347,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_C_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188349,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188351,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188353,
datad => VCC,
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_0_1_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188355,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_UN2_DIFF1_1_CARRY_0_BUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_188357,
datad => VCC,
cin => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11280\,
dataf => \GRFPU0.GRFPU_X0.VITER.STATE_14_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11268\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11270\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIEO5J4_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11272\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11273\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11274\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIH86J4_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11275\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11276\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIDO5J4_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11277\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIBG5J4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11278\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI985J4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11279\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11281\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11282\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIBHCV4_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11287\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11290\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0_0\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIMSO66_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11291\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_2\,
datae => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(0),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(1),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(2),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(3),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(3));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(4),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(4));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(5),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(5));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(6),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(6));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(7),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(7));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(8),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(8));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(9),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(9));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(10),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(10));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(11),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(11));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(12),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(12));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(13),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(13));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(14),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(14));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(15),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(15));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(16),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(16));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(17),
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(17));
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_I_M2_N_10L23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000d222f")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_10\,
dataf => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_2\(0),
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_3\(0),
datad => \GRFPC0.N_25165\,
datac => \GRFPC0.N_23872\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_144_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff2fffdfff0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_11\,
datac => N_186214,
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_3_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2000")
port map (
combout => N_186190,
dataf => \GRFPC0.N_24735_2\,
datae => \GRFPC0.N_24653\,
datad => \GRFPC0.N_24731\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
GRFPU0_GRFPU_X0_ITER_RNDMODE_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"02000000a8000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5193_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(67),
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DPI\,
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(1),
dataa => \GRFPU0.GRFPU_X0.N_19431\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f2f0f000220000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_2\(0),
dataf => \GRFPC0.N_24323\,
datae => \GRFPC0.N_24324\,
datad => \GRFPC0.N_25378\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2\,
datab => \GRFPC0.DIV.INST\(16),
dataa => \GRFPC0.DIV.INST\(17));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"dc505050cc000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.N_20291\,
datad => \GRFPU0.GRFPU_X0.N_19767\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0\,
datab => \GRFPU0.GRFPU_X0.N_80\,
dataa => \FPI.OP1\(51));
GRFPC0_RFA2_RS1DEP_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"dddeddeeffffffff")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_5\,
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2\,
datae => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\,
datac => \GRFPC0.INST\(31),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
dataa => \GRFPC0.N_131\);
GRFPC0_RFA2_RS1DEP_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff0000")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_7\,
dataf => N_186272,
datae => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_8\,
datad => N_186976);
GRFPC0_RFA2_RS1DEP_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0bbbbbbb00bb00bb")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9_0\,
dataf => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_7\,
datae => \GRFPC0.RFA2.RS1DEP_0_0_G1_N_7\,
datad => \GRFPC0.REGDEP_2_SQMUXA\,
datac => \GRFPC0.RFA2.RS1DEP_0_0_G1_N_6\,
datab => \GRFPC0.RFA2.RS1DEP_0_0_G1_0_N_6\,
dataa => \GRFPC0.N_21694\);
GRFPC0_RFA2_RS1DEP_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffff00ff00")
port map (
combout => \GRFPC0.N_10167\,
dataf => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9_0\,
datae => \GRFPC0.REGDEP_2_SQMUXA_2\,
datad => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9\,
datac => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_5\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187833,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(44),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187833,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(39),
datad => \FPI.OP2\(36),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187831,
datad => \GRFPU0.GRFPU_X0.N_20891_I\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187831,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(32),
datad => \FPI.OP2\(35),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622_2,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187829,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187829,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(35),
datad => \FPI.OP2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187819,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(38),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_0\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0040004000004040")
port map (
combout => N_187819,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(30),
datad => \FPI.OP2\(33),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187817,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187817,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(39),
datad => \FPI.OP2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187815,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187815,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(46),
datad => \FPI.OP2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187813,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187813,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(41),
datad => \FPI.OP2\(44),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187811,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187811,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(40),
datad => \FPI.OP2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187809,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(52),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187809,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(47),
datad => \FPI.OP2\(44),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187807,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187807,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(45),
datad => \FPI.OP2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187805,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datab => \GRFPU0.GRFPU_X0.N_218_0\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0040004000004040")
port map (
combout => N_187805,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(29),
datad => \FPI.OP2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187803,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187803,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(33),
datad => \FPI.OP2\(36),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622_2,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187801,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(57),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187801,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187799,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_0\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187799,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(34),
datad => \FPI.OP2\(31),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622_2,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187797,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(55),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187797,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(47),
datad => \FPI.OP2\(50),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187795,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020002000002020")
port map (
combout => N_187795,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(34),
datad => \FPI.OP2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187793,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187793,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(41),
datad => \FPI.OP2\(38),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187791,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187791,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(49),
datad => \FPI.OP2\(46),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187789,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187789,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(40),
datad => \FPI.OP2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187787,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187787,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(54),
datad => \FPI.OP2\(51),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000bf000000ff40")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => N_187785,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datab => \GRFPU0.GRFPU_X0.N_218_1\,
dataa => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000202000200020")
port map (
combout => N_187785,
dataf => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datae => \FPI.OP2\(45),
datad => \FPI.OP2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datab => N_49622,
dataa => \GRFPU0.GRFPU_X0.N_218\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIN6RNL1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(57),
datac => \FPI.OP1\(52),
datab => \FPI.OP1\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI8IQNL1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(42),
datac => \FPI.OP1\(34),
datab => \FPI.OP1\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIMERNL1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(53),
datac => \FPI.OP1\(45),
datab => \FPI.OP1\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI3T5JI1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(40),
datac => \FPI.OP1\(35),
datab => \FPI.OP1\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIH8H7H1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(47),
datac => \FPI.OP1\(42),
datab => \FPI.OP1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIFERNL1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(43),
datac => \FPI.OP1\(35),
datab => \FPI.OP1\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI9AQNL1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(46),
datac => \FPI.OP1\(41),
datab => \FPI.OP1\(38),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNITASNL1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(54),
datac => \FPI.OP1\(49),
datab => \FPI.OP1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI8MPNL1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(51),
datac => \FPI.OP1\(43),
datab => \FPI.OP1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI36PNL1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(49),
datac => \FPI.OP1\(41),
datab => \FPI.OP1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI2EPNL1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(45),
datac => \FPI.OP1\(40),
datab => \FPI.OP1\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI1MPNL1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(41),
datac => \FPI.OP1\(36),
datab => \FPI.OP1\(33),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNITLQUJ1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(48),
datac => \FPI.OP1\(43),
datab => \FPI.OP1\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIE6OGN1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(52),
datac => \FPI.OP1\(47),
datab => \FPI.OP1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI7H6JI1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(39),
datac => \FPI.OP1\(34),
datab => \FPI.OP1\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI82NGN1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(55),
datac => \FPI.OP1\(50),
datab => \FPI.OP1\(47),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_RNIIH82M1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(58),
datac => \FPI.OP1\(53),
datab => \FPI.OP1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIE8H7H1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(37),
datac => \FPI.OP1\(32),
datab => \FPI.OP1\(29),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNIHL7JI1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(44),
datac => \FPI.OP1\(36),
datab => \FPI.OP1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_RNI8T5JI1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(50),
datac => \FPI.OP1\(42),
datab => \FPI.OP1\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_RNIO59SK1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(38),
datac => \FPI.OP1\(33),
datab => \FPI.OP1\(30),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
GRFPC0_RFA2_RS1DEP_RNO_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00008acf0000153f")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_N_6\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datae => N_187733,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datab => \GRFPC0.WR2.CTRL.RDD\,
dataa => \GRFPC0.MEM.CTRL.RDD\);
GRFPC0_RFA2_RS1DEP_RNO_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => N_187733,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\);
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_RNI7RT4M_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffefefefcfcfcfcf")
port map (
combout => \GRFPU0.GRFPU_X0.N_19712\,
dataf => \GRFPU0.GRFPU_X0.N_19767\,
datae => \GRFPU0.GRFPU_X0.N_327\,
datad => N_187635,
datac => \GRFPU0.GRFPU_X0.N_80_0\,
datab => \FPI.FLOP_1\(1),
dataa => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_NC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_187635,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(53));
GRFPC0_VDIV_VALID_0_SQMUXA_RNIT2K4Q: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccffecffee")
port map (
combout => N_174898,
dataf => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
datad => \GRFPC0.N_21157\,
datac => N_52020_1,
datab => N_187631,
dataa => \GRFPC0.DIV.VALID_0\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_RNI9C5I1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff4ffffff44ff4f")
port map (
combout => N_187631,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID_0\,
dataa => N_63);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_3\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_8\(0),
datae => N_187629,
datad => \GRFPC0.N_25540\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_3_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff40ffffff00")
port map (
combout => N_187629,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\(0),
datad => \GRFPC0.N_25787\,
datac => \GRFPC0.N_23660\,
datab => \GRFPC0.N_23712\,
dataa => \GRFPC0.N_23662\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_0_O2_0_S_RNI82766_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0005000d00050005")
port map (
combout => \GRFPU0.GRFPU_X0.N_8197\,
dataf => N_187627,
datae => \GRFPU0.GRFPU_X0.N_20299\,
datad => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\,
datac => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_5\,
datab => N_184438,
dataa => \GRFPU0.GRFPU_X0.N_194\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10_0_A2_RNI2U5B2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => N_187627,
dataf => \FPI.OP2\(54),
datae => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\,
datad => \GRFPU0.GRFPU_X0.N_20296\,
datac => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\);
GRFPC0_UN1_WRENX2_2_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00d50075005d0057")
port map (
combout => \GRFPC0.UN1_WRENX2_2_4_0\,
dataf => \GRFPC0.N_18116\,
datae => \GRFPC0.N_23608\,
datad => N_187623,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.DIV.RD\(3),
dataa => N_63);
GRFPC0_UN1_WRENX2_2_4_0_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0333303333033330")
port map (
combout => N_187623,
dataf => \GRFPC0.DIV.RD\(1),
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.RFA.RS1\(1),
datac => \GRFPC0.RFA.RS1\(3),
datab => N_63);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_1_RNI7NFU7_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0\,
dataf => N_187621,
datae => \GRFPU0.GRFPU_X0.N_19767_6\,
datad => \GRFPU0.GRFPU_X0.N_331\,
datac => \GRFPU0.GRFPU_X0.N_80\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0_SUB\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffd")
port map (
combout => N_187621,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(60),
datab => \FPI.OP1\(61),
dataa => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_29_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_29\(4),
dataf => N_187587,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_20\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_18\(4),
datac => \FPI.OP1\(29),
datab => \FPI.OP1\(25));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_29_SUB_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_187587,
dataf => \FPI.OP1\(5),
datae => \FPI.OP1\(1),
datad => \FPI.OP1\(15),
datac => \FPI.OP1\(11),
datab => \FPI.OP1\(19),
dataa => \FPI.OP1\(23));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1133103300000000")
port map (
combout => \GRFPC0.N_24538_2\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.N_24016\,
datab => N_187567,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_2_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3fffff")
port map (
combout => N_187567,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => N_174890,
datad => \GRFPC0.V.STDATA_14\(19),
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"005f004f00000000")
port map (
combout => \GRFPC0.N_24798\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => N_187563,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_4_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcffffff")
port map (
combout => N_187563,
dataf => N_184373,
datae => \GRFPC0.V.STDATA_14\(17),
datad => N_174892,
datac => \GRFPC0.V.STDATA_14\(15),
datab => \GRFPC0.N_25491\);
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_D_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffccc8")
port map (
combout => N_138220,
dataf => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datae => N_187561,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_D_SUB_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c080ecccc8c0eccc")
port map (
combout => N_187561,
dataf => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datae => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_15_O2_NC_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffeffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20299\,
dataf => N_187551,
datae => \FPI.OP2\(46),
datad => \FPI.OP2\(48),
datac => \FPI.OP2\(47),
datab => \FPI.OP2\(33),
dataa => \FPI.OP2\(44));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_15_0_O2_NC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_187551,
dataf => \FPI.OP2\(41),
datae => \FPI.OP2\(42),
datad => \FPI.OP2\(32),
datac => \FPI.OP2\(50));
GRFPU0_GRFPU_X0_UN123_BCO_LSB_0_RNI0LFP7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffe0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_2\(2),
dataf => N_187537,
datae => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8));
GRFPU0_GRFPU_X0_UN133_BCO_LSB_0_0_RNIHHD66: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0f0f0ffffffff")
port map (
combout => N_187537,
dataf => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_0\,
datad => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_1\,
datac => \GRFPU0.GRFPU_X0.L1_5_4_1\(3));
\GRFPU0_GRFPU_X0_L1_4_1_3_I_RNIV2QO8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ffffff00")
port map (
combout => N_124886,
dataf => N_187533,
datae => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3593\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_RNIDJUQ7_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000ffff")
port map (
combout => N_187533,
dataf => N_124875,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f003f003f00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\,
dataf => \GRFPC0.N_19591\,
datae => \GRFPC0.N_19592\,
datad => N_187513,
datac => \GRFPC0.OP2_SN_N_9\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10_0_A2_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54ff54ff54ff5400")
port map (
combout => N_187513,
dataf => \GRFPC0.N_19921\,
datae => \GRFPC0.N_19920\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19657\,
datab => \GRFPC0.N_19658\,
dataa => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_L1_5_4_1_NC_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_4_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_3566\,
datae => N_187409,
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.DRES_1\(113),
datab => \GRFPU0.MULO.DRES_1\(112));
\GRFPU0_GRFPU_X0_L1_5_4_1_NC_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0f00ff")
port map (
combout => N_187409,
dataf => \GRFPU0.MULO.DRES_1S\(112),
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datad => N_31104,
datac => N_31105);
\GRFPC0_OP1_I_M4_3_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_23922\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_187403,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST\,
datab => N_746,
dataa => N_682);
\GRFPC0_OP1_I_M4_3_SUB_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_187403,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_746,
datac => N_682,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19222\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_187401,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_726,
dataa => N_662);
\GRFPC0_OP1_4_SUB_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_187401,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_726,
datac => N_662,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19236\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_187399,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_740,
dataa => N_676);
\GRFPC0_OP1_4_SUB_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_187399,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_740,
datac => N_676,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19237\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_187397,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_741,
dataa => N_677);
\GRFPC0_OP1_4_SUB_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_187397,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_741,
datac => N_677,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19235\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_187395,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_739,
dataa => N_675);
\GRFPC0_OP1_4_SUB_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_187395,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_739,
datac => N_675,
datab => N_197,
dataa => N_192);
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(61),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(6));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(8));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(58),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(6));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(8),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(5));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(59),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(58),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(59),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(61),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(9));
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_RNIC6K7R_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bf0f0f0faf0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_19713\,
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.N_19767\,
datad => \GRFPU0.GRFPU_X0.N_19768\,
datac => \GRFPU0.GRFPU_X0.N_20313_I\,
datab => \FPI.OP1\(51),
dataa => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_5_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffef40e04")
port map (
combout => \GRFPU0.GRFPU_X0.N_20296\,
dataf => \FPI.OP2\(43),
datae => \GRFPC0.N_19862\,
datad => \GRFPC0.N_19796\,
datac => \GRFPC0.OP2_SN_N_9\,
datab => \GRFPC0.N_19731\,
dataa => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(53),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(1));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(53),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49));
GRFPC0_FP_PIPELINE_12_REGDEPX2_384_N_4L6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_4\,
dataf => \GRFPC0.N_25755\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_12_REGDEPX2_384_N_6L11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_6\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datae => \GRFPC0.N_25757\,
datad => \GRFPC0.N_25117\,
datac => \GRFPC0.WR2.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_12_REGDEPX2_384_N_7L14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000007f")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_7\,
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_1\(1),
datae => N_186932,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_384_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384\(1),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370\(1),
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_7\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_6\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384_N_4\);
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_N_4L6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_4\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\(1),
datad => \GRFPC0.N_24635\,
datac => \GRFPC0.DIVI_0_SQMUXA_5\);
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_N_6L12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000cf00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_6\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_9\(1),
datae => \GRFPC0.N_24749\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_7\(1),
datac => N_174890,
datab => \GRFPC0.N_24115\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5d4c7f6e19083b2a")
port map (
combout => \GRFPC0.N_16975\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0\,
datae => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_6\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_14_N_4\,
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_N_6L12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f0f0f33ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_6\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3768_REGDEPX2\,
datae => \GRFPC0.N_23584\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.N_23587\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_N_7L15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_7\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_6\,
datae => \GRFPC0.N_23756\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datac => \GRFPC0.N_23588\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffef")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_5\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_N_7\,
datab => \GRFPC0.N_23761\,
dataa => \GRFPC0.N_23754\);
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_I_M2_N_4L7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_4\,
dataf => \GRFPC0.N_24327\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_I_M2_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000333f1115")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_9\,
dataf => \GRFPC0.N_25208\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_4\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f00f0f00000")
port map (
combout => N_124907,
dataf => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_10\,
datae => \GRFPC0.N_24997\,
datad => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1_6_I_M2_N_9\,
datac => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_395_0_O2_RNI1BAV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G3_N_7\,
dataf => \GRFPC0.N_23660\,
datae => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1770_REGDEPX2_RNIPGL12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f8f0f0f088000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G3_N_9\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.N_25338\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0\,
dataa => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_12_0_A2_I_O2_RNIT2363_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffffeffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G3_N_10\,
dataf => \GRFPC0.D.LDLCK_0_0_6__G3_N_9\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.N_25277\,
datab => \GRFPC0.DIV.RD_0\(3),
dataa => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_3_0_RNIVVJ8A_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff73")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G3\,
dataf => \GRFPC0.N_24965\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_8\(0),
datad => \GRFPC0.N_24952\,
datac => \GRFPC0.N_24948_1\,
datab => \GRFPC0.D.LDLCK_0_0_6__G3_N_10\,
dataa => \GRFPC0.D.LDLCK_0_0_6__G3_N_7\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_9_N_6L11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_6\,
dataf => \GRFPC0.N_24112\,
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.N_23587\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_9_N_8L17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_8\,
dataf => \GRFPC0.N_23584\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.N_25566\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_9_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f0ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_9\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_6\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2\,
datad => \GRFPC0.N_78_I_I_1\,
datac => \GRFPC0.EX.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_9_N_10L22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_10\,
dataf => \GRFPC0.N_24133\,
datae => \GRFPC0.N_24135\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_9\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_8\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9_N_10\,
datae => \GRFPC0.N_24881\,
datad => \GRFPC0.V.STDATA_14_M_5\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_N_5L8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0fffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_5\,
dataf => \GRFPC0.N_25546\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A2_3_1\(1),
datac => \GRFPC0.N_23587\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_N_6L11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_6\,
dataf => \GRFPC0.N_25522_2\,
datae => \FPI.FLOP_0\(1),
datad => \GRFPC0.V.STDATA_14\(14),
datac => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_N_7L13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_7\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_6\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_5\,
datac => \GRFPC0.DIVI_0_SQMUXA_5\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_11\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_N_7\,
datad => \GRFPC0.N_24090\,
datac => \GRFPC0.N_23660\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A3_0_0\(0));
GRFPC0_FP_PIPELINE_8_REGDEPX2_262_N_7L15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000003ff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_7\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(1),
datae => N_186254,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3903_REGDEPX2\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.WR2.CTRL.INST\(25));
GRFPC0_FP_PIPELINE_8_REGDEPX2_262_N_8L18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8_0\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_24088\,
datad => N_174892,
datac => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_8_REGDEPX2_262_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00f00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_9_0\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_262_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ffffff0fff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_9_0\,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253\(1),
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_7\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\);
GRFPC0_FP_PIPELINE_4_REGDEPX2_148_N_7L13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffbffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_7\,
dataf => \GRFPC0.EX.CTRL.RS1V\,
datae => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(17),
dataa => \GRFPC0.EX.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_4_REGDEPX2_148_N_8L16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_8\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_7\,
datad => \GRFPC0.N_78_I_I_2\,
datac => \GRFPC0.EX.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_4_REGDEPX2_148_N_9L19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f3000cf3ff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_9\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_126\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_8\,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_148_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0800ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148_N_9\,
datae => N_186944,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.N_25378\,
datab => \GRFPC0.N_251\,
dataa => \GRFPC0.DIV.RS1V\);
GRFPC0_FP_PIPELINE_9_REGDEPX2_289_N_2L1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_2\,
dataf => \GRFPC0.WR.CTRL.RS1V\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0\(0));
GRFPC0_FP_PIPELINE_9_REGDEPX2_289_N_5L8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ff0000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_5\,
dataf => \GRFPC0.N_25648_1\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_2\,
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
GRFPC0_FP_PIPELINE_9_REGDEPX2_289_N_7L13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f0000ff3fff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_7\,
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_283\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_289_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_7\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289_N_5\,
datad => \GRFPC0.N_25835_2\,
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_RFA2_RS1DEP_RNO_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f00f")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_8\,
dataf => \GRFPC0.UN1_REGDEP47_3\,
datae => \GRFPC0.UN1_REGDEP47_1\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datac => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_RFA2_RS1DEP_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000c00000")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G0_N_9\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP90_2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
datac => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G1\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_159_N_7L14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0008000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_7\,
dataf => \GRFPC0.N_23584\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15),
dataa => \GRFPC0.EX.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_5_REGDEPX2_159_N_8L18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ba30aa00aa00aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_8\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.N_24554\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11_1\(0),
datac => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(4),
dataa => \GRFPC0.N_23587\);
GRFPC0_FP_PIPELINE_5_REGDEPX2_159_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fff0ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_9\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(0),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2\,
datad => \GRFPC0.DIVI_0_SQMUXA_5\,
datac => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_159_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffffff0fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_9\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_8\,
datac => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_N_7\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_4L6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_4\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_335_0_A2_1_0\(0),
datae => N_174891);
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_8L17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff0000f0fff0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8_0\,
dataf => \GRFPC0.N_23708\,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_5\,
datad => \GRFPC0.N_24567\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_4\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff8fffffff8fff8f")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9_0\,
dataf => \GRFPC0.N_24483_I\,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_4\,
datad => \GRFPC0.N_24713\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_3\,
datab => \GRFPC0.EX.CTRL.RS1V\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10\(0));
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_10L22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fff0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_10\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9_0\,
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_351_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_10\,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_336_1_N_3L4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_3\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.N_23587\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_336_1_N_4L6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_4\,
dataf => \GRFPC0.N_23660\,
datae => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_336_1_N_5L8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_5\,
dataf => N_50724,
datae => \FPI.FLOP_0\(1),
datad => N_50656_0);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_336_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"75ff757555555555")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23708\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_5\,
datac => \GRFPC0.N_24567\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_4\,
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1_N_3\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_7L15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00ff3f3fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_7\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2\,
datab => \GRFPC0.DIV.RS1V\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_8L18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8_0\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_7\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.N_25277\,
datab => \GRFPC0.N_23822\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_9L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9_0\,
dataf => N_184425,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_3\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_10L22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_10_0\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_338\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faf8fffdfffdfffd")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_10_0\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9_0\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8_0\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_N_5L8_N_2L1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_2\,
dataf => \GRFPC0.INST\(12),
datae => \GRFPC0.INST\(10),
datad => \GRFPC0.INST\(8),
datac => \GRFPC0.INST\(13));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_N_5L8_N_3L3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_3\,
dataf => \GRFPC0.INST\(11),
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(6),
datac => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_N_5L8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5\,
dataf => \GRFPC0.N_10173_2\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_7_7_3\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_3\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5L8_N_2\,
datab => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_8_REGDEPX2_262_N_4L6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_4\,
dataf => N_186216,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
GRFPC0_FP_PIPELINE_8_REGDEPX2_262_N_8L17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_8\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_24088\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_4\,
datac => N_174892,
datab => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_4_REGDEPX2_144_N_10L22_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_186980,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.N_25222_1\,
datac => \GRFPC0.WR2.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_4_REGDEPX2_144_N_11L24_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_10\,
dataf => N_186980,
datae => \GRFPC0.N_25754\,
datad => \GRFPC0.N_25826_1\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_RFA2_RS1DEP_RNO_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0802000004010000")
port map (
combout => N_186976,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP50\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
dataa => \GRFPC0.MEM.CTRL.RDD\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_O2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000cc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_20291\,
dataf => \GRFPU0.GRFPU_X0.N_327\,
datae => N_186962,
datad => \GRFPU0.GRFPU_X0.N_331\,
datac => \FPI.FLOP_1_0\(1),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_O2_SUB_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"dddddddd55555554")
port map (
combout => N_186962,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(53),
datab => \FPI.FLOP_1_0\(1),
dataa => \FPI.NONSTD\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000e4ee")
port map (
combout => \GRFPC0.N_21137\,
dataf => N_186950,
datae => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
datac => N_52020_2,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
dataa => \GRFPC0.DIV.VALID_0\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5544554455ff55f4")
port map (
combout => N_186950,
dataf => \GRFPC0.N_21157\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID_0\,
dataa => N_63);
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_M4_D_N_12L28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000007f00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_12\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => N_186946,
datac => \GRFPC0.N_24088\,
datab => N_174892,
dataa => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_M4_D_N_12L28_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => N_186946,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_12\,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_10\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_11\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_146_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => N_186944,
dataf => N_186242,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_23819\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_253_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff80ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => N_186940,
datac => \GRFPC0.N_24088\,
datab => N_174892,
dataa => \FPI.FLOP_0\(6));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_253_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffff")
port map (
combout => N_186940,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_12\,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_10\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_11\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380\(1),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370\(1),
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_1\(1),
datad => N_186932,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eccca00000000000")
port map (
combout => N_186932,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_376_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_376\(0),
dataf => \GRFPC0.N_23617\,
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_1\(0),
datad => N_186918,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datab => \GRFPC0.N_23588\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_376_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0200000202")
port map (
combout => N_186918,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25164\,
datad => \GRFPC0.N_23639\,
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.INST\(27),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_283_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_283\(0),
dataf => \GRFPC0.N_23648\,
datae => N_186912,
datad => \GRFPC0.N_207\,
datac => \GRFPC0.N_23870\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_283_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeac0aa00")
port map (
combout => N_186912,
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.N_305\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4_0_0\(0),
datab => \GRFPC0.MEM.CTRL.RS1V\,
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10_0_A2_RNIKNUQ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_32\,
dataf => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\,
datae => N_186910,
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(49),
datab => \FPI.OP2\(45),
dataa => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_32_NC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_186910,
dataf => \FPI.OP2\(2),
datae => \FPI.OP2\(31),
datad => \FPI.OP2\(43));
GRFPC0_FP_PIPELINE_VRFA_ST_1_U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00aa00aa00ff00bf")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => N_186906,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_184337,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI\);
GRFPC0_FP_PIPELINE_VRFA_ST_1_U_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7775777775757777")
port map (
combout => N_186906,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => N_184395,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => N_138,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI\,
dataa => \GRFPC0.FP_PIPELINE.VRFA.ST_1_U_2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0b00000000")
port map (
combout => \GRFPC0.N_24823\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datac => N_186904,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => \GRFPC0.N_24016\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff3fffff")
port map (
combout => N_186904,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_0\(0),
datae => \GRFPC0.N_25505_2\,
datad => \GRFPC0.V.STDATA_14\(15),
datac => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.N_25549\);
GRFPC0_FP_PIPELINE_UN108_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcc00fffffc00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN108_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datae => N_186902,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_184337,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_UN108_HOLDN_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffaeffffffff")
port map (
combout => N_186902,
dataf => N_49622_0,
datae => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\,
datac => \GRFPC0.R.STATE_2\(1),
datab => \GRFPC0.R.STATE_191\(0),
dataa => N_64);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1313130300000000")
port map (
combout => \GRFPC0.N_24948_1\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => \GRFPC0.N_24016\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datab => N_186900,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_3_0_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => N_186900,
dataf => \GRFPC0.DIVI_0_SQMUXA_5\,
datae => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
GRFPC0_FP_PIPELINE_V_STATE10_RNI1JB3A: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff30ffffff00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\,
datad => N_186892,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10\);
GRFPC0_WREN_0_SQMUXA_2_RNI524N: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_186892,
dataf => \GRFPC0.WREN_0_SQMUXA_2\,
datae => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.WR2.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_SUB_RNI6QCV4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3c3c3c3c300c3c3")
port map (
combout => \GRFPC0.INST_0\,
dataf => N_184333,
datae => N_186882,
datad => \GRFPC0.N_198\,
datac => N_49622_0,
datab => \GRFPC0.FIFO.RD\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_SUB_X_RNITIH01_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_186882,
dataf => \GRFPC0.N_196\,
datae => N_186704,
datad => N_52826,
datac => \GRFPC0.FIFO.WR\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_SUB_RNI6QCV4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3c3c3c3c003c3c")
port map (
combout => \GRFPC0.INST_SN_N_2\,
dataf => N_184333,
datae => N_186880,
datad => \GRFPC0.N_198\,
datac => N_49622_0,
datab => \GRFPC0.FIFO.RD\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_SUB_X_RNITIH01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_186880,
dataf => \GRFPC0.N_196\,
datae => N_186704,
datad => N_52826,
datac => \GRFPC0.FIFO.WR\(0));
\GRFPC0_OP1_4_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19220\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186820,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_724,
dataa => N_660);
\GRFPC0_OP1_4_SUB_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186820,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_724,
datac => N_660,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19214\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186818,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_718,
dataa => N_654);
\GRFPC0_OP1_4_SUB_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186818,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_718,
datac => N_654,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19215\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186816,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_719,
dataa => N_655);
\GRFPC0_OP1_4_SUB_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186816,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_719,
datac => N_655,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19223\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186814,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_727,
dataa => N_663);
\GRFPC0_OP1_4_SUB_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186814,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_727,
datac => N_663,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19225\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186812,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_729,
dataa => N_665);
\GRFPC0_OP1_4_SUB_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186812,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_729,
datac => N_665,
datab => N_197,
dataa => N_192);
\GRFPC0_OP1_4_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc0000fafa")
port map (
combout => \GRFPC0.N_19221\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => N_186810,
datad => \GRFPC0.RFA.RS1D\,
datac => \GRFPC0.RFA.ST_0\,
datab => N_725,
dataa => N_661);
\GRFPC0_OP1_4_SUB_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b4f0f0f0b4f0000")
port map (
combout => N_186810,
dataf => \GRFPC0.RFA.RS1D\,
datae => \GRFPC0.RFA.ST\,
datad => N_725,
datac => N_661,
datab => N_197,
dataa => N_192);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_SUB_X: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => N_186704,
dataf => \GRFPC0.N_23498\,
datae => \GRFPC0.N_201_2\,
datad => N_186808,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_2_2\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_2\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_SUB_X_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bfffffff3fffffff")
port map (
combout => N_186808,
dataf => \GRFPC0.D.FLDLCK\,
datae => N_63,
datad => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datac => N_126,
datab => N_124,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_3_0\);
\GRFPC0_FIFO_INST_1_RNI6QFR_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"202f202000000000")
port map (
combout => \GRFPC0.N_23708\,
dataf => \GRFPC0.V.STDATA_14\(1),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.INST_1\(3),
dataa => \GRFPC0.FIFO.INST_1\(4));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(51),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48));
\GRFPC0_DIV_RESULT_0_0_42__G3_1\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_42__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(56),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(1));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(57),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(34),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34));
\GRFPC0_DIV_RESULT_0_0_62__G3_1\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_62__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(55),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(5));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(49),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(45),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(55),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(40),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_1\(35),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35));
\GRFPC0_DIV_RESULT_0_0_62__G3_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_62__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(10));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_0_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_0\(35),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41));
\GRFPC0_DIV_RESULT_0_0_42__G3_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_42__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(36),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(45),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(38),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(56),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(44),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(46),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(37),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(33),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(33),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(48),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(45));
\GRFPC0_DIV_RESULT_0_0_39__G3_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_39__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39));
\GRFPC0_DIV_RESULT_0_0_39__G3_1\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_39__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(44),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
dataf => N_184333,
datae => \GRFPC0.N_198\,
datad => \GRFPC0.N_196\,
datac => N_186704);
GRFPC0_RFA2_RS2DEP_RNO_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc0ffff0330ffff")
port map (
combout => N_186268,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffaaaa8880")
port map (
combout => \GRFPC0.RFA.RS2D_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS2D_IV_N_5\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
datab => \GRFPC0.N_10173_2\,
dataa => \GRFPC0.INST\(31));
GRFPC0_FP_PIPELINE_RSDEC_RS1V7_RNIPL1E3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"575757775f5f5fff")
port map (
combout => N_186256,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
datac => \GRFPC0.N_10173_2\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
dataa => \GRFPC0.INST\(31));
GRFPC0_VFIFO_PC_0_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
dataf => N_184333,
datae => N_184505,
datad => \GRFPC0.N_198\,
datac => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.R.STATE\(1),
dataa => \GRFPC0.R.STATE\(0));
GRFPC0_VFIFO_INST_1_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000010")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
dataf => N_184333,
datae => N_184505,
datad => \GRFPC0.N_198\,
datac => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.R.STATE\(1),
dataa => \GRFPC0.R.STATE\(0));
GRFPC0_WR2_CTRL_RDWR_RNIILMG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555575755ff57ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.RREG.RESV_1_0\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
dataa => N_63);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_O2_2_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc505000000000")
port map (
combout => \GRFPC0.N_24567\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_0_0\(29),
datab => \GRFPC0.FIFO.INST_1_0\(29),
dataa => \GRFPC0.FIFO.INST_0_0\(28));
GRFPC0_FP_PIPELINE_4_REGDEPX2_144_N_9L19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_9\,
dataf => \GRFPC0.N_25758\,
datae => \GRFPC0.N_25223_2\,
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_4_REGDEPX2_144_N_11L24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_11\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_10\,
datae => \GRFPC0.N_25580\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144_N_9\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\);
GRFPC0_RFA2_RS1DEP_RNO_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000222100002211")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_0_N_6\,
dataf => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datae => \GRFPC0.REGDEP_1_SQMUXA_1\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\,
datac => \GRFPC0.INST\(31),
datab => \GRFPC0.FP_PIPELINE.0.REGDEP66\,
dataa => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_8L16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8\,
dataf => \GRFPC0.N_260\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_0_REGDEPX2_360_N_9L19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"40000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_9\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_N_8\,
datae => \GRFPC0.N_25758\,
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(1),
dataa => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_M4_D_N_9L19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_9\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(1),
datae => \GRFPC0.N_25755\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3903_REGDEPX2\,
datac => \GRFPC0.WR2.RREG.RESV_0\,
datab => \GRFPC0.WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_M4_D_N_11L25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000070f0f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_11\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.N_24088\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262_N_4\,
datab => N_174892,
dataa => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_M4_D: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1fbf5fff0faf4fef")
port map (
combout => N_138228,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_11\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_12\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_M4_D_N_9\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\);
GRFPC0_RFA2_RS1DEP_RNO_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff3c")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_N_7\,
dataf => N_100350_TZ,
datae => \GRFPC0.UN1_REGDEP47_3\,
datad => \GRFPC0.UN1_REGDEP47_1\,
datac => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_DEPMUX_RES_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff7722ffff7520")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_1\,
dataf => \GRFPC0.N_24276\,
datae => N_186278,
datad => \GRFPC0.N_16962\,
datac => \GRFPC0.N_16968\,
datab => \GRFPC0.INST\(28),
dataa => \GRFPC0.INST\(29));
GRFPC0_FP_PIPELINE_DEPMUX_RES_1_1_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ddcc9988d5c49180")
port map (
combout => N_186278,
dataf => \GRFPC0.N_16974\,
datae => \GRFPC0.N_16961\,
datad => \GRFPC0.N_16955\,
datac => \GRFPC0.N_16975\,
datab => \GRFPC0.INST\(28),
dataa => \GRFPC0.INST\(29));
GRFPC0_RFA2_RS1DEP_RNO_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffdfffeff")
port map (
combout => N_186272,
dataf => N_186266,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
dataa => \GRFPC0.WR2.CTRL.RDD_0\);
GRFPC0_RFA2_RS2DEP_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"007b00ffffffffff")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_0\,
dataf => \GRFPC0.UN1_REGDEP173\,
datae => N_186268,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2\,
datac => \GRFPC0.RFA.RS2D_0_0_G1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_1\,
dataa => \GRFPC0.MEM.CTRL.RDD\);
GRFPC0_REGDEP_2_SQMUXA_3_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0000f0ff0000")
port map (
combout => N_186266,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
datac => \GRFPC0.MEM.CTRL.RDD\);
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_RD_RNIU0V95: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f3fdfcfbf3fefcf")
port map (
combout => \GRFPC0.UN1_REGDEP47_3\,
dataf => N_186256,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.RD\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RD\(4),
dataa => \GRFPC0.N_131\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_262_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eaaac000c000c000")
port map (
combout => N_186254,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datac => \GRFPC0.N_25757\,
datab => \GRFPC0.N_260\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cfff3ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_129\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
datad => N_186242,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0c00")
port map (
combout => N_186242,
dataf => \GRFPC0.N_25762\,
datae => \GRFPC0.N_25779\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0_0\(1),
datac => \GRFPC0.WR2.RREG.RESV_0\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_RFA_RS1_RNIIDIV4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f00000ff0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
dataf => N_186238,
datae => \GRFPC0.N_23608\,
datad => \GRFPC0.RFA.RS1\(3),
datac => N_63);
\GRFPC0_RFA_RD_RNIMMCI4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f00ff")
port map (
combout => N_186238,
dataf => \GRFPC0.FP_PIPELINE.UN105_HOLDN\,
datae => N_49622_0,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.RFA.RD\(3));
GRFPC0_REGDEP_1_SQMUXA_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03ffff30cfffff")
port map (
combout => N_184631,
dataf => \GRFPC0.N_23609\,
datae => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
datad => N_186236,
datac => \GRFPC0.RFA.RS1\(2),
datab => N_63);
GRFPC0_REGDEP_1_SQMUXA_1_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => N_186236,
dataf => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datae => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.RFA.RD\(2));
GRFPC0_FP_PIPELINE_0_EXEN2_I_S_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"007f00df00f700fd")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2_I_S_4_0\,
dataf => \GRFPC0.N_18116\,
datae => \GRFPC0.N_23609\,
datad => N_186232,
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2),
dataa => N_63);
GRFPC0_FP_PIPELINE_0_EXEN2_I_S_4_0_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000030000300003")
port map (
combout => N_186232,
dataf => \GRFPC0.EX.CTRL.RD\(1),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.RFA.RS1\(1),
datac => \GRFPC0.RFA.RS1\(2),
datab => N_63);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_248_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => N_186216,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3768_REGDEPX2\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000004c0013005f")
port map (
combout => \GRFPC0.N_25569\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(0),
datad => N_186214,
datac => \GRFPC0.N_25580\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000f2222222")
port map (
combout => N_186214,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A4_1\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datad => \GRFPC0.N_23588\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_365_RNIMH282_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffecff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_370\(1),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_365\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => N_186212,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2\,
datab => N_186186,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_EX_CTRL_INST_RNINLP31_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fffffffffffff")
port map (
combout => N_186212,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.N_78_I_I\,
datac => \GRFPC0.EX.CTRL.INST\(14));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_0_9_RNI9B01E_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_327\,
dataf => N_184435,
datae => N_186200,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_13\(4),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_9\(4),
datab => \FPI.OP1\(36),
dataa => \FPI.OP1\(49));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_0_REST_NC_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_186200,
dataf => \FPI.OP1\(34),
datae => \FPI.OP1\(35),
datad => \FPI.OP1\(38),
datac => \FPI.OP1\(33));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0055005100000000")
port map (
combout => \GRFPC0.N_24952\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => N_186174,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => N_186196);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_4_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => N_186196,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(16),
datac => N_174891);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff40ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_3\(0),
dataf => \GRFPC0.N_24533\,
datae => \GRFPC0.N_24242_2\,
datad => N_186190,
datac => \GRFPC0.N_23708\,
datab => N_50724,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\);
GRFPC0_FP_PIPELINE_UN109_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033ff000003ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datae => N_186188,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_184337,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_UN109_HOLDN_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffae")
port map (
combout => N_186188,
dataf => N_49622_0,
datae => \GRFPC0.FP_PIPELINE.V.STATE10\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\,
datac => \GRFPC0.R.STATE_2\(1),
datab => \GRFPC0.R.STATE_191\(0),
dataa => N_64);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_368_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => N_186186,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0d00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datac => N_186184,
datab => \GRFPC0.N_24016\,
dataa => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f00ff")
port map (
combout => N_186184,
dataf => \GRFPC0.N_24123\,
datae => \GRFPC0.N_24207\,
datad => \GRFPC0.N_24122\,
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_124_0_A2_1_1\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff04ffffffff")
port map (
combout => \GRFPC0.N_23648\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => N_186182,
datac => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => \GRFPC0.N_24016\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f0000ffffffff")
port map (
combout => N_186182,
dataf => \GRFPC0.N_23658\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_6414_0\,
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_A2_0\(1),
datac => \GRFPC0.N_23660\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0b00000000")
port map (
combout => \GRFPC0.N_23617\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datac => N_186176,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => \GRFPC0.N_24016\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A2_0_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003330fff")
port map (
combout => N_186176,
dataf => \GRFPC0.N_23643\,
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_A3_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2\,
datac => \GRFPC0.N_23660\,
datab => N_174891);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f300000000")
port map (
combout => \GRFPC0.N_24181\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => N_186174,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffdfffffdfdffff")
port map (
combout => N_186174,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datab => \GRFPC0.V.STDATA_14\(18),
dataa => \FPI.FLOP_0\(6));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0707070300000000")
port map (
combout => \GRFPC0.N_24950\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => \GRFPC0.N_24016\,
datac => N_186172,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => N_186172,
dataf => \GRFPC0.DIVI_0_SQMUXA_5\,
datae => \GRFPC0.N_24944_1\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => N_50792,
datab => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000555100000000")
port map (
combout => \GRFPC0.N_24133\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => N_186170);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0fffffffff")
port map (
combout => N_186170,
dataf => \GRFPC0.N_23660\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_3_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0cffffffff")
port map (
combout => \GRFPC0.N_24881\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => N_186168,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_3_I_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffffefeffff")
port map (
combout => N_186168,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datab => N_50792,
dataa => \GRFPC0.V.STDATA_14\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0077007300000000")
port map (
combout => \GRFPC0.N_24135\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => N_186166,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_1_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff3f")
port map (
combout => N_186166,
dataf => N_184373,
datae => \GRFPC0.V.STDATA_14\(17),
datad => \GRFPC0.V.STDATA_14\(18),
datac => N_174891,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN133_REGDEPX2_1\);
\GRFPC0_R_FSR_TEM_RNICB2J7_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0fcf0ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE6\,
dataf => \GRFPC0.N_24016\,
datae => N_186142,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.R.FSR.TEM\(3));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_3_1_RNIUQ065: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000fff0000")
port map (
combout => N_186142,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(2),
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_1\,
datad => \FPO.EXC\(0),
datac => \GRFPC0.R.FSR.TEM\(0));
GRFPC0_FP_PIPELINE_UN205_HOLDN_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
dataf => N_186140,
datae => \GRFPC0.N_198\,
datad => \GRFPC0.N_196\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\);
GRFPC0_FP_PIPELINE_UN205_HOLDN_1_0_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3fffbfff3fff3")
port map (
combout => N_186140,
dataf => \GRFPC0.N_23482\,
datae => N_52826,
datad => N_137,
datac => N_64,
datab => N_63,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0_0\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_365_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"004c005f00cc00ff")
port map (
combout => N_184569,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2\,
datad => N_186128,
datac => N_174892,
datab => \GRFPC0.N_23623\,
dataa => \FPI.FLOP_0\(6));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_365_SUB_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_186128,
dataf => N_174890,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
datad => \GRFPC0.N_24115\);
\GRFPC0_DIV_RESULT_0_0_32__G3_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_32__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(47),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(47),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(50),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(47));
\GRFPC0_DIV_RESULT_0_0_32__G3_1\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_32__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(50),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47));
GRFPC0_RFA2_RS2DEP_RNO_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0802000004010000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_2\,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEP66\,
datab => \GRFPC0.EX.CTRL.RD\(0),
dataa => \GRFPC0.N_78_I_I_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_O2_RNI3PJ3Q_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff737373ff333333")
port map (
combout => \GRFPU0.GRFPU_X0.N_20287\,
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.N_20291\,
datad => \GRFPU0.GRFPU_X0.N_19767\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0\,
datab => \GRFPU0.GRFPU_X0.N_80\,
dataa => \FPI.OP1\(51));
GRFPC0_FP_PIPELINE_RSDEC_RS1D_IV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a8a8a888a0a0a000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
datac => \GRFPC0.N_10173_2\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
dataa => \GRFPC0.INST\(31));
GRFPC0_DIVI_0_SQMUXA_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000caa00000000")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_5\,
dataf => N_51460,
datae => \GRFPC0.FIFO.INST_0_0\(19),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1\(31),
dataa => \GRFPC0.FIFO.INST_0\(31));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5444_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ca0000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5444_REGDEPX2\,
dataf => \GRFPC0.V.STDATA_14\(15),
datae => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.V.STDATA_14\(16),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.INST_1\(17),
dataa => \GRFPC0.FIFO.INST_0\(17));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5372_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ca00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5372_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.INST_1\(28),
dataa => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_WR_CTRL_INST_RET_14_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_24633_RETI\,
dataf => N_185356,
datae => N_185355);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_129_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.EX.CTRL.INST\(18),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_EX_CTRL_INST_RNI6UML_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(18),
datae => \GRFPC0.EX.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(17));
GRFPC0_UN1_WRENX2_2_5_RNITI3R3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000aa3f00000000")
port map (
combout => \GRFPC0.FPUSEL_6\(7),
dataf => \GRFPC0.FPUSEL_6_1\(7),
datae => \GRFPC0.FP_PIPELINE.0.WRENX2\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
datac => \GRFPC0.UN1_WRENX2_2_4_1\,
datab => \GRFPC0.UN1_WRENX2_2_5\,
dataa => \GRFPC0.WR2SEL_1\(7));
\GRFPC0_EX_CTRL_INST_RNIT7C7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_23588\,
dataf => \GRFPC0.N_78_I_I_0\,
datae => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_EX_CTRL_INST_RNIU08A_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_23584\,
dataf => \GRFPC0.N_78_I_I_0\,
datae => \GRFPC0.EX.CTRL.INST\(14));
GRFPU0_GRFPU_X0_ITER_R_I_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2_RETI\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
datad => \GRFPU0.GRFPU_X0.ITER.DPI\);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_RNIJTJH2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ST1_RNDMODE_RNIHPJH2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
GRFPU0_GRFPU_X0_R2_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10_RETI\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(55),
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(53),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(52));
GRFPC0_WR_CTRL_INST_RET_13_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24719_RETI\,
dataf => N_185330,
datae => N_185331);
GRFPC0_MEM_CTRL_INST_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00ff00ff")
port map (
combout => \GRFPC0.N_24642_RETI\,
dataf => N_185280,
datae => \GRFPC0.MEM.CTRL.RDDI\,
datad => \GRFPC0.MEM.CTRL.RS1VI\);
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI34DO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(1));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI44DO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(2));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI54DO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(3));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI64DO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(4));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI74DO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(5));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI84DO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(6));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI94DO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(7));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIA4DO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(8));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIJHAU_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(10));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIKLAU_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(11));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNILPAU_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(12));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIMTAU_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(13));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNI24DO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(0));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIB4DO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(9));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIN1BU_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(14));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIO5BU_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(15));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIQDBU_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(17));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIRHBU_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(18));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNISLBU_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(19));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIP9BU_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(16));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNILLAU_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(21));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIMPAU_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(22));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIKHAU_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(20));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNINTAU_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(23));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIRDBU_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(27));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIQ9BU_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(26));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNISHBU_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(28));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIO1BU_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(24));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIP5BU_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
dataf => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datae => \FPI.OP1_RETO\(25));
GRFPC0_WR_CTRL_INST_RET_12_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1_RETI\(0),
dataf => N_185344,
datae => N_185346,
datad => N_185345,
datac => N_185343);
GRFPC0_WR_CTRL_INST_RET_11_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0_RETI\(0),
dataf => N_185346,
datae => N_185344,
datad => N_185345,
datac => N_185343);
GRFPC0_WR_CTRL_RDD_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccc000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0_RETI\(1),
dataf => N_185346,
datae => N_185344,
datad => N_185342,
datac => \GRFPC0.N_131I\,
datab => \GRFPC0.WR.CTRL.RS1VI\);
GRFPC0_WR_CTRL_RDD_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccc0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0_RETI\(1),
dataf => N_185344,
datae => N_185346,
datad => N_185342,
datac => \GRFPC0.N_131I\,
datab => \GRFPC0.WR.CTRL.RS1VI\);
GRFPC0_WR_CTRL_INST_RET_10_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2_RETI\(0),
dataf => N_185344,
datae => N_185346,
datad => N_185343,
datac => N_185345);
GRFPC0_WR_CTRL_INST_RET_9_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25664_RETI\,
dataf => N_185343,
datae => N_185345);
GRFPC0_WR_CTRL_RDD_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPC0.N_25854_RETI\,
dataf => N_185346,
datae => N_185342,
datad => \GRFPC0.N_131I\);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_25_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfcfcffccfffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1_RETI\(10),
dataf => \GRFPU0.MULO.MRES_RETI\(71),
datae => \GRFPU0.MULO.MRES_RETI\(70),
datad => N_174945_RETI,
datac => \GRFPU0.GRFPU_X0.N_19279_I_RETI\,
datab => \GRFPU0.GRFPU_X0.N_19404_I_RETI\);
GRFPC0_WR_CTRL_INST_RET_8_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_25090_RETI\,
dataf => N_185344,
datae => N_185346,
datad => N_185343);
GRFPC0_WR_CTRL_INST_RET_7_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00ff")
port map (
combout => \GRFPC0.N_25586_RETI\,
dataf => \GRFPC0.N_25585_RETI\,
datae => N_185343,
datad => N_185345);
\GRFPC0_WR_CTRL_INST_RNIAVAON_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3f33")
port map (
combout => \GRFPC0.N_25585_RETI\,
dataf => N_185344,
datae => N_185346,
datad => N_185342,
datac => \GRFPC0.N_131I\,
datab => \GRFPC0.WR.CTRL.RS1VI\);
GRFPC0_WR_CTRL_INST_RET_5_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1_RETI\(0),
dataf => N_185346,
datae => N_185344,
datad => N_185345,
datac => N_185343,
datab => \GRFPC0.WR.CTRL.RS1VI\);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_4_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfcfcffccfffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1_RETI\(11),
dataf => \GRFPU0.MULO.MRES_RETI\(72),
datae => \GRFPU0.MULO.MRES_RETI\(71),
datad => N_174945_RETI,
datac => \GRFPU0.GRFPU_X0.N_19279_I_RETI\,
datab => \GRFPU0.GRFPU_X0.N_19404_I_RETI\);
GRFPU0_GRFPU_X0_VITER_STATE_18_SQMUXA_RNI458UF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f000")
port map (
combout => N_174945_RETI,
dataf => \GRFPU0.GRFPU_X0.N_11284_0\,
datae => \GRFPU0.GRFPU_X0.N_11278\,
datad => \GRFPU0.GRFPU_X0.N_11272\,
datac => N_29618);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIFQLSG_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19279_I_RETI\,
dataf => \GRFPU0.GRFPU_X0.N_11272\,
datae => \GRFPU0.GRFPU_X0.N_11275\,
datad => \GRFPU0.GRFPU_X0.N_11269_0\,
datac => N_29618);
GRFPU0_GRFPU_X0_VITER_ODDEXP_1_SQMUXA_1_RNIKEJA8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19404_I_RETI\,
dataf => \GRFPU0.GRFPU_X0.N_11277\,
datae => N_29618,
datad => N_91845);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI7FLR2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DPI\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_ITER_R_I_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000c000c333f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3406_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(44),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
datab => \GRFPU0.GRFPU_X0.ITER.DPI\);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_19_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(81),
datae => \GRFPU0.MULO.MRES_RETI\(76),
datad => \GRFPU0.MULO.MRES_RETI\(77));
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(79),
datae => \GRFPU0.MULO.MRES_RETI\(78),
datad => \GRFPU0.MULO.MRES_RETI\(75),
datac => \GRFPU0.MULO.MRES_RETI\(74));
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_21_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(78),
datae => \GRFPU0.MULO.MRES_RETI\(75),
datad => \GRFPU0.MULO.MRES_RETI\(74));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(54),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(55),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_54_RNIES61I4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(54),
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPC0_WR_CTRL_INST_RET_4_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0d5c0c0c0c0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0_RETI\(0),
dataf => \GRFPC0.N_25091_RETI\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_RETI\(0),
datad => \GRFPC0.N_25384_RETI\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_3_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_RETI\(0),
dataa => N_185343);
\GRFPC0_WR_CTRL_INST_RNIIEVBB_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25091_RETI\,
dataf => N_185344,
datae => N_185346);
GRFPC0_WR_CTRL_INST_RET_4_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_3_1\(0),
dataf => N_185331,
datae => N_185330,
datad => N_185332,
datac => N_185329);
GRFPC0_WR_CTRL_RS1V_RNIH64M6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25384_RETI\,
dataf => N_185345,
datae => \GRFPC0.WR.CTRL.RS1VI\);
GRFPC0_WR_CTRL_RS1V_RET_2_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_24957_RETI\,
dataf => \GRFPC0.N_24981_RETI\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_RETI\(0),
datad => N_185344,
datac => N_185345,
datab => \GRFPC0.WR.CTRL.RS1VI\);
\GRFPC0_WR_CTRL_INST_RNIGAVBB_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24981_RETI\,
dataf => N_185346,
datae => N_185343);
GRFPC0_MEM_CTRL_RDD_RNIPK1C5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.MEM.CTRL.RDDI\,
dataf => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
datae => \GRFPC0.MEM.CTRL.RDD\,
datad => N_63);
GRFPC0_MEM_CTRL_INST_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(0),
dataf => N_185266,
datae => \GRFPC0.MEM.CTRL.RDDI\);
GRFPU0_GRFPU_X0_ITER_STATE_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003333000c333f")
port map (
combout => N_184434_RETI,
dataf => \GRFPU0.GRFPU_X0.N_11279\,
datae => \GRFPU0.GRFPU_X0.N_11278\,
datad => \GRFPU0.GRFPU_X0.N_11275\,
datac => \GRFPU0.GRFPU_X0.N_11269_0\,
datab => N_29618);
GRFPC0_EX_CTRL_INST_RET_16_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_23587_RETI\,
dataf => N_52982,
datae => N_53023);
GRFPC0_EX_CTRL_INST_RET_15_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_RETI\,
dataf => N_53026,
datae => N_53024,
datad => N_53027,
datac => N_53025);
GRFPC0_EX_CTRL_INST_RET_14_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25532_RETI\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(1),
datae => \GRFPC0.N_25553_RETI\,
datad => N_53014,
datac => N_53016,
datab => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
\GRFPC0_EX_CTRL_INST_RNI4EIKS_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_25553_RETI\,
dataf => N_53015,
datae => N_53013);
GRFPC0_EX_CTRL_INST_RET_12_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0_RETI\(1),
dataf => N_53016,
datae => N_53014);
GRFPC0_EX_CTRL_INST_RET_11_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_24727_RETI\,
dataf => N_53014,
datae => N_53013,
datad => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
GRFPC0_EX_CTRL_INST_RET_10_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_252_RETI\,
dataf => N_53014,
datae => N_53015,
datad => N_53013);
GRFPC0_EX_CTRL_INST_RET_9_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24487_RETI\,
dataf => N_53016,
datae => N_53015);
GRFPU0_FPMUL0_R2_RET_213_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f00ff00f")
port map (
combout => \GRFPU0.MULO.DRES_1_RETI\(97),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0_RETI\,
datae => N_30906_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datac => \GRFPU0.GRFPU_X0.N_15336_I\);
GRFPC0_EX_CTRL_INST_RET_8_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.N_25566_RETI\,
dataf => N_53016,
datae => N_53015,
datad => N_53013);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIUCCI4_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11269_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
datae => \GRFPU0.GRFPU_X0.N_11269\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
GRFPU0_GRFPU_X0_ITER_STATE_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14_RETI\,
dataf => \GRFPU0.GRFPU_X0.N_11278\,
datae => \GRFPU0.GRFPU_X0.N_11272\,
datad => \GRFPU0.GRFPU_X0.N_11275\,
datac => \GRFPU0.GRFPU_X0.N_11269_0\);
GRFPC0_EX_CTRL_INST_RET_7_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_RETI\,
dataf => N_53016,
datae => N_53014,
datad => N_53015,
datac => N_53013);
GRFPC0_EX_CTRL_INST_RET_6_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0_RETI\(1),
dataf => N_53016,
datae => N_53014,
datad => N_53015,
datac => N_53013);
GRFPC0_EX_CTRL_INST_RET_5_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2_RETI\,
dataf => N_53014,
datae => N_53016,
datad => N_53015,
datac => N_53013);
GRFPC0_EX_CTRL_INST_RET_4_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2_RETI\,
dataf => N_53016,
datae => N_53014,
datad => N_53015,
datac => N_53013);
GRFPC0_EX_CTRL_INST_RET_3_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0_RETI\(0),
dataf => N_53016,
datae => N_53014,
datad => N_53015);
GRFPC0_WR_CTRL_INST_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_RETI\(0),
dataf => N_185353,
datae => \GRFPC0.N_131I\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(53),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(52),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_14_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(3));
\GRFPU0_GRFPU_X0_ITER_IDCST_RNILE913_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.IDI\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ID\(1),
datad => \GRFPU0.GRFPU_X0.ST1.ID\(1));
\GRFPU0_GRFPU_X0_ITER_IDCST_RNINI913_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.IDI\(2),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ID\(2),
datad => \GRFPU0.GRFPU_X0.ST1.ID\(2));
\GRFPU0_GRFPU_X0_ST1_IDCST_RNIJA913_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.IDI\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ID\(0),
datad => \GRFPU0.GRFPU_X0.ST1.ID\(0));
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_ITER_IDCST_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f37130177331100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB_RETI\(2),
dataf => \GRFPC0.FID_1\(0),
datae => \GRFPC0.FID_1\(2),
datad => \GRFPC0.FID_1\(1),
datac => \GRFPU0.GRFPU_X0.ITER.IDI\(0),
datab => \GRFPU0.GRFPU_X0.ITER.IDI\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.IDI\(1));
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_24_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(80),
datae => \GRFPU0.MULO.MRES_RETI\(75),
datad => \GRFPU0.MULO.MRES_RETI\(71));
\GRFPC0_WR_CTRL_INST_RNI6GIBB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_RETI\(0),
dataf => N_185328,
datae => \GRFPC0.N_131I\);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21036_RETI\,
dataf => N_29618,
datae => N_91845);
GRFPU0_GRFPU_X0_ITER_STATE_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2_RETI\,
dataf => \GRFPU0.GRFPU_X0.N_11279\,
datae => \GRFPU0.GRFPU_X0.N_11284_0\,
datad => \GRFPU0.GRFPU_X0.N_11277\,
datac => \GRFPU0.GRFPU_X0.N_11287\);
GRFPU0_GRFPU_X0_ST2_REG_RET_1_RNIER1R: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"af05af05af05cc44")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.REG\(63),
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2_RETO\(63),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_RETO\(63),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2_RETO\,
dataa => \GRFPU0.GRFPU_X0.N_4296_RETO\);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(76),
datae => \GRFPU0.MULO.MRES_RETI\(70),
datad => \GRFPU0.MULO.MRES_RETI\(69),
datac => \GRFPU0.MULO.MRES_RETI\(68),
datab => \GRFPU0.MULO.MRES_RETI\(67));
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_13_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(86),
datae => \GRFPU0.MULO.MRES_RETI\(82));
GRFPC0_RFA2_RS2SEL_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.OP2_SN_N_6_RETI\,
dataf => \GRFPC0.N_10170\,
datae => \GRFPC0.FPUSEL_1\(2));
GRFPC0_WR_CTRL_RS1V_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0_RETI\(0),
dataf => N_185344,
datae => N_185345,
datad => \GRFPC0.WR.CTRL.RS1VI\);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_27_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(79),
datae => \GRFPU0.MULO.MRES_RETI\(74),
datad => \GRFPU0.MULO.MRES_RETI\(72),
datac => \GRFPU0.MULO.MRES_RETI\(68));
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_26_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(80),
datae => \GRFPU0.MULO.MRES_RETI\(76),
datad => \GRFPU0.MULO.MRES_RETI\(73),
datac => \GRFPU0.MULO.MRES_RETI\(70),
datab => \GRFPU0.MULO.MRES_RETI\(69));
GRFPC0_EX_CTRL_INST_RET_2_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1_RETI\(1),
dataf => N_52982,
datae => N_53014,
datad => N_53013,
datac => N_53012,
datab => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
GRFPC0_EX_CTRL_RDD_RET_3_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc0c0000")
port map (
combout => \GRFPC0.N_24711_RETI\,
dataf => \GRFPC0.N_24119_RETI\,
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2_RETI\,
datad => N_52982,
datac => N_53012,
datab => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
\GRFPC0_EX_CTRL_INST_RNIJIJKS_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2_RETI\,
dataf => N_53016,
datae => N_53015);
GRFPC0_EX_CTRL_RDD_RET_2_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000300")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10_RETI\(0),
dataf => \GRFPC0.N_24119_RETI\,
datae => N_52982,
datad => N_53016,
datac => N_53015,
datab => N_53012);
\GRFPC0_EX_CTRL_INST_RNIV1IKS_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24119_RETI\,
dataf => N_53014,
datae => N_53013);
GRFPC0_WR_CTRL_RDD_RNIDM7M5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_131I\,
dataf => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
datae => \GRFPC0.N_131\,
datad => N_63);
\GRFPC0_WR_CTRL_INST_RNIG17CB_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_RETI\(0),
dataf => N_185342,
datae => \GRFPC0.N_131I\);
GRFPC0_RFA2_RS1SEL_RET_0_RNIM6BT1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000008000000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(6),
dataf => \GRFPC0.FPUSEL_6_1_RETO\(7),
datae => \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
datac => \GRFPC0.DIV.VALID_RETO\,
datab => \GRFPC0.UN1_WRENX2_2_5_RETO\,
dataa => \GRFPC0.UN1_WRENX2_2_4_1_RETO\);
GRFPC0_EX_CTRL_INST_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(1),
dataf => N_52982,
datae => N_52998);
GRFPC0_RFA_READ_RS1_RNIJO1G: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.EX.CTRL.RS1V_0_0_G1\,
dataf => \GRFPC0.RFA.READ_RS1\,
datae => N_61);
GRFPC0_EX_CTRL_RDD_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff000000ff00")
port map (
combout => \GRFPC0.N_25715_2_RETI\,
dataf => N_52982,
datae => N_53012,
datad => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
\GRFPC0_EX_CTRL_INST_RNIUMCRK_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(1),
dataf => N_52982,
datae => N_53012);
GRFPC0_EX_CTRL_INST_RET_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(1),
dataf => N_52982,
datae => N_53023);
GRFPU0_FPMUL0_R2_RET_212_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(96),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
datae => N_30961_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96));
GRFPU0_FPMUL0_R2_RET_211_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(101),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
datae => N_30971_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101));
\GRFPC0_EX_CTRL_RD_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_50632,
dataf => N_50527,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.RFA.RD\(4));
\GRFPC0_EX_CTRL_RD_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_50606,
dataf => N_50527,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.RFA.RD\(3));
\GRFPC0_EX_CTRL_RD_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_50580,
dataf => N_50527,
datae => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.RFA.RD\(2));
\GRFPC0_EX_CTRL_RD_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_50554,
dataf => N_50527,
datae => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datad => \GRFPC0.RFA.RD\(1));
\GRFPC0_EX_CTRL_RD_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_50528,
dataf => N_50527,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datad => \GRFPC0.RFA.RD\(0));
\GRFPC0_DIV_PC_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185513,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(31),
datad => \GRFPC0.WR2.CTRL.PC\(31));
\GRFPC0_DIV_PC_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185512,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(30),
datad => \GRFPC0.WR2.CTRL.PC\(30));
\GRFPC0_DIV_PC_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185511,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(29),
datad => \GRFPC0.WR2.CTRL.PC\(29));
\GRFPC0_DIV_PC_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185510,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(28),
datad => \GRFPC0.WR2.CTRL.PC\(28));
\GRFPC0_DIV_PC_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185509,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(27),
datad => \GRFPC0.WR2.CTRL.PC\(27));
\GRFPC0_DIV_PC_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185508,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(26),
datad => \GRFPC0.WR2.CTRL.PC\(26));
\GRFPC0_DIV_PC_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185507,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(25),
datad => \GRFPC0.WR2.CTRL.PC\(25));
\GRFPC0_DIV_PC_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185506,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(24),
datad => \GRFPC0.WR2.CTRL.PC\(24));
\GRFPC0_DIV_PC_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185505,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(23),
datad => \GRFPC0.WR2.CTRL.PC\(23));
\GRFPC0_DIV_PC_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185504,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(22),
datad => \GRFPC0.WR2.CTRL.PC\(22));
\GRFPC0_DIV_PC_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185503,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(21),
datad => \GRFPC0.WR2.CTRL.PC\(21));
\GRFPC0_DIV_PC_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185502,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(20),
datad => \GRFPC0.WR2.CTRL.PC\(20));
\GRFPC0_DIV_PC_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185501,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(19),
datad => \GRFPC0.WR2.CTRL.PC\(19));
\GRFPC0_DIV_PC_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185500,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(18),
datad => \GRFPC0.WR2.CTRL.PC\(18));
\GRFPC0_DIV_PC_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185499,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(17),
datad => \GRFPC0.WR2.CTRL.PC\(17));
\GRFPC0_DIV_PC_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185498,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(16),
datad => \GRFPC0.WR2.CTRL.PC\(16));
\GRFPC0_DIV_PC_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185497,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(15),
datad => \GRFPC0.WR2.CTRL.PC\(15));
\GRFPC0_DIV_PC_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185496,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(14),
datad => \GRFPC0.WR2.CTRL.PC\(14));
\GRFPC0_DIV_PC_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185495,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(13),
datad => \GRFPC0.WR2.CTRL.PC\(13));
\GRFPC0_DIV_PC_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185494,
dataf => \GRFPC0.DIV.PC_0_0_9__G2\,
datae => \GRFPC0.DIV.PC\(12),
datad => \GRFPC0.WR2.CTRL.PC\(12));
\GRFPC0_DIV_PC_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185493,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(11),
datad => \GRFPC0.WR2.CTRL.PC\(11));
\GRFPC0_DIV_PC_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185492,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(10),
datad => \GRFPC0.WR2.CTRL.PC\(10));
\GRFPC0_DIV_PC_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185491,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(9),
datad => \GRFPC0.WR2.CTRL.PC\(9));
\GRFPC0_DIV_PC_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185490,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(8),
datad => \GRFPC0.WR2.CTRL.PC\(8));
\GRFPC0_DIV_PC_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185489,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(7),
datad => \GRFPC0.WR2.CTRL.PC\(7));
\GRFPC0_DIV_PC_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185488,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(6),
datad => \GRFPC0.WR2.CTRL.PC\(6));
\GRFPC0_DIV_PC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185487,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(5),
datad => \GRFPC0.WR2.CTRL.PC\(5));
\GRFPC0_DIV_PC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185486,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(4),
datad => \GRFPC0.WR2.CTRL.PC\(4));
\GRFPC0_DIV_PC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185485,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(3),
datad => \GRFPC0.WR2.CTRL.PC\(3));
\GRFPC0_DIV_PC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185484,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.DIV.PC\(2),
datad => \GRFPC0.WR2.CTRL.PC\(2));
\GRFPC0_DIV_INST_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185483,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(31),
datad => \GRFPC0.DIV.INST\(31));
\GRFPC0_DIV_INST_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185482,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(30),
datad => \GRFPC0.DIV.INST\(30));
\GRFPC0_DIV_INST_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185481,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.DIV.INST\(29));
\GRFPC0_DIV_INST_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185480,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.DIV.INST\(28));
\GRFPC0_DIV_INST_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185479,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.DIV.INST\(27));
\GRFPC0_DIV_INST_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185478,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.DIV.INST\(26));
\GRFPC0_DIV_INST_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185477,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(25),
datad => \GRFPC0.DIV.INST\(25));
\GRFPC0_DIV_INST_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185476,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(24),
datad => \GRFPC0.DIV.INST\(24));
\GRFPC0_DIV_INST_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185475,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(23),
datad => \GRFPC0.DIV.INST\(23));
\GRFPC0_DIV_INST_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185474,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(22),
datad => \GRFPC0.DIV.INST\(22));
\GRFPC0_DIV_INST_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185473,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_1\,
datae => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.DIV.INST\(21));
\GRFPC0_DIV_INST_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185472,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(20),
datad => \GRFPC0.DIV.INST\(20));
\GRFPC0_DIV_INST_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185471,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(19),
datad => \GRFPC0.WR2.CTRL.INST\(19));
\GRFPC0_DIV_INST_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185470,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.DIV.INST\(18));
\GRFPC0_DIV_INST_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185469,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_DIV_INST_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185468,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_DIV_INST_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185467,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.DIV.INST\(15));
\GRFPC0_DIV_INST_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185466,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(14),
datad => \GRFPC0.DIV.INST\(14));
\GRFPC0_DIV_INST_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185465,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(13),
datad => \GRFPC0.WR2.CTRL.INST\(13));
\GRFPC0_DIV_INST_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185464,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(12),
datad => \GRFPC0.WR2.CTRL.INST\(12));
\GRFPC0_DIV_INST_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185463,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(11),
datad => \GRFPC0.WR2.CTRL.INST\(11));
\GRFPC0_DIV_INST_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185462,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(10),
datad => \GRFPC0.WR2.CTRL.INST\(10));
\GRFPC0_DIV_INST_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185461,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(9),
datad => \GRFPC0.WR2.CTRL.INST\(9));
\GRFPC0_DIV_INST_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185460,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(8),
datad => \GRFPC0.WR2.CTRL.INST\(8));
\GRFPC0_DIV_INST_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185459,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(7),
datad => \GRFPC0.WR2.CTRL.INST\(7));
\GRFPC0_DIV_INST_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185458,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(6),
datad => \GRFPC0.WR2.CTRL.INST\(6));
\GRFPC0_DIV_INST_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185457,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(5),
datad => \GRFPC0.WR2.CTRL.INST\(5));
\GRFPC0_DIV_INST_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185456,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.DIV.INST\(4));
\GRFPC0_DIV_INST_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185455,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_DIV_INST_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185454,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.DIV.INST\(2));
\GRFPC0_DIV_INST_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185453,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.DIV.INST\(1));
\GRFPC0_DIV_INST_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185452,
dataf => \GRFPC0.DIV.PC_0_0_9__G2_0\,
datae => \GRFPC0.DIV.INST\(0),
datad => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_WR2_CTRL_PC_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185451,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(31),
datad => \GRFPC0.WR.CTRL.PC\(31));
\GRFPC0_WR2_CTRL_PC_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185450,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(30),
datad => \GRFPC0.WR.CTRL.PC\(30));
\GRFPC0_WR2_CTRL_PC_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185449,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(29),
datad => \GRFPC0.WR.CTRL.PC\(29));
\GRFPC0_WR2_CTRL_PC_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185448,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(28),
datad => \GRFPC0.WR.CTRL.PC\(28));
\GRFPC0_WR2_CTRL_PC_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185447,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(27),
datad => \GRFPC0.WR.CTRL.PC\(27));
\GRFPC0_WR2_CTRL_PC_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185446,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(26),
datad => \GRFPC0.WR.CTRL.PC\(26));
\GRFPC0_WR2_CTRL_PC_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185445,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(25),
datad => \GRFPC0.WR.CTRL.PC\(25));
\GRFPC0_WR2_CTRL_PC_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185444,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(24),
datad => \GRFPC0.WR.CTRL.PC\(24));
\GRFPC0_WR2_CTRL_PC_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185443,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(23),
datad => \GRFPC0.WR.CTRL.PC\(23));
\GRFPC0_WR2_CTRL_PC_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185442,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(22),
datad => \GRFPC0.WR.CTRL.PC\(22));
\GRFPC0_WR2_CTRL_PC_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185441,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(21),
datad => \GRFPC0.WR.CTRL.PC\(21));
\GRFPC0_WR2_CTRL_PC_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185440,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(20),
datad => \GRFPC0.WR.CTRL.PC\(20));
\GRFPC0_WR2_CTRL_PC_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185439,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(19),
datad => \GRFPC0.WR.CTRL.PC\(19));
\GRFPC0_WR2_CTRL_PC_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185438,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(18),
datad => \GRFPC0.WR.CTRL.PC\(18));
\GRFPC0_WR2_CTRL_PC_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185437,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(17),
datad => \GRFPC0.WR.CTRL.PC\(17));
\GRFPC0_WR2_CTRL_PC_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185436,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(16),
datad => \GRFPC0.WR.CTRL.PC\(16));
\GRFPC0_WR2_CTRL_PC_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185435,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(15),
datad => \GRFPC0.WR.CTRL.PC\(15));
\GRFPC0_WR2_CTRL_PC_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185434,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(14),
datad => \GRFPC0.WR.CTRL.PC\(14));
\GRFPC0_WR2_CTRL_PC_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185433,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(13),
datad => \GRFPC0.WR.CTRL.PC\(13));
\GRFPC0_WR2_CTRL_PC_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185432,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(12),
datad => \GRFPC0.WR.CTRL.PC\(12));
\GRFPC0_WR2_CTRL_PC_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185431,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(11),
datad => \GRFPC0.WR.CTRL.PC\(11));
\GRFPC0_WR2_CTRL_PC_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185430,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(10),
datad => \GRFPC0.WR.CTRL.PC\(10));
\GRFPC0_WR2_CTRL_PC_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185429,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(9),
datad => \GRFPC0.WR.CTRL.PC\(9));
\GRFPC0_WR2_CTRL_PC_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185428,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
datae => \GRFPC0.WR2.CTRL.PC\(8),
datad => \GRFPC0.WR.CTRL.PC\(8));
\GRFPC0_WR2_CTRL_PC_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185427,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(7),
datad => \GRFPC0.WR.CTRL.PC\(7));
\GRFPC0_WR2_CTRL_PC_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185426,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(6),
datad => \GRFPC0.WR.CTRL.PC\(6));
\GRFPC0_WR2_CTRL_PC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185425,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(5),
datad => \GRFPC0.WR.CTRL.PC\(5));
\GRFPC0_WR2_CTRL_PC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185424,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(4),
datad => \GRFPC0.WR.CTRL.PC\(4));
\GRFPC0_WR2_CTRL_PC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185423,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(3),
datad => \GRFPC0.WR.CTRL.PC\(3));
\GRFPC0_WR2_CTRL_PC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185422,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.PC\(2),
datad => \GRFPC0.WR.CTRL.PC\(2));
\GRFPC0_WR2_CTRL_INST_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185421,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(31),
datad => \GRFPC0.WR.CTRL.INST\(31));
\GRFPC0_WR2_CTRL_INST_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185420,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(30),
datad => \GRFPC0.WR.CTRL.INST\(30));
\GRFPC0_WR2_CTRL_INST_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185419,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(29));
\GRFPC0_WR2_CTRL_INST_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185418,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_WR2_CTRL_INST_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185417,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_WR2_CTRL_INST_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185416,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_WR2_CTRL_INST_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185415,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(25),
datad => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_WR2_CTRL_INST_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185414,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(24),
datad => \GRFPC0.WR.CTRL.INST\(24));
\GRFPC0_WR2_CTRL_INST_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185413,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(23),
datad => \GRFPC0.WR.CTRL.INST\(23));
\GRFPC0_WR2_CTRL_INST_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185412,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(22),
datad => \GRFPC0.WR.CTRL.INST\(22));
\GRFPC0_WR2_CTRL_INST_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185411,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.WR.CTRL.INST\(21));
\GRFPC0_WR2_CTRL_INST_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185410,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(20),
datad => \GRFPC0.WR.CTRL.INST\(20));
\GRFPC0_WR2_CTRL_INST_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185409,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(19),
datad => \GRFPC0.WR.CTRL.INST\(19));
\GRFPC0_WR2_CTRL_INST_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185408,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_WR2_CTRL_INST_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185407,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(17),
datad => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_WR2_CTRL_INST_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185406,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.INST\(16));
\GRFPC0_WR2_CTRL_INST_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185405,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(15));
\GRFPC0_WR2_CTRL_INST_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185404,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(14),
datad => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_WR2_CTRL_INST_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185403,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(13),
datad => \GRFPC0.WR.CTRL.INST\(13));
\GRFPC0_WR2_CTRL_INST_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185402,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(12),
datad => \GRFPC0.WR.CTRL.INST\(12));
\GRFPC0_WR2_CTRL_INST_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185401,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
datae => \GRFPC0.WR2.CTRL.INST\(11),
datad => \GRFPC0.WR.CTRL.INST\(11));
\GRFPC0_WR2_CTRL_INST_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185400,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(10),
datad => \GRFPC0.WR.CTRL.INST\(10));
\GRFPC0_WR2_CTRL_INST_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185399,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(9),
datad => \GRFPC0.WR.CTRL.INST\(9));
\GRFPC0_WR2_CTRL_INST_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185398,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(8),
datad => \GRFPC0.WR.CTRL.INST\(8));
\GRFPC0_WR2_CTRL_INST_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185397,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(7),
datad => \GRFPC0.WR.CTRL.INST\(7));
\GRFPC0_WR2_CTRL_INST_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185396,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(6),
datad => \GRFPC0.WR.CTRL.INST\(6));
\GRFPC0_WR2_CTRL_INST_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185395,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(5),
datad => \GRFPC0.WR.CTRL.INST\(5));
\GRFPC0_WR2_CTRL_INST_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185394,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_WR2_CTRL_INST_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185393,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_WR2_CTRL_INST_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185392,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_WR2_CTRL_INST_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185391,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR.CTRL.INST\(1));
\GRFPC0_WR2_CTRL_INST_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185390,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR2.CTRL.INST\(0),
datad => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_WR_CTRL_PC_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185389,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(31),
datad => \GRFPC0.MEM.CTRL.PC\(31));
\GRFPC0_WR_CTRL_PC_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185388,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(30),
datad => \GRFPC0.MEM.CTRL.PC\(30));
\GRFPC0_WR_CTRL_PC_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185387,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(29),
datad => \GRFPC0.MEM.CTRL.PC\(29));
\GRFPC0_WR_CTRL_PC_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185386,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(28),
datad => \GRFPC0.MEM.CTRL.PC\(28));
\GRFPC0_WR_CTRL_PC_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185385,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(27),
datad => \GRFPC0.MEM.CTRL.PC\(27));
\GRFPC0_WR_CTRL_PC_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185384,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(26),
datad => \GRFPC0.MEM.CTRL.PC\(26));
\GRFPC0_WR_CTRL_PC_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185383,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(25),
datad => \GRFPC0.MEM.CTRL.PC\(25));
\GRFPC0_WR_CTRL_PC_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185382,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(24),
datad => \GRFPC0.MEM.CTRL.PC\(24));
\GRFPC0_WR_CTRL_PC_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185381,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(23),
datad => \GRFPC0.MEM.CTRL.PC\(23));
\GRFPC0_WR_CTRL_PC_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185380,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(22),
datad => \GRFPC0.MEM.CTRL.PC\(22));
\GRFPC0_WR_CTRL_PC_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185379,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(21),
datad => \GRFPC0.MEM.CTRL.PC\(21));
\GRFPC0_WR_CTRL_PC_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185378,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(20),
datad => \GRFPC0.MEM.CTRL.PC\(20));
\GRFPC0_WR_CTRL_PC_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185377,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(19),
datad => \GRFPC0.MEM.CTRL.PC\(19));
\GRFPC0_WR_CTRL_PC_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185376,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(18),
datad => \GRFPC0.MEM.CTRL.PC\(18));
\GRFPC0_WR_CTRL_PC_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185375,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(17),
datad => \GRFPC0.MEM.CTRL.PC\(17));
\GRFPC0_WR_CTRL_PC_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185374,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
datae => \GRFPC0.WR.CTRL.PC\(16),
datad => \GRFPC0.MEM.CTRL.PC\(16));
\GRFPC0_WR_CTRL_PC_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185373,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(15),
datad => \GRFPC0.MEM.CTRL.PC\(15));
\GRFPC0_WR_CTRL_PC_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185372,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(14),
datad => \GRFPC0.MEM.CTRL.PC\(14));
\GRFPC0_WR_CTRL_PC_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185371,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(13),
datad => \GRFPC0.MEM.CTRL.PC\(13));
\GRFPC0_WR_CTRL_PC_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185370,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(12),
datad => \GRFPC0.MEM.CTRL.PC\(12));
\GRFPC0_WR_CTRL_PC_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185369,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(11),
datad => \GRFPC0.MEM.CTRL.PC\(11));
\GRFPC0_WR_CTRL_PC_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185368,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(10),
datad => \GRFPC0.MEM.CTRL.PC\(10));
\GRFPC0_WR_CTRL_PC_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185367,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(9),
datad => \GRFPC0.MEM.CTRL.PC\(9));
\GRFPC0_WR_CTRL_PC_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185366,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(8),
datad => \GRFPC0.MEM.CTRL.PC\(8));
\GRFPC0_WR_CTRL_PC_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185365,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(7),
datad => \GRFPC0.MEM.CTRL.PC\(7));
\GRFPC0_WR_CTRL_PC_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185364,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(6),
datad => \GRFPC0.MEM.CTRL.PC\(6));
\GRFPC0_WR_CTRL_PC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185363,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(5),
datad => \GRFPC0.MEM.CTRL.PC\(5));
\GRFPC0_WR_CTRL_PC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185362,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(4),
datad => \GRFPC0.MEM.CTRL.PC\(4));
\GRFPC0_WR_CTRL_PC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185361,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(3),
datad => \GRFPC0.MEM.CTRL.PC\(3));
\GRFPC0_WR_CTRL_PC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185360,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.PC\(2),
datad => \GRFPC0.MEM.CTRL.PC\(2));
\GRFPC0_WR_CTRL_INST_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185359,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(31),
datad => \GRFPC0.MEM.CTRL.INST\(31));
\GRFPC0_WR_CTRL_INST_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185358,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(30),
datad => \GRFPC0.MEM.CTRL.INST\(30));
\GRFPC0_WR_CTRL_INST_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185357,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(29));
\GRFPC0_WR_CTRL_INST_RNIFVVL5_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185356,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_WR_CTRL_INST_RNIDRVL5_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185355,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_WR_CTRL_INST_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185354,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_WR_CTRL_INST_RNI9JVL5_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185353,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.MEM.CTRL.INST\(25),
datad => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_WR_CTRL_INST_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185352,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(24),
datad => \GRFPC0.MEM.CTRL.INST\(24));
\GRFPC0_WR_CTRL_INST_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185351,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(23),
datad => \GRFPC0.MEM.CTRL.INST\(23));
\GRFPC0_WR_CTRL_INST_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185350,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(22),
datad => \GRFPC0.MEM.CTRL.INST\(22));
\GRFPC0_WR_CTRL_INST_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185349,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(21),
datad => \GRFPC0.MEM.CTRL.INST\(21));
\GRFPC0_WR_CTRL_INST_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185348,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(20),
datad => \GRFPC0.MEM.CTRL.INST\(20));
\GRFPC0_WR_CTRL_INST_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185347,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
datae => \GRFPC0.WR.CTRL.INST\(19),
datad => \GRFPC0.MEM.CTRL.INST\(19));
\GRFPC0_WR_CTRL_INST_RNIBRVL5_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185346,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_WR_CTRL_INST_RNI9NVL5_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185345,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_WR_CTRL_INST_RNI7JVL5_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185344,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.INST\(16));
\GRFPC0_WR_CTRL_INST_RNI5FVL5_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185343,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(15));
\GRFPC0_WR_CTRL_INST_RNI3BVL5_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185342,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(14),
datad => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_WR_CTRL_INST_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185341,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(13),
datad => \GRFPC0.MEM.CTRL.INST\(13));
\GRFPC0_WR_CTRL_INST_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185340,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(12),
datad => \GRFPC0.MEM.CTRL.INST\(12));
\GRFPC0_WR_CTRL_INST_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185339,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(11),
datad => \GRFPC0.MEM.CTRL.INST\(11));
\GRFPC0_WR_CTRL_INST_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185338,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(10),
datad => \GRFPC0.MEM.CTRL.INST\(10));
\GRFPC0_WR_CTRL_INST_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185337,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(9),
datad => \GRFPC0.MEM.CTRL.INST\(9));
\GRFPC0_WR_CTRL_INST_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185336,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(8),
datad => \GRFPC0.MEM.CTRL.INST\(8));
\GRFPC0_WR_CTRL_INST_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185335,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(7),
datad => \GRFPC0.MEM.CTRL.INST\(7));
\GRFPC0_WR_CTRL_INST_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185334,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(6),
datad => \GRFPC0.MEM.CTRL.INST\(6));
\GRFPC0_WR_CTRL_INST_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185333,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(5),
datad => \GRFPC0.MEM.CTRL.INST\(5));
\GRFPC0_WR_CTRL_INST_RNI1ABL5_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185332,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(4));
\GRFPC0_WR_CTRL_INST_RNIV5BL5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185331,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_MEM_CTRL_INST_RNIT1BL5_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185330,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_MEM_CTRL_INST_RNIRTAL5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185329,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.WR.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_WR_CTRL_INST_RNIPPAL5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185328,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.MEM.CTRL.INST\(0),
datad => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_MEM_CTRL_PC_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185327,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(31),
datad => \GRFPC0.MEM.CTRL.PC\(31));
\GRFPC0_MEM_CTRL_PC_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185326,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(30),
datad => \GRFPC0.MEM.CTRL.PC\(30));
\GRFPC0_MEM_CTRL_PC_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185325,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(29),
datad => \GRFPC0.MEM.CTRL.PC\(29));
\GRFPC0_MEM_CTRL_PC_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185324,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(28),
datad => \GRFPC0.MEM.CTRL.PC\(28));
\GRFPC0_MEM_CTRL_PC_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185323,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(27),
datad => \GRFPC0.MEM.CTRL.PC\(27));
\GRFPC0_MEM_CTRL_PC_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185322,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(26),
datad => \GRFPC0.MEM.CTRL.PC\(26));
\GRFPC0_MEM_CTRL_PC_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185321,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(25),
datad => \GRFPC0.MEM.CTRL.PC\(25));
\GRFPC0_MEM_CTRL_PC_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185320,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
datae => \GRFPC0.EX.CTRL.PC\(24),
datad => \GRFPC0.MEM.CTRL.PC\(24));
\GRFPC0_MEM_CTRL_PC_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185319,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(23),
datad => \GRFPC0.MEM.CTRL.PC\(23));
\GRFPC0_MEM_CTRL_PC_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185318,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(22),
datad => \GRFPC0.MEM.CTRL.PC\(22));
\GRFPC0_MEM_CTRL_PC_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185317,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(21),
datad => \GRFPC0.MEM.CTRL.PC\(21));
\GRFPC0_MEM_CTRL_PC_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185316,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(20),
datad => \GRFPC0.MEM.CTRL.PC\(20));
\GRFPC0_MEM_CTRL_PC_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185315,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(19),
datad => \GRFPC0.MEM.CTRL.PC\(19));
\GRFPC0_MEM_CTRL_PC_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185314,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(18),
datad => \GRFPC0.MEM.CTRL.PC\(18));
\GRFPC0_MEM_CTRL_PC_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185313,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(17),
datad => \GRFPC0.MEM.CTRL.PC\(17));
\GRFPC0_MEM_CTRL_PC_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185312,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(16),
datad => \GRFPC0.MEM.CTRL.PC\(16));
\GRFPC0_MEM_CTRL_PC_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185311,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(15),
datad => \GRFPC0.MEM.CTRL.PC\(15));
\GRFPC0_MEM_CTRL_PC_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185310,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(14),
datad => \GRFPC0.MEM.CTRL.PC\(14));
\GRFPC0_MEM_CTRL_PC_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185309,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(13),
datad => \GRFPC0.MEM.CTRL.PC\(13));
\GRFPC0_MEM_CTRL_PC_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185308,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(12),
datad => \GRFPC0.MEM.CTRL.PC\(12));
\GRFPC0_MEM_CTRL_PC_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185307,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(11),
datad => \GRFPC0.MEM.CTRL.PC\(11));
\GRFPC0_MEM_CTRL_PC_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185306,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(10),
datad => \GRFPC0.MEM.CTRL.PC\(10));
\GRFPC0_MEM_CTRL_PC_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185305,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(9),
datad => \GRFPC0.MEM.CTRL.PC\(9));
\GRFPC0_MEM_CTRL_PC_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185304,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(8),
datad => \GRFPC0.MEM.CTRL.PC\(8));
\GRFPC0_MEM_CTRL_PC_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185303,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(7),
datad => \GRFPC0.MEM.CTRL.PC\(7));
\GRFPC0_MEM_CTRL_PC_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185302,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(6),
datad => \GRFPC0.MEM.CTRL.PC\(6));
\GRFPC0_MEM_CTRL_PC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185301,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(5),
datad => \GRFPC0.MEM.CTRL.PC\(5));
\GRFPC0_MEM_CTRL_PC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185300,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(4),
datad => \GRFPC0.MEM.CTRL.PC\(4));
\GRFPC0_MEM_CTRL_PC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185299,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(3),
datad => \GRFPC0.MEM.CTRL.PC\(3));
\GRFPC0_MEM_CTRL_PC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185298,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.PC\(2),
datad => \GRFPC0.MEM.CTRL.PC\(2));
\GRFPC0_MEM_CTRL_INST_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185297,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.INST\(31),
datad => \GRFPC0.MEM.CTRL.INST\(31));
\GRFPC0_MEM_CTRL_INST_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185296,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.MEM.CTRL.INST\(30),
datad => \GRFPC0.EX.CTRL.INST\(30));
\GRFPC0_MEM_CTRL_INST_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185295,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPC0_MEM_CTRL_INST_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185294,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_MEM_CTRL_INST_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185293,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
datae => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(27));
\GRFPC0_MEM_CTRL_INST_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185292,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_MEM_CTRL_INST_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185291,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(25),
datad => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_MEM_CTRL_INST_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185290,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(24),
datad => \GRFPC0.MEM.CTRL.INST\(24));
\GRFPC0_MEM_CTRL_INST_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185289,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(23),
datad => \GRFPC0.MEM.CTRL.INST\(23));
\GRFPC0_MEM_CTRL_INST_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185288,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(22),
datad => \GRFPC0.EX.CTRL.INST\(22));
\GRFPC0_MEM_CTRL_INST_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185287,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(21),
datad => \GRFPC0.MEM.CTRL.INST\(21));
\GRFPC0_MEM_CTRL_INST_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185286,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(20),
datad => \GRFPC0.EX.CTRL.INST\(20));
\GRFPC0_MEM_CTRL_INST_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185285,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(19),
datad => \GRFPC0.MEM.CTRL.INST\(19));
\GRFPC0_MEM_CTRL_INST_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185284,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_MEM_CTRL_INST_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185283,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_MEM_CTRL_INST_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185282,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(16));
\GRFPC0_MEM_CTRL_INST_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185281,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_EX_CTRL_INST_RNILOQG5_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185280,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(14),
datad => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_MEM_CTRL_INST_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185279,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(13),
datad => \GRFPC0.MEM.CTRL.INST\(13));
\GRFPC0_MEM_CTRL_INST_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185278,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(12),
datad => \GRFPC0.MEM.CTRL.INST\(12));
\GRFPC0_MEM_CTRL_INST_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185277,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(11),
datad => \GRFPC0.MEM.CTRL.INST\(11));
\GRFPC0_MEM_CTRL_INST_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185276,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(10),
datad => \GRFPC0.MEM.CTRL.INST\(10));
\GRFPC0_MEM_CTRL_INST_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185275,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(9),
datad => \GRFPC0.MEM.CTRL.INST\(9));
\GRFPC0_MEM_CTRL_INST_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185274,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(8),
datad => \GRFPC0.MEM.CTRL.INST\(8));
\GRFPC0_MEM_CTRL_INST_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185273,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(7),
datad => \GRFPC0.MEM.CTRL.INST\(7));
\GRFPC0_MEM_CTRL_INST_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185272,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(6),
datad => \GRFPC0.MEM.CTRL.INST\(6));
\GRFPC0_MEM_CTRL_INST_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185271,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(5),
datad => \GRFPC0.MEM.CTRL.INST\(5));
\GRFPC0_MEM_CTRL_INST_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185270,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(4));
\GRFPC0_MEM_CTRL_INST_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185269,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_MEM_CTRL_INST_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185268,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_MEM_CTRL_INST_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_185267,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.EX.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_EX_CTRL_INST_RNIVLTF5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_185266,
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(0),
datad => \GRFPC0.EX.CTRL.INST\(0));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(51),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(50),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(49),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(48),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(47),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(46),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(45),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(44),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(43),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(42),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(41),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(40),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(39),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(38),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(37),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(36),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(35),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(34),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(33),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(32),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(31),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(30),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(29),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(10),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(9),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(8),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(7),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(7),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(6),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(5),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(4),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(3),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(2),
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(1),
datae => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\);
\GRFPC0_WR2_RREG_EXCT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29911,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \FPO.EXC\(0),
datad => \GRFPC0.WR.RREG.EXCT\(0));
\GRFPC0_WR2_RREG_EXCT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29912,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \GRFPU0.GRFPU_X0.N_8_I_0\,
datad => \GRFPC0.WR.RREG.EXCT\(1));
\GRFPC0_WR2_RREG_EXCT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29913,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \FPO.EXC\(2),
datad => \GRFPC0.WR.RREG.EXCT\(2));
\GRFPC0_WR2_RREG_EXCT_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29914,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => \GRFPC0.WR.RREG.EXCT\(3));
\GRFPC0_WR2_RREG_EXCT_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29915,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \GRFPU0.GRFPU_X0.N_19274_I_0\,
datad => \GRFPC0.WR.RREG.EXCT\(4));
\GRFPC0_WR2_RREG_EXCT_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_29916,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
datae => \GRFPC0.FPO_I_4_I_0\(69),
datad => \GRFPC0.WR.RREG.EXCT\(5));
\GRFPC0_EX_RREG_EXCT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_91840,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datae => N_29893,
datad => \GRFPC0.EX.RREG.EXCT\(0));
GRFPC0_DIV_EXC_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => N_185265,
dataf => N_29701,
datae => \GRFPC0.DIV.EXC_1_0_G0_I\,
datad => \GRFPC0.DIV.EXC\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_17_RNI94R74: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000003f3")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_9_0_A3_1\(4),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49));
\GRFPU0_GRFPU_X0_INF_ABS0_3_RNIG23P7_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00001d0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(3),
dataf => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
datad => \GRFPU0.GRFPU_X0.N_3226\,
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffc33323330")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(52),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(0),
datae => \GRFPU0.GRFPU_X0.N_20779\,
datad => \GRFPU0.GRFPU_X0.N_20826\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
datab => \GRFPU0.GRFPU_X0.N_4296\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33332202ffffeece")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(53),
dataf => N_124898,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\(53),
datad => \GRFPU0.GRFPU_X0.N_20863\,
datac => \GRFPU0.GRFPU_X0.N_21039\,
datab => \GRFPU0.GRFPU_X0.N_4296\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3ff33c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(54),
datae => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datad => \GRFPU0.GRFPU_X0.L2_0_6\(2),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(2),
datab => \GRFPU0.GRFPU_X0.N_4296\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf00f0f0c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(55),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(55),
datad => \GRFPU0.GRFPU_X0.N_20779\,
datac => \GRFPU0.GRFPU_X0.N_4296\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf0fc0f0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(56),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(56),
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.N_4296\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_16_RNI9EC82: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000030303f3")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_9_0_A3_5\(4),
dataf => \GRFPU0.GRFPU_X0.N_20521\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_16_RNI9OQRF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(4),
dataf => \GRFPU0.GRFPU_X0.L2_0_9_0_A3_5\(4),
datae => \GRFPU0.GRFPU_X0.L2_0_6_1\(4),
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.L2_0_9_0_A3_1\(4),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_I_O3_RNIS29G6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000030f0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6\(3),
dataf => \GRFPU0.GRFPU_X0.N_20521\,
datae => \GRFPU0.GRFPU_X0.L2_0_6_1\(4),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(4),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datad => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN242_BCO_MSB\(15));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_26_RNI5FTO3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fff0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_3235_1\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(3),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datac => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.UN242_BCO_MSB\(15));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0000003f3f")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(2),
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => \GRFPU0.GRFPU_X0.N_20521\,
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L2_0_6\(0),
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_7\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => \GRFPU0.GRFPU_X0.L1_0_7\(0),
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_7\(0),
datab => \GRFPU0.GRFPU_X0.L1_1_1_6\(0));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_25_RNIUQJB2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_3235_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff3fc000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_7\(0),
dataf => \GRFPU0.GRFPU_X0.N_20521\,
datae => \GRFPU0.GRFPU_X0.BCO_MSB_1_7\(0),
datad => \GRFPU0.GRFPU_X0.L1_0_1_6\(0),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_13_RNIV79D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20790\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(45));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_12_RNIT39D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20789\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(44));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_12_RNI085L5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
datae => \GRFPU0.GRFPU_X0.N_20647\,
datad => \GRFPU0.GRFPU_X0.N_20790\,
datac => \GRFPU0.GRFPU_X0.N_20789\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_9_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => N_124856,
dataf => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
datad => \GRFPU0.GRFPU_X0.N_20647\,
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_0\(1),
datab => \GRFPU0.GRFPU_X0.N_3226\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124876,
dataf => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datae => N_124856,
datad => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_3263\,
datab => \GRFPU0.GRFPU_X0.N_3253\);
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_RNIFAC54_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003f30000")
port map (
combout => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_20792\,
datae => \GRFPU0.GRFPU_X0.N_3286\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_19_RNI2O8D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(51));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_20_RNI8EIB2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_3286\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffcfffff0000")
port map (
combout => N_124855,
dataf => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3283\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
datac => \GRFPU0.GRFPU_X0.N_20474\,
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_7_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15343\,
dataf => \GRFPU0.GRFPU_X0.N_4126_1\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_12_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_8_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000003f3")
port map (
combout => \GRFPU0.GRFPU_X0.N_3233\,
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_I_0\(1),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffc03f00")
port map (
combout => N_124877,
dataf => \GRFPU0.GRFPU_X0.N_20521\,
datae => \GRFPU0.GRFPU_X0.N_15343\,
datad => \GRFPU0.GRFPU_X0.N_3233\,
datac => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ccccff00")
port map (
combout => N_124898,
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datad => N_124877,
datac => N_124876,
datab => N_124855);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_15_RNI3G9D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_24_RNI3C9D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(56));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_14_RNI1C9D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20647\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(46));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_18_RNI0K8D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_4126_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000f0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20521\,
dataf => \GRFPU0.GRFPU_X0.N_4126_1\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_16_RNI8872: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_5_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_10_RNIR1P1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_6_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_35_RNI79T4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_7_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_5_0\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_6_0\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_42_RNIUJN6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49_N_7_0\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f101f100f003f30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_3_0\(0),
datad => N_108267,
datac => N_108265,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_0\(0),
dataa => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_3_0\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2\,
datae => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datad => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_2\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datab => \GRFPU0.GRFPU_X0.COMB.SIGN2_1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f101f100f003f30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_3_0\(1),
datad => N_108266,
datac => N_108265,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_0\(1),
dataa => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_14_RNI4DL2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_20\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_27_RNI6HT4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_20\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_44_RNIEH67: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_51\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_12_RNIG918: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_8\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_13_RNI8VHE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_8\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_19_RNI6JPG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_29\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_36_RNIJV1J: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_43\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_29\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_50_RNII0EK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_43\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_52_RNI4819: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_59\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_49\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_58_RNI63261: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_59\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_51\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000000c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_3_0\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2\,
datae => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datad => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_2\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datab => \GRFPU0.GRFPU_X0.COMB.SIGN2_1\);
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_9L21_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222222222222220")
port map (
combout => N_184585,
dataf => \GRFPC0.N_24735_2\,
datae => \GRFPC0.N_24653\,
datad => \GRFPC0.N_24688\,
datac => \GRFPC0.N_24706\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_I_A2_3_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff2fffff")
port map (
combout => N_184521,
dataf => N_184373,
datae => N_174891,
datad => \GRFPC0.N_24493\,
datac => \GRFPC0.N_23709\,
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_S_RNIQOVIF_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0100000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_333\,
dataf => \GRFPU0.GRFPU_X0.N_327\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_29\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_27\(4),
datac => N_184442,
datab => \FPI.OP1\(9),
dataa => \FPI.OP1\(13));
GRFPC0_UN1_WRENX10_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff84000000")
port map (
combout => \GRFPC0.UN1_WRENX10_1\,
dataf => \GRFPC0.FP_PIPELINE.1.EXEN7\,
datae => \GRFPC0.FPUSEL_1_0_3__G0_E_2\,
datad => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
datac => RFI2_RD2ADDRZ(1),
datab => \GRFPC0.MEM.CTRL.RDWR\,
dataa => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff101010ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_4\(1),
dataf => \GRFPC0.N_25708_2\,
datae => \GRFPC0.N_185_1\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
datac => \GRFPC0.N_234_1\,
datab => \GRFPC0.EX.CTRL.INST\(29),
dataa => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"002f00ff00000000")
port map (
combout => \GRFPC0.N_22582\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX_102_I_A4_1\(0),
datae => \GRFPC0.N_22619_1\,
datad => \GRFPC0.N_22614\,
datac => N_174901,
datab => \GRFPC0.FIFO.INST_1_0\(6),
dataa => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeeeeeeeeeeee000")
port map (
combout => \GRFPC0.N_25310\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\(0),
datae => \GRFPC0.N_25312\,
datad => \GRFPC0.N_25314_1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN816_REGDEPX2_2\,
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff4000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1),
dataf => \GRFPC0.N_25156_2\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_0\(1),
datad => \GRFPC0.N_23813_1\,
datac => \GRFPC0.N_23821\,
datab => \GRFPC0.DIV.RD_0\(3),
dataa => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000dfff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_7\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_3\(0),
datae => \GRFPC0.N_24662\,
datad => \GRFPC0.N_25845\,
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(18),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff4000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(0),
datae => \GRFPC0.N_25710\,
datad => \GRFPC0.N_24306_1\,
datac => \GRFPC0.N_24327\,
datab => \GRFPC0.WR2.CTRL.INST\(18),
dataa => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\(1),
dataf => \GRFPC0.N_24942\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_O2_4_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_11\(1),
datac => \GRFPC0.N_24946\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
GRFPC0_RFA2_RS2DEP_RNO_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33b70000cced0000")
port map (
combout => N_100355_TZ,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP104\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP2_I_M_0_2_0\,
datac => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datab => \GRFPC0.DIV.RDD\,
dataa => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff222f000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_5\(0),
dataf => \GRFPC0.N_25713\,
datae => \GRFPC0.N_24330\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4650_REGDEPX2\,
datac => \GRFPC0.N_207_1\,
datab => \GRFPC0.DIV.RD_0\(3),
dataa => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_D_LDLCK_RNO_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000800080008")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_3_TZ\,
dataf => \GRFPC0.N_23463_1\,
datae => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_0\(1),
datad => \GRFPC0.N_24347\,
datac => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.INST_0\(3),
dataa => \GRFPC0.FIFO.INST_0\(1));
\GRFPC0_D_LDLCK_RNO_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff010001000100")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_0_0\(7),
datad => \GRFPC0.N_92_1\,
datac => \GRFPC0.N_24280\,
datab => N_106,
dataa => N_107);
GRFPC0_REGDEP_2_SQMUXA_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"28ff14ff00000000")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA_6\,
dataf => \GRFPC0.REGDEP_2_SQMUXA_4\,
datae => \GRFPC0.RFA.RS2D_0_0_G1\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
datac => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datab => \GRFPC0.WR.CTRL.RD\(0),
dataa => \GRFPC0.N_131\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeaaaffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1_1\,
dataf => \GRFPU0.GRFPU_X0.N_20843_1\,
datae => \GRFPU0.GRFPU_X0.N_20849\,
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.N_20803\,
datab => \GRFPU0.GRFPU_X0.N_4352\,
dataa => \FPI.OP1_RETO\(18));
GRFPU0_GRFPU_X0_ST3_ZERO_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffea")
port map (
combout => \GRFPU0.GRFPU_X0.N_11215\,
dataf => \GRFPU0.GRFPU_X0.N_7459\,
datae => \GRFPU0.GRFPU_X0.VST3.ZERO_1_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_7023\,
datac => \GRFPU0.GRFPU_X0.N_7053\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.ZERO\);
\GRFPC0_D_STLCK_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4fffff0f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_3\,
dataf => \GRFPC0.N_22422\,
datae => \GRFPC0.N_22421\,
datad => \GRFPC0.N_21543\,
datac => \GRFPC0.D.STLCK_0_0_14__G1_0\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STLCK_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffbff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1\,
dataf => \GRFPC0.N_23053\,
datae => N_100346_TZ,
datad => \GRFPC0.D.STLCK_0_0_1__G1_5\,
datac => \GRFPC0.N_23010\,
datab => \GRFPC0.EX.CTRL.RD\(0),
dataa => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STLCK_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000b00")
port map (
combout => \GRFPC0.N_23053\,
dataf => \GRFPC0.N_23046\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_23004\,
datac => \GRFPC0.N_22998\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9_1\(1),
dataa => \GRFPC0.N_78_I_I_1\);
\GRFPC0_D_STLCK_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffe0ffe0e0")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_1\,
dataf => \GRFPC0.N_22183\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_20847\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_A4_0\(1),
datab => \GRFPC0.N_78_I_I_0\,
dataa => N_266);
\GRFPC0_D_LDLCK_RNO_2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaaaaaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_3\,
dataf => \GRFPC0.N_24605\,
datae => \GRFPC0.N_22743_1\,
datad => \GRFPC0.N_24442\,
datac => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(1),
dataa => \GRFPC0.D.LDLCK_0_0_31__G1_1\);
GRFPC0_D_FSTLCK_RNO_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_8\,
dataf => \GRFPC0.D.FSTLCK_0_0_G1_3\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_0\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datab => \GRFPC0.EX.CTRL.CCWR\,
dataa => \GRFPC0.WR.CTRL.AFSR\);
GRFPC0_RFA2_RS2DEP_RNIHV233: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffeffffffffff")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => \GRFPC0.EX.CTRL.PC_0_0_10__G1_0_4697_I_O4_1_1\,
datad => \FPI.START_1\,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.RFA.ST_0\,
dataa => \GRFPC0.RFA2.RS2DEP\);
GRFPC0_MEM_CTRL_PEND_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaa00008880")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.VMEM.CTRL.PEND_0_SQMUXA_1\,
datae => \GRFPC0.FIFO_INC_3_SQMUXA\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.MEM.CTRL.PEND\,
dataa => N_52981_2);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff40")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_5\(0),
dataf => \GRFPC0.N_25811\,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_2\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_0\(0),
datac => \GRFPC0.N_25098\,
datab => \GRFPC0.WR.CTRL.INST\(4),
dataa => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff22222220")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_3\(0),
datae => \GRFPC0.N_25763\,
datad => \GRFPC0.N_25823\,
datac => \GRFPC0.N_25824\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000dddf0000")
port map (
combout => \GRFPC0.N_25259\,
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380\(0),
datae => \GRFPC0.N_25259_TZ_TZ\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2_2_0\(0),
datac => \GRFPC0.N_25330\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaaac000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_3\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_0\(0),
datae => \GRFPC0.N_25295_1\,
datad => \GRFPC0.N_25314_1\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(29),
dataa => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffdfff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_289\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_2\(0),
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f3f700000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_3\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\(0),
datae => \GRFPC0.N_24709\,
datad => \GRFPC0.N_24715\,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.DIV\,
dataa => \GRFPC0.N_24711\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00df000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_7\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\(0),
datad => \GRFPC0.N_25077\,
datac => \GRFPC0.N_25098\,
datab => \GRFPC0.WR.CTRL.INST\(4),
dataa => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_10_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffdfff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_10\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159\(0),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_4\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_3\(0),
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000800aa0808aaaa")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A4_1\(0),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_8_1\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A2_1_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
datac => \GRFPC0.N_131_1\,
datab => \GRFPC0.WR.CTRL.INST\(0),
dataa => \GRFPC0.N_25586\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f222f000fffffddd")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_1\(0),
dataf => \GRFPC0.N_25569\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_144\(0),
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_12_0\(1),
datac => \GRFPC0.N_248\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f222f000f222f222")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_0\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_0_0\(0),
datae => \GRFPC0.N_25135\,
datad => \GRFPC0.N_24323\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffd000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(0),
datae => \GRFPC0.N_25312\,
datad => \GRFPC0.N_25682\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2_2\,
datab => \GRFPC0.MEM.CTRL.RDD_0\,
dataa => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0400")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_5\(0),
dataf => \GRFPC0.N_24602\,
datae => \GRFPC0.N_24503\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.MEM.CTRL.DIV\,
dataa => \GRFPC0.N_24642\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_199_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffaeaa")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_3\(0),
dataf => \GRFPC0.N_25165\,
datae => \GRFPC0.N_23872\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_8_1\(0),
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.INST\(27),
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff7f35500")
port map (
combout => \GRFPC0.N_25580\,
dataf => \GRFPC0.N_25655\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_8_1\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0\(0),
datac => \GRFPC0.MEM.CTRL.RDD_1\,
datab => \GRFPC0.MEM.CTRL.INST\(0),
dataa => \GRFPC0.N_24642\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffeeef000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_4\(1),
dataf => \GRFPC0.N_25514\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_2_0\(1),
datad => \GRFPC0.N_25708_2\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2\,
datab => \GRFPC0.N_131_0\,
dataa => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffe0")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\(1),
dataf => \GRFPC0.N_25389\,
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\(1),
datad => \GRFPC0.N_25379\,
datac => \GRFPC0.N_25442\,
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffdfff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_384\(1),
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380\(1),
datad => \GRFPC0.N_23445\,
datac => \GRFPC0.N_23446\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff20ffff2020")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_11\(1),
datad => \GRFPC0.N_24628\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_O2_1_0\(1),
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222222222222220")
port map (
combout => \GRFPC0.N_25177\,
dataf => \GRFPC0.N_25156_2\,
datae => \GRFPC0.N_25222\,
datad => \GRFPC0.N_25179\,
datac => \GRFPC0.N_25223\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff2f0fffff2200")
port map (
combout => \GRFPC0.N_24767\,
dataf => \GRFPC0.N_25203_1\,
datae => \GRFPC0.N_24848\,
datad => \GRFPC0.N_24761\,
datac => \GRFPC0.N_23623\,
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff22fffdff20")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_173\(1),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_17\(1),
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff2f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(1),
datae => \GRFPC0.N_25612\,
datad => \GRFPC0.N_23810\,
datac => \GRFPC0.N_25617\,
datab => \GRFPC0.WR2.RREG.RESV_0\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_12_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffddfffdff00fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_12\(1),
dataf => \GRFPC0.N_24209\,
datae => \GRFPC0.N_24881\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_10\(1),
datac => \GRFPC0.N_24205\,
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff2f0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\(0),
dataf => \GRFPC0.N_24823\,
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\(0),
datad => \GRFPC0.N_24869\,
datac => \GRFPC0.N_24789\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0cff00ff0cffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_20832\,
datad => \GRFPC0.N_105\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datab => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_13_1_REGDEPX_244_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f600ff0fffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(1),
dataf => \GRFPC0.N_25\,
datae => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_2_I\(1),
datad => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_1\(1),
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1\(11),
dataa => \GRFPC0.FIFO.INST_1\(12));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_129_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffeeef000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_129\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_126\(1),
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(1),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.N_78_I_I_2\,
dataa => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_9\(1),
dataf => \GRFPC0.N_24161\,
datae => \GRFPC0.N_24753\,
datad => \GRFPC0.N_24798\,
datac => \GRFPC0.N_24794\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPU0_GRFPU_X0_L1_2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f4f0f4ffff0000")
port map (
combout => N_124870,
dataf => \GRFPU0.GRFPU_X0.N_10526\,
datae => \GRFPU0.GRFPU_X0.N_3503\,
datad => \GRFPU0.GRFPU_X0.TZI\(22),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DP_4\,
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"66ff660f66f06600")
port map (
combout => \GRFPU0.GRFPU_X0.N_17918\,
dataf => \GRFPU0.GRFPU_X0.N_17783\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_173_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffeccfa00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_173\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\(1),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_3\(1),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2580_REGDEPX2\,
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.WR2.CTRL.RS1V\,
dataa => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffff00ccffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => N_184679,
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datac => N_184753,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => N_184753,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.MULO.MRES\(117),
datad => \GRFPU0.MULO.MRES\(116));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff0f")
port map (
combout => N_184679,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(57),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
datad => \GRFPU0.GRFPU_X0.N_19502_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_L1_5_4_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f000cc00cc")
port map (
combout => N_184577,
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31109,
datad => N_31108,
datac => N_31111,
datab => N_31110);
GRFPC0_UN1_EX_CTRL_RDD_1_RNIP1V42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f6f00000000")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA_4\,
dataf => \GRFPC0.UN1_REGDEP173\,
datae => N_184647,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP156\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datab => \GRFPC0.FP_PIPELINE.RS2_1\(0),
dataa => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD_RNIUNUF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0000f0ff0000")
port map (
combout => N_184647,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
datac => \GRFPC0.MEM.CTRL.RDD\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff30000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(53),
datae => N_184645,
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_SUB_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00dd20fd02df22ff")
port map (
combout => N_184645,
dataf => N_184477,
datae => \GRFPU0.GRFPU_X0.N_17671\,
datad => N_138080,
datac => \GRFPU0.GRFPU_X0.N_19496_0\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffa0000fffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => N_184643,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(50),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
dataa => \GRFPU0.GRFPU_X0.N_17115\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c030f005c535f5")
port map (
combout => N_184643,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(50),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffdd0000fff5")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => N_184641,
datad => \GRFPU0.GRFPU_X0.N_19496\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datab => \GRFPU0.GRFPU_X0.N_17107\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33bb77ff30b874fc")
port map (
combout => N_184641,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(42),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(42),
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => N_174935);
GRFPC0_REGDEP_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000300000000")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP90_1\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
datac => N_184631,
datab => \GRFPC0.N_23661\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_1_RNIEO751: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_M\,
dataf => N_184623,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_1_0\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\);
\GRFPC0_INST_U_RNI1TFG_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => N_184623,
dataf => \GRFPC0.INST\(11),
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(10),
datac => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(31));
\GRFPC0_INST_RNI3CTI1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000100000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
dataf => N_184609,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(10),
datac => \GRFPC0.INST\(6),
datab => \GRFPC0.INST\(13),
dataa => \GRFPC0.INST\(7));
\GRFPC0_INST_RNIIIIK_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => N_184609,
dataf => \GRFPC0.INST\(11),
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(8),
datac => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_9L21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff7f0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_9\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => N_184585,
datad => N_184377,
datac => \GRFPC0.N_23708\,
datab => N_50724,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\);
\GRFPU0_GRFPU_X0_L1_5_4_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c0cffaaffaa")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\(0),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(113),
datad => \GRFPU0.MULO.DRES_1S\(112),
datac => \GRFPU0.MULO.DRES_1\(114),
datab => \GRFPU0.MULO.DRES_1\(115),
dataa => N_184577);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_1_RNI8N202_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33ffffffb3")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(0),
dataf => \GRFPC0.N_24910\,
datae => \GRFPC0.N_24128\,
datad => \GRFPC0.N_24126\,
datac => \GRFPC0.N_24127_1\,
datab => N_184575,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_11_RNICQ8T_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0fff0fff")
port map (
combout => N_184575,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(0),
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.N_23587\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_365_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000554500000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_365\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\,
dataa => N_184569);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_A2_3_A2_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00cf00000000")
port map (
combout => \GRFPC0.N_24090\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => N_184567,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_A2_3_A2_0_A2_SUB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffffefeffff")
port map (
combout => N_184567,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00cf00000000")
port map (
combout => \GRFPC0.N_24242_2\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => N_184523,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff2fffff2f2ffff")
port map (
combout => N_184523,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10\,
datab => \FPI.FLOP_0\(1),
dataa => N_50656_0);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"005f004f00000000")
port map (
combout => \GRFPC0.N_24535\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datad => N_184521,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff7fff")
port map (
combout => N_184505,
dataf => \GRFPC0.N_196\,
datae => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\,
datad => N_124,
datac => N_126,
datab => \GRFPC0.CCWR_0_SQMUXA_2_0\,
dataa => N_63);
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_1_RNI644T1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
datae => N_184495,
datad => \GRFPC0.WR2.RREG.RESV_1_0\,
datac => \GRFPC0.R.FSR.TEM\(1),
datab => \GRFPC0.WR2.RREG.EXCT\(5),
dataa => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPC0_WR2_RREG_EXCT_RNIC3LV_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => N_184495,
dataf => \GRFPC0.R.FSR.TEM\(4),
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.WR2.RREG.EXCT\(4),
datac => \GRFPC0.WR2.RREG.EXCT\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_SUB_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff0f")
port map (
combout => N_184477,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(53),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
datad => \GRFPU0.GRFPU_X0.N_19502_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ccaa")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7_1\,
dataf => \GRFPC0.INST\(13),
datae => \GRFPC0.INST_SN_N_2\,
datad => \GRFPC0.INST_0\,
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_1\(6),
dataa => N_109);
\GRFPU0_GRFPU_X0_L1_5_1_3_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00caca")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_3_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(111),
datac => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datab => N_31103,
dataa => N_31102);
\GRFPU0_GRFPU_X0_L1_5_4_2_NC_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"530053005300ffac")
port map (
combout => \GRFPU0.GRFPU_X0.N_3566\,
dataf => \GRFPU0.MULO.DRES_1\(114),
datae => \GRFPU0.MULO.DRES_1\(115),
datad => N_184379,
datac => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datab => \GRFPU0.FPMUL0.SX\(120),
dataa => N_31009);
\GRFPU0_GRFPU_X0_L1_5_4_2_NC_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00330033")
port map (
combout => N_184379,
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31109,
datad => N_31108,
datac => N_31111,
datab => N_31110);
GRFPC0_FP_PIPELINE_11_REGDEPX2_351_N_8L18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffcfffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_351_N_8\,
dataf => \GRFPC0.N_24535\,
datae => \GRFPC0.N_25754\,
datad => \GRFPC0.N_25365\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_8_REGDEPX2_253_N_7L12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_7\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3768_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
GRFPC0_FP_PIPELINE_8_REGDEPX2_253_N_8L14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_8\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
GRFPC0_FP_PIPELINE_8_REGDEPX2_253_N_10L20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_10\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_25730\,
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_8_REGDEPX2_253_N_11L24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_11\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_1\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_0_A2_0\,
datac => \GRFPC0.MEM.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_8_REGDEPX2_253_N_12L27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7fff00ff00ff00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_12\,
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_7\,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_253_N_8\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_S_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff59999fff55555")
port map (
combout => N_184444,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(52),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(53),
dataf => N_184444,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_0\(53),
datad => \GRFPU0.GRFPU_X0.N_19818_1\,
datac => \GRFPU0.GRFPU_X0.UN23_EXP\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_20_S_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"004400cc236723ef")
port map (
combout => N_184443,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_39_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(16),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(47),
datad => N_184443);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_S_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_184442,
dataf => \FPI.OP1\(30),
datae => \FPI.OP1\(6),
datad => \FPI.OP1\(2),
datac => \FPI.OP1\(26),
datab => \FPI.OP1\(17),
dataa => \FPI.OP1\(21));
\GRFPC0_D_STLCK_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ff30ff33")
port map (
combout => N_184441,
dataf => \GRFPC0.N_23290_I\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.N_21043\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STLCK_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1\,
dataf => N_184441,
datae => \GRFPC0.N_23337\,
datad => \GRFPC0.D.STLCK_0_0_26__G1_3\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_46_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8040201008040201")
port map (
combout => N_184440,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_46\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_40\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_30\,
datad => N_184440,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
\GRFPC0_D_STLCK_RNO_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f1000000f5")
port map (
combout => N_184439,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_23066\,
datad => \GRFPC0.D.STLCK_0_0_1__G1_1\,
datac => \GRFPC0.N_22981\,
datab => \GRFPC0.EX.CTRL.RD\(0),
dataa => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STLCK_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00fff0ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_5\,
dataf => \GRFPC0.N_23443\,
datae => \GRFPC0.N_22811\,
datad => N_184439,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_0_O2_0_S_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => N_184438,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53),
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(49),
datab => \FPI.OP2\(39),
dataa => \FPI.OP2\(40));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_0_O2_0_S_RNICGI05_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20304\,
dataf => \GRFPU0.GRFPU_X0.N_20299\,
datae => N_184438,
datad => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\,
datac => \GRFPU0.GRFPU_X0.N_20296\,
datab => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_10\);
GRFPU0_GRFPU_X0_COMB_IEXC25_NE_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8484884421212211")
port map (
combout => N_184437,
dataf => \GRFPU0.GRFPU_X0.L4_7\(2),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(5));
GRFPU0_GRFPU_X0_IEXC_0_SQMUXA_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3fcffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_3\,
datae => N_184437,
datad => \GRFPU0.GRFPU_X0.L4_7\(3),
datac => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_0\,
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(4));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3338323c333c333")
port map (
combout => N_184436,
dataf => \GRFPU0.GRFPU_X0.N_21896\,
datae => \GRFPU0.GRFPU_X0.N_8376\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
dataa => \GRFPU0.MULO.MRES\(96));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_M2_RNI3NIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff30ffc0ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\,
dataf => \GRFPU0.GRFPU_X0.N_19607_I\,
datae => \GRFPU0.GRFPU_X0.N_19652\,
datad => N_184436,
datac => \GRFPU0.GRFPU_X0.N_8376\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_0_S_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_184435,
dataf => \FPI.OP1\(40),
datae => \FPI.OP1\(41),
datad => \FPI.OP1\(45),
datac => \FPI.OP1\(44),
datab => \FPI.OP1\(46),
dataa => \FPI.OP1\(48));
GRFPU0_GRFPU_X0_ITER_STATE_RET_RNI37B11_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f3ffff33f333f3")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datae => \GRFPU0.GRFPU_X0.N_21036\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2\,
datab => N_184434);
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_13_S_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_184433,
dataf => \GRFPU0.MULO.MRES\(39),
datae => \GRFPU0.MULO.MRES\(42),
datad => \GRFPU0.MULO.MRES\(33),
datac => \GRFPU0.MULO.MRES\(34));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_22_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_13\(0),
dataf => N_184433,
datae => \GRFPU0.MULO.MRES\(41),
datad => \GRFPU0.MULO.MRES\(58),
datac => \GRFPU0.MULO.MRES\(44),
datab => \GRFPU0.MULO.MRES\(40));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNINHP7G1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0b0f0f0f0b0b0b")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(1),
datae => N_184431,
datad => N_138220,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datab => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(6));
GRFPU0_GRFPU_X0_UN1_QP1_SP_4_RNI8HA0I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff00fffffffff")
port map (
combout => N_184431,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB_S_1\(5),
datae => \GRFPU0.GRFPU_X0.L4_2_2\(2),
datad => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_NC_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa00a0a0ee88e8e8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(1),
dataf => \GRFPU0.GRFPU_X0.L4\(0),
datae => N_184429,
datad => N_124886,
datac => N_138078,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_NC_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ff00ff00")
port map (
combout => N_184429,
dataf => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datad => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeaeaffffeac0")
port map (
combout => N_184425,
dataf => \GRFPC0.N_24703\,
datae => \GRFPC0.N_24535\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_A3_6_3\(0),
datac => \GRFPC0.N_24713\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_RNI09NT6_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0023")
port map (
combout => N_124875,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => N_184413,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(14),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(15));
\GRFPU0_GRFPU_X0_L1_5_4_NC_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => N_184413,
dataf => \GRFPU0.GRFPU_X0.N_3566\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(113),
datac => \GRFPU0.MULO.DRES_1S\(112));
\GRFPU0_GRFPU_X0_L4_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff4455ffff4454")
port map (
combout => N_138079,
dataf => N_184405,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(19),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1));
\GRFPU0_GRFPU_X0_L4_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => N_184405,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.DRES_1S\(118));
GRFPC0_DIVI_0_SQMUXA_4_M2_E_0_RNICCJU4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0f0fffcf0f0f")
port map (
combout => N_52020,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => N_184395,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_WR2_CTRL_SEQERR_0_RNIOLLV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0f000f")
port map (
combout => N_184395,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.WR2.CTRL.SEQERR_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000555100000000")
port map (
combout => \GRFPC0.N_24126\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => N_184391);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0fffffffffff")
port map (
combout => N_184391,
dataf => \GRFPC0.N_23660\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000555100000000")
port map (
combout => \GRFPC0.N_24128\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataa => N_184389);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_1_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0fffffffffff")
port map (
combout => N_184389,
dataf => \GRFPC0.N_25505_2\,
datae => \GRFPC0.V.STDATA_14\(18),
datad => \FPI.FLOP_0\(6),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN133_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000554500000000")
port map (
combout => \GRFPC0.N_24533\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.N_24016\,
dataa => N_184387);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_I_A2_2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffffffffffff")
port map (
combout => N_184387,
dataf => \GRFPC0.N_24567\,
datae => \GRFPC0.N_23660\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffec00000000")
port map (
combout => \GRFPC0.N_24703\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => N_184377,
datad => \GRFPC0.N_24735_2\,
datac => \GRFPC0.N_23708\,
datab => \GRFPC0.N_24688\,
dataa => N_50724);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ffffffff")
port map (
combout => N_184377,
dataf => \GRFPC0.DIVI_0_SQMUXA_5\,
datae => \FPI.FLOP_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => N_50656_0);
GRFPC0_DIVI_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff300000000")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => N_184375,
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datac => \GRFPC0.N_24016\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\);
GRFPC0_DIVI_0_SQMUXA_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff7fff7fff7")
port map (
combout => N_184375,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.V.STDATA_14\(19),
datab => N_51460,
dataa => \GRFPC0.V.STDATA_14\(31));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_0_A2_3_I_O2_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1133103300000000")
port map (
combout => \GRFPC0.N_24483_I\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.N_24016\,
datab => N_184373,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_0_A2_3_I_O2_I_A2_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3fff")
port map (
combout => N_184373,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datae => \GRFPC0.V.STDATA_14\(19),
datad => \FPI.FLOP_0\(6),
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_3_I_O4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ecececfcffffffff")
port map (
combout => \GRFPC0.N_24910\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => \GRFPC0.N_24016\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datab => N_184347,
dataa => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_3_I_O4_SUB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff3f")
port map (
combout => N_184347,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(19),
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
GRFPC0_WR2_CTRL_SEQERR_0_RNIV01G4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefeeeeefffeeeee")
port map (
combout => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
dataa => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNIU0BN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_184337,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.R.STATE_189\(0),
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.FPR.RDY\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
dataf => N_184333,
datae => \GRFPC0.N_198\,
datad => \GRFPC0.N_196\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffefffcfffc")
port map (
combout => N_184333,
dataf => \GRFPC0.N_23482\,
datae => N_52826,
datad => \GRFPC0.FIFO.FULL\,
datac => N_138,
datab => N_137,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0_0\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0b0e0a05010400")
port map (
combout => \GRFPC0.N_196\,
dataf => \GRFPC0.N_23607\,
datae => \GRFPC0.N_22020\,
datad => \GRFPC0.N_22027\,
datac => N_184323,
datab => N_130,
dataa => N_128);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_SUB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0fff")
port map (
combout => N_184323,
dataf => \GRFPC0.R.STATE_190\(0),
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.N_23533\,
datac => \GRFPC0.N_23479\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI3QH51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000f1f0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => N_184293,
datad => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.WR2.RREG.RESV_1_0\,
datab => \GRFPC0.R.STATE_2\(1),
dataa => \GRFPC0.R.STATE_191\(0));
GRFPC0_WR2_CTRL_RDWR_RNIGHLA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => N_184293,
dataf => \GRFPC0.WR2.CTRL.LD\,
datae => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.CTRL.RDWR\);
GRFPC0_DIVI_0_SQMUXA_4_M7_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1101000000000000")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_4_M7_3\,
dataf => N_51364,
datae => N_51426,
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.R.STATE_189\(0),
datab => \GRFPC0.WR2.CTRL.SEQERR_0\,
dataa => N_64);
GRFPC0_FP_PIPELINE_UN14_OP_7_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ac")
port map (
combout => \GRFPC0.FP_PIPELINE.UN14_OP_7_1\,
dataf => \FPI.FLOP\(4),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(8),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.INST_0\(5),
dataa => \GRFPC0.FIFO.INST_1\(5));
GRFPC0_FP_PIPELINE_UN17_OP_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000053")
port map (
combout => \GRFPC0.FP_PIPELINE.UN17_OP_7_1_0\,
dataf => \FPI.FLOP\(4),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(8),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.INST_0\(5),
dataa => \GRFPC0.FIFO.INST_1\(5));
GRFPC0_FP_PIPELINE_UN8_OP_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ac0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\,
dataf => \FPI.FLOP\(4),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(8),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.INST_0\(5),
dataa => \GRFPC0.FIFO.INST_1\(5));
GRFPC0_FP_PIPELINE_UN11_OP_7_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000530000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_OP_7_1\,
dataf => \FPI.FLOP\(4),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(8),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.INST_0\(5),
dataa => \GRFPC0.FIFO.INST_1\(5));
\GRFPC0_DIV_EXCT_0_0_0__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcfcfcfcfd")
port map (
combout => \FPO.EXC\(0),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datab => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
dataa => \GRFPU0.GRFPU_X0.ST4.RDY\);
\GRFPU0_DIVROM0_DATA_1_6_0__M81\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"204ffa00ffe017fc")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_82\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPC0_D_STDLCK_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdfcddccfffcffcc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21055_I\,
datad => \GRFPC0.N_21416_2\,
datac => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datab => \GRFPC0.D.STDLCK_0_0_5__G1_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_WR_CTRL_VCNT_RNIRNTG6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"777f000055550000")
port map (
combout => \GRFPC0.N_10177\,
dataf => N_50097,
datae => \GRFPC0.WR2.RREG.RESV_0_0_G0_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64,
dataa => N_63);
GRFPU0_GRFPU_X0_COMB_UN13_ITER_OF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datac => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_SQRTROM0_DATA_1_6_0__M48\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30000ffff0000fff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_49\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3e20c1d0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19600_I_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\,
datae => N_124901,
datad => \GRFPU0.GRFPU_X0.N_8376\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff10000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_5\(1),
datae => \GRFPC0.N_25747_I\,
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datab => \GRFPC0.EX.CTRL.INST\(17),
dataa => \GRFPC0.N_24119\);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RNIFL4I3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff73000000")
port map (
combout => N_174882,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G1_E_1\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_15\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_5_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff02000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5_1\(1),
dataf => \GRFPC0.N_24649\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(1),
dataa => \GRFPC0.N_24719\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_3_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_3\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_7\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_5\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f1f0f0f011000000")
port map (
combout => \GRFPC0.N_23810\,
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.N_25755\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN816_REGDEPX2_2\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_1_0\(1),
datab => \GRFPC0.WR2.CTRL.INST\(28),
dataa => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_1_REGDEP104: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000082410000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP104\,
dataf => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP104_0\,
datad => RFI2_RD2ADDRZ(3),
datac => RFI2_RD2ADDRZ(1),
datab => \GRFPC0.DIV.RD\(2),
dataa => \GRFPC0.DIV.RD\(4));
\GRFPU0_DIVROM0_DATA_1_6_0__M95\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fff000fff003ff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_96\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
dataf => N_31337,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(24),
datab => N_31173);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000040000000")
port map (
combout => \GRFPC0.N_22468\,
dataf => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.N_24438\,
datab => \GRFPC0.FIFO.INST_0\(3),
dataa => \GRFPC0.FIFO.INST_0\(1));
\GRFPC0_D_LDLCK_RNO_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff10ff00ff00ff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_1\,
dataf => \GRFPC0.N_24287_2\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.D.LDLCK_0_0_0__G1_0\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datab => N_119,
dataa => N_118);
\GRFPC0_D_LDLCK_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff101010ff000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_3_TZ\,
dataf => \GRFPC0.N_23463_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_1\,
datab => \GRFPC0.FIFO.INST_0\(18),
dataa => \GRFPC0.FIFO.INST_0\(17));
GRFPC0_FP_PIPELINE_FCC_1_M2S4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fff8fff8")
port map (
combout => N_58190,
dataf => \GRFPC0.WR2.CTRL.CCWR\,
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.FCC_VALID_0_SQMUXA_1\,
datac => \GRFPC0.FCC_VALID_0_SQMUXA\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_V_STDATA_1_SS7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffffffccffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_3\);
GRFPC0_FP_PIPELINE_V_STDATA_1_M9S2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ffffff33ff30")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_3\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datad => \GRFPC0.WR.CTRL.PEND\,
datac => \GRFPC0.MEM.CTRL.INST\(0),
datab => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0cc00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datad => \GRFPC0.WR.CTRL.PEND\,
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPU0_GRFPU_X0_L1_2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cfcc0000cfcf")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_15295\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPC0_D_STLCK_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2f2f2")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_4\,
dataf => \GRFPC0.N_22835\,
datae => \GRFPC0.STDDEP_0_SQMUXA_125\,
datad => \GRFPC0.N_22819\,
datac => \GRFPC0.D.STLCK_0_0_4__G1_1\,
datab => \GRFPC0.N_21177\,
dataa => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STLCK_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_9__G1_2\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
GRFPC0_EX_CTRL_LD_RNIOA781: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0080000000000000")
port map (
combout => \GRFPC0.N_21967\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_270,
datad => N_269,
datac => N_266,
datab => N_267,
dataa => N_268);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff7b3f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(22),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(83),
dataa => \GRFPU0.MULO.MRES\(82));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0080000000000000")
port map (
combout => \GRFPC0.N_21907\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23417_2\,
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(16),
dataa => \GRFPC0.FIFO.INST_1\(15));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_I_O2_0_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00aa00000caa0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_0\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datad => \GRFPC0.N_21170\,
datac => \GRFPC0.N_21172\,
datab => \GRFPC0.N_131_0\,
dataa => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_FIFO_INST_0_RNIBUKC2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000100000000000")
port map (
combout => \GRFPC0.N_21775\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(29),
dataa => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000010")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_1\,
dataf => N_123,
datae => N_125,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI\,
datac => N_127,
datab => N_137,
dataa => N_138);
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_60_0_A5_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0088000000080000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60_0_A5_0\(0),
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0_0\(27),
dataa => \GRFPC0.FIFO.INST_0_0\(26));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD_1_1_RNI1DN62: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000008400000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
dataf => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
datae => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_2\,
datac => RFI2_RD2ADDRZ(3),
datab => \GRFPC0.MEM.CTRL.RDWR\,
dataa => \GRFPC0.MEM.CTRL.RD\(4));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"e00f00efe00000e0")
port map (
combout => N_125070,
dataf => \GRFPU0.GRFPU_X0.UN1_INCDP\(0),
datae => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.G_DP_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2000000000000000")
port map (
combout => \GRFPC0.N_24822\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23588\,
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(3),
datab => \GRFPC0.EX.CTRL.INST\(1),
dataa => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000000000000")
port map (
combout => \GRFPC0.N_24602\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.N_25378\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(17),
dataa => \GRFPC0.DIV.RS1V\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000002")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\,
dataf => \GRFPU0.MULO.MRES\(84),
datae => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.MULO.MRES\(92),
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000800000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_A5_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_19264\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(10),
datad => \GRFPU0.GRFPU_X0.N_19270\,
datac => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_1_2\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(5),
dataa => \GRFPU0.GRFPU_X0.UN8_C\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000008000")
port map (
combout => \GRFPC0.N_22470\,
dataf => N_104,
datae => N_107,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datab => N_106,
dataa => N_105);
\GRFPC0_D_STDLCK_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000008000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_5\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_2\,
datac => \GRFPC0.STDDEP_0_SQMUXA_83\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
dataa => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc00f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_20824\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4352\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc00f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(55),
dataf => \GRFPU0.GRFPU_X0.N_20814\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4352\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000220f0f0f2f")
port map (
combout => \GRFPC0.N_61\,
dataf => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR2.RREG.RESV_0\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => N_63);
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_3_RNI5ADEE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff004500000000")
port map (
combout => \FPO.ALLOW_1\(1),
dataf => \GRFPU0.GRFPU_X0.ALLOW_0_1__G0_1_0\,
datae => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
datad => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.N_157\,
datab => N_49622_0,
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1575_DEP_0_A4_0_RNIRPD01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ddd0fff0fff0fff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_0_A4_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datab => N_268,
dataa => N_269);
\GRFPC0_EX_CTRL_PC_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52562,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(25),
dataa => N_165);
GRFPC0_FP_PIPELINE_8_STDEP_336_SEL1_I_0_A2_I_O2_RNIR6AJ6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0404ff040000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_22179\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datac => \GRFPC0.N_20833\,
datab => \GRFPC0.N_21046_I\,
dataa => \GRFPC0.N_78_I_I\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaae00ccfafe00cc")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_17857_1\,
datad => \GRFPC0.N_21252\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.N_131_2\,
dataa => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_EX_CTRL_PC_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52490,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(23),
dataa => N_163);
\GRFPC0_EX_CTRL_PC_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52598,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(26),
dataa => N_166);
\GRFPC0_EX_CTRL_PC_RNO_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52670,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(28),
dataa => N_168);
\GRFPC0_EX_CTRL_PC_RNO_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52634,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(27),
dataa => N_167);
\GRFPC0_EX_CTRL_PC_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_51770,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.R.STATE_189\(0),
datab => \GRFPC0.EX.CTRL.PC\(3),
dataa => N_143);
GRFPC0_RFA_RDWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000001000")
port map (
combout => N_50438,
dataf => N_52020,
datae => CPO_LDLOCKZ,
datad => \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_3\,
datac => \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_4\,
datab => N_138,
dataa => N_64);
\GRFPC0_EX_CTRL_PC_RNO_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000053050000")
port map (
combout => N_52706,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.EX.CTRL.PC\(29),
dataa => N_169);
\GRFPC0_D_STDLCK_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff003100")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_1__G1_5\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0_1\,
datad => \GRFPC0.N_21860\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datab => \GRFPC0.N_21785\,
dataa => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_126_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000020")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_126\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(27),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_D_STLCK_RNO_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000088000000")
port map (
combout => \GRFPC0.N_22774\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => N_130,
dataa => N_129);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f909f909")
port map (
combout => \GRFPU0.GRFPU_X0.N_19671\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(97),
datad => N_31018,
datac => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(97),
dataa => \GRFPU0.FPMUL0.CS_DP_R\);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(29),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19831\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
GRFPU0_GRFPU_X0_IEXC_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6325\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_IDOUT_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ccccccf0")
port map (
combout => \FPO.IDOUT\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(0));
\GRFPU0_GRFPU_X0_IDOUT_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ccccccf0")
port map (
combout => \FPO.IDOUT\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(1),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(1));
\GRFPU0_GRFPU_X0_IDOUT_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ccccccf0")
port map (
combout => \FPO.IDOUT\(2),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(2));
\GRFPU0_GRFPU_X0_IDOUT_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ccccccf0")
port map (
combout => \FPO.IDOUT\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(3),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(3));
\GRFPU0_GRFPU_X0_IDOUT_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ccccccf0")
port map (
combout => \FPO.IDOUT\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(4));
\GRFPU0_GRFPU_X0_IDOUT_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(5));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI3H6Q_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_VST4_REG2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_6466\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(31),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(32));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(32),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(33));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(33),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(34));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(34),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(35));
\GRFPU0_GRFPU_X0_BIAS_4_0_A3_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f0000ffff0000")
port map (
combout => N_123290,
dataf => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_BIAS15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6660\,
dataf => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_25\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_22\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(1),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(4),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(2));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(38),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(39));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19680\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(117),
datac => \GRFPU0.MULO.MRES_1S\(117),
datab => N_31003);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f0c")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datab => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003ff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(42),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(43));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(44),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19594_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(103),
datac => \GRFPU0.MULO.MRES_1S\(103),
datab => N_30975);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(46),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(47));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f0c")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003ff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0));
\GRFPU0_GRFPU_X0_L2_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0eef0eeffff0000")
port map (
combout => N_124845,
dataf => \GRFPU0.GRFPU_X0.N_10765\,
datae => N_124821,
datad => \GRFPU0.GRFPU_X0.N_10728\,
datac => \GRFPU0.GRFPU_X0.N_3643\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_2_01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000cffff000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX6_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00c0000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_VST3_REG_33_C2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => N_36015,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18752\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(0),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18762\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(10),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18763\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(11),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18764\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(12),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18765\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(13),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18766\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(14),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18767\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(15),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18768\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(16),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18769\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(17),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18770\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(18),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18771\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(19),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18753\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(1),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18772\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(20),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18773\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(21),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18775\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(23),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18776\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(24),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18777\,
dataf => \FPO.RES\(25),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(25),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18778\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(26),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18779\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(27),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18780\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(28),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18781\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(29),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18754\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(2),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18783\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(31),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18784\,
dataf => \FPO.RES\(32),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(32),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18785\,
dataf => \GRFPU0.GRFPU_X0.N_21442_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(33),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18786\,
dataf => \GRFPU0.GRFPU_X0.N_21439_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(34),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18787\,
dataf => \GRFPU0.GRFPU_X0.N_19990_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(35),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18788\,
dataf => \GRFPU0.GRFPU_X0.N_21443_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(36),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18789\,
dataf => \GRFPU0.GRFPU_X0.N_21440_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(37),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18790\,
dataf => \GRFPU0.GRFPU_X0.N_21435_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(38),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18791\,
dataf => \FPO.RES\(39),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(39),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18755\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(3),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18792\,
dataf => \GRFPU0.GRFPU_X0.N_21441_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(40),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18793\,
dataf => \GRFPU0.GRFPU_X0.N_21430_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(41),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18794\,
dataf => \FPO.RES\(42),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(42),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18795\,
dataf => \GRFPU0.GRFPU_X0.N_21427_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(43),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18796\,
dataf => \GRFPU0.GRFPU_X0.N_21431_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(44),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18797\,
dataf => \GRFPU0.GRFPU_X0.N_20333_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(45),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18798\,
dataf => \GRFPU0.GRFPU_X0.N_21428_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(46),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18799\,
dataf => \GRFPU0.GRFPU_X0.N_63_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(47),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18800\,
dataf => \GRFPU0.GRFPU_X0.N_21444_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(48),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18801\,
dataf => \GRFPU0.GRFPU_X0.N_21429_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(49),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18756\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(4),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18802\,
dataf => \GRFPU0.GRFPU_X0.N_21436_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(50),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18803\,
dataf => \GRFPU0.GRFPU_X0.N_21432_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(51),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18804\,
dataf => \GRFPU0.GRFPU_X0.N_21426_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(52),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18805\,
dataf => \GRFPU0.GRFPU_X0.N_21437_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(53),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18807\,
dataf => \GRFPU0.GRFPU_X0.N_21423_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(55),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18808\,
dataf => \GRFPU0.GRFPU_X0.N_21438_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(56),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18809\,
dataf => \GRFPU0.GRFPU_X0.N_21433_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(57),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18810\,
dataf => \GRFPU0.GRFPU_X0.N_21424_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(58),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18811\,
dataf => \GRFPU0.GRFPU_X0.N_19903_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(59),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18757\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(5),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18812\,
dataf => \GRFPU0.GRFPU_X0.N_21434_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(60),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18813\,
dataf => \GRFPU0.GRFPU_X0.N_21425_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(61),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00f3c0")
port map (
combout => \GRFPC0.N_18815\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \FPO.RES\(63),
datac => \GRFPC0.WR.RREG.RES\(63),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18758\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(6),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18759\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(7),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18760\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(8),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_18761\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(9),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_23999\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(22),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_23956\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(30),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_24000\,
dataf => \GRFPU0.GRFPU_X0.N_67_I_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(54),
datab => N_63);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_I_M2_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3000000c0")
port map (
combout => \GRFPC0.N_23957\,
dataf => \FPO.RES\(62),
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(62),
datab => N_63);
\GRFPU0_GRFPU_X0_ITER_ND_I_RNINT0L1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_0_1\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_L1_4_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffe0ffe0ffff0000")
port map (
combout => N_124850,
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3463\,
datad => \GRFPU0.GRFPU_X0.N_3346\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
GRFPU0_GRFPU_X0_UN23_EXP_ANC4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_35934,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_3_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19821_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_5_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19823\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19794\,
dataf => \GRFPU0.GRFPU_X0.N_19829\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19800\,
dataf => \GRFPU0.GRFPU_X0.N_19829\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPU0_GRFPU_X0_COMB_EXP_14_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f00f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5),
dataf => N_35934,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0f30f0003fffc0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => N_124896,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPU0_GRFPU_X0_L4_6_RNI19VU_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffc0ff0fcf00ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => N_124896,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPU0_GRFPU_X0_REST_1_2_0_RNIGJER1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000300030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4233\,
dataf => \GRFPU0.GRFPU_X0.REST_1_2_0\(6),
datae => \GRFPU0.GRFPU_X0.N_18426\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNIB1S61_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fdff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_17757_M_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPU0_GRFPU_X0_L1_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(3),
dataf => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19682\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(107),
datac => \GRFPU0.MULO.MRES_1S\(107),
datab => N_30983);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19683\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(108),
datac => \GRFPU0.MULO.MRES_1S\(108),
datab => N_30985);
\GRFPC0_R_FSR_AEXC_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88fff0ff8800f000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(0),
dataf => \GRFPC0.N_18399\,
datae => \GRFPC0.N_18417\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
datac => \GRFPC0.N_18406\,
datab => \GRFPC0.WR2.RREG.RES\(5),
dataa => N_61);
\GRFPC0_R_FSR_AEXC_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88fff0ff8800f000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(1),
dataf => \GRFPC0.N_18400\,
datae => \GRFPC0.N_18417\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
datac => \GRFPC0.N_18407\,
datab => \GRFPC0.WR2.RREG.RES\(6),
dataa => N_61);
\GRFPC0_R_FSR_AEXC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88fff0ff8800f000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(2),
dataf => \GRFPC0.N_18401\,
datae => \GRFPC0.N_18417\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
datac => \GRFPC0.N_18408\,
datab => \GRFPC0.WR2.RREG.RES\(7),
dataa => N_61);
GRFPU0_GRFPU_X0_COMB_VST2_QSNAN12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000c000c00c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4355\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19314\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_19\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(94),
datac => \GRFPU0.FPMUL0.SX\(95),
datab => N_30959);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17323\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(94),
datac => \GRFPU0.MULO.MRES_1\(94));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17374\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(94),
datac => \GRFPU0.MULO.MRES_1S\(94));
GRFPU0_GRFPU_X0_NXX_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_3\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.MULO.MRES\(90),
datad => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIR4AM2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00c000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_1\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_2_TZ\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f00ff00ff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17324\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datac => \GRFPU0.FPMUL0.SX\(95),
datab => N_30959);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17375\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(95),
datac => N_30959,
datab => \GRFPU0.MULO.MRES_1S\(95));
\GRFPU0_DIVROM0_DATA_1_6_0__M28\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fc3c3c3c3c3c3c3")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_29\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfcf00cfcf00")
port map (
combout => \GRFPC0.N_24287_2\,
dataf => N_122,
datae => N_115,
datad => N_114,
datac => N_117,
datab => N_109);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19676\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(97),
datac => \GRFPU0.MULO.MRES_1S\(97),
datab => N_30963);
GRFPU0_GRFPU_X0_COMB_TMP316_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00010000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6875\,
dataf => \GRFPU0.GRFPU_X0.N_6860\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff330000f0300000")
port map (
combout => \GRFPC0.N_24324\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RS1V\,
datad => \GRFPC0.DIV.RDD_0\,
datac => \GRFPC0.DIV.VALID_0\,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_24602_1\,
dataf => \GRFPC0.DIV.RS1V\,
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.INST\(14));
\GRFPU0_GRFPU_X0_ST3_FARRES_RNIGFB32_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(28),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f000ffcfff0f")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\(0),
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_12\(0),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G5\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(99),
datac => \GRFPU0.MULO.MRES_1S\(99),
datab => N_30967);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3813_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(28),
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G5\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(100),
datac => \GRFPU0.MULO.MRES_1S\(100),
datab => N_30969);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19677\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(114),
datac => \GRFPU0.MULO.MRES_1S\(114),
datab => N_30997);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_7\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(0));
\GRFPU0_GRFPU_X0_L1_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f020f02ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPC0_WRDATA_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(0),
dataf => N_456,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(1),
dataf => N_457,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(2),
dataf => N_458,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(3),
dataf => N_459,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(4),
dataf => N_460,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(5),
dataf => N_461,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(6),
dataf => N_462,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(7),
dataf => N_463,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(8),
dataf => N_464,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(9),
dataf => N_465,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(10),
dataf => N_466,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(11),
dataf => N_467,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(12),
dataf => N_468,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(13),
dataf => N_469,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(14),
dataf => N_470,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(15),
dataf => N_471,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(16),
dataf => N_472,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(17),
dataf => N_473,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(18),
dataf => N_474,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(19),
dataf => N_475,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(20),
dataf => N_476,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(21),
dataf => N_477,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(22),
dataf => N_478,
datae => \GRFPC0.N_24006\,
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(23),
dataf => N_479,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(24),
dataf => N_480,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(25),
dataf => N_481,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(26),
dataf => N_482,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(27),
dataf => N_483,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(28),
dataf => N_484,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(29),
dataf => N_485,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(31),
dataf => N_487,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
datad => N_449,
datac => N_448);
\GRFPC0_WRDATA_I_M2_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(30),
dataf => N_486,
datae => \GRFPC0.N_23913\,
datad => N_449,
datac => N_448);
GRFPU0_GRFPU_X0_UN38_BCO_LSB_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
GRFPC0_V_STDATA_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300f3f3f300f300")
port map (
combout => \GRFPC0.V.STDATA_0_SQMUXA_1\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\,
datac => N_274,
datab => N_273);
GRFPC0_FP_PIPELINE_V_STDATA_1_M6S2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
dataf => \GRFPC0.FP_PIPELINE.UN63_HOLDN\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.PEND\,
datac => N_274,
datab => N_273);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17399\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(119),
datac => \GRFPU0.MULO.MRES_1S\(119),
datab => N_31007);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19678\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(115),
datac => \GRFPU0.MULO.MRES_1S\(115),
datab => N_30999);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00000")
port map (
combout => \GRFPC0.N_25451_2\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_0\(0),
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2580_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2580_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4634_REGDEPX2_1_0_0_A2_0_A2_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000030300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ff00c0c00000")
port map (
combout => \GRFPC0.N_25540_1\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN205_REGDEPX2_1_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000c000c333f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.RD_1\(0));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5516_REGDEPX2_2_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003fff3fff3fff")
port map (
combout => \GRFPC0.N_24115\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ff00c0c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_0_3_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_35_0_A2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c3f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_1_0\(0),
dataf => \GRFPC0.V.STDATA_14\(3),
datae => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3c00000")
port map (
combout => \GRFPC0.N_24944_1\,
dataf => \GRFPC0.V.STDATA_14\(3),
datae => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffcfffcff0c0")
port map (
combout => N_174890,
dataf => \GRFPC0.FIFO.INST_0\(0),
datae => \GRFPC0.FIFO.INST_0_0\(6),
datad => \GRFPC0.FIFO.INST_1_0\(6),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_154_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPC0.V.STDATA_14_I_M_5_0\(0),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FIFO_INST_1_RNIEHKJ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c00ff0000")
port map (
combout => \GRFPC0.V.STDATA_14_M_5\(0),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(0));
GRFPC0_OP2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f000000ff")
port map (
combout => \GRFPC0.OP2_4\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.RFA.RS2D\,
datac => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FIFO_INST_1_RNIVT4P_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000ff0000")
port map (
combout => \GRFPC0.OP2_SN_N_5\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.RFA.RS2D\,
datac => \GRFPC0.FIFO.INST_1\(0));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8421000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_37\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_4\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_22\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_395_0_A2_2_A2_0_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333300f0000000f0")
port map (
combout => \GRFPC0.N_23712\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000330c0c0c3f")
port map (
combout => \GRFPC0.N_25646_2\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(28),
datac => \GRFPC0.FIFO.INST_1_0\(27),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_22_IV_I_A2_0_0_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c3f3f3fccffffff")
port map (
combout => \GRFPC0.N_23711_LI\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(28),
datac => \GRFPC0.FIFO.INST_1_0\(27),
datab => \GRFPC0.FIFO.RD_1\(0));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN61_REGDEPX2_1_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000330c0c0c3f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(26),
datac => \GRFPC0.FIFO.INST_1_0\(27),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f3f00ffffff")
port map (
combout => \GRFPC0.N_24218\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c033f300c000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A3_0_0\(0),
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(29),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_A2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030300000ff00")
port map (
combout => \GRFPC0.N_24095\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(29),
datab => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(10),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(10),
datac => \GRFPC0.FIFO.PC_1\(10),
datab => \GRFPC0.FIFO.PC_0\(10));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_395_0_O2_2_1_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fffff33ff33ff")
port map (
combout => \GRFPC0.N_23662\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_424_0_A3_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f033003300")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0\(0),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6767_REGDEPX2_0_A2_0_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0fff3333ffff")
port map (
combout => \GRFPC0.N_24490\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_65_0_A2_2_A2_0_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc030303cf")
port map (
combout => \GRFPC0.N_24079\,
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.RD_1\(0));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN133_REGDEPX2_1_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c00330c3f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN133_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_335_0_A2_3_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff33ff0f0fffff")
port map (
combout => \GRFPC0.N_24493\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_I_A2_3_SUB_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0033330000")
port map (
combout => \GRFPC0.N_23709\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FIFO_INST_0_RNI77KJ1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0fff3333ffff")
port map (
combout => \GRFPC0.N_25491\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FIFO_INST_0_RNI77KJ1_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0033330000")
port map (
combout => \GRFPC0.N_24081\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_4_0_A3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_4_0_A3_0\(1),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_424_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000cccc0000")
port map (
combout => \GRFPC0.N_25549\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11));
GRFPC0_DIV_EXC_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff0000ffff0000")
port map (
combout => N_52981_2,
dataf => N_484,
datae => N_61,
datad => N_450,
datac => N_449,
datab => N_448);
GRFPC0_V_FSR_CEXC_1_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003fff0000")
port map (
combout => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
dataf => \GRFPC0.DIV.EXCT\(5),
datae => N_61,
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffc0000000")
port map (
combout => \GRFPC0.N_18406\,
dataf => \GRFPC0.R.FSR.AEXC\(0),
datae => N_461,
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffc0000000")
port map (
combout => \GRFPC0.N_18407\,
dataf => \GRFPC0.R.FSR.AEXC\(1),
datae => N_462,
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffc0000000")
port map (
combout => \GRFPC0.N_18408\,
dataf => \GRFPC0.R.FSR.AEXC\(2),
datae => N_463,
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffc0000000")
port map (
combout => \GRFPC0.N_18409\,
dataf => \GRFPC0.R.FSR.AEXC\(3),
datae => N_464,
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffc0000000")
port map (
combout => \GRFPC0.N_18410\,
dataf => \GRFPC0.R.FSR.AEXC\(4),
datae => N_465,
datad => N_450,
datac => N_449,
datab => N_448);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
dataf => N_484,
datae => N_450,
datad => N_449,
datac => N_448);
GRFPC0_V_FSR_AEXC_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff00000000")
port map (
combout => \GRFPC0.V.FSR.AEXC_1_SQMUXA\,
dataf => N_61,
datae => N_450,
datad => N_449,
datac => N_448);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_7_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_25058_1\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.N_131_0\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_0_0\(1),
dataf => \GRFPC0.N_131_1\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000f00000")
port map (
combout => \GRFPC0.N_25648_2\,
dataf => \GRFPC0.N_131_0\,
datae => \GRFPC0.WR.CTRL.INST\(1),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(0));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8421000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_40\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_23\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_2\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(19),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(19),
datac => \GRFPC0.FIFO.PC_1\(19),
datab => \GRFPC0.FIFO.PC_0\(19));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_8_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_25708_2\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.N_78_I_I_1\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_11_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11_1\(0),
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_9_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0c00000")
port map (
combout => \GRFPC0.N_23873_2\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.N_78_I_I_1\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_0_A2_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_185_1\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.N_78_I_I_1\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN710_REGDEPX2_0_A2_1_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_4_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000f00000")
port map (
combout => \GRFPC0.N_25674\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000000f0000")
port map (
combout => \GRFPC0.N_25835_2\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_10_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_25367_I\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.N_131_2\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25786_2\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_8_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_8_1\(0),
dataf => \GRFPC0.N_131_1\,
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(28),
datac => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_12_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12_0\(1),
dataf => N_103,
datae => N_109,
datad => N_105,
datac => N_104);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4999_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
dataf => N_106,
datae => N_107,
datad => N_105,
datac => N_104);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0000000000000")
port map (
combout => \GRFPC0.N_22575\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX\,
datad => N_109,
datac => N_103);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00000")
port map (
combout => \GRFPC0.N_25703_3\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\,
datad => \GRFPC0.MEM.CTRL.RDD\,
datac => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25845\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_2_0_A2_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.N_25388\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00c000")
port map (
combout => \GRFPC0.N_24971\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.N_131_1\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPC0.N_24979_2\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.RDD_1\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPC0.N_25433_1\,
dataf => \GRFPC0.MEM.CTRL.RDD_1\,
datae => \GRFPC0.MEM.CTRL.RS1V\,
datad => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A4_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_25624\,
dataf => \GRFPC0.N_25682\,
datae => \GRFPC0.MEM.CTRL.RDD_2\,
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_I_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0c000000000")
port map (
combout => \GRFPC0.N_25721\,
dataf => \GRFPC0.N_25730\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.RDD_2\,
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0c00000")
port map (
combout => \GRFPC0.N_25174_1\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD_0\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A4_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPC0.N_24030_2\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.RS1V\,
datad => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_3\(1),
dataf => \GRFPC0.N_25757\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_23816_1\,
dataf => \GRFPC0.N_25757\,
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN383_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1712_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1712_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fc0000000000")
port map (
combout => \GRFPC0.N_25175\,
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0_0\(1),
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00000")
port map (
combout => \GRFPC0.N_25175_1\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_8_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.RDD_0\,
datad => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_17_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_17\(1),
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f0fff000f00")
port map (
combout => \GRFPC0.N_248\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.VALID_0\,
datac => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.N_25296_1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\(0),
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.WR2.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1181_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN285_REGDEPX2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_105_0_A2_2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_23797\,
dataf => \GRFPC0.MEM.CTRL.INST\(18),
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18104\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18114\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18115\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18116\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18117\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18118\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18119\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18120\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18121\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18122\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18123\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18124\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18125\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18126\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18127\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18128\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18129\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18130\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18131\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18132\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18106\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18137\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18138\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18141\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18144\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18149\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18151\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18153\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18108\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18154\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18155\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18109\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18111\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18112\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18113\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_L1_6_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3883\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_L1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f040f04ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_10901\,
datae => \GRFPU0.GRFPU_X0.L1_2_1_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPU0_GRFPU_X0_L1_4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f020f02ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(0),
dataf => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_L1_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => N_124837,
dataf => \GRFPU0.GRFPU_X0.N_3813\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_L1_4_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1\(3),
dataf => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
GRFPU0_GRFPU_X0_UN83_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1775_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1463_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19689\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(118),
datac => \GRFPU0.MULO.MRES_1S\(118),
datab => N_31005);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_14_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_14\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_12_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_12_0_A4_0\(1),
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD_0\(3),
datac => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_12_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_12\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19593_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(102),
datac => \GRFPU0.MULO.MRES_1S\(102),
datab => N_30973);
GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_UN2384_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2384_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3632_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4880_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4880_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_3_1_CHECK_DEP_UN1136_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1136_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(15));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(45),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(46));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19592_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(101),
datac => \GRFPU0.MULO.MRES_1S\(101),
datab => N_30971);
\GRFPC0_FP_PIPELINE_13_REGDEPX_250_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_250\(1),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX_248\(1),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
datad => N_174900,
datac => N_117,
datab => N_109);
\GRFPC0_FP_PIPELINE_14_REGDEPX_268_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_268\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX_266\(1),
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
datad => N_174900,
datac => N_117,
datab => N_109);
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2887_REGDEPX_0_A2_1_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(29),
datad => \GRFPC0.FIFO.INST_0_0\(26),
datac => \GRFPC0.FIFO.INST_0_0\(28));
GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_UN3511_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0\(28),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_0\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(115),
datad => \GRFPU0.MULO.DRES_1\(115),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(98),
datad => \GRFPU0.MULO.DRES_1\(98),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(102),
datad => \GRFPU0.MULO.DRES_1\(102),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.MULO.DRES_1\(103),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(105),
datad => \GRFPU0.MULO.DRES_1\(105),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.MULO.DRES_1\(109),
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(110),
datad => \GRFPU0.MULO.DRES_1\(110),
datac => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(111),
datad => \GRFPU0.MULO.DRES_1\(111),
datac => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPC0_FP_PIPELINE_0_STDEP_202_0_IV_I_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_202_0_IV_I_A2_0_0\(0),
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_269,
datad => N_268,
datac => N_270,
datab => N_267);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(31),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(31),
datac => \GRFPC0.FIFO.PC_1\(31),
datab => \GRFPC0.FIFO.PC_0\(31));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_2_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff003c3c3c00")
port map (
combout => \GRFPC0.N_21957_1\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_22664\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1344_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_40_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_40\(1),
dataf => \GRFPC0.N_24402\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_I_A2_1_0\(0),
datac => \GRFPC0.FIFO.INST_0_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0000000000000")
port map (
combout => \GRFPC0.N_91\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0000000000000")
port map (
combout => \GRFPC0.N_23070\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(26),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FIFO.PC_1\(26),
datab => \GRFPC0.FIFO.PC_0\(26));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff003c3c3c00")
port map (
combout => \GRFPC0.N_23417_2\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(14),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_22472\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_2_1_REGDEPX_46_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.REGDEPX_46\(1),
dataf => \GRFPC0.FP_PIPELINE.2.1.REGDEPX_44\(1),
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1_0\(6));
\GRFPC0_FP_PIPELINE_14_1_REGDEPX_262_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_262\(1),
dataf => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(1),
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(45),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.DRES_1\(105),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(105),
datab => N_30979);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19596_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(105),
datac => \GRFPU0.MULO.MRES_1S\(105),
datab => N_30979);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(17),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.FIFO.PC_1\(17),
datab => \GRFPC0.FIFO.PC_0\(17));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19681\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(106),
datac => \GRFPU0.MULO.MRES_1S\(106),
datab => N_30981);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19595_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(104),
datac => \GRFPU0.MULO.MRES_1S\(104),
datab => N_30977);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24843\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(1),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_190_0_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_237\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_24845\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(1),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(6),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(6),
datac => \GRFPC0.FIFO.PC_1\(6),
datab => \GRFPC0.FIFO.PC_0\(6));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_3_0\(1),
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_25697\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2960_REGDEPX2_0_A3_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19687\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(112),
datac => \GRFPU0.MULO.MRES_1S\(112),
datab => N_30993);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_320_I_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPC0.N_24897\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\(0),
dataf => \GRFPC0.N_25164\,
datae => \GRFPC0.N_131_2\,
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_25448\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0ff00f000")
port map (
combout => \GRFPC0.N_25457\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_8_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => \GRFPC0.N_25308_2\,
dataf => \GRFPC0.DIV.INST\(3),
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_8_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fff0")
port map (
combout => \GRFPC0.N_23811_1\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.RDD_0\,
datac => \GRFPC0.DIV.INST\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19685\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(110),
datac => \GRFPU0.MULO.MRES_1S\(110),
datab => N_30989);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_12_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPC0.N_25442\,
dataf => \GRFPC0.N_25277\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0ff00f000")
port map (
combout => \GRFPC0.N_23813_1\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.VALID_0\,
datac => \GRFPC0.DIV.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19686\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(111),
datac => \GRFPU0.MULO.MRES_1S\(111),
datab => N_30991);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(49),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.DRES_1\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(109),
datab => N_30987);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19684\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(109),
datac => \GRFPU0.MULO.MRES_1S\(109),
datab => N_30987);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0000f0c00000")
port map (
combout => \GRFPC0.N_25458\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RS1V\,
datad => \GRFPC0.DIV.RDD_0\,
datac => \GRFPC0.DIV.VALID_0\,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_A4_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => \GRFPC0.N_25309_1\,
dataf => \GRFPC0.DIV.RS1V\,
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPC0.N_25385\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.N_25012\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_1_0\(0),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_15_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15\(0),
dataf => N_118,
datae => N_120,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datac => N_121,
datab => N_119);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1864_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\,
dataf => N_118,
datae => N_120,
datad => N_121,
datac => N_119);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1552_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
dataf => N_118,
datae => N_120,
datad => N_121,
datac => N_119);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_VST2_EXC_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4226\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIPV661_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20766\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI7JFJ1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0c0c0c0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19526_1\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
GRFPU0_GRFPU_X0_ST1_SIGN2_RNILJ992: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f00030300000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4373\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c00000ffc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19405_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.N_5437\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA_RNICIJJ1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19293_I\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4378\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_0_RNI5V491_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19495_I\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIC5JD1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcfcfcfcfcfcfc")
port map (
combout => \GRFPU0.GRFPU_X0.N_20_I\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1_I_M\(28),
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VITER_DBUF_0_SQMUXA_2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f00000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VITER_ND_I_5_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30f00000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_5193\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VITER_STATE_13_SQMUXA_2_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19408\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNINCAM1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19264\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_45\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL0_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_I_O2_0_0_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21541\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL1_I_0_A2_1_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.N_22288\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcfc000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19272\,
dataf => \GRFPU0.GRFPU_X0.N_19213\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(1),
datad => \GRFPU0.GRFPU_X0.UN8_C\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI4IOO2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19253_1\,
dataf => \GRFPU0.GRFPU_X0.N_19264\,
datae => \GRFPU0.GRFPU_X0.N_19212\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_UN8_C_CARRY_7_RNIJU9R: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffff03")
port map (
combout => N_124830,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(9),
datae => \GRFPU0.GRFPU_X0.UN8_C\(8),
datad => \GRFPU0.GRFPU_X0.UN8_C\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3_2\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(10),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_8\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX\);
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O3_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.N_22981\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_20961_2\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4010_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1386_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI1JBR1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNITR9G1_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_A2_3_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20843_1\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
GRFPU0_GRFPU_X0_COMB_VST2_ADD2_RNIAHAH1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff3f3f3fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
datae => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_4\,
datad => \GRFPU0.GRFPU_X0.N_4227\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27));
GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_UN2368_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff3c3c003c")
port map (
combout => \GRFPC0.N_22619_2\,
dataf => \GRFPC0.FIFO.INST_1_0\(19),
datae => \GRFPC0.FIFO.INST_1_0\(6),
datad => \GRFPC0.FIFO.INST_1\(14),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_6_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3c000000000000")
port map (
combout => \GRFPC0.N_89_1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22305\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(12));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_46\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_1\,
dataf => \GRFPC0.N_21783\,
datae => \GRFPC0.N_21785\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_21803\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STLCK_RNO_7_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_22964\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_21170\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_STDDEP_0_SQMUXA_168_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => N_174897,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf00000000000000")
port map (
combout => \GRFPC0.N_21919\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3632_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1_0\(6));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPC0.N_168_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => N_174901,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_3_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_22100\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_64_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcf000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_64\(0),
dataf => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\(0),
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1136_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1_0\(6));
\GRFPC0_FP_PIPELINE_4_1_REGDEPX_82_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcf000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.REGDEPX_82\(0),
dataf => \GRFPC0.FP_PIPELINE.4.1.REGDEPX_80\(0),
datae => N_174901,
datad => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_1_0\(6));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN97_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1047_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_64\,
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.C\(9),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(7));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
dataf => \GRFPC0.N_23609\,
datae => \GRFPC0.WR2.CTRL.RD\(2),
datad => \GRFPC0.RFA.RS1\(2),
datac => N_63);
\GRFPC0_RS1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(1),
dataf => N_448,
datae => N_453,
datad => N_63,
datac => \GRFPC0.N_23609\,
datab => \GRFPC0.RFA.RS1\(2));
\GRFPC0_FP_PIPELINE_4_STDEP_194_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fffffffffff")
port map (
combout => \GRFPC0.N_17107\,
dataf => \GRFPC0.RFA.LD\,
datae => \GRFPC0.RFA.RDD\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\,
datac => N_197);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIQ0H91_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4997\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff000000000000")
port map (
combout => \GRFPC0.N_24446\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPC0.N_24362\,
dataf => \GRFPC0.N_24348\,
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_78_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000cf000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_78\(0),
dataf => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_76\(0),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ffffffff")
port map (
combout => \GRFPC0.N_24347\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_167_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f00ffff")
port map (
combout => \GRFPC0.N_24361\,
dataf => \GRFPC0.N_24348\,
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0\(6));
GRFPC0_FP_PIPELINE_10_STDEP_416_SEL0_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_77\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL1_I_0_A2_0_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_21467\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_14_STDEP_576_SEL0_0_1_O2_0_O5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL1_I_0_A2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_21703\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_STDDEP_0_SQMUXA_3_I_O5_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0fffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_3_I_O5_0\,
dataf => N_201,
datae => N_198,
datad => N_200,
datac => N_199);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_59\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_2_STDEP_88_SEL1_I_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_17905_1\,
dataf => \GRFPC0.N_131_1\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_21172\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_335_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff0fffff3333")
port map (
combout => N_174891,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_1_0\(6),
datac => \GRFPC0.FIFO.INST_1\(14),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_190_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0ffcfcfc0c")
port map (
combout => N_174892,
dataf => \GRFPC0.FIFO.INST_0_0\(6),
datae => \GRFPC0.FIFO.INST_1_0\(6),
datad => \GRFPC0.FIFO.INST_1\(14),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_A2_2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.N_305\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.N_78_I_I\,
datab => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A2_1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0000")
port map (
combout => \GRFPC0.N_25808_2\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\,
datad => \GRFPC0.N_78_I_I\,
datac => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_12_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0000")
port map (
combout => \GRFPC0.N_207_1\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\,
datad => \GRFPC0.N_78_I_I\,
datac => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_0\(1),
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5973_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3\(1),
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_310_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_25544\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24713\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0003000")
port map (
combout => \GRFPC0.N_23787\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.RDD_1\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.MEM.CTRL.INST\(14));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3842_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_19_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19_0\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff00000000")
port map (
combout => \GRFPC0.N_21420\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_21336\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_RNIMQPB7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffff00cc")
port map (
combout => \GRFPC0.N_22183\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332\(1),
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_0\(1),
datad => \GRFPC0.N_20833\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
\GRFPC0_D_STLCK_RNO_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22124\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
\GRFPC0_D_STLCK_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000033ffffff")
port map (
combout => \GRFPC0.N_22075\,
dataf => \GRFPC0.FP_PIPELINE.9.STDEP_372\(1),
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff000000000000")
port map (
combout => \GRFPC0.N_21663\,
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff00000000")
port map (
combout => \GRFPC0.N_21973\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_21467\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A3_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ff00ff00")
port map (
combout => \GRFPC0.N_21974\,
dataf => \GRFPC0.N_21467\,
datae => \GRFPC0.N_21891\,
datad => \GRFPC0.N_78_I_I_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O2_RNI0JF03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => N_100325,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_45\,
datad => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STLCK_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f00ffff0f0f")
port map (
combout => \GRFPC0.N_22804\,
dataf => \GRFPC0.FP_PIPELINE.2.STDEP_92\(1),
datae => \GRFPC0.N_21177\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_2\);
\GRFPC0_D_STLCK_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0030ffff0000")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_5\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.D.STLCK_0_0_13__G1_4\,
datad => \GRFPC0.N_21703\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I_0\);
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL1_I_0_A2_0_O2_RNIATBD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_22513\,
dataf => \GRFPC0.N_21703\,
datae => \GRFPC0.N_78_I_I_2\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_A3_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cf000000cc00")
port map (
combout => \GRFPC0.N_22364\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_22288\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff00000000")
port map (
combout => \GRFPC0.N_109\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_77\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_1\);
\GRFPC0_D_STLCK_RNO_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30000000000000")
port map (
combout => \GRFPC0.N_22045\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_17452\,
datad => \GRFPC0.N_77\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPC0.N_21291_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_21337\,
dataf => \GRFPC0.N_21336\,
datae => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.N_78_I_I_2\);
\GRFPC0_FP_PIPELINE_0_STDEP_202_0_IV_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPC0.N_22690\,
dataf => \GRFPC0.RFA.LD\,
datae => \GRFPC0.RFA.RDD\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\,
datac => N_197);
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3199_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(29),
datad => \GRFPC0.FIFO.INST_0_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_UN1_FIFO_INST_0_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfffffff")
port map (
combout => \GRFPC0.UN1_FIFO.INST_0_9\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_12\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_8\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNI8COP1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.N_19483_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPC0_UN1_FIFO_INST_0_16_I_O2_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPC0.N_24443\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_DEP_2_IV_0_O4_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_24433\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_15_0_CHECK_DEP_UN4759_REGDEPX_I_0_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.N_23401\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(28),
datac => \GRFPC0.FIFO.INST_0\(26));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fc0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36172,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(16),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.FIFO.PC_1\(16),
datab => \GRFPC0.FIFO.PC_0\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(25),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(25),
datac => \GRFPC0.FIFO.PC_1\(25),
datab => \GRFPC0.FIFO.PC_0\(25));
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_I_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_I_A2_1_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_DEP_1_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1_0_A2_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
GRFPU0_GRFPU_X0_EXP_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff003fffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datae => \GRFPU0.GRFPU_X0.N_4063\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPC0_D_STDLCK_RNO_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.N_194\,
dataf => \GRFPC0.RFA.LD\,
datae => N_198,
datad => N_199,
datac => N_201,
datab => N_200);
GRFPC0_RFA_LD_RNIL6ET: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_21791\,
dataf => \GRFPC0.RFA.LD\,
datae => N_199,
datad => N_198,
datac => N_201,
datab => N_200);
GRFPC0_STDDEP_0_SQMUXA_5_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22809\,
dataf => \GRFPC0.RFA.LD\,
datae => N_199,
datad => N_198,
datac => N_201,
datab => N_200);
\GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_DEP_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_I_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_I_A2_1_0\(0),
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000bfffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_1\(0),
dataf => \GRFPC0.N_25074\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.N_25264_I\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_2\,
datab => \GRFPC0.WR2.CTRL.INST\(16),
dataa => \GRFPC0.WR2.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1744_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27));
GRFPC0_FP_PIPELINE_0_MEMEN2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000030cf0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62_0\,
dataf => \GRFPC0.N_18116\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.RFA.RS1\(1),
datab => N_63);
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\,
dataf => \GRFPC0.N_18116\,
datae => \GRFPC0.WR2.CTRL.RD\(1),
datad => \GRFPC0.RFA.RS1\(1),
datac => N_63);
\GRFPC0_RS1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(0),
dataf => N_448,
datae => N_452,
datad => N_63,
datac => \GRFPC0.N_18116\,
datab => \GRFPC0.RFA.RS1\(1));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_24_IV_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000030300ff")
port map (
combout => \GRFPC0.N_23623\,
dataf => \GRFPC0.FIFO.INST_0\(25),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1_0\(6),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_395_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3ff00f3f3ffff")
port map (
combout => \GRFPC0.N_23660\,
dataf => \GRFPC0.FIFO.INST_0\(25),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3c000000000")
port map (
combout => \GRFPC0.N_24712_2\,
dataf => \GRFPC0.V.STDATA_14\(15),
datae => \GRFPC0.V.STDATA_14\(14),
datad => \GRFPC0.FIFO.INST_0_0\(6),
datac => \GRFPC0.FIFO.INST_1_0\(6),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0ffff00000000")
port map (
combout => \GRFPC0.N_25505_2\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(14),
datad => \GRFPC0.FIFO.INST_0_0\(6),
datac => \GRFPC0.FIFO.INST_1_0\(6),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffff00000000")
port map (
combout => \GRFPC0.N_24127_1\,
dataf => \GRFPC0.V.STDATA_14\(3),
datae => N_50656_0,
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.INST_0_0\(6),
datab => \GRFPC0.FIFO.INST_1_0\(6));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333333333f3f33ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_194\,
dataf => \FPI.FLOP\(0),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_L1_3_1_5_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_3266\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38));
\GRFPU0_DIVROM0_DATA_1_6_0__M137\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333333333333000c")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_138\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_DIVROM0_DATA_1_6_0__M109\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000fffff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_110\,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_SQRTROM0_DATA_1_6_0__M64\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff00000000fff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_65\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_SQRTROM0_DATA_1_6_0__M78\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000fff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_79\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_SQRTROM0_DATA_1_6_0__M68\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000fffffffff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_69\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0ffffff")
port map (
combout => \GRFPC0.N_21998\,
dataf => N_129,
datae => N_130,
datad => N_132,
datac => N_131);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8),
dataf => N_129,
datae => N_130,
datad => N_132,
datac => N_131);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
dataf => N_129,
datae => N_130,
datad => N_132,
datac => N_131);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(2),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fffcff0000fc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11246\,
dataf => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18));
GRFPC0_STDDEP_0_SQMUXA_101_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_101\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3304_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3304_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2680_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(42),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(102),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30916,
datab => N_30915);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(11),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(11),
datac => \GRFPC0.FIFO.PC_1\(11),
datab => \GRFPC0.FIFO.PC_0\(11));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(25),
dataf => N_131,
datae => N_132,
datad => N_122,
datac => N_130,
datab => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
dataf => N_129,
datae => N_130,
datad => N_132,
datac => N_131);
GRFPC0_EX_CTRL_LD_RNIA6811_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_I_1\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_269,
datad => N_270,
datac => N_267,
datab => N_268);
GRFPC0_UN1_VFIFO_RD10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000fff0")
port map (
combout => \GRFPC0.UN1_VFIFO.RD10\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_64);
GRFPC0_FPEXC_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPC0.FPEXC_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datad => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.R.STATE_2\(1),
datab => \GRFPC0.R.STATE_191\(0));
GRFPC0_FIFO_FULL_RNIUMEU: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_201_2\,
dataf => \GRFPC0.R.STATE_1\(1),
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f330")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
dataf => \GRFPC0.R.STATE_1\(1),
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => \GRFPC0.FIFO.RD_1_0\(0));
GRFPC0_FP_PIPELINE_0_1_FIFO_INST_V_TMP_IV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cf0c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
dataf => \GRFPC0.R.STATE_1\(1),
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => \GRFPC0.FIFO.RD_1_0\(0));
GRFPC0_FP_PIPELINE_FIFOV2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f3000000fc")
port map (
combout => \GRFPC0.FP_PIPELINE.FIFOV2\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
GRFPC0_FP_PIPELINE_FPRDY_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR2.RREG.RESV_1_0\);
GRFPC0_FP_PIPELINE_UN1_VFIFO_FULL10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff03ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
dataf => \GRFPC0.FIFO.FULL\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datad => N_49468_I,
datac => \GRFPC0.R.STATE_2\(1),
datab => \GRFPC0.R.STATE_191\(0));
GRFPC0_FP_PIPELINE_VFIFO_FULL_6_F0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303fc000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datae => N_49468_I,
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.R.STATE_2\(1),
datab => \GRFPC0.R.STATE_191\(0));
GRFPC0_FP_PIPELINE_VFIFO_RD10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
dataf => \GRFPC0.R.STATE_2\(1),
datae => \GRFPC0.R.STATE_191\(0),
datad => N_64);
GRFPC0_FPEXC_0_SQMUXA_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ffff")
port map (
combout => \GRFPC0.N_24016\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FPR.RDY\,
datad => \GRFPC0.R.STATE_2\(1),
datac => \GRFPC0.R.STATE_191\(0));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_RNI9ICJ7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00ff00fc00fc00")
port map (
combout => N_50328,
dataf => N_50374_4,
datae => N_137,
datad => \GRFPC0.RFA.ST_0_0_G1_0_2289_A2_4\,
datac => N_136,
datab => N_135);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_23533\,
dataf => \GRFPC0.FP_PIPELINE.UN1_CPI\,
datae => N_133,
datad => N_134,
datac => N_137,
datab => N_138);
\GRFPC0_D_STLCK_RNO_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_A4_0\(1),
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_270,
datad => N_267,
datac => N_269,
datab => N_268);
GRFPC0_STDDEP_0_SQMUXA_18_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_22076\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_270,
datad => N_267,
datac => N_269,
datab => N_268);
\GRFPC0_FP_PIPELINE_8_STDEP_354_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_20847\,
dataf => \GRFPC0.RFA.LD\,
datae => N_201,
datad => N_198,
datac => N_200,
datab => N_199);
GRFPC0_RFA_LD_RNIL6ET_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_22077\,
dataf => \GRFPC0.RFA.LD\,
datae => N_201,
datad => N_198,
datac => N_200,
datab => N_199);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(47),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(48));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(49),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(50));
GRFPC0_FP_PIPELINE_VRFA_STDFQ_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.STDFQ_1\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST7_0\,
datad => N_124,
datac => N_123);
GRFPC0_FP_PIPELINE_0_STDEP_8_SEL0_0_1_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_D_STLCK_RNO_5_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc00fffffcf0")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_2\,
dataf => \GRFPC0.N_21043\,
datae => \GRFPC0.D.STLCK_0_0_27__G1_0\,
datad => \GRFPC0.N_23365\,
datac => \GRFPC0.N_78_I_I_0\,
datab => N_266);
\GRFPC0_D_STLCK_RNO_5_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPC0.N_22851\,
dataf => \GRFPC0.N_22807\,
datae => \GRFPC0.N_78_I_I_2\,
datad => N_266);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A2_3_1\(1),
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4650_REGDEPX2_0_A2_1_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4650_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(48),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(49));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc00cf00")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_1\(0),
dataf => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_0\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.N_17857_1\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_21544\,
dataf => \GRFPC0.N_21542\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_O3_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffffff")
port map (
combout => \GRFPC0.N_21882\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_21459\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_21461\,
dataf => \GRFPC0.N_21459\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00cc00cf")
port map (
combout => \GRFPC0.N_23550\,
dataf => \GRFPC0.N_23549\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ffffffff")
port map (
combout => \GRFPC0.N_21253\,
dataf => \GRFPC0.N_17857_1\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_A2_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_A2_1_1\(0),
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
datae => \GRFPC0.N_21627\,
datad => \GRFPC0.N_21620\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff000f000f000")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPC0_FP_PIPELINE_FCC_1_SS0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3f003f003f00")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_SS0\,
dataf => \GRFPC0.EX.CTRL.CCWR\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.FCC_VALID_0_SQMUXA\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.MEM.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_FCC_1_M2S2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
dataf => \GRFPC0.EX.CTRL.CCWR\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.CCWR\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.N_22918_1\,
dataf => N_131,
datae => N_132,
datad => N_122,
datac => N_130,
datab => N_129);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c0000000c000c")
port map (
combout => \GRFPC0.N_21668\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => \GRFPC0.N_21996\,
datac => N_130,
datab => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
dataf => N_129,
datae => N_130,
datad => N_132,
datac => N_131);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_0_1_RNI0N641: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcfffcffffff")
port map (
combout => \GRFPC0.N_22992\,
dataf => N_128,
datae => \GRFPC0.N_22782\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4),
datac => N_132,
datab => N_131);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_25_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffcffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_25_I\(1),
dataf => N_128,
datae => \GRFPC0.N_22782\,
datad => \GRFPC0.N_21997\,
datac => N_132,
datab => N_131);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(39),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(40));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25223\,
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_4_STDEP_198_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.N_17073\,
dataf => \GRFPC0.N_23044\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_0_A4_0\,
datac => N_268,
datab => N_269);
GRFPC0_EX_CTRL_LD_RNIA6811_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23365\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_267,
datad => N_270,
datac => N_268,
datab => N_269);
\GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_DEP_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.DEP_1_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_258_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(1),
dataf => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(6));
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000f")
port map (
combout => \GRFPC0.N_24360\,
dataf => \GRFPC0.N_24348\,
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_167_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167\(1),
dataf => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\(1),
datae => \GRFPC0.N_24348\,
datad => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0_0\(6));
GRFPC0_FP_PIPELINE_UN11_SHARE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00fcfcfc00fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.LD\,
datad => \GRFPC0.MEM.CTRL.CCWR\,
datac => \GRFPC0.MEM.CTRL.VCNT\(1),
datab => \GRFPC0.MEM.CTRL.VCNT\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(21),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(21),
datac => \GRFPC0.FIFO.PC_1\(21),
datab => \GRFPC0.FIFO.PC_0\(21));
\GRFPC0_WR_CTRL_VCNT_RNIU1HL5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300000033003f00")
port map (
combout => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
dataf => N_52020,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.N_131\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_UN1_WRENX10_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_2\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => RFI2_RD2ADDRZ(3),
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_1_REGDEP146_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0300c03")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP146_2\,
dataf => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_2\,
datae => RFI2_RD2ADDRZ(3),
datad => RFI2_RD2ADDRZ(0),
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_RFA2_RS2DEP_RNO_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_1\,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
datae => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEP50\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_1_RNITKPS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccfccf")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
datae => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.FPR.ID\(1),
datab => N_63);
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_1_RNIH73V: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff003c")
port map (
combout => \GRFPC0.N_121_1\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
datae => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
datad => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.CTRL.ID\(1),
datab => \GRFPC0.FPR.ID\(1));
GRFPC0_VEX_RREG_RESV_0_SQMUXA_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c00c")
port map (
combout => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
datae => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.FPR.ID\(1),
datab => N_63);
GRFPC0_FP_PIPELINE_1_EXEN7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7\,
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => \GRFPC0.FPUSEL_1_0_1__G0_3_0_0\,
datad => RFI2_RD2ADDRZ(3),
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21001\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.N_20975\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_15_STDEP_612_SEL1_I_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_17842_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_O3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.N_21459\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4976_DEP_I_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.N_40\,
dataf => \GRFPC0.MEM.CTRL.RD\(4),
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21542\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_O2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_22558\,
dataf => N_174896,
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_1_0\(0),
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(18),
datad => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\(11),
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4167_REGDEPX_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24368\,
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_22626\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_A2_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_19335\,
dataf => \GRFPU0.MULO.MRES\(94),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\(1),
dataf => N_120,
datae => N_121,
datad => N_174900,
datac => N_119,
datab => N_118);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4048_REGDEPX_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
dataf => N_120,
datae => N_121,
datad => N_119,
datac => N_118);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(50),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(53));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(51),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_EMIN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ccc0ccc0c0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_6571\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
dataf => \GRFPU0.MULO.DRES_1\(98),
datae => \GRFPU0.MULO.DRES_1S\(97),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
dataf => \GRFPU0.MULO.DRES_1\(118),
datae => \GRFPU0.MULO.DRES_1S\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
GRFPU0_GRFPU_X0_COMB_RNDBIT_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => \GRFPU0.MULO.MRES\(67),
datac => N_31009,
datab => \GRFPU0.MULO.DRES_S\(66));
GRFPU0_GRFPU_X0_ITER_NORM_RNID3FS_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5221\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcffcc0c0c00cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17107\,
dataf => \GRFPU0.MULO.MRES\(102),
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(120),
datac => N_31009,
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17109\,
dataf => \GRFPU0.MULO.MRES\(104),
datae => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff330fccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17113\,
dataf => \GRFPU0.MULO.MRES\(107),
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17115\,
dataf => \GRFPU0.MULO.MRES\(110),
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17117\,
dataf => \GRFPU0.MULO.MRES\(112),
datae => \GRFPU0.MULO.MRES\(111),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_31009);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17400\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(120),
datac => N_31009,
datab => \GRFPU0.MULO.MRES_1S\(120));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_18_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000cf")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_18\(0),
dataf => N_106,
datae => N_107,
datad => \GRFPC0.N_24280\,
datac => N_103,
datab => N_109);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18817\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(0),
datad => N_416,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18827\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(10),
datad => N_426,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18828\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(11),
datad => N_427,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18829\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(12),
datad => N_428,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18830\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(13),
datad => N_429,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18831\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(14),
datad => N_430,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18832\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(15),
datad => N_431,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18833\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(16),
datad => N_432,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18834\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(17),
datad => N_433,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18835\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(18),
datad => N_434,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18836\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(19),
datad => N_435,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18818\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(1),
datad => N_417,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18837\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(20),
datad => N_436,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18838\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(21),
datad => N_437,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18839\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(22),
datad => N_438,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18840\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(23),
datad => N_439,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18841\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(24),
datad => N_440,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18842\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(25),
datad => N_441,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18843\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(26),
datad => N_442,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18844\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(27),
datad => N_443,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18845\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(28),
datad => N_444,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18846\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(29),
datad => N_445,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18819\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(2),
datad => N_418,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18848\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(31),
datad => N_447,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18820\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(3),
datad => N_419,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18821\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(4),
datad => N_420,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18822\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(5),
datad => N_421,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18823\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(6),
datad => N_422,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18824\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(7),
datad => N_423,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18825\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(8),
datad => N_424,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_18826\,
dataf => \GRFPC0.N_131_2\,
datae => \GRFPC0.WR2.RREG.RES\(9),
datad => N_425,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_23937\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(30),
datad => N_446,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18849\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(32),
datad => N_416,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18850\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(33),
datad => N_417,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18851\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(34),
datad => N_418,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18852\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(35),
datad => N_419,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18853\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(36),
datad => N_420,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18854\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(37),
datad => N_421,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18855\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(38),
datad => N_422,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18856\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(39),
datad => N_423,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18857\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(40),
datad => N_424,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18858\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(41),
datad => N_425,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18859\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(42),
datad => N_426,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18860\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(43),
datad => N_427,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18861\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(44),
datad => N_428,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18862\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(45),
datad => N_429,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18863\,
dataf => \GRFPC0.N_131_3\,
datae => \GRFPC0.WR2.RREG.RES\(46),
datad => N_430,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18864\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(47),
datad => N_431,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18865\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(48),
datad => N_432,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18866\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(49),
datad => N_433,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18867\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(50),
datad => N_434,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18868\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(51),
datad => N_435,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18869\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(52),
datad => N_436,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18870\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(53),
datad => N_437,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18872\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(55),
datad => N_439,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18873\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(56),
datad => N_440,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18874\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(57),
datad => N_441,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18875\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(58),
datad => N_442,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18876\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(59),
datad => N_443,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18877\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(60),
datad => N_444,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18878\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(61),
datad => N_445,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_18880\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(63),
datad => N_447,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_I_M2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_24001\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(54),
datad => N_438,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_I_M2_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_23938\,
dataf => \GRFPC0.N_131\,
datae => \GRFPC0.WR2.RREG.RES\(62),
datad => N_446,
datac => N_412,
datab => N_411);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A3_2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21_1_0\(0),
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_470_0_A2_2_A2_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25087\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.N_25384\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25179\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datae => \GRFPC0.N_25236\,
datad => \GRFPC0.N_25179_1\,
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_A2_4_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25098\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.INST\(1),
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_470_0_A2_3_1_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25450_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25795_2\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_3_I_O2_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffffff")
port map (
combout => \GRFPC0.N_25163\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_25677\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_23746\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2\(0));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNI8QEN3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPU0_GRFPU_X0_ST3_V_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00ff0cf")
port map (
combout => \GRFPU0.GRFPU_X0.N_19463\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000ff00f30")
port map (
combout => \GRFPU0.GRFPU_X0.N_6809\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPC0_FP_PIPELINE_1_DIVEN10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c300300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10\,
dataf => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
datae => RFI2_RD2ADDRZ(2),
datad => RFI2_RD2ADDRZ(1),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD_0\(3));
GRFPC0_RFA2_RS2SEL_RET_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00000c00c00000c")
port map (
combout => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\,
dataf => RFI2_RD2ADDRZ(2),
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.VALID\);
\GRFPC0_R_FSR_AEXC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88fff0ff8800f000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(4),
dataf => \GRFPC0.N_18403\,
datae => \GRFPC0.N_18417\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
datac => \GRFPC0.N_18410\,
datab => \GRFPC0.WR2.RREG.RES\(9),
dataa => N_61);
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN80_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A5_7_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22750_1\,
dataf => N_174896,
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_D_STDLCK_RNO_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_0\,
dataf => \GRFPC0.N_22719\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_22778\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
GRFPC0_RFA_LD_RNIL6ET_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_1_I_1\,
dataf => \GRFPC0.RFA.LD\,
datae => N_200,
datad => N_201,
datac => N_199,
datab => N_198);
GRFPC0_RFA_LD_RNIL6ET_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_21896\,
dataf => \GRFPC0.RFA.LD\,
datae => N_201,
datad => N_200,
datac => N_199,
datab => N_198);
GRFPC0_RFA_LD_RNIL6ET_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_22324\,
dataf => \GRFPC0.RFA.LD\,
datae => N_200,
datad => N_201,
datac => N_199,
datab => N_198);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIDFKF1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_7_1\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPC0_FP_PIPELINE_WREN_1_F0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff3f00c0ffff")
port map (
combout => RFI1_WRENZ,
dataf => N_451,
datae => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPC0_FP_PIPELINE_WREN_1_F0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0ffff0000ff3f")
port map (
combout => RFI2_WRENZ,
dataf => N_451,
datae => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
datad => N_450,
datac => N_449,
datab => N_448);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(43),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(44));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_24731\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPU0_GRFPU_X0_TZI2_RNI2ERP1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1\(3),
dataf => \GRFPU0.GRFPU_X0.TZI2\(21),
datae => \GRFPU0.GRFPU_X0.N_3356\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4464_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
GRFPC0_FP_PIPELINE_6_0_CHECK_DEP_UN1968_REGDEPX_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3320_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4568_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(16),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2696_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(16),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff3c3c003c")
port map (
combout => \GRFPC0.N_23463_1\,
dataf => \GRFPC0.FIFO.INST_0_0\(19),
datae => \GRFPC0.FIFO.INST_0_0\(6),
datad => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_0_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_0_SQMUXA_S1_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datae => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_0_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datae => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ST1.OP2NX\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_9_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_9_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_0_STDEP_16_SEL0_0_0_I_O2_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcffffff")
port map (
combout => \GRFPC0.N_22982\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
\GRFPC0_D_STLCK_RNO_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_23010\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.N_78_I_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_21012\,
dataf => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.N_78_I_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2_4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_21016_1\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffffff")
port map (
combout => \GRFPC0.N_21783\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_2_STDEP_96_SEL1_I_0_A2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_21177\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_6\,
dataf => \GRFPU0.MULO.MRES\(84),
datae => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPU0_GRFPU_X0_COMB_OP_GT_VST3_EXC40LT9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0404000404000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7053\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_2_1\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_1\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA_RNITRGN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0f0f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_8154\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
GRFPC0_FP_PIPELINE_UN11_OP_7_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00330033")
port map (
combout => \GRFPC0.FP_PIPELINE.UN8_OP_7_4\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_0\(10));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_223\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(10),
datad => \GRFPC0.FIFO.INST_0\(10),
datac => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2));
GRFPU0_GRFPU_X0_UN238_BCO_LSB_0_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.N_22998\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(29),
datac => \GRFPC0.FIFO.INST_0_0\(28),
datab => \GRFPC0.FIFO.INST_0_0\(26));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5577_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270TT_1_M1_E: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270TT_1_N_5\,
dataf => \GRFPC0.N_25271\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.N_23756\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3903_REGDEPX2\,
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03000000000000")
port map (
combout => \GRFPC0.N_25227\,
dataf => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6990_REGDEPX2\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.RREG.RESV_1_0\,
datab => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0000")
port map (
combout => \GRFPC0.N_23756_1\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.N_25452\,
dataf => \GRFPC0.N_25826_1\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_1_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2\,
datae => \GRFPC0.WR2.CTRL.RDD_0\,
datad => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A3_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f3")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A3_1\(0),
dataf => \GRFPC0.N_25365\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_A2_1_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_I_A2_1_0_0\(0),
dataf => \GRFPC0.N_25110\,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6549_REGDEPX2\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17119\,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.MULO.MRES\(114),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(113),
datab => N_30995);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19688\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(113),
datac => \GRFPU0.MULO.MRES_1S\(113),
datab => N_30995);
GRFPC0_STDDEP_0_SQMUXA_6_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_22313\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_269,
datad => N_270,
datac => N_267,
datab => N_268);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21891\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_269,
datad => N_270,
datac => N_267,
datab => N_268);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_5_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_5_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.RS1V\,
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
GRFPU0_GRFPU_X0_COMB_GUARD_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.MRES\(95),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(96),
datab => N_30961);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(36),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.DRES_1\(96),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(96),
datab => N_30961);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17376\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(96),
datac => \GRFPU0.MULO.MRES_1S\(96),
datab => N_30961);
\GRFPC0_FP_PIPELINE_0_STDEP_34_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_17115\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_159\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(36),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(37));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4271_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_UN26_FPUSTART_0_RNITRLG4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3c3cf00f0f0f0f")
port map (
combout => \FPI.OPID\(0),
dataf => N_49622_0,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.RFA.ST_0\,
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\);
GRFPC0_VEX_CTRL_ID_2_1_CO0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c000f0f0f0f0")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_1_CO0\,
dataf => N_49622_0,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.ST\,
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(41),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(42));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_2_0_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6151_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_10_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0cc00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_124_0_A2_1_1\(1),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(39),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1314_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(55),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30942,
datab => N_30941);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(22),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN631_REGDEPX_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX_0\,
dataf => N_104,
datae => N_107,
datad => N_106);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN943_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX\,
dataf => N_104,
datae => N_105,
datad => N_107,
datac => N_106);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(38),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.DRES_1\(98),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(98),
datab => N_30965);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19589\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(98),
datac => \GRFPU0.MULO.MRES_1S\(98),
datab => N_30965);
GRFPC0_MEM_CTRL_LD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_50271,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_61,
datad => N_64);
GRFPC0_WR2_CTRL_LD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_50123,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => N_61,
datad => N_64);
GRFPC0_WR_CTRL_LD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_50192,
dataf => \GRFPC0.MEM.CTRL.LD\,
datae => N_61,
datad => N_64);
GRFPU0_GRFPU_X0_UN1_RND_INC_2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_123286,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_16\(0),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIEB5B2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20965\,
dataf => \GRFPU0.GRFPU_X0.L1_5_0_A2_1\(3),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc000000000000")
port map (
combout => \GRFPC0.N_24330\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f0fff000f00")
port map (
combout => \GRFPC0.N_24323\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.RDD_0\,
datad => \GRFPC0.DIV.VALID_0\,
datac => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_25485\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.VALID_0\);
GRFPC0_VDIV_VALID_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff00ff00ff00")
port map (
combout => \GRFPC0.VDIV.VALID_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_25352\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.VALID_0\);
GRFPC0_FP_PIPELINE_1_REGDEP104_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00000ff00f0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP104_0\,
dataf => RFI2_RD2ADDRZ(2),
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.RD_0\(3),
datac => \GRFPC0.DIV.VALID_0\);
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN391_REGDEPX_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(29),
datad => \GRFPC0.FIFO.INST_0_0\(26),
datac => \GRFPC0.FIFO.INST_0_0\(28));
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1015_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(29),
datad => \GRFPC0.FIFO.INST_0_0\(26),
datac => \GRFPC0.FIFO.INST_0_0\(28));
GRFPC0_STDDEP_0_SQMUXA_125_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_125\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_5_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.N_25325_1\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD_0\(3),
datac => \GRFPC0.DIV.RD_0\(4));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2623_REGDEPX2_0_A4_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2623_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
dataf => N_31313,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(12),
datab => N_31149);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
dataf => N_31303,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(7),
datab => N_31139);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
dataf => N_31301,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(6),
datab => N_31137);
GRFPC0_V_FSR_CEXC_4_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.CTRL.AFSR\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\,
datab => N_61);
GRFPC0_V_FSR_CEXC_3_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f030000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA_1\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.WR2.CTRL.AFSR\);
GRFPC0_WR2_CTRL_AFSR_RNIAO881: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f33333333333333")
port map (
combout => \GRFPC0.N_18417\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.CTRL.AFSR\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\,
datab => N_61);
GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2S2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0f0f0f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.CTRL.AFSR\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24289\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.N_24282\,
datac => N_105,
datab => N_104);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_23414\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.N_24282\,
datac => N_105,
datab => N_104);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(30),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_190_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_23872\,
dataf => \GRFPC0.N_23584\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_4_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25747_I\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000c00000")
port map (
combout => \GRFPC0.N_24791\,
dataf => \GRFPC0.N_24843\,
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_3_0\(1),
datad => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A4_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A4_1_0\(1),
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\,
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.N_24119\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23870\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.N_24554\,
datad => \GRFPC0.N_25565\,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_10_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0000")
port map (
combout => \GRFPC0.N_25217_1\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\,
datad => \GRFPC0.MEM.CTRL.RDD\,
datac => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A2_10_A4_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f03000000000")
port map (
combout => \GRFPC0.N_23803\,
dataf => \GRFPC0.N_23788\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RDD_1\,
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_25682\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25834\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\,
datad => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_23621\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
datad => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23783\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_23788\,
datad => \GRFPC0.N_23783_1\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24789\,
dataf => \GRFPC0.N_25685\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_1_A2_I_O4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00fff0ff")
port map (
combout => \GRFPC0.N_25589\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.RDD_1\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c0c00")
port map (
combout => \GRFPC0.N_25702\,
dataf => \GRFPC0.N_25693_2\,
datae => \GRFPC0.N_25706\,
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_0\(1),
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A4_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_24795_2\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_24964\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN222_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_21039\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(35),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(36));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cffc000000000000")
port map (
combout => \GRFPC0.N_169_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => N_114,
datac => N_115,
datab => N_122);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3003ffffffffffff")
port map (
combout => \GRFPC0.N_22180\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX\,
datad => N_114,
datac => N_115,
datab => N_122);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_7_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cffc000000000000")
port map (
combout => \GRFPC0.N_88_1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => N_114,
datac => N_115,
datab => N_122);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(38),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(30),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(42));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
GRFPC0_RFA2_RS2DEP_RNO_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0000f0f0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP2_I_M_0_2_0\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datad => \GRFPC0.DIV.VALID_0\,
datac => \GRFPC0.DIV.RD\(0));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_A4_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_A4_0_0\,
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\(0),
dataf => \GRFPC0.N_25758\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN400_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_11_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3932_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3932_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(8),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(8),
datac => \GRFPC0.FIFO.PC_1\(8),
datab => \GRFPC0.FIFO.PC_0\(8));
\GRFPC0_EX_CTRL_PC_RNO_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52517,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(24),
datab => N_164);
\GRFPC0_EX_CTRL_PC_RNO_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52157,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(14),
datab => N_154);
\GRFPC0_EX_CTRL_PC_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52733,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(30),
datab => N_170);
\GRFPC0_EX_CTRL_PC_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51869,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(6),
datab => N_146);
\GRFPC0_EX_CTRL_PC_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52049,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(11),
datab => N_151);
\GRFPC0_EX_CTRL_PC_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52769,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(31),
datab => N_171);
\GRFPC0_EX_CTRL_PC_RNO_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51905,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(7),
datab => N_147);
\GRFPC0_EX_CTRL_PC_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52445,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(22),
datab => N_162);
\GRFPC0_EX_CTRL_PC_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51941,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(8),
datab => N_148);
\GRFPC0_EX_CTRL_PC_RNO_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51977,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(9),
datab => N_149);
\GRFPC0_EX_CTRL_PC_RNO_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51833,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(5),
datab => N_145);
\GRFPC0_EX_CTRL_PC_RNO_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52193,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(15),
datab => N_155);
\GRFPC0_EX_CTRL_PC_RNO_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52229,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(16),
datab => N_156);
\GRFPC0_EX_CTRL_PC_RNO_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52121,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(13),
datab => N_153);
\GRFPC0_EX_CTRL_PC_RNO_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52373,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(20),
datab => N_160);
\GRFPC0_EX_CTRL_PC_RNO_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52301,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(18),
datab => N_158);
\GRFPC0_EX_CTRL_PC_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52409,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(21),
datab => N_161);
\GRFPC0_EX_CTRL_PC_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51797,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(4),
datab => N_144);
\GRFPC0_EX_CTRL_PC_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52265,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(17),
datab => N_157);
\GRFPC0_EX_CTRL_PC_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52013,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(10),
datab => N_150);
\GRFPC0_EX_CTRL_PC_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_51725,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(2),
datab => N_142);
\GRFPC0_EX_CTRL_PC_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52337,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.EX.CTRL.PC\(19),
datab => N_159);
\GRFPC0_EX_CTRL_PC_RNO_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000330f0033")
port map (
combout => N_52085,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_0\(1),
datad => \GRFPC0.R.STATE_189\(0),
datac => \GRFPC0.EX.CTRL.PC\(12),
datab => N_152);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(4),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.FIFO.PC_1\(4),
datab => \GRFPC0.FIFO.PC_0\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(3),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.FIFO.PC_1\(3),
datab => \GRFPC0.FIFO.PC_0\(3));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3946_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfffcfc")
port map (
combout => \GRFPC0.N_21627\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffff")
port map (
combout => \GRFPC0.N_21635\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_21785\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(1),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_25445\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.DIV.RD_0\(3),
datab => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25401\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_23822\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_113_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_24363\,
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3855_REGDEPX_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPC0.N_24356\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1359_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_110_IV_0_O4_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_24444\,
dataf => \GRFPC0.FIFO.INST_0_0\(19),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(29),
datac => \GRFPC0.FIFO.INST_0_0\(26),
datab => \GRFPC0.FIFO.INST_0_0\(28));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_38_IV_I_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_24437\,
dataf => \GRFPC0.FIFO.INST_0_0\(19),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPC0_FP_PIPELINE_7_0_REGDEPX_128_IV_0_O4_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_24408\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0_0\(27),
datad => \GRFPC0.FIFO.INST_0_0\(29),
datac => \GRFPC0.FIFO.INST_0_0\(28),
datab => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
dataf => N_31309,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(10),
datab => N_31145);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4360_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
dataf => N_121,
datae => N_119,
datad => N_120,
datac => N_118);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
dataf => N_31295,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(3),
datab => N_31131);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_3_0\(0),
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2211_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5136_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25214\,
dataf => \GRFPC0.N_25589\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000300000000000")
port map (
combout => \GRFPC0.N_24701\,
dataf => \GRFPC0.N_24701_1\,
datae => \GRFPC0.MEM.CTRL.RDD_2\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24668\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_24701_1\,
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300030003000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_I_M_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff003f003f003f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(35),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_25443\,
dataf => \GRFPC0.N_257\,
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.RDD_0\,
datab => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\(0),
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_12_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12\(0),
dataf => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19679\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(116),
datac => \GRFPU0.MULO.MRES_1S\(116),
datab => N_31001);
\GRFPC0_FIFO_VCNT_1_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fafaf0c3faeb")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0_2__G2\,
dataf => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_0_0\,
datad => \GRFPC0.FIFO.VCNT_1\(0),
datac => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_1\(1),
dataa => N_61);
\GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_ALTB_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f33033f330300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(1),
datae => \FPI.FLUSHID\(3),
datad => \FPI.FLUSHID\(2),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(2),
datab => \GRFPU0.GRFPU_X0.ST1.ID\(3));
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_RD_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\,
dataf => \GRFPC0.N_23608\,
datae => \GRFPC0.MEM.CTRL.RD\(3),
datad => \GRFPC0.RFA.RS1\(3),
datac => N_63);
GRFPC0_FP_PIPELINE_0_WRENX2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000030cf0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_0\,
dataf => \GRFPC0.N_23608\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.RFA.RS1\(3),
datab => N_63);
\GRFPC0_RS1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(2),
dataf => N_448,
datae => N_454,
datad => N_63,
datac => \GRFPC0.N_23608\,
datab => \GRFPC0.RFA.RS1\(3));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_O3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff0fff330000")
port map (
combout => \GRFPC0.N_23612\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5577_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
datad => \GRFPC0.MEM.CTRL.RDD_2\,
datac => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_19264\,
datae => \GRFPU0.GRFPU_X0.N_19270\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_1_2\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(5),
datab => \GRFPU0.GRFPU_X0.UN8_C\(4));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5283_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5283_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25361\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(18),
datad => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_24448\,
dataf => N_174896,
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(15),
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_76_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_76\(0),
dataf => \GRFPC0.N_22674\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1344_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPC0.N_23309_1\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => N_174896,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(14));
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
dataf => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.WR2.EXC\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_A2_9_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_296\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f0f0c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4379\,
dataf => \GRFPU0.GRFPU_X0.N_5299\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(38),
dataf => \GRFPU0.GRFPU_X0.N_20608\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_RNO_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(35),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_UN1_ITER_SQRT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f3f0fff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_5438\,
dataf => \GRFPU0.GRFPU_X0.N_5299\,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
GRFPU0_GRFPU_X0_COMB_UN1_ITER_EMIN_RNIS6LK2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.N_5430\,
dataf => \GRFPU0.GRFPU_X0.N_5299\,
datae => \GRFPU0.GRFPU_X0.N_6571\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fff0f0f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(31),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fff0f0f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fff0f0f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_IV_0_A2_7_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
GRFPC0_FP_PIPELINE_V_STDATA_1_SS4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fffffff3")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
dataf => \GRFPC0.FP_PIPELINE.UN63_HOLDN\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_3\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5091_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5091_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_24715\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_12_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.N_24696_1\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(27));
GRFPU0_GRFPU_X0_VITER_EXP_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033ff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
GRFPU0_GRFPU_X0_COMB_VITER_EXP12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_6097\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_138138,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => N_138110,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => N_138114,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => N_138118,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(14),
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0cccfcccfccc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0cccfcccfccc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO3\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccfcccfccc0cccf")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO3\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0f33ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_83\,
dataf => \FPI.FLOP\(6),
datae => \FPI.FLOP\(3),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(7),
datab => \GRFPC0.FIFO.INST_0\(7));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_2_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0cc0f330000")
port map (
combout => \GRFPU0.GRFPU_X0.N_76\,
dataf => \FPI.FLOP\(6),
datae => \FPI.FLOP\(5),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(7),
datab => \GRFPC0.FIFO.INST_0\(7));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_24358\,
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
dataf => N_31339,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(25),
datab => N_31175);
GRFPU0_GRFPU_X0_COMB_VST2_DIFF2_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300030003030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31177,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc000000fc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(53),
dataf => N_31341,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G5\,
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300330f33ff330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20623\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f330fff0f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_20455\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f330fff0f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_20468\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f330fff0f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_20473\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300330f33ff330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20463\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300330f33ff330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20616\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123534,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123535,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123536,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123537,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_123538,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123539,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123540,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_123526,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123543,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123544,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_122928,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_122934,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_123527,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => N_122958,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122964,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122974,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122979,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122980,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123528,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122985,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122986,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122992,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf00c0f0c00")
port map (
combout => N_123013,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0c0ffcf00c00")
port map (
combout => N_123023,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123529,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0c0ffcf00c00")
port map (
combout => N_123031,
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(6),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0c0ffcf00c00")
port map (
combout => N_123032,
dataf => \GRFPU0.DIVROM0.RADDR\(6),
datae => \GRFPU0.DIVROM0.RADDR\(7),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_123530,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123532,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123533,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_123542,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_122957,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf00c0f0c00")
port map (
combout => N_123003,
dataf => \GRFPU0.DIVROM0.RADDR\(1),
datae => \GRFPU0.DIVROM0.RADDR\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123545,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => N_122973,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123531,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_I_M2_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_123541,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24645\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.N_25695\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O3_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc000000cc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_O3_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_23430\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_69_I\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_2\);
\GRFPC0_D_STDLCK_RNO_8_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_3\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.N_131_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_0\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_21336\,
datad => \GRFPC0.N_21338\,
datac => \GRFPC0.N_131_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O2_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_0\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_45\,
datad => \GRFPC0.N_20974\,
datac => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ffffffffffff")
port map (
combout => \GRFPC0.N_21121\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffffffffffff")
port map (
combout => \GRFPC0.N_21123\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffffffffffff")
port map (
combout => \GRFPC0.N_21471\,
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ffffffffffff")
port map (
combout => \GRFPC0.N_21468\,
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_20925\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_2\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_20976\,
dataf => \GRFPC0.N_20974\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_20985\,
dataf => \GRFPC0.N_20974\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_21341\,
dataf => \GRFPC0.N_21338\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_D_STLCK_RNO_4_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc000000cc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_21339\,
datad => \GRFPC0.N_21338\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_21549\,
dataf => \GRFPC0.N_21540\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_21545\,
dataf => \GRFPC0.N_21540\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPC0.N_20838\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A3_4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0300000")
port map (
combout => \GRFPC0.N_24306_1\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.RDD_0\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_10_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000f00")
port map (
combout => \GRFPC0.N_25360\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_A0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_25264_I\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.RS1V\,
datad => \GRFPC0.WR2.CTRL.INST\(14));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN416_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN416_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD_0\(3),
datac => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_220\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.N_23821\,
datac => \GRFPC0.DIV.RD_0\(3),
datab => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23813\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_23817\,
datac => \GRFPC0.DIV.RD_0\(3),
datab => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_O2_0\(0),
dataf => \GRFPC0.N_25317\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.N_23817\,
datac => \GRFPC0.DIV.RD_0\(3),
datab => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_320_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_24958\,
dataf => \GRFPC0.N_25236\,
datae => \GRFPC0.N_131_1\,
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_25074\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.N_25786_1\,
datad => \GRFPC0.N_25179_1\,
datac => \GRFPC0.N_131_0\,
datab => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_22329_1\,
dataf => N_132,
datae => N_131,
datad => N_122,
datac => N_130,
datab => N_129);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7),
dataf => N_131,
datae => N_132,
datad => N_130,
datac => N_129);
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f0cf")
port map (
combout => \GRFPU0.GRFPU_X0.N_7439\,
dataf => \GRFPU0.GRFPU_X0.N_7459\,
datae => \GRFPU0.GRFPU_X0.N_6809\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f30")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_7019\,
datae => \GRFPU0.GRFPU_X0.N_7028\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNIR6E71_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19398\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
dataf => N_31299,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(5),
datab => N_31135);
\GRFPC0_R_FSR_AEXC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88fff0ff8800f000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(3),
dataf => \GRFPC0.N_18402\,
datae => \GRFPC0.N_18417\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
datac => \GRFPC0.N_18409\,
datab => \GRFPC0.WR2.RREG.RES\(8),
dataa => N_61);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_14_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_14\(0),
dataf => N_120,
datae => N_121,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datac => N_119,
datab => N_118);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_22333_1\,
dataf => N_174900,
datae => N_121,
datad => N_120,
datac => N_119,
datab => N_118);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4984_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
dataf => N_120,
datae => N_121,
datad => N_119,
datac => N_118);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\(1),
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_4\,
dataf => \GRFPC0.N_18119\,
datae => \GRFPC0.WR2.CTRL.RD\(4),
datad => \GRFPC0.RFA.RS1\(4),
datac => N_63);
\GRFPC0_RS1_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(3),
dataf => N_448,
datae => N_455,
datad => N_63,
datac => \GRFPC0.N_18119\,
datab => \GRFPC0.RFA.RS1\(4));
GRFPC0_FP_PIPELINE_0_UN1_DIV_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\,
dataf => \GRFPC0.N_18115\,
datae => \GRFPC0.DIV.RD\(0),
datad => \GRFPC0.RFA.RS1\(0),
datac => N_63);
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
dataf => \GRFPC0.N_18115\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.RFA.RS1\(0),
datac => N_63);
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD\,
dataf => \GRFPC0.N_18115\,
datae => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.RFA.RS1\(0),
datac => N_63);
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.RD\,
dataf => \GRFPC0.N_18115\,
datae => \GRFPC0.WR.CTRL.RD\(0),
datad => \GRFPC0.RFA.RS1\(0),
datac => N_63);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A3_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_12_0\(1),
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.DIV.RD_0\(3),
datac => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_24302\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.N_23817\,
datac => \GRFPC0.DIV.RD_0\(3),
datab => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23462_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25289\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.N_23822\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(37),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(38));
GRFPC0_RFA_LD_RNIL6ET_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_23282\,
dataf => \GRFPC0.RFA.LD\,
datae => N_200,
datad => N_201,
datac => N_198,
datab => N_199);
GRFPC0_STDDEP_0_SQMUXA_24_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_21092\,
dataf => N_200,
datae => N_198,
datad => N_199);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25711\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25695\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_25314_1\,
dataf => \GRFPC0.N_25754\,
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25312\,
dataf => \GRFPC0.N_25758\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\(0),
datad => \GRFPC0.WR2.RREG.RESV_0\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25317\,
dataf => \GRFPC0.N_268\,
datae => \GRFPC0.N_25360\,
datad => \GRFPC0.WR2.RREG.RESV_0\,
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25350\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\,
datad => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25417\,
dataf => \GRFPC0.N_25438_1\,
datae => \GRFPC0.N_25759\,
datad => \GRFPC0.WR2.RREG.RESV_0\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cc000ccfccfffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_FLOP4_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f0000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30003030ffffff30")
port map (
combout => \GRFPU0.GRFPU_X0.N_7795_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c0c0ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff0303ffffff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_8171_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_21076_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0));
GRFPC0_FP_PIPELINE_V_STDATA_1_SS1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003300000030")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
dataf => \GRFPC0.WR.CTRL.PEND\,
datae => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.WR2.CTRL.PEND\,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI_3\);
GRFPC0_FIFO_INC_3_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FIFO_INC_3_SQMUXA\,
dataf => \GRFPC0.VDIV.EXC_1_SQMUXA\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => \GRFPC0.MEM.CTRL.PEND\);
GRFPC0_FP_PIPELINE_UN63_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN63_HOLDN\,
dataf => \GRFPC0.WR.CTRL.PEND\,
datae => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => \GRFPC0.MEM.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\(0),
dataf => \GRFPC0.N_25754\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25314\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_25754\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN816_REGDEPX2_2\,
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25303\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_25755\,
datad => \GRFPC0.N_25303_1\,
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_25722_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.N_24867\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
dataf => N_31325,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(18),
datab => N_31161);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A2_2_0\(0),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_MEM_CTRL_RD_RNIBEDQ_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(23),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(23),
datac => \GRFPC0.FIFO.PC_1\(23),
datab => \GRFPC0.FIFO.PC_0\(23));
GRFPU0_GRFPU_X0_COMB_VEXC_5_1_I_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_8_I_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datab => \GRFPU0.GRFPU_X0.ST4.RDY\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_4_I_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19274_I_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datab => \GRFPU0.GRFPU_X0.ST4.RDY\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPC0.FPO_I_4_I_0\(69),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN320_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_UN1_REGDEP119: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30c0ffff030cffff")
port map (
combout => \GRFPC0.UN1_REGDEP119\,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4864_REGDEPX_0_A3_1_RNI5LHO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_90\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22972_I\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(29));
GRFPC0_STDDEP_0_SQMUXA_124_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_124\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_0_0\(1),
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_25135\,
dataf => \GRFPC0.N_25117\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25437\,
dataf => \GRFPC0.N_25757\,
datae => \GRFPC0.N_260\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_21622\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4687_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
dataf => N_105,
datae => N_106,
datad => N_104,
datac => N_107);
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_13_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_13\(0),
dataf => N_106,
datae => N_105,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datac => N_104,
datab => N_107);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2815_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
dataf => N_105,
datae => N_106,
datad => N_104,
datac => N_107);
\GRFPU0_GRFPU_X0_L4_2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001ffff00010000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(2),
datae => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPC0_R_STATE_0_RNIMLSC5_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00f0000")
port map (
combout => \GRFPC0.DIV.PC_0_0_9__G2\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.R.STATE_189\(0));
\GRFPC0_R_STATE_2_RNITDM05_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE_2\(1),
datad => \GRFPC0.R.STATE_191\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIV7J25_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000ccccc0cc")
port map (
combout => N_50070_3,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => N_61);
GRFPC0_EX_CTRL_AFSR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000c0c0")
port map (
combout => N_50395,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_189\(0),
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.RFA.AFSR\,
datab => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\);
\GRFPC0_R_STATE_1_RNIVBM18_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f0ff")
port map (
combout => N_50527,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.R.STATE_190\(0),
datac => \GRFPC0.R.STATE_1\(1));
GRFPC0_FP_PIPELINE_UN105_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fff0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN105_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_191\(0),
datad => \GRFPC0.R.STATE_2\(1),
datac => N_64);
GRFPC0_FP_PIPELINE_UN1_PENDEXC_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_PENDEXC_2\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.R.STATE_191\(0),
datac => \GRFPC0.R.STATE_2\(1));
\GRFPC0_R_STATE_RNI2E425_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fffff0ff")
port map (
combout => N_50097,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1));
GRFPC0_EX_CTRL_LD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000c0c0")
port map (
combout => N_50387,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.R.STATE_189\(0),
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\);
GRFPC0_EX_CTRL_SEQERR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000c0c0")
port map (
combout => N_50340,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.RFA.SEQERR\,
datab => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\);
GRFPC0_EX_CTRL_STDFQ_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030003030")
port map (
combout => N_50405,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.R.STATE_1\(1),
datac => \GRFPC0.RFA.STDFQ\,
datab => N_64);
\GRFPC0_R_STATE_RNI07II_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f000f0f0")
port map (
combout => N_52984_2,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.R.STATE\(1),
datac => N_61);
GRFPC0_MEM_CTRL_LD_RNIGQOH: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f000f0f0f0f0")
port map (
combout => N_52987_2,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.MEM.CTRL.LD\,
datac => N_61);
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(40),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(33),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(45));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25222\,
dataf => \GRFPC0.N_24327\,
datae => \GRFPC0.N_25757\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25454\,
dataf => \GRFPC0.N_24327\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22925_1\,
dataf => N_118,
datae => N_174900,
datad => N_119,
datac => N_121,
datab => N_120);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN928_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\,
dataf => N_118,
datae => N_119,
datad => N_121,
datac => N_120);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(22),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(22),
datac => \GRFPC0.FIFO.PC_1\(22),
datab => \GRFPC0.FIFO.PC_0\(22));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4857_REGDEPX2_0_A2_1_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4857_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25326\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6621_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_QNE2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.QNE2\,
dataf => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datae => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_4\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\,
datac => \GRFPC0.R.STATE_190\(0),
datab => \GRFPC0.R.STATE_1\(1));
GRFPC0_FP_PIPELINE_V_STATE2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE2_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_4\,
datae => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\,
datad => \GRFPC0.R.STATE_191\(0),
datac => \GRFPC0.R.STATE_2\(1));
\GRFPC0_RFAREG_R_STATE_4_M0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0f0c0")
port map (
combout => \GRFPC0.RFAREG.R.STATE_4_M0\(1),
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND\,
datac => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.R.STATE\(0));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7047_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7047_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN351_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_14_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3887_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
GRFPC0_VWR2_CTRL_PEND_1_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_1_SQMUXA_2\,
dataf => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.DIV.EXC\,
datab => \GRFPC0.WR2.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25403\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5298_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2191_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX\,
dataf => N_107,
datae => N_104,
datad => N_106,
datac => N_105);
\GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_DEP_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\(1),
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_DEP_2_IV_I_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0000000c0000")
port map (
combout => \GRFPC0.N_22698\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_DEP_2_IV_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000000")
port map (
combout => \GRFPC0.N_22697\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.INST_0_0\(27),
datab => \GRFPC0.FIFO.INST_0_0\(26));
GRFPC0_STDDEP_0_SQMUXA_109_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_31\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_DEP_2_IV_0_I4_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_22620\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(28),
datad => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
dataf => N_31323,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(17),
datab => N_31159);
GRFPU0_GRFPU_X0_ST2_DIFFN_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030000030003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11265\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26),
datad => N_31177,
datac => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\);
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_276_0_0_A4_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0c00000c000")
port map (
combout => \GRFPC0.N_24606_1\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_2_LI\,
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_D_STDLCK_RNO_5_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_117_I_1\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_2_LI\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_STDDEP_0_SQMUXA_93_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_93\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
dataf => N_31319,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(15),
datab => N_31155);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(20),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(20),
datac => \GRFPC0.FIFO.PC_1\(20),
datab => \GRFPC0.FIFO.PC_0\(20));
\GRFPC0_D_STLCK_RNO_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ff00fff3f30000")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.N_23365\,
datad => \GRFPC0.N_23282\,
datac => \GRFPC0.N_78_I_I_0\,
datab => N_266);
\GRFPC0_D_STLCK_RNO_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0300000")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_1\,
dataf => \GRFPC0.D.STLCK_0_0_30__G1_0\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.N_78_I_I_0\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP\,
datab => N_266);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00ff")
port map (
combout => \GRFPC0.N_22494\,
dataf => \GRFPC0.N_22448\,
datae => \GRFPC0.N_78_I_I_2\,
datad => N_266);
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPC0.N_158\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.N_78_I_I_2\,
datad => \GRFPC0.STDDEP_0_SQMUXA_31_I_I_A3_0\,
datac => N_266);
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00ff")
port map (
combout => \GRFPC0.N_191\,
dataf => \GRFPC0.N_162\,
datae => \GRFPC0.N_78_I_I_2\,
datad => N_266);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_167\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_1\,
datac => N_106,
datab => N_104);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNIMBC32_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(27),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(28));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
dataf => N_31315,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(13),
datab => N_31151);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
dataf => N_31321,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datac => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(16),
datab => N_31157);
\GRFPC0_WR_RREG_EXCT_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0fc303030")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_4__G2\,
dataf => \GRFPC0.N_65_0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.MEM.RREG.EXCT\(4),
datab => N_63);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.WR2.RREG.RESV_1_0\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.WR2.RREG.EXCT\(4));
\GRFPC0_MEM_RREG_EXCT_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0f0f0f0")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_4__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.EX.RREG.EXCT\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000f0")
port map (
combout => \GRFPC0.N_24207\,
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(16),
datac => \GRFPC0.V.STDATA_14\(14));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff7ffc8ffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
dataf => N_138228,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_262\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_N_11\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_M9_I_A4_0_0\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0cae")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(54),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(54),
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.MULO.MRES\(115),
datab => N_174945,
dataa => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_COMB_SIGN2_1_RNIA57U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.CCV_2_SQMUXA_S3_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datae => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datad => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datac => \GRFPU0.GRFPU_X0.COMB.SIGN2_1\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3030303ff0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_4961_0\,
datae => \GRFPU0.GRFPU_X0.CCV_1_SQMUXA_S2_0\,
datad => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_10_1_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3030303ff0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_10_1_IV_0\(1),
dataf => \GRFPU0.GRFPU_X0.N_4961_0\,
datae => \GRFPU0.GRFPU_X0.CCV_0_SQMUXA_S1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_335_0_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_335_0_A2_1_0\(0),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc00ceaae")
port map (
combout => \GRFPU0.GRFPU_X0.N_19496\,
dataf => \GRFPU0.GRFPU_X0.N_19517\,
datae => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datad => \GRFPU0.GRFPU_X0.N_51_I\,
datac => \GRFPU0.GRFPU_X0.N_77_I\,
datab => \GRFPU0.GRFPU_X0.G_672_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_22111_1\,
dataf => N_119,
datae => N_120,
datad => N_121,
datac => N_174900,
datab => N_118);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A3_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0c000000000000")
port map (
combout => \GRFPC0.N_303\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \FPI.FLOP_0\(1),
datac => \GRFPC0.V.STDATA_14\(14),
datab => \FPI.FLOP_0\(6));
\GRFPU0_SQRTROM0_DATA_1_6_0__M80\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff33ff3fcc33cc")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_81\,
dataf => N_124803,
datae => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_2\,
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_NXX_1_I_A2_19_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_14\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_16\,
datae => \GRFPU0.GRFPU_X0.NXX_1_I_A2_12\,
datad => \GRFPU0.GRFPU_X0.NXX_1_I_A2_9\,
datac => \GRFPU0.GRFPU_X0.NXX_1_I_A2_8\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0ace")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
datad => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.MULO.MRES\(94),
datab => N_174945,
dataa => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_21176\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.N_20995\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_21174\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.N_20995\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPC0.N_107\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.N_21703_2\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_D_LDLCK_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff08f80")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0\,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX_250\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1));
\GRFPU0_SQRTROM0_DATA_1_6_0__M93\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3c3c0c3c3c3ccc")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_94\,
dataf => N_124803,
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00cc00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(25),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => \GRFPU0.GRFPU_X0.N_21036\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00cc00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(27),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.N_21036\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00cc00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(28),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => \GRFPU0.GRFPU_X0.N_21036\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00cc00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_0\(33),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.N_21036\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\,
datae => \GRFPU0.GRFPU_X0.N_4378\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.N_21036\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_IV_0_A2_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000fc00fc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_21169\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_A2_13_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffcc0c0ccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_21034\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.N_4369\,
datab => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_IV_0_A2_5_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cf0fcf0fcf0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_21179\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_2_0_TZ_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f0f3f0f3f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_0\(26),
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcfcfc00f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(16),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcfcfc00f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(29),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcfcfc00f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(30),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcfcfc00f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(9),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f0c0f0c0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(16),
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f0c0f0c0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(29),
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f0c0f0c0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(30),
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c00cc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_268\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.N_4369\,
datab => \GRFPU0.MULO.DRES_1\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_4_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c00cc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_264\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.N_4369\,
datab => \GRFPU0.MULO.DRES_1\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_5_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c00cc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_265\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datac => \GRFPU0.GRFPU_X0.N_4369\,
datab => \GRFPU0.MULO.DRES_1\(89));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00cfcfcfcfcfcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(19));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00cfcfcfcfcfcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_16__G3_0_1549_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccffccffccff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccffccffccff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00cfcfcfcfcfcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_7__G3_0_1445_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
GRFPU0_GRFPU_X0_VITER_ND_I_3_SQMUXA_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0f0f000c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.N_19404_I\);
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIGM4U1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20333_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(45),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(45),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(45),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(42));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_8_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000303300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19832\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPC0_FIFO_INST_0_RNIK0I73_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.N_250\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.N_25522_2\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_21543\,
dataf => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.N_21556\,
dataf => \GRFPC0.N_20995\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_23_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_23_IV\(0),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16),
datab => N_174891);
\GRFPC0_FIFO_INST_0_RNIK0I73_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.N_24088\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
\GRFPC0_WR_RREG_EXCT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0fc303030")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_1__G2\,
dataf => \GRFPC0.N_65_0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.MEM.RREG.EXCT\(1),
datab => N_63);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(1),
dataf => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.R.FSR.TEM\(1),
datac => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.WR2.RREG.RESV_1_0\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPC0_MEM_RREG_EXCT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0f0f0f0")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_1__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.EX.RREG.EXCT\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_602_0_IV_I_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23243\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD\,
datad => N_201,
datac => N_198,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\);
\GRFPC0_D_STLCK_RNO_3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23240\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => N_201,
datac => N_198,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\);
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL1_I_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_17377\,
dataf => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2429_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2\,
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25192\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.N_24981\,
datab => \GRFPC0.N_25384\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_25184\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.N_25091\,
datab => \GRFPC0.N_25384\);
\GRFPU0_GRFPU_X0_ITER_EXPOP_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aeaafeaaa2aa02aa")
port map (
combout => N_91846,
dataf => \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
GRFPC0_FP_PIPELINE_6_STDEP_256_SEL0_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_21710\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.N_21703_2\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_10_STDEP_416_SEL0_0_I_O2_1_1_RNITQCP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcff")
port map (
combout => \GRFPC0.N_22439\,
dataf => \GRFPC0.N_21703_2\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.N_78_I_I_2\);
\GRFPC0_D_STLCK_RNO_7_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0c0f0")
port map (
combout => \GRFPC0.N_21409\,
dataf => \GRFPC0.N_21353\,
datae => \GRFPC0.N_21336\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RDD_2\,
datab => \GRFPC0.N_78_I_I_2\);
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_2_RNIRF9N2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.N_21423\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21336\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_2\);
\GRFPU0_GRFPU_X0_L1_0_5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10409\,
dataf => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.TZI2\(0),
datad => \GRFPU0.GRFPU_X0.TZI2\(1),
datac => \GRFPU0.GRFPU_X0.L1_0_5_1\(3));
GRFPC0_STDDEP_0_SQMUXA_96_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_96\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22972_I\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_EX_CTRL_CCWR_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4000000000000000")
port map (
combout => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_8\,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_4\,
datad => N_50358,
datac => \FPI.START_1\,
datab => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_3\,
dataa => \GRFPC0.RFA2.RS2DEP\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25706\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_24554\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0cc00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(0),
dataf => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\(0),
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.N_24753\,
dataf => \GRFPC0.N_24798\,
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_O2_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datac => \GRFPC0.N_24867\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
GRFPU0_GRFPU_X0_COMB_VST3_REG_33_C7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => N_36040,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_VST3_REG_33_SUM7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffea00")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375\(0),
dataf => \GRFPC0.N_23617\,
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.N_23588\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2\,
dataa => \GRFPC0.N_23639\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff000ff0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_19432\,
datae => \GRFPU0.GRFPU_X0.N_5193\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0c0cff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(38),
dataf => \GRFPU0.MULO.MRES\(98),
datae => \GRFPU0.GRFPU_X0.N_19432\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(19));
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL0_0_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.N_21472\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.N_21703_2\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_10_STDEP_416_SEL0_0_I_O2_1_1_RNI93RK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_21981\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.N_21703_2\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_0_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0300fcff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17783\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\(63),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\(63),
datad => \GRFPU0.GRFPU_X0.N_18396\,
datac => \GRFPU0.GRFPU_X0.N_4205\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5));
GRFPU0_GRFPU_X0_IEXC_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f0c0cff0fcccc")
port map (
combout => \GRFPU0.GRFPU_X0.IEXC_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC25_I\,
datae => \GRFPU0.GRFPU_X0.N_6453\,
datad => \GRFPU0.GRFPU_X0.N_6328\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00cfffcf")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_4\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.C\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19196\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.C\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPC0_D_STDLCK_RNO_7_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_4\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_2\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_4_STDEP_176_SEL0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL0\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_4_STDEP_176_SEL1_I_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_17422\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.N_78_I_I_2\);
\GRFPC0_D_LDLCK_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00000000")
port map (
combout => \GRFPC0.N_22497\,
dataf => \GRFPC0.N_21749\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22858\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FIFO_INST_RNINMCL2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffffff")
port map (
combout => \GRFPC0.N_22457\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FIFO.INST_1_0\(19),
datac => \GRFPC0.FIFO.INST_1_0\(25));
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1744_REGDEPX_RNI1MLL2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_21386\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_DEP_2_IV_0_O4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffff3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_2_I\(1),
dataf => \GRFPC0.N_22858\,
datae => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1\(27),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_22920\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.STDDEP_0_SQMUXA_106_I_I_A2_0_A4_1\,
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => \GRFPC0.N_23412\,
dataf => \GRFPC0.N_150\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_23066\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_0_0\(1),
datab => \GRFPC0.FIFO.INST_1\(25));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN391_REGDEPX_0_A2_0_RNIQKKS1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_92\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datae => \GRFPC0.N_24422\,
datad => \GRFPC0.FIFO.INST_0_0\(19),
datac => \GRFPC0.FIFO.INST_0_0\(29),
datab => \GRFPC0.FIFO.INST_0_0\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25777\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datad => \GRFPC0.N_25756\,
datac => \GRFPC0.N_268\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00003fff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(60));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25420\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_24327\,
datad => \GRFPC0.N_25757\,
datac => \GRFPC0.N_268\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_EX_RREG_EXCT_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f000f0f0f0f")
port map (
combout => N_29893,
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datac => N_63);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00ff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(0),
dataf => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.R.FSR.TEM\(0),
datac => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(0));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfff0ccccffff")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.WR2.RREG.RESV_1_0\,
datad => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datab => \GRFPC0.WR2.RREG.EXCT\(0));
\GRFPC0_MEM_RREG_EXCT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffcccccccc")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_0__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datab => \GRFPC0.EX.RREG.EXCT\(0));
GRFPU0_GRFPU_X0_COMB_VST2_EXC56_RNI604B1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33333300f0f0f000")
port map (
combout => N_45083,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.N_4313\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21185\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352\,
datad => \GRFPU0.GRFPU_X0.N_4227\,
datac => \GRFPU0.GRFPU_X0.N_4285\,
datab => \GRFPU0.GRFPU_X0.N_4284\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc000fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20478\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_4285\,
datac => \GRFPU0.GRFPU_X0.N_4284\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_VST2_ADD_1_1_U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0f00f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\,
dataf => \GRFPU0.GRFPU_X0.N_4285\,
datae => \GRFPU0.GRFPU_X0.N_4284\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
GRFPU0_GRFPU_X0_COMB_VST2_REG36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
dataf => \GRFPU0.GRFPU_X0.N_4285\,
datae => \GRFPU0.GRFPU_X0.N_4284\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\);
GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_I_O2_I_A3_0_0_A2_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0fffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21039\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_A2_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccc000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20849\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_4285\,
datac => \GRFPU0.GRFPU_X0.N_4284\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G5\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21058\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11217\,
dataf => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_3\,
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\,
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\,
datae => \GRFPU0.GRFPU_X0.UN1_VST2.REG108\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.N_4285\,
datab => \GRFPU0.GRFPU_X0.N_4284\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIVAC21_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_4285\,
datae => \GRFPU0.GRFPU_X0.N_4284\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21439_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(34),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(31));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_9_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_9_1\(0),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16),
datab => \FPI.FLOP\(6));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2357_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
\GRFPC0_FP_PIPELINE_14_1_REGDEPX_260_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_260\(1),
dataf => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(1),
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datad => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX_1\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24841\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_1\,
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_DIV_RESULT_0_0_32__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(32),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPC0.DIV.RESULT_0_0_32__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_32__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(32),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(29));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24367\,
dataf => N_174896,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
datad => \GRFPC0.N_23613_I_0\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff333f")
port map (
combout => \GRFPU0.GRFPU_X0.N_219\,
dataf => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\,
datae => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_5\,
datad => \FPI.FLOP_0\(1),
datac => \FPI.FLOP\(0),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc00000c0c")
port map (
combout => N_138130,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.DRES_1\(98),
datac => \GRFPU0.MULO.DRES_1S\(97),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc00000c0c")
port map (
combout => N_138139,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000c0c0")
port map (
combout => N_138115,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cff000000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20891_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(40),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_5\(40),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc00000c0c")
port map (
combout => N_138122,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.DRES_1\(101),
datac => \GRFPU0.MULO.DRES_1S\(100),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000000cc")
port map (
combout => N_138131,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003030000000f0")
port map (
combout => N_138123,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(100),
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12),
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000c0c0")
port map (
combout => N_138094,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.DRES_1S\(118),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0c00000cc00")
port map (
combout => N_138111,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0c00000cc00")
port map (
combout => N_138119,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000c0c0")
port map (
combout => N_138095,
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16306\,
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(101),
datad => \GRFPU0.MULO.DRES_1S\(100),
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
GRFPU0_GRFPU_X0_UN1_VITER_FLUSH0_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccc000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6498\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF_0\,
datab => \GRFPU0.GRFPU_X0.ITER.NORM\);
\GRFPU0_GRFPU_X0_RES_1_6_I_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21430_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(38));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff800080ff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_278\(1),
datae => \GRFPC0.N_23649\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datac => \GRFPC0.N_24554\,
datab => \GRFPC0.N_25565\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(13),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(34),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(44),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(50),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(51),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccfcccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(54),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_72\,
datae => \GRFPU0.GRFPU_X0.N_4373\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccfcccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(56),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_91\,
datae => \GRFPU0.GRFPU_X0.N_4373\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(8),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(12),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(22),
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
GRFPU0_GRFPU_X0_NXX_1_I_A2_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_21\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_14\,
datae => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19\,
datad => \GRFPU0.GRFPU_X0.NXX_1_36\,
datac => \GRFPU0.GRFPU_X0.NXX_1_I_A2_10\,
datab => \GRFPU0.GRFPU_X0.NXX_1_39\,
dataa => \GRFPU0.GRFPU_X0.NXX_1_I_A2_7\);
\GRFPC0_EX_CTRL_VCNT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330f330f330f0000")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
dataf => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
datad => \GRFPC0.FIFO.RD_1_0\(0),
datac => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_1\(0));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_TZ_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffbfff00ff00ff")
port map (
combout => \GRFPC0.N_25259_TZ_TZ\,
dataf => \GRFPC0.N_25276\,
datae => \GRFPC0.N_25326\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datab => \GRFPC0.N_24299_1\,
dataa => \GRFPC0.N_23809\);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_80\,
dataf => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_1\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_23719\,
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16),
datab => \FPI.FLOP_0\(6));
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.N_6100\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25593\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_23584\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.N_252\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_310_0_A3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25529\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.N_25553\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff7d5f3c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(25),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(85),
dataa => \GRFPU0.MULO.MRES\(86));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_2\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25217_1\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\(1),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_207\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_234_1\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.N_23587\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccfaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(55),
datae => \GRFPU0.MULO.MRES\(115),
datad => \GRFPU0.MULO.MRES\(116),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\,
dataa => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff3f00000000")
port map (
combout => \GRFPC0.N_21949\,
dataf => N_38025,
datae => \GRFPC0.N_21474\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_3\(33),
datad => \GRFPU0.GRFPU_X0.N_19335\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_RNDBIT_4_RNI118U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000300fc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5299_I_M\,
dataf => \GRFPU0.GRFPU_X0.N_19502_0\,
datae => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff300000000")
port map (
combout => N_52964,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(46),
dataf => \GRFPU0.GRFPU_X0.N_16259\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16311\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_0_A2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19524\,
dataf => \GRFPU0.GRFPU_X0.N_19504\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_19503\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(28),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(28),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(18),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(24),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(24),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(25),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(23),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(19),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(19),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(44),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_16257\,
datad => \GRFPU0.GRFPU_X0.N_16309\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c0c0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(47),
dataf => \GRFPU0.GRFPU_X0.N_16260\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16312\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000c0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_16304\,
datad => \GRFPU0.GRFPU_X0.N_16252\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(52),
dataf => \GRFPU0.GRFPU_X0.N_16265\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16317\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(11),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(22),
dataf => \GRFPU0.GRFPU_X0.N_20620\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(22),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(22),
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12));
GRFPC0_FP_PIPELINE_1_REGDEP132: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000082410000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
dataf => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_2\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP132_0\,
datad => RFI2_RD2ADDRZ(3),
datac => RFI2_RD2ADDRZ(2),
datab => \GRFPC0.WR.CTRL.RD\(3),
dataa => \GRFPC0.WR.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIP1T52_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_1\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_VST4_SEL3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPC0_FP_PIPELINE_1_WRENX10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000008400000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10\,
dataf => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
datae => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_2\,
datac => RFI2_RD2ADDRZ(0),
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfffffff")
port map (
combout => \GRFPC0.N_21477\,
dataf => \GRFPC0.N_20995\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_11_STDEP_456_3_I_O3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_21460\,
dataf => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RDD_2\);
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36187,
dataf => N_36167,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
datad => N_36167,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(56));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36167,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36167,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17605\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => N_36167,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36182,
dataf => N_36167,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPC0_D_STDLCK_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30000000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_0\,
dataf => \GRFPC0.N_22807\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
\GRFPC0_D_STLCK_RNO_4_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22847\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
datac => N_199,
datab => N_198);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000030000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_7781_6\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_A3_0_0\(0),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16),
datab => \FPI.FLOP_0\(6));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_36129,
dataf => N_36109,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3300000")
port map (
combout => \GRFPC0.N_165_1\,
dataf => N_52826,
datae => \GRFPC0.N_22443\,
datad => \GRFPC0.FIFO.RD_4\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3300000")
port map (
combout => \GRFPC0.N_91_1\,
dataf => N_52826,
datae => \GRFPC0.N_22310\,
datad => \GRFPC0.FIFO.RD_4\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3300000")
port map (
combout => \GRFPC0.N_89_1\,
dataf => N_52826,
datae => N_174901,
datad => \GRFPC0.FIFO.RD_4\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33f3f3ff")
port map (
combout => \GRFPC0.N_22082\,
dataf => N_52826,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.FIFO.INST_1\(25));
GRFPC0_STDDEP_0_SQMUXA_87_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f30030")
port map (
combout => \GRFPC0.N_21055_I\,
dataf => N_52826,
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR\(0));
\GRFPU0_GRFPU_X0_VST3_REG_37_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc33000a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPC0_FP_PIPELINE_2_STDEP_96_SEL0_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.N_21182\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_2_STDEP_96_SEL1_I_0_A2_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_17250\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.N_78_I_I_2\);
GRFPU0_GRFPU_X0_VST2_EXC_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_2_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_4997\,
datae => \GRFPU0.GRFPU_X0.REST_1_1\(2),
datad => \GRFPU0.GRFPU_X0.N_4325\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
GRFPC0_FP_PIPELINE_UN3_FIFO_CLR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000300")
port map (
combout => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
dataf => \GRFPC0.FIFO_INC_5_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datad => N_50667_1,
datac => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_4\,
datab => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\);
\GRFPU0_GRFPU_X0_VST3_REG_37_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc33000a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000555d00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_0\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_O2_0_0\(1),
datac => \GRFPU0.GRFPU_X0.UN8_C\(10),
datab => \GRFPU0.GRFPU_X0.UN8_C\(9),
dataa => \GRFPU0.GRFPU_X0.N_26\);
GRFPU0_GRFPU_X0_UN1_QP1_SP_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.DRES_1\(98),
datab => \GRFPU0.MULO.DRES_1S\(97));
GRFPC0_FP_PIPELINE_0_WR2EN2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2_2\,
dataf => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.WR2.CTRL.RD\(0),
datac => \GRFPC0.WR2.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0ccc0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_228_1\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0ccc0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_21000_1\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c0000000ccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_19817\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_8_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000003ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19837\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => \GRFPU0.GRFPU_X0.N_6453\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
dataf => \GRFPU0.GRFPU_X0.N_18161\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5),
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(59),
dataf => \GRFPU0.GRFPU_X0.N_18163\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(7),
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0300ccff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(60),
dataf => \GRFPU0.GRFPU_X0.EXP_11\(8),
datae => \GRFPU0.GRFPU_X0.N_18099\,
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.N_6328\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_24653\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0),
datab => \GRFPC0.N_24633\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffcffffffffff")
port map (
combout => \GRFPC0.N_23403\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.N_24433\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_A3_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\(0),
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FIFO.INST_0_0\(19),
datad => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033000000030000")
port map (
combout => \GRFPC0.N_22622\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.N_22620\,
datad => \GRFPC0.FIFO.INST_0_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0_0\(29));
GRFPC0_FP_PIPELINE_0_MEMEN2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.MEMEN2\,
dataf => \GRFPC0.FP_PIPELINE.0.MEMEN2_0_A2_1\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datad => \GRFPC0.N_23611\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21426_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(49));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_24517\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.N_23726\,
datad => \GRFPC0.DIVI_0_SQMUXA_5\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_0_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000f00")
port map (
combout => \GRFPC0.N_23728\,
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_24_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fffffff3")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\(0),
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.N_24095\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_0_RNIMT611_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_2\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.N_25703_3\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\(1),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_RNIC2N01_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_7\,
dataf => \GRFPC0.N_24644\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.N_257\,
datab => \GRFPC0.N_25465\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25412\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.N_257\,
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25425\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.N_257\,
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_0_STDEP_242_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000f000f000")
port map (
combout => \GRFPC0.N_21372\,
dataf => N_128,
datae => \GRFPC0.N_22782\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STLCK_RNO_8_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPC0.N_21382\,
dataf => N_128,
datae => \GRFPC0.N_22782\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_0_0\(7),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => N_122,
datad => \GRFPC0.N_22782\,
datac => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc000000000000")
port map (
combout => \GRFPC0.N_22467\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6),
datad => N_122,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc000000")
port map (
combout => \GRFPC0.N_20860\,
dataf => N_122,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8),
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(31),
dataf => N_122,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.N_22782\,
datac => N_128);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I_RNISG6L: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => \GRFPC0.N_22485_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_22782\,
datad => N_128);
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_22560\,
dataf => N_174896,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_O2_0\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_22565\,
dataf => N_174896,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datad => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_O2_0\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff00f0")
port map (
combout => \GRFPC0.N_24205\,
dataf => N_50724,
datae => \FPI.FLOP_0\(1),
datad => \GRFPC0.V.STDATA_14\(1),
datac => N_50656_0);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_21921\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0003000000000")
port map (
combout => \GRFPC0.N_23030\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_0_0\(1),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_8_STDEP_350_0_IV_I_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_22226\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_202_0_IV_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_22689\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_D_LDLCK_RNO_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000fff3f3f3")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_1\,
dataf => \GRFPC0.N_22179\,
datae => \GRFPC0.N_22718\,
datad => \GRFPC0.N_112\,
datac => \GRFPC0.N_22858\,
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_163\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3304_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffff00000000")
port map (
combout => \GRFPC0.N_22835\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_87\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22858\,
datac => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_A5_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff3fff3ff0000")
port map (
combout => \GRFPC0.N_22757\,
dataf => \GRFPC0.N_22721\,
datae => \GRFPC0.STDDEP_0_SQMUXA_90\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22858\,
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_22495\,
dataf => \GRFPC0.N_21749\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_23452\,
dataf => \GRFPC0.N_150\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_4_1_REGDEPX_80_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f000300")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.REGDEPX_80\(0),
dataf => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_78\(0),
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_5_STDEP_238_0_IV_I_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_22614\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0003000000000")
port map (
combout => \GRFPC0.N_22912\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.STDDEP_0_SQMUXA_106_I_I_A2_0_A4_1\,
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A4_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25612\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_23788\,
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A4_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25620\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_23788\,
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPU0_GRFPU_X0_RES_1_6_I_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21427_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21440_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(37),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(37),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21441_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(40),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(37));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25715\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23584\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.N_25553\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_202_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.N_17057\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => N_174895,
datad => N_131,
datac => N_132,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4));
GRFPC0_WR2_EXC_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => \GRFPC0.WR2.EXC_0_0_G0_0_A3_1\,
dataf => \GRFPC0.WR2.CTRL.SEQERR\,
datae => \GRFPC0.WR2.EXC\,
datad => N_61,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\,
datab => N_484);
\GRFPC0_RFAREG_R_STATE_4_M0_RNIL05Q1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f3f00003f00")
port map (
combout => \GRFPC0.R.STATE_0_0_1__G2\,
dataf => \GRFPC0.RFAREG.R.STATE_4_M0\(1),
datae => N_50358,
datad => N_65,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\,
datab => N_484);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.N_23717\,
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0cae")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(52),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(52),
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.MULO.MRES\(113),
datab => N_174945,
dataa => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPC0_D_STLCK_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff4f4f4")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_2\,
dataf => \GRFPC0.N_22721\,
datae => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60_0_A5_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.N_22778\,
datab => \GRFPC0.N_20852\,
dataa => \GRFPC0.N_22719\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6151_REGDEPX2_0_A2_0_A2_RNI3C7M1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000f000f000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_3\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_25708_2\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5973_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6151_REGDEPX2\);
\GRFPC0_FP_PIPELINE_1_0_REGDEPX_23_I_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000c000000")
port map (
combout => \GRFPC0.N_24409\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.N_24422\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24807\,
dataf => \GRFPC0.N_25747_I\,
datae => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.N_25553\);
\GRFPU0_GRFPU_X0_RES_1_6_I_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8caf000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_67_I_0\,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54),
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54),
datad => \GRFPU0.GRFPU_X0.N_21448\,
datac => \GRFPU0.GRFPU_X0.N_431\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeac0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(44),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(44),
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.MULO.MRES\(105),
datab => N_174945,
dataa => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O3_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.N_22289\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_12_STDEP_496_SEL0_0_I_O2_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fffffff")
port map (
combout => \GRFPC0.N_23398\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_17302\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfffffff")
port map (
combout => \GRFPC0.N_21178\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_1\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4864_REGDEPX_0_A3_1_RNITPDN1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23148\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22972_I\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4864_REGDEPX_0_A3_1_RNITPDN1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_21612\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22972_I\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_455_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.N_24221\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_3_0_A3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.N_24252\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_92_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22737_2\,
dataf => N_174895,
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_22573_1\,
dataf => N_122,
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_167_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22466_2\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22473_2\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1),
datae => N_124,
datad => N_126,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_138);
\GRFPU0_GRFPU_X0_L2_0_5_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030303000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(2),
dataf => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_1\,
datad => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_1\,
datab => \GRFPU0.GRFPU_X0.L1_0_5_1\(3));
GRFPU0_GRFPU_X0_UN43_BCO_LSB_0_RNIAFGK3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(4),
dataf => \GRFPU0.GRFPU_X0.N_10409\,
datae => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_1\,
datad => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.L2_0_7_0\(4),
datab => \GRFPU0.GRFPU_X0.L2_0_7_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPC0_DIV_RESULT_0_0_39__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(39),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPC0.DIV.RESULT_0_0_39__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_39__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(36));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_25164\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_O2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_0_O2_1_0\(1),
dataf => \GRFPC0.N_25225\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_25164\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datab => \GRFPC0.N_25236\);
\GRFPU0_GRFPU_X0_RES_1_6_I_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21424_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(58),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(58),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc3cf030cc0cc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_218\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_1_0\(0),
datac => \GRFPC0.N_251\,
datab => \GRFPC0.DIV.RS1V\);
GRFPU0_GRFPU_X0_COMB_UN7_G_SP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfcffff0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_6863\,
dataf => \GRFPU0.GRFPU_X0.N_11478\,
datae => \GRFPU0.GRFPU_X0.COMB.S_SP_2\,
datad => \GRFPU0.GRFPU_X0.N_15702\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => N_31236,
datad => \GRFPU0.GRFPU_X0.N_15702\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffffffccf0f0f0")
port map (
combout => \GRFPC0.N_21631\,
dataf => \GRFPC0.N_21620\,
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RDD_0\,
datab => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000c0000000")
port map (
combout => \GRFPC0.N_24662\,
dataf => \GRFPC0.N_24701\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_A3_4_0\(1),
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_42_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_42\(1),
dataf => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_40\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.N_24438\,
datab => \GRFPC0.N_24352\);
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIIPIV1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_5_0\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.N_22839\,
dataf => \GRFPC0.N_21997\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f00000000")
port map (
combout => \GRFPC0.N_23195_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => N_122,
datad => \GRFPC0.N_22782\,
datac => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f3000000000000")
port map (
combout => \GRFPC0.N_22461\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6),
datad => N_122,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f30000")
port map (
combout => \GRFPC0.N_22039\,
dataf => N_122,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.N_21998\,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPC0.N_22477\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6),
datad => \GRFPC0.N_22782\,
datac => N_128);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_22942\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datac => \GRFPC0.N_22782\,
datab => N_128);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I_RNISG6L_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_22942_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_22782\,
datad => N_128);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_23423\,
dataf => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4),
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_12_REGDEPX_230_0_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00ff")
port map (
combout => \GRFPC0.N_22231_1\,
dataf => N_122,
datae => \GRFPC0.N_22782\,
datad => N_128);
\GRFPC0_FP_PIPELINE_4_REGDEPX_86_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00f30000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_86\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datad => N_122,
datac => \GRFPC0.N_22782\,
datab => N_128);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_22325_2\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.N_22782\,
datad => N_128);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25887\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.N_25657\,
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_O2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0ccfffff")
port map (
combout => \GRFPC0.N_22819\,
dataf => N_52826,
datae => \GRFPC0.FIFO.INST_0\(25),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_I_A2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0fc0000")
port map (
combout => \GRFPC0.N_22743_1\,
dataf => N_52826,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_276_0_0_A4_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c0fc")
port map (
combout => \GRFPC0.N_24606_2\,
dataf => N_52826,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0fc0000")
port map (
combout => \GRFPC0.N_22749_1\,
dataf => N_52826,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datad => \GRFPC0.FIFO.RD_4\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
GRFPC0_STDDEP_0_SQMUXA_117_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c0fc")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_117_1\,
dataf => N_52826,
datae => \GRFPC0.N_23401\,
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21443_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(36),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(36),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33));
\GRFPU0_GRFPU_X0_RES_1_6_I_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_63_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(47),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(47),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(44));
\GRFPU0_GRFPU_X0_RES_1_6_I_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21428_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(46),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(43));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI50U62_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_96\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.N_4369\,
datad => \GRFPU0.GRFPU_X0.N_26\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_EXC36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6995\,
dataf => \GRFPU0.GRFPU_X0.N_6661\,
datae => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
datad => \GRFPU0.GRFPU_X0.COMB.BIAS15_1\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_BIAS15_1_RNIBO7D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
datae => \GRFPU0.GRFPU_X0.COMB.BIAS15_1\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_RES_1_6_I_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21423_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(55),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(55),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(52));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000ffff0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.N_15701\,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30));
\GRFPU0_GRFPU_X0_RES_1_6_I_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21429_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(49),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(49),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(46));
GRFPC0_FP_PIPELINE_0_UN1_FPO_4_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc33cc0ff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_3\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPC0.EX.CTRL.ID\(3),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(3),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(3));
GRFPU0_GRFPU_X0_ST4_RDY_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f333f333f000c")
port map (
combout => \GRFPU0.GRFPU_X0.N_11225\,
dataf => \GRFPU0.GRFPU_X0.N_6485\,
datae => \GRFPU0.GRFPU_X0.N_6484\,
datad => \GRFPU0.GRFPU_X0.N_6453\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc33cc0ff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_2\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPC0.EX.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc33cc0ff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_1\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(1),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(1));
GRFPC0_FP_PIPELINE_0_UN1_FPO_1_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff00ff03c3c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_1_5\,
dataf => \GRFPU0.GRFPU_X0.N_6453\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(5));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25785\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datad => \GRFPC0.N_25092\,
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25190\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datad => \GRFPC0.N_25234\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(3));
GRFPU0_GRFPU_X0_UN1_VST4_EXC_0_SQMUXA_1_TZ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff00fcfc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7913_TZ\,
dataf => \GRFPU0.GRFPU_X0.N_6863\,
datae => \GRFPU0.GRFPU_X0.N_9851\,
datad => \GRFPU0.GRFPU_X0.N_9852\,
datac => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\,
datab => \GRFPU0.GRFPU_X0.COMB.G_DP_1\);
\GRFPU0_GRFPU_X0_L1_6_1_3_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00330033")
port map (
combout => \GRFPU0.GRFPU_X0.N_3576\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(119),
datad => \GRFPU0.MULO.DRES_1S\(118),
datac => \GRFPU0.MULO.DRES_1\(118),
datab => \GRFPU0.MULO.DRES_1S\(117));
GRFPU0_GRFPU_X0_UN133_BCO_LSB_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(118),
datac => \GRFPU0.MULO.DRES_1S\(117));
\GRFPC0_D_STDLCK_RNO_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_0\,
dataf => \GRFPC0.N_22077\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_270,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\,
datab => N_267);
\GRFPC0_D_STLCK_RNO_4_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_22115\,
dataf => \GRFPC0.N_23044\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_270,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\,
datab => N_267);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffc0000ffcc")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2_0\(1),
dataf => \GRFPC0.N_24193\,
datae => \GRFPC0.N_24221\,
datad => \FPI.FLOP_0\(1),
datac => N_50656_0,
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_0_0_A2_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.N_23726\,
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000c000")
port map (
combout => \GRFPC0.N_24122\,
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_25330\,
dataf => \GRFPC0.N_25117\,
datae => \GRFPC0.N_25756\,
datad => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPU0_GRFPU_X0_L2_1_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffffffca000000")
port map (
combout => N_124882,
dataf => N_124866,
datae => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.L1_2_1\(3),
datac => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.N_3373\,
dataa => \GRFPU0.GRFPU_X0.N_3473\);
\GRFPU0_GRFPU_X0_RES_1_6_I_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21442_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(33),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(33),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(30));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_1_1\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.N_130\,
datad => N_174897,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_RES_1_6_I_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19903_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(59),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(59),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(56));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24287\,
dataf => \GRFPC0.N_21911_3\,
datae => \GRFPC0.N_24279\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
datab => N_174900);
GRFPC0_OP1_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300030003ff")
port map (
combout => \GRFPC0.OP1_4\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => \GRFPC0.RFA.RS1D\,
datad => \GRFPC0.RFA.ST_0\,
datac => N_192,
datab => N_197);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_1_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_1_0\,
dataf => \FPI.FLOP_1\(1),
datae => \FPI.FLOP\(5),
datad => \FPI.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2));
GRFPC0_FP_PIPELINE_1_WR2EN10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000008400000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
dataf => \GRFPC0.FP_PIPELINE.1.WR2EN10_1\,
datae => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD_2_3\,
datac => RFI2_RD2ADDRZ(3),
datab => \GRFPC0.WR2.CTRL.RDWR\,
dataa => \GRFPC0.WR2.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0010")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(0),
dataf => \GRFPC0.N_25594\,
datae => \GRFPC0.N_25887\,
datad => \GRFPC0.N_25589\,
datac => \GRFPC0.N_23788\,
datab => \GRFPC0.MEM.CTRL.INST\(28),
dataa => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPU0_GRFPU_X0_RES_1_6_I_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21433_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(57),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(54));
\GRFPC0_FP_PIPELINE_14_REGDEPX_266_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_266\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1),
datae => N_122,
datad => N_174895,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.N_21997\);
\GRFPU0_GRFPU_X0_RES_1_6_I_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21425_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(61),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(61),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(61),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(58));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefeeeffff0000")
port map (
combout => N_124846,
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => N_124823,
datad => \GRFPU0.GRFPU_X0.N_3633\,
datac => \GRFPU0.GRFPU_X0.N_19491\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(13));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21437_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(53),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(53),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(50));
\GRFPU0_GRFPU_X0_RES_1_6_I_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21436_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(50),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(50),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(47));
GRFPU0_GRFPU_X0_ITER_NX_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.DRES_S\(66));
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNIF9HG1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f00fcccccc33")
port map (
combout => \GRFPU0.GRFPU_X0.N_5299\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.DRES_S\(66));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25779\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datad => \GRFPC0.N_25757\,
datac => \GRFPC0.N_25222_1\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_D_STLCK_RNO_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_38_I_M_I_A3_9_1\(1),
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_FP_PIPELINE_2_REGDEPX_50_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_50\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX_48\(1),
datae => N_174895,
datad => N_122,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datab => \GRFPC0.N_21997\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_10_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_4\(1),
dataf => \GRFPC0.N_23216\,
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.N_24791\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datab => \GRFPC0.N_24795_2\,
dataa => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPC0_OP2_4_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19785\,
dataf => N_50656_0,
datae => \GRFPC0.RFA.RS2D\,
datad => N_750,
datac => N_686);
\GRFPC0_OP2_4_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19796\,
dataf => N_50656_0,
datae => \GRFPC0.RFA.RS2D\,
datad => N_761,
datac => N_697);
\GRFPC0_OP2_4_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19797\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_762,
datac => N_698);
\GRFPC0_OP2_4_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19799\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_764,
datac => N_700);
\GRFPC0_OP2_4_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19800\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_765,
datac => N_701);
\GRFPC0_OP2_4_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19802\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_767,
datac => N_703);
\GRFPC0_OP2_4_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19803\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_768,
datac => N_704);
\GRFPC0_OP2_4_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19804\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_769,
datac => N_705);
\GRFPC0_OP2_4_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19806\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_771,
datac => N_707);
\GRFPC0_OP2_4_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19807\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_772,
datac => N_708);
\GRFPC0_OP2_4_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19808\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_773,
datac => N_709);
\GRFPC0_OP2_4_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19809\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_774,
datac => N_710);
\GRFPC0_OP2_4_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19810\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_775,
datac => N_711);
\GRFPC0_OP2_4_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19811\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_776,
datac => N_712);
\GRFPC0_OP2_4_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19812\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_777,
datac => N_713);
\GRFPC0_OP2_4_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19814\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_779,
datac => N_715);
\GRFPC0_OP2_I_M2_4_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_23993\,
dataf => N_50656,
datae => \GRFPC0.RFA.RS2D\,
datad => N_770,
datac => N_706);
GRFPC0_UN1_WRENX2_2_4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000c00300003")
port map (
combout => \GRFPC0.UN1_WRENX2_2_4_1\,
dataf => \GRFPC0.N_23611\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.DIV.RD\(3));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cf000000cc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_21253\,
datad => \GRFPC0.N_21252\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_2\);
\GRFPC0_D_STLCK_RNO_4_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_177\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_2_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffff3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_2_IV\(1),
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_4_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_137\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.N_24433\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A3_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
combout => \GRFPC0.N_21956_1\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A5_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_22735\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19990_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_0\(35),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0_1\(35),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21444_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(48),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(45));
\GRFPC0_FIFO_INST_1_RNIG6PF1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_24087\,
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f300")
port map (
combout => \GRFPC0.N_24688\,
dataf => \GRFPC0.N_23741\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.RDD_2\,
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25432\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_23741\,
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A4_0_0\(1),
dataf => \FPI.FLOP_0\(1),
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => N_50656_0);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0\(1),
dataf => N_50724,
datae => \FPI.FLOP_0\(1),
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datab => N_50656_0);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.N_24123\,
dataf => \FPI.FLOP_0\(1),
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
datab => N_50656_0);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033002000330000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11233\,
dataf => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\,
datad => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_4\,
datac => \GRFPU0.GRFPU_X0.N_4373\,
datab => \GRFPU0.GRFPU_X0.N_4226\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_0_O4_I_I4_I_O4_0_0_I_O4_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3ff0000ffff")
port map (
combout => \GRFPC0.N_23443\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datae => N_128,
datad => N_127,
datac => N_124,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00ffff0000ffff")
port map (
combout => \GRFPC0.N_94\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datae => N_128,
datad => N_127,
datac => N_124,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_I_O2_0_O4_0_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datae => N_127,
datad => N_124,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0_0\,
dataf => N_122,
datae => \GRFPC0.N_23533\,
datad => N_127,
datac => N_124,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0ffc0c0")
port map (
combout => \GRFPC0.N_23479\,
dataf => N_124,
datae => \GRFPC0.N_290\,
datad => N_122,
datac => N_127,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25059\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.N_25090\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_3_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_3_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPU0_GRFPU_X0_RES_1_6_I_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21431_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(44),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(44),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(41));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24977\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.N_23797\,
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23761\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_1\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_0_A2_0\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f330300000000")
port map (
combout => \GRFPC0.N_101\,
dataf => \GRFPC0.N_90\,
datae => \GRFPC0.N_59\,
datad => \GRFPC0.N_56\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeca00000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_0\(1),
dataf => \GRFPC0.N_25432\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => \GRFPC0.N_24696_1\,
datac => \GRFPC0.N_24697_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
GRFPC0_FP_PIPELINE_0_MEMEN2_0_A2_1_0_RNIDN342: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fcffff00000000")
port map (
combout => \GRFPC0.FPUSEL_6_1\(7),
dataf => \GRFPC0.N_21694\,
datae => \GRFPC0.FP_PIPELINE.0.MEMEN2_0_A2_1\,
datad => \GRFPC0.N_23611\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25028\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_25759\,
datad => \GRFPC0.N_25745_I\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25781\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_25759\,
datad => \GRFPC0.N_25223_2\,
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(1));
\GRFPC0_WR_RREG_EXCT_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0fc303030")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_5__G2\,
dataf => \GRFPC0.N_65_0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datac => \GRFPC0.MEM.RREG.EXCT\(5),
datab => N_63);
\GRFPC0_MEM_RREG_EXCT_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0f0f0f0")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_5__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datac => \GRFPC0.EX.RREG.EXCT\(5));
\GRFPC0_DIV_RESULT_0_0_62__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(62),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPC0.DIV.RESULT_0_0_62__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_62__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(62),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(59));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0_2\,
dataf => \GRFPC0.N_20833\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_105\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPC0.N_20832\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_20834\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25512\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25361\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24939\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datad => \GRFPC0.N_25338\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A5_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23217\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25271\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.N_24278\,
datab => \GRFPC0.DIV.RS1V\);
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3304_REGDEPX_1_RNI4OQQ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22179\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_1\,
dataf => \GRFPC0.N_21043\,
datae => \GRFPC0.N_21039\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4302_DEP\,
datac => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24376\,
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A2_7_1\,
dataf => \GRFPC0.N_21029\,
datae => \GRFPC0.N_20974\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A2_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24542_1\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.N_23623\,
datad => \GRFPC0.V.STDATA_14\(19),
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_4_I_O4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_24909\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.V.STDATA_14\(19),
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_A2_2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_302\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.V.STDATA_14\(19),
datad => \GRFPC0.N_23711_LI\,
datac => N_51460,
datab => \GRFPC0.V.STDATA_14\(31));
GRFPC0_EX_CTRL_DIV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.EX.CTRL.DIV_0_0_G1\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.V.STDATA_14\(19),
datad => N_51460,
datac => \GRFPC0.V.STDATA_14\(31),
datab => N_61);
\GRFPU0_GRFPU_X0_RES_1_6_I_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21432_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(51),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(48));
GRFPC0_EX_CTRL_PEND_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaa08008800")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\,
datae => \GRFPC0.VDIV.EXC_1_SQMUXA\,
datad => N_52826,
datac => \GRFPC0.FP_PIPELINE.UN63_HOLDN\,
datab => \GRFPC0.EX.CTRL.PEND\,
dataa => N_52981_2);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff3ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_A2_0\(1),
dataf => \FPI.FLOP_0\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
\GRFPU0_GRFPU_X0_RES_1_6_I_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21435_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(38),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(35));
GRFPC0_V_FSR_CEXC_0_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303030303000")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
dataf => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA_1\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => N_61,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24664\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_24637\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A3_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24671\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.N_24637\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21434_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(60),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(57));
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22865\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_D_STLCK_RNO_3_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_22850\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPU0_GRFPU_X0_RES_1_6_I_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21438_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_21448\,
datae => \GRFPU0.GRFPU_X0.N_431\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(56),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(56),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(53));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M7_4_03_0_G2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff0000c00000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4),
dataf => \GRFPU0.GRFPU_X0.N_20965\,
datae => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3836\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000030000000")
port map (
combout => \GRFPC0.N_23643\,
dataf => \FPI.FLOP_0\(1),
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
datab => N_50656_0);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_424_0_A3_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0_0\(0),
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FIFO_INST_1_RNIG6PF1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.N_24193\,
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_23758\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.WR.CTRL.RS1V\,
datad => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.N_25090\);
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3304_REGDEPX_1_RNI4OQQ1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_55_LI\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_65_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_2\(0),
dataf => N_50724,
datae => \FPI.FLOP_0\(1),
datad => N_50792,
datac => N_50656_0,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_1\);
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL0_0_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_21821\,
dataf => \GRFPC0.N_21046_I\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
\GRFPC0_DIV_RESULT_0_0_42__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(42),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_431_0\,
datad => \GRFPC0.DIV.RESULT_0_0_42__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_42__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(39));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_21128\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.N_20995\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EXP_1_SN_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcc00c000c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.N_6097\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffce0a0a0a")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_5\(0),
dataf => \GRFPC0.N_23758\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.N_25758\,
datac => \GRFPC0.N_25589\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3932_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\);
\GRFPU0_GRFPU_X0_L4_2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4\(3),
datae => \GRFPU0.GRFPU_X0.N_20965\,
datad => \GRFPU0.GRFPU_X0.L1_4_2\(0),
datac => \GRFPU0.GRFPU_X0.L1_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_1\(0));
\GRFPU0_GRFPU_X0_L4_2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00ff00")
port map (
combout => N_124872,
dataf => \GRFPU0.GRFPU_X0.L1_4\(3),
datae => \GRFPU0.GRFPU_X0.N_20965\,
datad => N_124825,
datac => N_124829,
datab => \GRFPU0.GRFPU_X0.N_3873\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A3_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_24297\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25271\,
datad => \GRFPC0.N_24602_1\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(17));
\GRFPC0_D_STLCK_RNO_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff00ff00ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_2\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.D.STLCK_0_0_21__G1_1\,
datac => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3304_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_D_LDLCK_RNO_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22760\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.N_22972_I\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_FP_PIPELINE_15_STDEP_630_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.N_17173\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_23116\,
dataf => \GRFPC0.N_22354\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_STDDEP_0_SQMUXA_87_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_87\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22985\,
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_O2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0f0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15508\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datab => \GRFPU0.GRFPU_X0.N_19404_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(4));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_3_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_3\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(2),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPC0_FP_PIPELINE_0_REGDEPX2_270_1_M9_I_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000eac00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_1_N_11\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270TT_1_N_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datab => \GRFPC0.N_23811_1\,
dataa => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3946_REGDEPX2\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000f0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_46\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_A5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000ccc0")
port map (
combout => \GRFPC0.N_22766\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_20976\,
datad => \GRFPC0.N_46\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_21000\,
dataf => \GRFPC0.N_21029\,
datae => N_38008,
datad => \GRFPC0.N_20976\,
datac => \GRFPC0.N_46\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_260_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_1\(1),
dataf => \GRFPC0.N_25059\,
datae => \GRFPC0.N_25367_I\,
datad => \GRFPC0.N_25058_1\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(21),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(21),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_IV_0_A2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030330033")
port map (
combout => \GRFPU0.GRFPU_X0.N_21152\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.N_19502_0\,
datad => \GRFPU0.GRFPU_X0.N_19403\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(16));
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffffffcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19405\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.N_5437\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_2_RNIEQJJ8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcfffff0fcf0fc")
port map (
combout => N_174933,
dataf => \GRFPU0.GRFPU_X0.N_157\,
datae => N_49622,
datad => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datab => \GRFPU0.GRFPU_X0.N_5437\);
GRFPU0_GRFPU_X0_ITER_V_RNI6KR26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.N_6466\,
datac => \GRFPU0.GRFPU_X0.N_5437\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_ITER_V_4_RNI2N245: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fff0fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5184\,
dataf => \GRFPU0.GRFPU_X0.N_5188\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datad => \GRFPU0.GRFPU_X0.N_5437\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f3f0ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(44),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(104),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fcf00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(36),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPC0_D_STLCK_RNO_3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_23322\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.N_21055_I\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeac0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\(0),
dataf => \GRFPC0.N_25289\,
datae => \GRFPC0.N_25290\,
datad => \GRFPC0.N_25352\,
datac => \GRFPC0.N_25217_1\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffd5c05500")
port map (
combout => \GRFPC0.N_24628\,
dataf => \GRFPC0.N_24707\,
datae => \GRFPC0.N_250\,
datad => \GRFPC0.N_23726\,
datac => N_174892,
datab => \FPI.FLOP_0\(6),
dataa => \GRFPC0.N_23711_LI\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(26),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(26),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_22249\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2904_REGDEPX_2\,
datab => \GRFPC0.N_24372_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffff0c0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(59),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00fff0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(59),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00f0000cc33")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_0\,
dataf => \GRFPU0.GRFPU_X0.N_6466\,
datae => \GRFPC0.WR.CTRL.ID\(7),
datad => \GRFPC0.WR.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00f0000cc33")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_0\,
dataf => \GRFPU0.GRFPU_X0.N_6466\,
datae => \GRFPC0.MEM.CTRL.ID\(7),
datad => \GRFPC0.MEM.CTRL.ID\(0),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(0));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_1\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(22),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47\(51),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_6\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(0),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000030f000003000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(21),
dataf => \GRFPU0.GRFPU_X0.N_20620\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(30),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_I_M_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19502_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
GRFPU0_GRFPU_X0_VITER_STATE_14_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.STATE_14_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.N_5438\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_S_RNIOEQJ1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003ff0000")
port map (
combout => N_108265,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.N_19243_2\,
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.N_4352\,
datab => \GRFPU0.GRFPU_X0.N_4227\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20842\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.N_4227_0\,
datac => \GRFPU0.GRFPU_X0.N_4997\,
datab => \GRFPU0.GRFPU_X0.N_20773\);
GRFPU0_GRFPU_X0_COMB_VST2_REG107_0_RNIA6PE4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20863\,
dataf => \GRFPU0.GRFPU_X0.N_20881\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4352_0\,
datac => \GRFPU0.GRFPU_X0.N_4227_0\);
GRFPU0_GRFPU_X0_COMB_VST2_EXC56_RNIJ8KA2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f3f3f3f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(38),
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352\,
datad => \GRFPU0.GRFPU_X0.N_4227_0\,
datac => \GRFPU0.GRFPU_X0.N_4997\,
datab => \GRFPU0.GRFPU_X0.N_4313\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffffffc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(56),
dataf => \GRFPU0.GRFPU_X0.N_17154\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4352_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_S_RNI862V1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20816_1\,
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_19243_2\,
datac => \GRFPU0.GRFPU_X0.N_4352\);
GRFPU0_GRFPU_X0_COMB_VST2_REG107_0_RNICQ241: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_242\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPC0_D_LDLCK_RNO_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc00000c0c00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
datac => \GRFPC0.N_22111_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(25),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(25),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_21010\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_46\,
datad => \GRFPC0.N_45\,
datac => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_S_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff003fffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19243_2\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4997\,
datad => \GRFPU0.GRFPU_X0.N_4313\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A4_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25617\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.N_25834\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(24),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(24),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_L4_7_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300f300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(4),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datad => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datac => \GRFPU0.GRFPU_X0.N_20965\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\);
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_A3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_23064\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_1\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff080f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_2\(1),
dataf => \GRFPC0.N_25404\,
datae => \GRFPC0.N_25697\,
datad => \GRFPC0.N_25721\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datab => \GRFPC0.N_25722_1\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1));
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_1_RNI6UCU3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030003000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19513_I\,
dataf => \GRFPU0.GRFPU_X0.N_4379\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_O2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00cf03cf0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_19339\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.N_6660\,
datad => \GRFPU0.GRFPU_X0.N_6661\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcffffff0c0f000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(53),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G1\,
datae => \GRFPU0.GRFPU_X0.N_6660\,
datad => \GRFPU0.GRFPU_X0.N_6661\,
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000030f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G4\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.N_6660\,
datac => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(9),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3f0f3300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(27),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.MULO.MRES\(87));
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff3fff3fff0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\,
dataf => \GRFPU0.GRFPU_X0.N_6485\,
datae => \GRFPU0.GRFPU_X0.N_6484\,
datad => \GRFPU0.GRFPU_X0.N_6466\,
datac => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_ST3_RDY_RNI3N556: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4045\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_6485\,
datad => \GRFPU0.GRFPU_X0.N_6484\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_25816\,
dataf => \GRFPC0.N_25388\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25211\,
dataf => \GRFPC0.N_25388\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_170_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_25045\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datae => \GRFPC0.N_25388\,
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0044004000")
port map (
combout => \GRFPC0.N_25186\,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445_0_O2_1_0\(1),
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_24327\,
datab => \GRFPC0.N_24030_2\,
dataa => \GRFPC0.N_25117\);
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_5192\,
dataf => \GRFPU0.GRFPU_X0.N_5299\,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.GRFPU_X0.N_19502\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
GRFPC0_FP_PIPELINE_UN68_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300330033000300")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => N_52826,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR2.RREG.RESV_1_0\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_154_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000030")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_154\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(1),
datae => N_50724,
datad => N_50792,
datac => \GRFPC0.N_25540_1\,
datab => \GRFPC0.V.STDATA_14_I_M_5_0\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_99\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.N_62\,
datac => \GRFPC0.N_59\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(19),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(52),
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_0_18__G0_0_0\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.N_19397\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_22_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_22\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_20\(0),
datae => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_16\(0),
datad => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_13\(0),
datac => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_12\(0),
datab => \GRFPU0.MULO.MRES\(66));
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_O2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33003000")
port map (
combout => \GRFPC0.N_23107\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_228\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23401\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_4_STDEP_176_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00c0ff3f0000")
port map (
combout => \GRFPC0.N_17424\,
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_172\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_21046_I\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_1\(1),
dataf => \GRFPC0.N_25308\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2\,
datab => \GRFPC0.N_24727\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8f08800")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_1\(1),
dataf => \GRFPC0.N_25639\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2\);
GRFPC0_FP_PIPELINE_UN11_FPEXC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_FPEXC\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datad => N_52826,
datac => \GRFPC0.FPO_I_4_I_0\(69),
datab => \GRFPC0.FPR.RDY\);
GRFPC0_FP_PIPELINE_0_WR2EN2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0008000400000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
dataf => \GRFPC0.FP_PIPELINE.0.WR2EN2_2\,
datae => \GRFPC0.N_23611\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
dataa => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_D_LDLCK_RNO_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc00000c0c00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
datac => \GRFPC0.N_22111_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A5_6_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_22745\,
dataf => N_174900,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datad => \GRFPC0.N_24279\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_RNIKV0P7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000cccfccc0")
port map (
combout => N_91843,
dataf => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datac => \GRFPU0.GRFPU_X0.N_5437\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\);
\GRFPC0_FP_PIPELINE_2_REGDEPX_53_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff888f000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_53\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX_50\(1),
datae => N_174900,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_562_0_IV_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23358\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.N_22620\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_0_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(51),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPC0_D_STDLCK_RNO_3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_12_7\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP\,
datad => \GRFPC0.N_40\,
datac => N_100260,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_RNIS8LL7_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(3),
dataf => \GRFPU0.GRFPU_X0.L1_5_4_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_6\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datac => \GRFPC0.N_260\,
datab => \GRFPC0.N_25264_I\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(28),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(28),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(1),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(30),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5410ffff54100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(3),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47\(32),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
dataf => \GRFPU0.GRFPU_X0.N_16266\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.DRES_1\(113),
datab => \GRFPU0.MULO.DRES_1S\(112));
\GRFPC0_D_LDLCK_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff080")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(1),
datae => \GRFPC0.D.LDLCK_0_0_21__G1_4\,
datad => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datab => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.DEP_1_0\(1),
dataa => \GRFPC0.N_24442\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_8_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaeaffea")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_8_0_2\(1),
dataf => \GRFPC0.N_24209\,
datae => \GRFPC0.N_24881\,
datad => \GRFPC0.N_24205\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN222_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
dataa => \GRFPC0.N_25532\);
\GRFPC0_D_STLCK_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000fff")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_28__G1_2\,
datae => \GRFPC0.N_23175\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_A2_0_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccfccccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19818_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_6328\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.N_19823\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f0330033003300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(20),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_I_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003000000030f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11_I_M\(0),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(52));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(54));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(55));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(56));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(57));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.GRFPU_X0.N_19403\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(58));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => N_36139,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(8));
\GRFPC0_D_STLCK_RNO_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f000000000000")
port map (
combout => \GRFPC0.N_20967\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_17302\,
datad => \GRFPC0.N_21046_I\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f003f000000")
port map (
combout => \GRFPC0.N_144\,
dataf => \GRFPC0.N_20960\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_8_0\,
datad => \GRFPC0.N_20908\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A3_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000ccc00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A3_0_2\,
dataf => \GRFPC0.N_20908\,
datae => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.N_131_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_O2_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f3f3f3f003f")
port map (
combout => \GRFPC0.N_155_2\,
dataf => \GRFPC0.N_20960\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_O2_8_0\,
datad => \GRFPC0.N_20908\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4010_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_A2_3_1_RNIV6GE1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000ffff3333")
port map (
combout => \GRFPU0.GRFPU_X0.N_20484\,
dataf => \GRFPU0.GRFPU_X0.N_20478\,
datae => \GRFPU0.GRFPU_X0.N_20843_1\,
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.N_4227\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6759_1\,
dataf => \GRFPU0.GRFPU_X0.N_7023\,
datae => \GRFPU0.GRFPU_X0.N_6660\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT10\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccff00fcccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.N_6661\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ae00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\(0),
datae => \GRFPC0.N_24958\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.N_24897\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
dataa => \GRFPC0.N_24957\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(8),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19499\,
dataf => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4040ff4040404040")
port map (
combout => \GRFPC0.N_21904\,
dataf => N_107,
datae => N_106,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12_0\(1),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
datab => N_174895,
dataa => N_122);
\GRFPC0_FP_PIPELINE_4_REGDEPX_89_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff888f000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_89\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_86\(0),
datae => N_174900,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0));
\GRFPC0_D_STDLCK_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff0fff0fff0fff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datae => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datad => \GRFPC0.N_22896\,
datac => \GRFPC0.N_21791\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_1\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.N_22620\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_0_0\(29));
\GRFPC0_D_STLCK_RNO_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_23004\,
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_1\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300030000000")
port map (
combout => \GRFPC0.N_22939\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_228\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_22600\,
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.N_22620\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(29));
\GRFPC0_D_STLCK_RNO_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300030003000")
port map (
combout => \GRFPC0.N_22943\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_228\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_D_STLCK_RNO_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300030003000")
port map (
combout => \GRFPC0.N_22123\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_228\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_22607\,
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22620\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_STDDEP_0_SQMUXA_111_I_O5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_23175\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(2));
\GRFPC0_D_STDLCK_RNO_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff00ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_3\,
dataf => \GRFPC0.N_23175\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.D.STDLCK_0_0_14__G1_1\,
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPU0_GRFPU_X0_L3_0_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(3),
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => \GRFPU0.GRFPU_X0.N_3846\,
datad => \GRFPU0.GRFPU_X0.L2_1_1\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_25481\,
dataf => \GRFPC0.N_25436\,
datae => \GRFPC0.N_25437\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_25438_1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_8_0\(1));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff1000")
port map (
combout => \GRFPC0.N_21327\,
dataf => \GRFPC0.N_22597\,
datae => \GRFPC0.N_22598\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datac => \GRFPC0.N_21337\,
datab => \GRFPC0.N_21353\,
dataa => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_D_LDLCK_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffeaffaaeaeaaaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_3_0\,
dataf => \GRFPC0.D.LDLCK_0_0_0__G1_3_TZ\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.N_22443\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_0__G1_1\);
GRFPC0_WR_CTRL_PEND_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaa808880888088")
port map (
combout => \GRFPC0.WR.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_7\,
datad => \GRFPC0.VDIV.EXC_1_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.UN50_HOLDN\,
datab => \GRFPC0.WR.CTRL.PEND\,
dataa => N_52981_2);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_1_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_0\(23),
dataf => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\(1),
datae => \GRFPC0.N_21957_1\,
datad => \GRFPC0.N_24427\,
datac => \GRFPC0.FIFO.INST_0\(15),
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_25426\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.N_25309_1\,
datad => \GRFPC0.N_25378\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25404\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25271\,
datad => \GRFPC0.N_25309_1\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(17));
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_ID_1_RNI13RM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303030303033")
port map (
combout => \GRFPC0.FPUSEL_6_0_1__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
datae => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.ID_1\,
datac => \GRFPC0.EX.RREG.RESV\,
datab => N_63);
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36192,
dataf => N_36172,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fc0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36172,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1),
dataf => \GRFPC0.N_25747_I\,
datae => \GRFPC0.N_25458\,
datad => \GRFPC0.N_25385\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec00ff00a000ff00")
port map (
combout => \GRFPC0.N_22463\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_24363\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23463_1\,
datab => \GRFPC0.N_24444\,
dataa => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O3_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0003333f333")
port map (
combout => \GRFPU0.GRFPU_X0.N_20488\,
dataf => \GRFPU0.GRFPU_X0.N_20478\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_4997\,
datac => \GRFPU0.GRFPU_X0.N_4313\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(19),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f0330033003300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(19),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => \GRFPU0.MULO.MRES\(80));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff0f")
port map (
combout => \GRFPC0.N_21600\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21542\,
datad => \GRFPC0.N_22288\,
datac => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_23304\,
dataf => N_122,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_22649\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_A2_0_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20876\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_4997\,
datac => \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_310_0_A3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffc00000")
port map (
combout => \GRFPC0.N_25527\,
dataf => \GRFPC0.N_25530\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datad => \GRFPC0.N_25544\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4650_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25782\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_24030_2\,
datad => \GRFPC0.N_25222_1\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffaeaaffff0600")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(56),
dataf => \GRFPU0.GRFPU_X0.N_19837\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => N_36172,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(3));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(34));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(43));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(56));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffccffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(58));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(0),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(29),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_9_RNIC8L21_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff8888f8888888")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_1\(0),
dataf => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.N_25758\,
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0_0\(1),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A4_1_0\(1),
dataa => \GRFPC0.N_25715_2\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A4_0_RNIFUO33_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_5\(0),
dataf => \GRFPC0.N_24926\,
datae => \GRFPC0.N_24967\,
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.N_25264_I\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1712_REGDEPX2\);
\GRFPU0_GRFPU_X0_COMB_EXP_14_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fc0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(7),
dataf => N_35934,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_22332\,
dataf => N_106,
datae => N_107,
datad => \GRFPC0.N_24280\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1));
\GRFPC0_D_STLCK_RNO_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4f4f4f4f4")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_2\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_88\,
datae => \GRFPC0.N_22082\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_402_0_IV_I_O2_0_0\(0),
datac => \GRFPC0.D.STLCK_0_0_18__G1_0\,
datab => \GRFPC0.N_20852\,
dataa => \GRFPC0.N_22076\);
\GRFPC0_D_STLCK_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff03ff03ff03")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_2\,
dataf => \GRFPC0.N_24606_2\,
datae => \GRFPC0.N_24606_1\,
datad => \GRFPC0.D.STLCK_0_0_31__G1_0\,
datac => \GRFPC0.N_23044\,
datab => \GRFPC0.STDDEP_0_SQMUXA_I_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff73335000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_5\(0),
dataf => \GRFPC0.N_25591\,
datae => \GRFPC0.N_25295_1\,
datad => \GRFPC0.N_25352\,
datac => \GRFPC0.N_25338\,
datab => \GRFPC0.DIV.INST\(4),
dataa => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3f0f3300")
port map (
combout => \GRFPC0.N_23658\,
dataf => \GRFPC0.N_23719\,
datae => \GRFPC0.N_23708\,
datad => \GRFPC0.N_24567\,
datac => N_50724,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_SUB_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f0f0ffccffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_6414_0\,
dataf => \GRFPC0.N_23719\,
datae => \GRFPC0.N_23708\,
datad => N_50724,
datac => \GRFPC0.V.STDATA_14\(14),
datab => N_50656_0);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(50),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_RNIVT7S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7459\,
dataf => \GRFPU0.GRFPU_X0.N_19484\,
datae => \GRFPU0.GRFPU_X0.N_6659\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPU0_GRFPU_X0_UN1_VST3_REG22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffff3ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\,
dataf => \GRFPU0.GRFPU_X0.N_19484\,
datae => \GRFPU0.GRFPU_X0.N_6659\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFN\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000eae2c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
datab => \GRFPU0.GRFPU_X0.ITER.V_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(5));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_0_RNI08RH1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f0000f0000")
port map (
combout => \GRFPC0.N_70\,
dataf => \GRFPC0.N_121_1\,
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RESV\,
datac => N_63);
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_0_RNIG2H11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c3f00000033")
port map (
combout => \GRFPC0.N_47\,
dataf => \GRFPC0.N_65_0\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => N_63);
GRFPC0_DIV_PEND_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030000030000000")
port map (
combout => N_52981,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\,
datac => N_61,
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5410ffff54100000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(5),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47\(34),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff004000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\(0),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.N_24602_1\,
datab => \GRFPC0.N_25477\,
dataa => \GRFPC0.DIV.INST\(16));
\GRFPC0_FP_PIPELINE_12_REGDEPX_230_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX_230_0_0\(0),
dataf => \GRFPC0.N_23391\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4),
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datac => \GRFPC0.N_22649\,
datab => N_122);
GRFPC0_FP_PIPELINE_0_STDDEP_114_IV_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f0f0f33000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_114_2\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff808080")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375_0_1\(0),
dataf => \GRFPC0.N_23621\,
datae => \GRFPC0.N_23612\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.N_25808_2\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5546_REGDEPX2\,
dataa => \GRFPC0.EX.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI5FRQ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0f0f000")
port map (
combout => \GRFPC0.WR2SEL_1\(7),
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FPR.RDY\,
datac => N_63);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00c000ff00")
port map (
combout => \GRFPC0.N_22829\,
dataf => \GRFPC0.N_24413\,
datae => \GRFPC0.N_24358\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23463_1\,
datab => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_41_I_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec00ff00a000ff00")
port map (
combout => \GRFPC0.N_22913\,
dataf => \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\(0),
datae => \GRFPC0.N_24362\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23463_1\,
datab => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN391_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_I_A2_1_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22373\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2368_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f300f300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\(1),
dataf => N_38007,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_WR_RREG_EXCT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fff00f00")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_0__G2\,
dataf => \GRFPC0.N_65_0\,
datae => \FPO.EXC\(0),
datad => \GRFPC0.MEM.RREG.EXCT\(0),
datac => N_63);
\GRFPC0_WR_RREG_EXCT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_2__G2\,
dataf => \FPO.EXC\(2),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.EXCT\(2),
datac => N_63);
\GRFPC0_WR_RREG_EXCT_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.EXCT_0_0_3__G2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.EXCT\(3),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_0__G2\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(0),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_10__G2\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(10),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_11__G2\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(11),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_12__G2\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(12),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_13__G2\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(13),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_14__G2\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(14),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_15__G2\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(15),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_16__G2\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(16),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_17__G2\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(17),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_18__G2\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(18),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_19__G2\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(19),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_1__G2\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(1),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_20__G2\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(20),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_21__G2\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(21),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_22__G2\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(22),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_23__G2\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(23),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_24__G2\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(24),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_25__G2\,
dataf => \FPO.RES\(25),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(25),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_26__G2\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(26),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_27__G2\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(27),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_28__G2\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(28),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_29__G2\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(29),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_2__G2\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(2),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_30__G2\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(30),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_31__G2\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(31),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_32__G2\,
dataf => \FPO.RES\(32),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(32),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_33__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21442_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(33),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_34__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21439_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(34),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_35__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19990_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(35),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_36__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21443_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(36),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_37__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21440_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(37),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_38__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21435_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(38),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_39__G2\,
dataf => \FPO.RES\(39),
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(39),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_3__G2\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(3),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_40__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21441_I_0\,
datae => \GRFPC0.N_65_1\,
datad => \GRFPC0.MEM.RREG.RES\(40),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_41__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21430_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(41),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_42__G2\,
dataf => \FPO.RES\(42),
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(42),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_43__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21427_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(43),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_44__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21431_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(44),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_45__G2\,
dataf => \GRFPU0.GRFPU_X0.N_20333_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(45),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_46__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21428_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(46),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_47__G2\,
dataf => \GRFPU0.GRFPU_X0.N_63_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(47),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_48__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21444_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(48),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_49__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21429_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(49),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_4__G2\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(4),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_50__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21436_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(50),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_51__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21432_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(51),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_52__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21426_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(52),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_53__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21437_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(53),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_54__G2\,
dataf => \GRFPU0.GRFPU_X0.N_67_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(54),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_55__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21423_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(55),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_56__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21438_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(56),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_57__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21433_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(57),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_58__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21424_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(58),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_59__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19903_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(59),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_5__G2\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(5),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_60__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21434_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(60),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_61__G2\,
dataf => \GRFPU0.GRFPU_X0.N_21425_I_0\,
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(61),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_62__G2\,
dataf => \FPO.RES\(62),
datae => \GRFPC0.N_65\,
datad => \GRFPC0.MEM.RREG.RES\(62),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fff00f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_63__G2\,
dataf => \GRFPC0.N_65\,
datae => \FPO.RES\(63),
datad => \GRFPC0.MEM.RREG.RES\(63),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_6__G2\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(6),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_7__G2\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(7),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_8__G2\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(8),
datac => N_63);
\GRFPC0_WR_RREG_RES_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff000f00")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_9__G2\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.N_65_0\,
datad => \GRFPC0.MEM.RREG.RES\(9),
datac => N_63);
GRFPU0_GRFPU_X0_VST3_REG_0_SQMUXA_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555400000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
dataf => \GRFPU0.GRFPU_X0.N_7439\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
datad => \GRFPU0.GRFPU_X0.N_6660\,
datac => \GRFPU0.GRFPU_X0.N_6661\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_8\,
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPC0_FP_PIPELINE_0_WRENX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2\,
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2_1\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datad => \GRFPC0.FP_PIPELINE.0.WRENX2_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.RD\,
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_D_LDLCK_RNO_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_4\,
dataf => \GRFPC0.N_22743_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22310\,
datac => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1359_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f03300fff0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(37),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(98),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_3\(1),
datae => \GRFPC0.N_25425\,
datad => \GRFPC0.N_185_1\,
datac => \GRFPC0.N_23813_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN416_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeca0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_0\(0),
datae => \GRFPC0.N_24323\,
datad => \GRFPC0.N_24324\,
datac => \GRFPC0.N_257\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2\,
dataa => \GRFPC0.N_25465\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(2),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(31),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff3fff")
port map (
combout => \GRFPC0.N_25169\,
dataf => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_14\(0),
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_12\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.N_24602_1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7047_REGDEPX2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f0330033003300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.MULO.MRES\(82));
GRFPU0_GRFPU_X0_ST3_QSNAN_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_21692\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.N_6661\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST2.QSNAN\);
GRFPU0_GRFPU_X0_UN1_VST3_EXC37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.N_6661\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
GRFPU0_GRFPU_X0_UN1_VST3_EXC_4_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.N_6661\,
datad => \GRFPU0.GRFPU_X0.N_7053\,
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff30ff32")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_19197\,
datae => \GRFPU0.GRFPU_X0.N_53\,
datad => \GRFPU0.GRFPU_X0.N_19196\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_0_TZ\(0),
datab => \GRFPU0.GRFPU_X0.C\(11),
dataa => \GRFPU0.GRFPU_X0.C\(10));
\GRFPC0_D_LDLCK_RNO_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G3\,
dataf => \GRFPC0.N_21996\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => N_122);
GRFPU0_GRFPU_X0_RDY_F0_I_A2_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c000000c3000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19318_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \FPI.FLUSH\,
datac => \FPI.FLUSHID\(5),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(5));
\GRFPC0_D_LDLCK_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfcccccc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_3\,
dataf => \GRFPC0.N_22074\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22146\,
datac => \GRFPC0.FIFO.INST_1_0\(25),
datab => \GRFPC0.D.LDLCK_0_0_18__G1_1\);
GRFPU0_GRFPU_X0_UN1_VST3_REG_2_SQMUXA_RNIKLCU1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffecffb3ffa0")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
dataf => \GRFPU0.GRFPU_X0.UN1_VST3.REG_4_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.UN1_VST3.REG_2_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\,
datac => \GRFPU0.GRFPU_X0.N_6809\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8ff88f8f88888")
port map (
combout => \GRFPC0.N_25165\,
dataf => \GRFPC0.N_25161\,
datae => \GRFPC0.N_23735\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.N_23787\,
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2945_REGDEPX2\);
\GRFPC0_D_STLCK_RNO_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfffcfcfcfc")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_2\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_90\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datad => \GRFPC0.N_21055_I\,
datac => \GRFPC0.N_22735\,
datab => \GRFPC0.D.STLCK_0_0_7__G1_0\);
\GRFPC0_D_LDLCK_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffcc0c")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150\(1),
datae => \GRFPC0.D.LDLCK_0_0_9__G1_6\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datac => \GRFPC0.N_21055_I\,
datab => \GRFPC0.STDDEP_0_SQMUXA_83\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11),
datac => \FPI.FLOP\(6),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(11),
dataa => \GRFPC0.EX.CTRL.PC\(11));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(19),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3_0\,
datab => \GRFPU0.MULO.MRES\(79),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
GRFPU0_GRFPU_X0_UN1_VST3_REG_4_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1010101f10101010")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG_4_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\,
datae => \GRFPU0.GRFPU_X0.N_6809\,
datad => \GRFPU0.GRFPU_X0.N_6639\,
datac => \GRFPU0.GRFPU_X0.N_6611\,
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fcf03cf03cf03")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_8154\,
datae => \GRFPU0.GRFPU_X0.N_4094\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffeaffc0ffc0ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(14),
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(74),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPC0_D_LDLCK_RNO_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_20__G1_2\,
datae => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_185\(0),
datad => \GRFPC0.N_165_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
dataf => \GRFPU0.GRFPU_X0.N_19283_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
datab => \FPO.IDOUT\(3),
dataa => \GRFPC0.WR.CTRL.ID\(3));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_O4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30003000")
port map (
combout => \GRFPC0.N_23392\,
dataf => \GRFPC0.N_150\,
datae => \GRFPC0.N_22354\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datab => \GRFPC0.N_24356\);
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f735f5073735050")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
dataf => \GRFPU0.GRFPU_X0.N_17757_M_1\,
datae => \GRFPU0.GRFPU_X0.N_7226\,
datad => \GRFPU0.GRFPU_X0.N_17757_M_0\,
datac => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datab => \GRFPU0.GRFPU_X0.N_11367\,
dataa => \GRFPU0.GRFPU_X0.ITER.DP_0\);
GRFPU0_GRFPU_X0_VITER_STATE_13_SQMUXA_2_I_RNIRM3D2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003030ff30")
port map (
combout => \GRFPU0.GRFPU_X0.N_19292_I\,
dataf => \GRFPU0.GRFPU_X0.N_19408\,
datae => \GRFPU0.GRFPU_X0.N_5299\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(38),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(13),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(24),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(11),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(21),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f0c0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(34),
dataf => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datad => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54105410ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(27),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(27),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_6\(1),
dataf => \GRFPC0.N_25306\,
datae => \GRFPC0.N_25682\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(48),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3_0\,
datab => \GRFPU0.MULO.MRES\(108),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff2f22ffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11259\,
dataf => \GRFPU0.GRFPU_X0.N_19259_1\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__N_5\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G2_2\,
datac => N_124830,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
dataa => \GRFPU0.GRFPU_X0.N_26\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeccca000")
port map (
combout => \GRFPC0.N_25762\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_2\(1),
datae => \GRFPC0.N_25786_2\,
datad => \GRFPC0.N_24979_2\,
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
dataa => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_5_0\(1));
\GRFPC0_D_STLCK_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3fff3fff3f300")
port map (
combout => \GRFPC0.N_20913\,
dataf => \GRFPC0.N_23428\,
datae => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_0\(1),
datad => \GRFPC0.N_17302\,
datac => \GRFPC0.N_21046_I\,
datab => \GRFPC0.N_20961_2\);
GRFPC0_FP_PIPELINE_V_FSR_FCC_1_SS0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccfccccccccccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SS0\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2S4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccfcfccccccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S4_1\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\,
datad => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffa8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_6\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\(0),
datae => \GRFPC0.N_24502\,
datad => \GRFPC0.N_24601\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_1_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\);
\GRFPU0_GRFPU_X0_VST3_REG_37_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33cc000a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37));
\GRFPC0_D_LDLCK_RNO_2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1_0\,
dataf => \GRFPC0.N_167_1\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datac => \GRFPC0.N_22325_2\,
datab => N_122);
\GRFPC0_D_STLCK_RNO_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfcfccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_3\,
dataf => \GRFPC0.N_23302\,
datae => \GRFPC0.N_22718\,
datad => \GRFPC0.N_228\,
datac => \GRFPC0.STDDEP_0_SQMUXA_92\,
datab => \GRFPC0.D.STLCK_0_0_26__G1_0\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_O4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPC0.N_23387\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_165_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.N_24443\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffecffa0ffa0ffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(18),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(18),
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
dataa => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11288\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_5_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19307\,
datac => \FPI.FLUSH\,
datab => N_61);
GRFPU0_GRFPU_X0_VRDY_0_SQMUXA_1_1_I_O2_RNIVK8C: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_19307\,
datae => \FPI.FLUSH\,
datad => N_61);
GRFPU0_GRFPU_X0_VRDY_0_SQMUXA_1_1_I_O2_RNI920P3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff33f030")
port map (
combout => \GRFPU0.GRFPU_X0.N_19431\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.N_19307\,
datac => \GRFPU0.GRFPU_X0.ITER.V_3\,
datab => \FPI.FLUSH\);
\GRFPC0_D_STDLCK_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfff0ff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_3\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_88\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.N_21631\,
datac => \GRFPC0.D.STDLCK_0_0_9__G1_0\,
datab => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(26),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3_0\,
datab => \GRFPU0.MULO.MRES\(86),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(26));
\GRFPC0_D_LDLCK_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeca0ffffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1\,
dataf => \GRFPC0.N_24997\,
datae => \GRFPC0.D.LDLCK_0_0_14__G1_4\,
datad => \GRFPC0.N_168_1\,
datac => \GRFPC0.N_165_1\,
datab => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2384_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2399_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8f8f8f8f8f8f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_2\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datad => \GRFPC0.N_24408\,
datac => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
datab => \GRFPC0.N_22466_2\,
dataa => \GRFPC0.N_22333_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O3_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ffff0030")
port map (
combout => \GRFPU0.GRFPU_X0.N_20480\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_20599\,
datad => \GRFPU0.GRFPU_X0.N_20764_0\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00c000c000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20479\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_20599\,
datad => \GRFPU0.GRFPU_X0.N_20764_0\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20846\,
dataf => \GRFPU0.GRFPU_X0.N_20764\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff30fff0fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_21058\,
datac => \GRFPU0.GRFPU_X0.N_21042\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_6_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcc00fffffcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(53),
dataf => \GRFPU0.GRFPU_X0.N_20764\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(53),
datad => N_45083,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030003f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20562_1\,
dataf => \GRFPU0.GRFPU_X0.N_20764\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
\GRFPC0_D_LDLCK_RNO_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfcfcffcccccc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_4\,
dataf => \GRFPC0.N_165_1\,
datae => \GRFPC0.N_22749_1\,
datad => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\,
datab => \GRFPC0.D.LDLCK_0_0_26__G1_1\);
\GRFPC0_D_STLCK_RNO_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f3fffff0f3")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_2\,
dataf => \GRFPC0.N_21472\,
datae => \GRFPC0.D.STLCK_0_0_22__G1_0\,
datad => \GRFPC0.N_21891\,
datac => \GRFPC0.N_78_I_I_0\,
datab => N_266);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(1),
dataf => \GRFPC0.N_25529\,
datae => \GRFPC0.N_25403\,
datad => \GRFPC0.N_25401\,
datac => \GRFPC0.N_25451_2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_4_0\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_10__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI065Q_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_12__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI2E5Q_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_13__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI4M5Q_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_14__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_15__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI866Q_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_17__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_18__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI5M5Q_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_19__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_1__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_21__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccc000c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_23__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI2FC61_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_4__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_9__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datab => N_61);
\GRFPC0_D_LDLCK_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffeaffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_5\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.D.LDLCK_0_0_7__G1_2\,
datad => \GRFPC0.N_22735\,
datac => \GRFPC0.N_22743_1\,
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2030203000002030")
port map (
combout => N_52963,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
datae => \GRFPU0.GRFPU_X0.N_296\,
datad => \GRFPU0.GRFPU_X0.N_21179\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_7__G3_0_1445_I_0\,
datab => \GRFPU0.GRFPU_X0.N_21169\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(32),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3_0\,
datab => \GRFPU0.MULO.MRES\(92),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_9\(0),
dataf => \GRFPC0.N_218\,
datae => \GRFPC0.N_23748\,
datad => \GRFPC0.N_23803\,
datac => \GRFPC0.N_24323\,
datab => \GRFPC0.N_24701_1\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_0_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(17),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(17),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPC0_D_LDLCK_RNO_3_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0ff000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_0_0\(7),
datac => \GRFPC0.N_22473_2\,
datab => N_174900);
\GRFPC0_D_STLCK_RNO_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffbff00ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_0\,
dataf => \GRFPC0.N_21055_I\,
datae => \GRFPC0.STDDEP_0_SQMUXA_101\,
datad => \GRFPC0.N_23240\,
datac => \GRFPC0.N_22858\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
dataa => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(29),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3_0\,
datab => \GRFPU0.MULO.MRES\(89),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_RNIIRB54: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_6759\,
dataf => \GRFPU0.GRFPU_X0.N_7023\,
datae => \GRFPU0.GRFPU_X0.N_6660\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPC0_FP_PIPELINE_15_STDEP_616_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff03fffc030003")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_616\(1),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_612\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_17377\,
datac => \GRFPC0.N_21046_I\,
datab => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(21),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3_0\,
datab => \GRFPU0.MULO.MRES\(81),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
GRFPU0_GRFPU_X0_COMB_STICKY_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffffffcccffcc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.STICKY_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_19\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_19\,
datad => \GRFPU0.MULO.MRES_0\(120),
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.MULO.MRES\(94));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25407\,
dataf => \GRFPC0.N_25458\,
datae => \GRFPC0.DIV.INST\(16),
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_9\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_4\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_3\(0),
datad => \GRFPC0.N_220\,
datac => \GRFPC0.N_24306_1\,
datab => \GRFPC0.N_24327\,
dataa => \GRFPC0.N_268\);
\GRFPC0_D_LDLCK_RNO_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fff8fff8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_3\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
datae => \GRFPC0.N_21956_1\,
datad => \GRFPC0.N_22664\,
datac => \GRFPC0.D.LDLCK_0_0_9__G1_0\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
dataa => \GRFPC0.N_92_1\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcfc0000fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.RREG.RESV_1_0\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0ccf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fc0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.WR2.RREG.RESV_1\,
datab => \GRFPC0.WR2.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fc0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.WR2.RREG.RESV_1\,
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fc0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.WR2.RREG.RESV_1\,
datab => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fc0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.WR2.RREG.RESV_1\,
datab => \GRFPC0.WR2.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_VDIV_RDD_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f3c0f0f0")
port map (
combout => \GRFPC0.N_130\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.WR2.RREG.RESV_1\);
GRFPU0_GRFPU_X0_VITER_DBUF_7_1_ANC3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f0f3333000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO3\,
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO1\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.L2_0\(2),
datac => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datab => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15));
GRFPU0_GRFPU_X0_VITER_STATE_18_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.STATE_18_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfaaccc0c0aacc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(47),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(47));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8fff088880000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_6\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_24979_2\,
datad => \GRFPC0.N_24964\,
datac => \GRFPC0.N_24962\,
datab => \GRFPC0.N_23797\,
dataa => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(49),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3_0\,
datab => \GRFPU0.MULO.MRES\(109),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(9),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3_0\,
datab => \GRFPU0.MULO.MRES\(69),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
GRFPC0_FP_PIPELINE_UN26_FPUSTART_0_RNIPCAL4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003fc00ff00ff0")
port map (
combout => \FPI.OPID\(1),
dataf => N_49622_0,
datae => N_50504_4,
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\);
GRFPC0_VEX_CTRL_ID_2_1_CO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c000f000f000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_1_CO1\,
dataf => N_49622_0,
datae => N_50504_4,
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\);
\GRFPU0_GRFPU_X0_L4_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(4),
dataf => \GRFPU0.GRFPU_X0.N_7365\,
datae => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(4),
datad => \GRFPU0.GRFPU_X0.L1_2\(3),
datac => \GRFPU0.GRFPU_X0.N_19295\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_O2_0_2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d0f050f0c0f000f0")
port map (
combout => \GRFPC0.N_22096\,
dataf => \GRFPC0.N_22698\,
datae => \GRFPC0.N_24448\,
datad => \GRFPC0.N_24361\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datab => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2904_REGDEPX_2\,
dataa => \GRFPC0.FIFO.INST_0\(19));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfff0fffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(59),
datae => \GRFPU0.GRFPU_X0.N_6995\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_33\(59),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6),
datac => \FPI.FLOP_0\(1),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(6),
dataa => \GRFPC0.EX.CTRL.PC\(6));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003003")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_4\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_3\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_1\,
datad => \FPO.IDOUT\(5),
datac => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.EX.CTRL.ID\(7));
GRFPU0_GRFPU_X0_UN1_VALLOW_2_SQMUXA_4_RNII0515: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030003300")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_1_1_S4\,
dataf => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
datae => \GRFPU0.GRFPU_X0.N_157\,
datad => \GRFPU0.GRFPU_X0.N_6809\,
datac => N_49622,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00cf00ff00ff00f")
port map (
combout => N_123284,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_25\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(28));
\GRFPC0_D_LDLCK_RNO_2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f080f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_0\,
dataf => \GRFPC0.N_22253\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_13\(0),
datad => \GRFPC0.N_22180\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8),
dataa => \GRFPC0.N_22231_1\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(45),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3_0\,
datab => \GRFPU0.MULO.MRES\(105),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0e0f0c0f0a0f000")
port map (
combout => \GRFPC0.N_21917\,
dataf => \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\(0),
datae => \GRFPC0.N_24448\,
datad => \GRFPC0.N_24376\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datab => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX\,
dataa => \GRFPC0.N_24427\);
\GRFPC0_D_LDLCK_RNO_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_6\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.N_23148\,
datad => \GRFPC0.N_89_1\,
datac => \GRFPC0.N_22305\,
datab => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4880_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1_6\,
dataf => \GRFPC0.D.LDLCK_0_0_9__G1_3\,
datae => \GRFPC0.D.LDLCK_0_0_9__G1_4\,
datad => \GRFPC0.N_89_1\,
datac => \GRFPC0.N_22305\,
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1\,
dataf => \GRFPC0.N_24\,
datae => \GRFPC0.D.LDLCK_0_0_12__G1_3\,
datad => \GRFPC0.N_22495\,
datac => \GRFPC0.N_165_1\,
datab => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff808080")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_1\,
dataf => \GRFPC0.N_22575\,
datae => \GRFPC0.N_88_1_0\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\,
datac => N_174895,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
dataa => \GRFPC0.N_22573_1\);
\GRFPC0_D_STLCK_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3fff0fff0fff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_3\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
datad => \GRFPC0.N_22689\,
datac => \GRFPC0.D.STLCK_0_0_8__G1_1\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36182,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17608\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => N_36182,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36200,
dataf => N_36182,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3cccccff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => N_36182,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36182,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPC0_D_LDLCK_RNO_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffafaeaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_2\,
dataf => \GRFPC0.N_21907\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O3_1_0\(23),
datad => \GRFPC0.N_21956_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datab => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_23__G1_0\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080c0a0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(10),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3_0\,
datab => \GRFPU0.MULO.MRES\(70),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0fbfaf00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_23_IV\(0),
datad => \GRFPC0.N_24087\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\(0),
datab => \GRFPC0.V.STDATA_14_M_5\(0),
dataa => \FPI.FLOP_0\(6));
GRFPC0_FP_PIPELINE_1_REGDEP160_0_RNINI3J3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FPUSEL_1\(1),
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => \GRFPC0.FPUSEL_1_0_1__G0_3_0_0\,
datad => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
datac => \GRFPC0.N_121_1\,
datab => N_63);
\GRFPC0_D_LDLCK_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff8f8f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_2\,
dataf => \GRFPC0.N_22373\,
datae => \GRFPC0.N_22333_1\,
datad => \GRFPC0.N_22473_2\,
datac => \GRFPC0.N_22332\,
datab => \GRFPC0.N_22737_2\,
dataa => \GRFPC0.N_22329_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_7\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_1\(1),
datad => \GRFPC0.N_24671\,
datac => \GRFPC0.N_25451_2\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_0\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0008000c000a000f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_I_M_1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1_I_M\(28),
datab => \GRFPU0.MULO.MRES\(88),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPC0_D_LDLCK_RNO_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
datae => \GRFPC0.N_24287\,
datad => \GRFPC0.N_24285\,
datac => \GRFPC0.N_22649\,
datab => \GRFPC0.N_22573_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0041000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_5\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_1_5\,
datac => \FPO.IDOUT\(0),
datab => \GRFPC0.WR2.CTRL.ID\(0),
dataa => \GRFPC0.WR2.CTRL.ID\(7));
\GRFPC0_D_LDLCK_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
datae => \GRFPC0.D.LDLCK_0_0_16__G1_4\,
datad => \GRFPC0.N_89_1\,
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
datab => \GRFPC0.N_22440\);
\GRFPC0_D_LDLCK_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(0),
datae => \GRFPC0.D.LDLCK_0_0_20__G1_4\,
datad => \GRFPC0.N_89_1\,
datac => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\,
datab => \GRFPC0.N_22440\);
\GRFPC0_D_LDLCK_RNO_3_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff888f888f888")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_1_0\(31),
datad => \GRFPC0.N_88_1_0\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
dataa => \GRFPC0.N_92_1\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_2_0_RNIN88K7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_12\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0_9\,
datae => \GRFPC0.D.LDLCK_0_0_27__G1_0_5\,
datad => \GRFPC0.D.LDLCK_0_0_27__G1_0_3\,
datac => \GRFPC0.D.LDLCK_0_0_27__G1_0_2\,
datab => \GRFPC0.N_25450_1\,
dataa => \GRFPC0.N_25648_1\);
\GRFPU0_GRFPU_X0_L4_6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(4),
dataf => \GRFPU0.GRFPU_X0.N_10558\,
datae => \GRFPU0.GRFPU_X0.N_10519\,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.N_10521\,
datab => \GRFPU0.GRFPU_X0.L3_0_1\(5));
\GRFPC0_D_LDLCK_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffec")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(0),
datae => \GRFPC0.D.LDLCK_0_0_18__G1_3\,
datad => \GRFPC0.N_22096\,
datac => \GRFPC0.N_165_1\,
datab => \GRFPC0.N_22100\,
dataa => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3023_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1_2\,
dataf => \GRFPC0.N_22924_1\,
datae => \GRFPC0.N_23417_2\,
datad => \GRFPC0.D.LDLCK_0_0_3__G1_0\,
datac => \GRFPC0.N_22925_1\,
datab => \GRFPC0.N_22473_2\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_3_0\(41),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datad => \GRFPU0.GRFPU_X0.N_20764\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_2\(53),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_4352\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_0);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_0);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000cfff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
dataf => \GRFPU0.GRFPU_X0.N_20286_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(56),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datac => \GRFPU0.GRFPU_X0.N_218_0\,
datab => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000cfff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
dataf => \GRFPU0.GRFPU_X0.N_20288_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(59),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datac => \GRFPU0.GRFPU_X0.N_218_0\,
datab => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_I_A2_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19514\,
dataf => \GRFPU0.GRFPU_X0.N_19510_I_0\,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000cfff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
dataf => \GRFPU0.DIVROMI\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(56),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datac => \GRFPU0.GRFPU_X0.N_218_1\,
datab => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000cfff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
dataf => \GRFPU0.DIVROMI\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(58),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datac => \GRFPU0.GRFPU_X0.N_218_1\,
datab => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
datad => \GRFPU0.GRFPU_X0.N_218_1\,
datac => N_49622_2);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datad => \GRFPU0.GRFPU_X0.N_218_0\,
datac => N_49622_1);
\GRFPU0_GRFPU_X0_L4_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00003fff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datae => \GRFPU0.GRFPU_X0.N_10895\,
datad => \GRFPU0.GRFPU_X0.N_10894\,
datac => \GRFPU0.GRFPU_X0.N_10896\,
datab => \GRFPU0.GRFPU_X0.L3_1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(7),
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(67));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_3\(1),
datae => \GRFPC0.N_25451_2\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2\,
datac => \GRFPC0.N_25174_1\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1712_REGDEPX2\);
\GRFPC0_D_STDLCK_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_90\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.N_21015\,
datac => \GRFPC0.D.STDLCK_0_0_3__G1_0\,
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefaeeaafcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(17),
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A2_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033330300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19332\,
dataf => \GRFPU0.GRFPU_X0.N_19408\,
datae => \GRFPU0.GRFPU_X0.N_5299_I_M\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A2_2_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033330300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19334\,
dataf => \GRFPU0.GRFPU_X0.N_19408\,
datae => \GRFPU0.GRFPU_X0.N_5299_I_M\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_A2_2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033330300")
port map (
combout => \GRFPU0.GRFPU_X0.N_20670\,
dataf => \GRFPU0.GRFPU_X0.N_19408\,
datae => \GRFPU0.GRFPU_X0.N_5299_I_M\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O2_RNIQBRR5_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ccccc0c0ccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_20485\,
dataf => \GRFPU0.GRFPU_X0.N_20881\,
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.N_20764\,
datac => \GRFPU0.GRFPU_X0.N_20478\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPC0_D_LDLCK_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3f00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(0),
datae => \GRFPC0.D.LDLCK_0_0_22__G1_4\,
datad => \GRFPC0.STDDEP_0_SQMUXA_96\,
datac => \GRFPC0.N_22354\,
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\);
\GRFPU0_GRFPU_X0_L4_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc0cfc0c")
port map (
combout => N_124895,
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => N_124889,
datad => N_124882,
datac => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datab => N_124867);
\GRFPC0_D_STLCK_RNO_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffeee")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_4\,
dataf => \GRFPC0.N_22124\,
datae => \GRFPC0.N_22123\,
datad => \GRFPC0.STDDEP_0_SQMUXA_88\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datab => \GRFPC0.N_22115\,
dataa => \GRFPC0.D.STLCK_0_0_19__G1_0\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f807f80ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_16176\,
datad => \FPI.OP2\(54),
datac => \FPI.OP2\(52),
datab => \FPI.OP2\(53),
dataa => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19767\,
dataf => \GRFPU0.GRFPU_X0.N_19767_6\,
datae => \FPI.OP1\(58),
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(60),
datab => \FPI.OP1\(61));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccfaccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(18),
dataf => \GRFPU0.GRFPU_X0.N_20848\,
datae => \GRFPU0.GRFPU_X0.N_20881\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G5\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_9\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_4\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_2\(1),
datad => \GRFPC0.N_25518\,
datac => \GRFPC0.N_25512\,
datab => \GRFPC0.N_25500\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_10_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefaeeaa")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_3\(0),
dataf => \GRFPC0.N_24302\,
datae => \GRFPC0.N_23787\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2580_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\,
datab => \GRFPC0.N_23756_1\,
dataa => \GRFPC0.N_23746\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffafa27052200")
port map (
combout => N_124901,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_0\,
datae => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.N_5\,
datad => \GRFPU0.GRFPU_X0.N_21896\,
datac => \GRFPU0.GRFPU_X0.N_8376\,
datab => \GRFPU0.MULO.MRES\(97),
dataa => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\);
\GRFPC0_D_LDLCK_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefaffffeeaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_4\,
dataf => \GRFPC0.N_168_1\,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.N_165_1\,
datac => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_4__G1_1\);
GRFPU0_GRFPU_X0_UN1_VST4_SEL2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000200")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1\,
dataf => \GRFPU0.GRFPU_X0.N_7797\,
datae => \GRFPU0.GRFPU_X0.N_7753\,
datad => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_0\,
datac => \GRFPU0.GRFPU_X0.N_7781\,
datab => \GRFPU0.GRFPU_X0.N_7767\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefaeeaaeeaaeeaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(11),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => \GRFPU0.MULO.MRES\(71),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_O2_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.N_380\,
dataf => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\,
datae => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_5\,
datad => \FPI.OP2\(54),
datac => \FPI.OP2\(52),
datab => \FPI.OP2\(53));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20295\,
dataf => \FPI.OP2\(54),
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(53),
datac => \FPI.FLOP\(1));
\GRFPC0_D_LDLCK_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffec")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1\,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(0),
datae => \GRFPC0.D.LDLCK_0_0_28__G1_4\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_0\(0),
datac => \GRFPC0.N_168_1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_1\(0),
dataa => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\);
\GRFPC0_R_FSR_CEXC_RNO_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(0),
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(1),
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(2),
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(3),
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_R_FSR_CEXC_RNO_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(4),
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_D_LDLCK_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff222a")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1_1\,
dataf => \GRFPC0.N_23066\,
datae => \GRFPC0.N_23070\,
datad => N_122,
datac => \GRFPC0.N_22992\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_2_0\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0400")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_2\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0\(1),
datae => \GRFPC0.N_25819\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datac => \GRFPC0.N_25163\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\,
dataa => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_D_STLCK_RNO_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff080808")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_4\,
dataf => \GRFPC0.D.STLCK_0_0_23__G1_2\,
datae => \GRFPC0.STDDEP_0_SQMUXA_96\,
datad => \GRFPC0.N_22457\,
datac => \GRFPC0.N_228\,
datab => \GRFPC0.N_24606_2\,
dataa => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX\);
GRFPC0_FP_PIPELINE_0_STDEP10_0_A2_0_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD_0\(4),
datac => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A3_6_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffefa")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350_0_A3_6_3\(0),
dataf => \GRFPC0.N_24735_2\,
datae => \GRFPC0.N_24653\,
datad => \GRFPC0.N_24713\,
datac => \GRFPC0.N_24688\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
dataa => \GRFPC0.N_24706\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefaeeaafcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(18),
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN4_DEP_2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN4_DEP_2\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD_0\(3),
datad => \GRFPC0.DIV.RD_0\(4),
datac => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3cccccff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => N_36187,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36187,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_26_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccfff0fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_26_I_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3333ff0fff0f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
GRFPC0_VEX_CTRL_ID_2_1_CO0_RNIC34B: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00ff00ff00")
port map (
combout => \FPI.OPID\(2),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO0\,
datae => \GRFPC0.EX.CTRL.ID\(1),
datad => \GRFPC0.EX.CTRL.ID\(2));
GRFPC0_VEX_CTRL_ID_2_1_CO0_RNIASOF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \FPI.OPID\(3),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO0\,
datae => \GRFPC0.EX.CTRL.ID\(1),
datad => \GRFPC0.EX.CTRL.ID\(2),
datac => \GRFPC0.EX.CTRL.ID\(3));
GRFPC0_VEX_CTRL_ID_2_1_CO0_RNI9PDK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \FPI.OPID\(4),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO0\,
datae => \GRFPC0.EX.CTRL.ID\(1),
datad => \GRFPC0.EX.CTRL.ID\(2),
datac => \GRFPC0.EX.CTRL.ID\(3),
datab => \GRFPC0.EX.CTRL.ID\(4));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16176\,
dataf => \GRFPU0.GRFPU_X0.N_80\,
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(56),
datac => \FPI.OP2\(57));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16177\,
dataf => \GRFPU0.GRFPU_X0.N_80\,
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(56),
datac => \FPI.OP2\(57),
datab => \FPI.OP2\(58));
GRFPU0_GRFPU_X0_UN38_EXP_1_CO4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(57),
datac => \FPI.OP2\(58),
datab => \FPI.OP2\(59));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(4),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_A2_2_4__N_4\,
datae => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\,
datad => \GRFPU0.GRFPU_X0.N_80\,
datac => \FPI.OP2\(55),
datab => \FPI.OP2\(56));
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I_1_RNI3UHR2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.ITER.V_3\,
datab => N_61);
GRFPC0_STDEP_2_SQMUXA_137_I_O2_0_S: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfffff0fff0ff")
port map (
combout => \GRFPC0.N_21146\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDEP10_0_A2_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000330f")
port map (
combout => \GRFPC0.N_193\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(1));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_28\,
dataf => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_20\,
datae => \FPI.OP2\(13),
datad => \FPI.OP2\(9),
datac => \FPI.OP2\(15),
datab => \FPI.OP2\(22));
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f330000ffff0000")
port map (
combout => \GRFPC0.N_25876\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_23571\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.DIV.RDD_0\);
GRFPC0_FP_PIPELINE_12_STDEP2026_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f3300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP2026\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPC0_FP_PIPELINE_6_STDEP1018_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f3300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP1018\,
dataf => \GRFPC0.N_23571\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD_0\);
GRFPC0_STDEP_2_SQMUXA_128_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_128\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.N_23571\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPC0_STDEP_2_SQMUXA_135_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_135\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPC0_STDEP_2_SQMUXA_142: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0cc00000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_142\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.N_23535_1\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPC0_STDEP_2_SQMUXA_138_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_138\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.N_23572\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f330000ffff0000")
port map (
combout => \GRFPC0.N_21683_1\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD_0\,
datab => \GRFPC0.DIV.RDD_0\);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_26_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f33ffffffff")
port map (
combout => \GRFPC0.N_21054\,
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
GRFPU0_GRFPU_X0_UN13_EXP_1_CO3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(58),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(57));
GRFPU0_GRFPU_X0_UN13_EXP_1_CO2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_388_3_0\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(56),
datad => \FPI.OP1\(57));
\GRFPC0_D_LDLCK_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffefa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
datae => \GRFPC0.D.LDLCK_0_0_17__G1_3\,
datad => \GRFPC0.N_89_1_0\,
datac => \GRFPC0.N_91\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2696_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_17__G1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8ffffff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(15),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(15),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_5193\,
dataa => \GRFPU0.MULO.MRES\(75));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_5\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_6\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\(0),
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_8_0\(1));
\GRFPC0_D_STLCK_RNO_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_0\,
dataf => \GRFPC0.N_20852\,
datae => \GRFPC0.N_22313\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_22649\);
\GRFPC0_D_STLCK_RNO_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.N_21896\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_22649\);
\GRFPC0_D_STLCK_RNO_2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.STDDEP_0_SQMUXA_1_I_1\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_22649\);
\GRFPC0_D_LDLCK_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eecccccceac0c0c0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\(1),
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datad => \GRFPC0.N_21055_I\,
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
dataa => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"008000aa00aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_20890_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(9),
datae => \GRFPU0.GRFPU_X0.N_21025\,
datad => \GRFPU0.GRFPU_X0.N_20989\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
datab => \GRFPU0.GRFPU_X0.N_296\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(9));
\GRFPC0_D_STLCK_RNO_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4444f444ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_1\,
dataf => \GRFPC0.N_17115\,
datae => \GRFPC0.N_23044\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_31_I_I_A3_0\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataa => \GRFPC0.N_22992\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fffff0fcf")
port map (
combout => \GRFPC0.N_21716\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\,
datac => \GRFPC0.N_131_0\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\);
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPC0.N_21794\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.N_131_0\);
GRFPU0_GRFPU_X0_NXX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.NXX\,
dataf => \GRFPU0.GRFPU_X0.NXX_8\,
datae => \GRFPU0.MULO.MRES\(95),
datad => \GRFPU0.GRFPU_X0.NXX_3\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.MULO.MRES\(93),
dataa => \GRFPU0.MULO.MRES\(89));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefcfffffcfc")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_8\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_5\(0),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_9_1\(0),
datac => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_4\(0),
datab => \GRFPC0.N_25816\,
dataa => N_174891);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0ff8ff080")
port map (
combout => \GRFPU0.GRFPU_X0.N_16650\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(56),
datae => N_138076,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(56),
datac => \GRFPU0.GRFPU_X0.N_21025\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"08080c0c0008000c")
port map (
combout => N_52967,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_296\,
datac => \GRFPU0.GRFPU_X0.N_21152\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_16__G3_0_1549_I_0\,
dataa => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffeeefffffaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(36),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(36),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffc00fe00fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(27),
dataf => \GRFPU0.GRFPU_X0.N_17645\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
datad => \GRFPU0.GRFPU_X0.N_19496\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(27),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPC0_D_STLCK_RNO_3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_1\,
dataf => \GRFPC0.N_22513\,
datae => \GRFPC0.N_22483\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6),
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => N_174895);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8ffffff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(10),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_5193\,
dataa => \GRFPU0.MULO.MRES\(70));
GRFPC0_V_FSR_CEXC_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000033000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
dataf => \GRFPC0.FPEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.STATE6\,
datad => \GRFPC0.V.FSR.CEXC_2_SQMUXA_1_0\,
datac => \GRFPC0.FPO_I_4_I_0\(69),
datab => \GRFPC0.WR2.RREG.EXCT\(5));
GRFPC0_V_FSR_CEXC_3_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000033000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
dataf => \GRFPC0.FPEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.STATE6\,
datad => \GRFPC0.V.FSR.CEXC_3_SQMUXA_1_0\,
datac => \GRFPC0.FPO_I_4_I_0\(69),
datab => \GRFPC0.WR2.RREG.EXCT\(5));
\GRFPC0_D_LDLCK_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(1),
datae => \GRFPC0.N_22468\,
datad => \GRFPC0.N_22497\,
datac => \GRFPC0.D.LDLCK_0_0_13__G1_2\,
datab => \GRFPC0.N_22472\);
GRFPC0_UN1_STDEP2530: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.UN1_STDEP2530\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.N_130\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_RNI1GAGQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0f0000000f")
port map (
combout => N_38025,
dataf => \GRFPC0.N_21137_0\,
datae => N_174898,
datad => \GRFPC0.N_130\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_RNIV24JQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0000000f0")
port map (
combout => N_38026,
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.N_130\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0fffffff")
port map (
combout => \GRFPC0.N_21553\,
dataf => \GRFPC0.N_21137_1\,
datae => \GRFPC0.N_130\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f3000000f3")
port map (
combout => \GRFPC0.N_25877\,
dataf => \GRFPC0.N_21137_0\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.N_130\,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPC0.N_90\,
dataf => \GRFPC0.STDEP_2_SQMUXA_138\,
datae => N_174898,
datad => \GRFPC0.N_23572\,
datac => \GRFPC0.N_130\,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffeaffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(49),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.N_175\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.N_130\,
datac => \GRFPC0.N_21123\);
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_73\,
dataf => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G4\,
datae => \GRFPU0.GRFPU_X0.N_19767_6\,
datad => \GRFPU0.GRFPU_X0.N_19767_5\,
datac => \FPI.FLOP\(6),
datab => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_ST1_OP1NX_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11297\,
dataf => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G4\,
datae => \GRFPU0.GRFPU_X0.N_19767_6\,
datad => \GRFPU0.GRFPU_X0.N_19767_5\,
datac => \GRFPU0.GRFPU_X0.N_80\,
datab => \FPI.NONSTD\);
\GRFPC0_D_STLCK_RNO_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fff2fff2")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_2\,
dataf => \GRFPC0.N_22457\,
datae => \GRFPC0.STDDEP_0_SQMUXA_87\,
datad => \GRFPC0.N_22847\,
datac => \GRFPC0.N_22851\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_25_I\(1),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffeaffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(45),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f300c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(59),
dataf => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datac => \GRFPU0.MULO.DRES_1\(119),
datab => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"008000aa00aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_20889_I\,
dataf => \GRFPU0.GRFPU_X0.N_21025\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(16),
datad => \GRFPU0.GRFPU_X0.N_20981\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
datab => \GRFPU0.GRFPU_X0.N_296\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(16));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_RNI288P5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => N_50374_4,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => CPO_LDLOCKZ,
datad => N_50358,
datac => N_138,
datab => N_64);
GRFPC0_RFA_RDD_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => N_50421_11,
dataf => CPO_LDLOCKZ,
datae => N_134,
datad => N_133,
datac => N_137,
datab => N_64);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_RNIR7801: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => N_50421_9,
dataf => CPO_LDLOCKZ,
datae => N_133,
datad => N_134,
datac => N_64);
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19768\,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(53));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19722\,
dataf => \GRFPU0.GRFPU_X0.N_327\,
datae => \FPI.OP1\(54),
datad => \FPI.OP1\(52),
datac => \FPI.OP1\(51),
datab => \FPI.OP1\(53));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
dataf => \GRFPU0.GRFPU_X0.N_19283_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\,
datac => \FPO.IDOUT\(1),
datab => \GRFPC0.DIV.ID\(1),
dataa => \GRFPC0.DIV.ID\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8ffffff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(17),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(17),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_5193\,
dataa => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8ffffff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(12),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_5193\,
dataa => \GRFPU0.MULO.MRES\(72));
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_M4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7777777777774447")
port map (
combout => \GRFPC0.N_22013\,
dataf => \GRFPC0.N_96\,
datae => \GRFPC0.FP_PIPELINE.10.STDEP_412_3_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datac => \GRFPC0.N_62\,
datab => \GRFPC0.N_107\,
dataa => \GRFPC0.N_17452\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"008000aa00aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_20886_I\,
dataf => \GRFPU0.GRFPU_X0.N_21025\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(29),
datad => \GRFPU0.GRFPU_X0.N_20953\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
datab => \GRFPU0.GRFPU_X0.N_296\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"008000aa00aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_20888_I\,
dataf => \GRFPU0.GRFPU_X0.N_21025\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(30),
datad => \GRFPU0.GRFPU_X0.N_20969\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(30),
datab => \GRFPU0.GRFPU_X0.N_296\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_0\(30));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O3_0_RNI1ID24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c0c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20313_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\,
datae => \GRFPU0.GRFPU_X0.N_157\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\,
datac => N_49622,
datab => \FPI.FLOP_1\(1));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_3_0_0_A2_1_RNIMDFR3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19777\,
dataf => \GRFPU0.GRFPU_X0.N_388\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\,
datad => \GRFPU0.GRFPU_X0.N_157\,
datac => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\,
datab => N_49622);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_31\,
dataf => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_25\,
datae => \FPI.OP2\(0),
datad => \FPI.OP2\(11),
datac => \FPI.OP2\(40),
datab => \FPI.OP2\(39));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_A2_4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0f000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_A2_4_0\(1),
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.N_130\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0),
datac => \GRFPC0.N_21123\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPC0.N_23428\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_A4_1\(1),
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.N_130\,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPC0.N_23556\,
dataf => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A2_1\(1),
datae => N_174898,
datad => \GRFPC0.N_23571\,
datac => \GRFPC0.N_130\,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0aaffccf0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(14),
datab => \GRFPC0.DIV.INST\(14),
dataa => \GRFPC0.WR2.CTRL.PC\(14));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN676_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN676_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_21029\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPU0_GRFPU_X0_UN28_EXP_ANC7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36324,
dataf => N_36304,
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(57),
datac => \FPI.OP2\(58),
datab => \FPI.OP2\(59));
GRFPU0_GRFPU_X0_UN28_EXP_ANC6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36319,
dataf => N_36304,
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(57),
datac => \FPI.OP2\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffc0f0e0f0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13),
dataf => \GRFPU0.GRFPU_X0.N_17631\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(13),
datac => \GRFPU0.GRFPU_X0.N_19496_0\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(13),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNI5GRL_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19484\,
datae => \GRFPU0.GRFPU_X0.N_6654\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(59),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(59),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPC0_D_STLCK_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"222222222222bbb2")
port map (
combout => \GRFPC0.N_22001\,
dataf => \GRFPC0.N_101\,
datae => \GRFPC0.FP_PIPELINE.10.STDEP_412_3_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datac => \GRFPC0.N_58\,
datab => \GRFPC0.N_107\,
dataa => \GRFPC0.N_17452\);
\GRFPU0_GRFPU_X0_UN38_EXP_M_RNI42H9_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\,
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(57),
datac => \FPI.OP2\(61),
datab => \FPI.OP2\(62));
GRFPU0_GRFPU_X0_UN13_EXP_1_CO5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
dataf => \GRFPU0.GRFPU_X0.N_388_3\,
datae => \FPI.OP1\(58),
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(60),
datab => \FPI.OP1\(57));
GRFPU0_GRFPU_X0_UN3_EXP_ANC3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36249,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(53),
datac => \FPI.OP1\(55));
GRFPU0_GRFPU_X0_UN3_EXP_ANC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_36244,
dataf => \FPI.OP1\(54),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(53));
GRFPC0_FP_PIPELINE_V_STATE10_RNI7DP09: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0cc00cc00cc00")
port map (
combout => \GRFPC0.N_21157\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => N_63);
\GRFPC0_DIV_ID_RNIIA3H9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_0__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(0),
datab => \GRFPC0.DIV.ID\(0));
\GRFPC0_DIV_ID_RNIKE3H9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_1__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(1),
datab => \GRFPC0.DIV.ID\(1));
\GRFPC0_DIV_ID_RNIMI3H9_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_2__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(2),
datab => \GRFPC0.DIV.ID\(2));
\GRFPC0_RFA2_FID_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_3__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(3),
datab => \GRFPC0.DIV.ID\(3));
\GRFPC0_RFA2_FID_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_4__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(4),
datab => \GRFPC0.DIV.ID\(4));
\GRFPC0_RFA2_FID_RNO_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_5__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.DIV.ID\(5));
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_O2_0_S_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffaebfaabb")
port map (
combout => \GRFPC0.N_132\,
dataf => \GRFPC0.N_20884\,
datae => \GRFPC0.N_21794\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datac => \GRFPC0.N_20838\,
datab => \GRFPC0.N_20834\,
dataa => \GRFPC0.N_105\);
\GRFPC0_D_LDLCK_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccc4ccc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1_3\,
dataf => \GRFPC0.N_23116\,
datae => \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\(0),
datad => \GRFPC0.N_24367\,
datac => \GRFPC0.N_24368\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
dataa => \GRFPC0.N_23401\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffe54")
port map (
combout => \GRFPC0.N_23737\,
dataf => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_2\(0),
datae => \GRFPC0.N_25208\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_3\(0),
datac => \GRFPC0.N_25165\,
datab => \GRFPC0.N_23872\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_35_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_221\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_1_0\(0),
datac => N_50792,
datab => N_174890);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24228\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => N_174890,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_1\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_0_3_0\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_190_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_227\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_0_1\(0),
datad => \GRFPC0.DIVI_0_SQMUXA_5\,
datac => N_174892,
datab => \FPI.FLOP_0\(6));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_25203_1\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.N_23711_LI\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_430_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24161\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.DIVI_0_SQMUXA_5\,
datad => \GRFPC0.N_23623\,
datac => \GRFPC0.N_23711_LI\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000ffff0000")
port map (
combout => \GRFPC0.N_24749\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.N_24798\,
datad => \GRFPC0.DIVI_0_SQMUXA_5\,
datac => N_50724,
datab => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_155_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2\,
datac => \GRFPC0.DIVI_0_SQMUXA_5\,
datab => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0fffffffffff")
port map (
combout => \GRFPC0.N_23649\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4\,
datae => N_100153,
datad => \GRFPC0.N_23658\,
datac => \GRFPC0.DIVI_0_SQMUXA_5\);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_26_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_1_STDEP178_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP178_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1332_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00303030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\(24),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.N_20478\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(24));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_26_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_82\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0cae")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(55),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(55),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f770f773f330f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_19607_I\,
dataf => \GRFPU0.GRFPU_X0.N_19652\,
datae => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_22\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.MRES\(68),
dataa => \GRFPU0.MULO.MRES\(69));
\GRFPC0_FP_PIPELINE_2_STDEP_100_0_IV_I_A2_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_A2_1_1\(0),
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN4_DEP_2\,
datac => \GRFPC0.N_21178\,
datab => \GRFPC0.N_21174\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_9_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000c000c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19838\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datae => \GRFPU0.GRFPU_X0.N_4066_0\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.N_19832\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_11_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000f000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19829\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datae => \GRFPU0.GRFPU_X0.N_4066_0\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_A2_9_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000f000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_19899\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datae => \GRFPU0.GRFPU_X0.N_4066_0\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ccccccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16749_I\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datad => \GRFPU0.GRFPU_X0.N_4066_0\,
datac => \GRFPU0.GRFPU_X0.N_7654\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(51),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(57),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(57),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(54),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(54),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54));
\GRFPC0_D_LDLCK_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaaac000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_21__G1_2\,
datae => \GRFPC0.N_89_1_0\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datac => \GRFPC0.N_21055_I\,
datab => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3304_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3320_REGDEPX\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_2_RNIC3B31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333ff3fffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1_SN_N_6\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_FP_PIPELINE_UN1_CPI_7_RNIG9U95: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000c000cc00c0")
port map (
combout => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => N_50358,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_7\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.N_78_I_I\);
GRFPC0_MEM_CTRL_STDFQ_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000c000cc00c0")
port map (
combout => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => N_50358,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_7\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.EX.CTRL.STDFQ\);
GRFPC0_VFIFO_INST_1_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3fffff")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_0\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datad => N_52826,
datac => N_50358,
datab => \GRFPC0.FIFO.WR\(0));
GRFPC0_VFIFO_INST_0_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffcfffff")
port map (
combout => \GRFPC0.VFIFO.INST_0_1_0\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datad => N_52826,
datac => N_50358,
datab => \GRFPC0.FIFO.WR\(0));
\GRFPC0_EX_CTRL_PC_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccfc")
port map (
combout => N_53055,
dataf => N_52636,
datae => N_52634,
datad => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datac => N_50358,
datab => \GRFPC0.EX.CTRL.PC\(27));
\GRFPC0_EX_CTRL_PC_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccfc")
port map (
combout => N_53056,
dataf => N_52672,
datae => N_52670,
datad => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datac => N_50358,
datab => \GRFPC0.EX.CTRL.PC\(28));
\GRFPC0_EX_CTRL_PC_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccfc")
port map (
combout => N_53057,
dataf => N_52708,
datae => N_52706,
datad => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datac => N_50358,
datab => \GRFPC0.EX.CTRL.PC\(29));
GRFPC0_FID_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.FID_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => N_50358,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datab => N_64);
GRFPC0_FP_PIPELINE_UN1_CPI_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfcfccc0cfcf")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_12\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => N_50358,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.LD\,
datab => N_64);
GRFPC0_DIV_VALID_RNIJB0AF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN\,
dataf => \GRFPC0.DIV.VALID\,
datae => N_63,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
datac => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datab => N_50358);
GRFPC0_FP_PIPELINE_VRFA_LD_1_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.N_22811\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => N_50358,
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
GRFPC0_FP_PIPELINE_VRFA_RDWR_1_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => N_50358,
datac => N_138,
datab => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP\);
GRFPC0_EX_CTRL_LD_RNI26KB5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000ccc0c00")
port map (
combout => N_52992_1,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => N_50358,
datad => \GRFPC0.EX.CTRL.LD\,
datac => N_64,
datab => N_61);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cfcfc0cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(2),
datae => \GRFPU0.GRFPU_X0.L4_1\(2),
datad => \GRFPU0.GRFPU_X0.L4_1\(3),
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
GRFPU0_GRFPU_X0_VITER_DBUF_13_SUM4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f00ff00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(4),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(2),
datae => \GRFPU0.GRFPU_X0.L4_1\(2),
datad => \GRFPU0.GRFPU_X0.L4_1\(3),
datac => \GRFPU0.GRFPU_X0.L4_1\(4));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_O2_4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c0c0c0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_O2_4_0\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0\(1),
datad => N_50792,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_9_0\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23867\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_24127_1\,
datad => N_50724,
datac => N_50792,
datab => \GRFPC0.V.STDATA_14\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.N_10716\);
GRFPC0_STDEP_2_SQMUXA_133_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_133_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\);
GRFPC0_UN1_STDEP682: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c000c000000")
port map (
combout => \GRFPC0.UN1_STDEP682\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(40),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPC0_D_STLCK_RNO_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2f22")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_2\,
dataf => \GRFPC0.N_163\,
datae => \GRFPC0.N_191\,
datad => \GRFPC0.N_22455\,
datac => \GRFPC0.N_22006\,
datab => \GRFPC0.N_21998\,
dataa => \GRFPC0.N_22942_1\);
\GRFPC0_D_STLCK_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0cff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_4\,
dataf => \GRFPC0.N_22721\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.D.STLCK_0_0_7__G1_2\,
datac => \GRFPC0.N_21016_1\,
datab => \GRFPC0.N_21012\);
\GRFPC0_FP_PIPELINE_13_STDEP_524_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc0000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_524\(1),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_0_2_RNI8OMH7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
dataf => \GRFPC0.D.LDLCK_0_0_5__G1_0_14\,
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.N_25522_2\,
datac => N_174892,
datab => \FPI.FLOP_0\(6));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.N_24088\,
datac => N_174892,
datab => \FPI.FLOP_0\(6));
GRFPU0_GRFPU_X0_ST1_V_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8a2a00002a8a0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11356\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH\,
datae => \GRFPU0.GRFPU_X0.N_80\,
datad => \FPI.OPID\(5),
datac => \FPI.FLUSH\,
datab => \FPI.FLUSHID\(5),
dataa => N_61);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(25),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffbaaaffff1200")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(62),
dataf => \GRFPU0.GRFPU_X0.N_19837\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(62),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datac => N_36200,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"08000c000a000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(34),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(34),
datac => \GRFPU0.GRFPU_X0.N_19334\,
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_O2_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0fff3")
port map (
combout => \GRFPU0.GRFPU_X0.N_18\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.N_19890\,
datad => \GRFPU0.GRFPU_X0.N_19840\,
datac => \GRFPU0.GRFPU_X0.N_4066_0\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03ffff0f0300ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(59),
datae => \GRFPU0.GRFPU_X0.N_13127_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.N_19890\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_24209\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23623\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN61_REGDEPX2_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(36),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
GRFPU0_GRFPU_X0_UN28_EXP_ANC8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36329,
dataf => N_36314,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(59),
datac => \FPI.OP2\(60));
GRFPU0_GRFPU_X0_UN3_EXP_ANC5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36259,
dataf => \GRFPU0.GRFPU_X0.N_19778_1\,
datae => \FPI.OP1\(54),
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(56),
datab => \FPI.OP1\(57));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25540\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => N_50724,
datad => N_50792,
datac => \GRFPC0.V.STDATA_14_M_5\(0),
datab => \GRFPC0.N_25540_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcccc0fff0ccc")
port map (
combout => \GRFPC0.N_23449\,
dataf => \GRFPC0.N_23474\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_23403\,
datac => \GRFPC0.N_23398\,
datab => \GRFPC0.N_78_I_I_2\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(12),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(29),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPC0_D_STLCK_RNO_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffefffaf")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_5\,
dataf => \GRFPC0.N_23449\,
datae => \GRFPC0.N_23474\,
datad => \GRFPC0.N_23452\,
datac => \GRFPC0.N_23403\,
datab => \GRFPC0.N_23398\,
dataa => \GRFPC0.D.STLCK_0_0_24__G1_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.N_10716\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000300000")
port map (
combout => \GRFPC0.N_21763\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datad => \GRFPC0.N_21704\,
datac => \GRFPC0.N_21703\,
datab => \GRFPC0.N_131_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(32),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"08000c000a000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(21),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(21),
datac => \GRFPU0.GRFPU_X0.N_19332\,
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000303000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPC0_D_STLCK_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_3\,
dataf => \GRFPC0.N_23064\,
datae => \GRFPC0.N_23030\,
datad => \GRFPC0.N_159\,
datac => \GRFPC0.N_158\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0),
dataa => \GRFPC0.N_22942_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"08000c000a000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(38),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(38),
datac => \GRFPU0.GRFPU_X0.N_20670\,
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(8),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPC0_EX_CTRL_INST_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53021,
dataf => N_51424,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51426,
datab => \GRFPC0.EX.CTRL.INST\(23));
GRFPC0_RFA_STDFQ_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_2421_A2_1\,
dataf => N_50421_9,
datae => N_127,
datad => N_122,
datac => N_50421_2,
datab => N_137);
\GRFPC0_EX_CTRL_INST_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53005,
dataf => N_50892,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(2),
datab => \GRFPC0.EX.CTRL.INST\(7));
\GRFPC0_D_LDLCK_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffcfc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\(1),
datad => \GRFPC0.N_24635\,
datac => \GRFPC0.D.LDLCK_0_0_31__G1_5\,
datab => \GRFPC0.D.LDLCK_0_0_31__G1_6\);
\GRFPU0_GRFPU_X0_UN13_EXP_1_SUM_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => N_36217,
dataf => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(60),
datac => \FPI.OP1\(61),
datab => \FPI.OP1\(62));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcfffffcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_8127_M_I\,
dataf => \GRFPU0.GRFPU_X0.N_20304\,
datae => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datad => \FPI.OP2\(54),
datac => \GRFPU0.GRFPU_X0.N_194\,
datab => \FPI.FLOP_0\(1));
\GRFPC0_R_FSR_CEXC_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc8ff88ffc0ff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
datac => \GRFPU0.GRFPU_X0.N_19274_I_0\,
datab => \GRFPC0.R.FSR.TEM\(4),
dataa => \GRFPC0.WR2.RREG.EXCT\(4));
\GRFPC0_EX_CTRL_INST_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53001,
dataf => N_50756,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(3),
datab => \GRFPC0.EX.CTRL.INST\(3));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff002000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_2_4__N_6\,
datad => \GRFPU0.GRFPU_X0.N_19777\,
datac => N_36244,
datab => \FPI.OP1\(51),
dataa => \FPI.FLOP\(1));
\GRFPC0_EX_CTRL_INST_RNI1DRAE_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53024,
dataf => N_51526,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_EX_CTRL_INST_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53011,
dataf => N_51096,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(8),
datab => \GRFPC0.EX.CTRL.INST\(13));
\GRFPC0_EX_CTRL_INST_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53010,
dataf => N_51062,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(7),
datab => \GRFPC0.EX.CTRL.INST\(12));
\GRFPC0_EX_CTRL_INST_RNI7PRAE_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53025,
dataf => N_51560,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_3_REGDEPX_70_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff404040")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX_70\(0),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX_66\(0),
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_14\(0),
datad => N_174900,
datac => \GRFPC0.N_22649\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
dataa => N_122);
\GRFPC0_FP_PIPELINE_5_REGDEPX_106_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff404040ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_106\(0),
dataf => \GRFPC0.N_22538\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_15\(0),
datad => N_174900,
datac => \GRFPC0.N_22649\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
dataa => N_122);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00ff0c")
port map (
combout => \GRFPC0.N_83\,
dataf => N_52020_2,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_10_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_22878\,
dataf => N_52020_2,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(2),
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_15_RNIMIJ96: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_129_I_1\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
GRFPC0_STDDEP_0_SQMUXA_131: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_131\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_RNIH2476: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.N_22542\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
datac => N_138,
datab => \GRFPC0.RFA.LD_0_0_I0_I_1\);
\GRFPC0_EX_CTRL_INST_RNIG0UPD_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_52998,
dataf => N_50654,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_50656_0,
datab => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_D_STDLCK_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffbfffffffbb")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_21749\,
datad => \GRFPC0.N_21775\,
datac => \GRFPC0.N_21710\,
datab => \GRFPC0.N_22439\,
dataa => \GRFPC0.D.STDLCK_0_0_6__G1_0\);
\GRFPC0_EX_CTRL_INST_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53004,
dataf => N_50858,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP_0\(1),
datab => \GRFPC0.EX.CTRL.INST\(6));
\GRFPC0_EX_CTRL_INST_RNI7J9AE_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53015,
dataf => N_51232,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(17),
datab => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_EX_CTRL_INST_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53029,
dataf => N_51690,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(31),
datab => \GRFPC0.EX.CTRL.INST\(31));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24946\,
dataf => \GRFPC0.N_24483_I\,
datae => \GRFPC0.N_24712_2\,
datad => \GRFPC0.V.STDATA_14\(17),
datac => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.V.STDATA_14\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_O2_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fc0000000000")
port map (
combout => N_100290,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_6328\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
GRFPU0_GRFPU_X0_UN3_EXP_ANC6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36264,
dataf => N_36244,
datae => \FPI.OP1\(55),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(58),
datab => \FPI.OP1\(57));
\GRFPC0_EX_CTRL_INST_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_52999,
dataf => N_50688,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_EX_CTRL_INST_RNIOE8AE_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53012,
dataf => N_51130,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.EX.CTRL.INST\(14));
GRFPC0_D_FSTLCK_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f003f003f33")
port map (
combout => \GRFPC0.N_20796\,
dataf => N_52020_2,
datae => N_49622_0,
datad => \GRFPC0.RFA.RDWR\,
datac => N_63,
datab => N_64);
\GRFPC0_FP_PIPELINE_VEX_CTRL_RD_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f3c0")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1\(1),
dataf => N_52020,
datae => N_49622_0,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.RFA.RD\(1),
datab => N_64);
\GRFPC0_FP_PIPELINE_VEX_CTRL_RD_1_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f3c0")
port map (
combout => \GRFPC0.N_23661\,
dataf => N_52020,
datae => N_49622_0,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datac => \GRFPC0.RFA.RD\(0),
datab => N_64);
\GRFPC0_EX_CTRL_INST_RNIB5SAE_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53026,
dataf => N_51594,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_EX_CTRL_INST_RNICV9AE_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53016,
dataf => N_51266,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_EX_CTRL_INST_RNIHHSAE_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53027,
dataf => N_51628,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.EX.CTRL.INST\(29));
\GRFPC0_EX_CTRL_INST_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53003,
dataf => N_50824,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(0),
datab => \GRFPC0.EX.CTRL.INST\(5));
\GRFPC0_EX_CTRL_INST_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53019,
dataf => N_51362,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51364,
datab => \GRFPC0.EX.CTRL.INST\(21));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.N_24942\,
dataf => \GRFPC0.N_24909\,
datae => \GRFPC0.N_23623\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_1__G3\);
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.N_87\,
dataf => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datae => \GRFPU0.GRFPU_X0.N_20294\,
datad => \FPI.OP2\(54),
datac => \FPI.FLOP\(0),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_4\,
dataf => \GRFPU0.GRFPU_X0.N_221\,
datae => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datad => \GRFPU0.GRFPU_X0.N_20294\,
datac => \FPI.OP2\(54),
datab => \GRFPU0.GRFPU_X0.N_20313_I\);
\GRFPC0_EX_CTRL_INST_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53000,
dataf => N_50722,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_50724,
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_EX_CTRL_INST_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53006,
dataf => N_50926,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(3),
datab => \GRFPC0.EX.CTRL.INST\(8));
\GRFPC0_EX_CTRL_INST_RNI279AE_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53014,
dataf => N_51198,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.EX.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_ORV_TMP_1_RNI2G2H5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300033003f00")
port map (
combout => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.RDD\,
datac => \GRFPC0.MEM.CTRL.LD\,
datab => N_64);
GRFPC0_WR_CTRL_STDFQ_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30003000303030f0")
port map (
combout => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.MEM.CTRL.STDFQ\,
datab => N_64);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A3_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0000070500000")
port map (
combout => \GRFPC0.N_21963\,
dataf => \GRFPC0.N_21949\,
datae => \GRFPC0.N_21882\,
datad => \GRFPC0.N_21794\,
datac => \GRFPC0.N_21472\,
datab => \GRFPC0.N_21468\,
dataa => \GRFPC0.N_21477\);
\GRFPC0_R_FSR_CEXC_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffeaffc0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(2),
datac => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(2),
dataa => \GRFPC0.DIV.EXCT\(2));
\GRFPC0_EX_CTRL_INST_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53007,
dataf => N_50960,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(4),
datab => \GRFPC0.EX.CTRL.INST\(9));
\GRFPC0_EX_CTRL_INST_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53017,
dataf => N_51300,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(19),
datab => \GRFPC0.EX.CTRL.INST\(19));
\GRFPC0_EX_CTRL_INST_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53002,
dataf => N_50790,
datae => N_52020,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_50792,
datab => \GRFPC0.EX.CTRL.INST\(4));
\GRFPC0_D_STLCK_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffefffe")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1_3\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_21775\,
datad => \GRFPC0.N_22513\,
datac => \GRFPC0.N_110\,
datab => \GRFPC0.N_22494\,
dataa => \GRFPC0.N_22477\);
\GRFPC0_R_FSR_CEXC_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc8ff88ffc0ff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datab => \GRFPC0.R.FSR.TEM\(3),
dataa => \GRFPC0.WR2.RREG.EXCT\(3));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_0_RNIUQ4K1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7fff7fff55557fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20282_I\,
dataf => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datae => \GRFPU0.GRFPU_X0.N_20295\,
datad => \GRFPU0.GRFPU_X0.N_20317\,
datac => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\,
datab => \GRFPU0.GRFPU_X0.N_343_3\,
dataa => \GRFPU0.GRFPU_X0.N_80_0\);
\GRFPC0_EX_CTRL_INST_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53022,
dataf => N_51458,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51460,
datab => \GRFPC0.EX.CTRL.INST\(24));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_24832\,
dataf => \GRFPC0.N_24910\,
datae => N_50724,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datab => N_174890);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_24848\,
dataf => \GRFPC0.N_24910\,
datae => N_50724,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datab => N_174890);
\GRFPC0_EX_CTRL_INST_RNITQ8AE_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53013,
dataf => N_51164,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.V.STDATA_14\(15),
datab => \GRFPC0.EX.CTRL.INST\(15));
GRFPC0_FIFO_FULL_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccf00000000")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1\,
dataf => \GRFPC0.FIFO.FULL_0_0_G1_0\,
datae => \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\(0),
datad => N_52020_1,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_EX_CTRL_INST_RNIR0RAE_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53023,
dataf => N_51492,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.EX.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(58),
dataf => \GRFPU0.GRFPU_X0.N_18\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(7),
datac => \GRFPU0.GRFPU_X0.N_19832\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_7_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19836\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datad => \GRFPU0.GRFPU_X0.N_19831\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.N_19823\);
\GRFPC0_EX_CTRL_INST_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53009,
dataf => N_51028,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(6),
datab => \GRFPC0.EX.CTRL.INST\(11));
\GRFPC0_EX_CTRL_INST_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53008,
dataf => N_50994,
datae => N_52020_2,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \FPI.FLOP\(5),
datab => \GRFPC0.EX.CTRL.INST\(10));
GRFPC0_REN1_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000303300000000")
port map (
combout => \GRFPC0.REN1_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datae => N_448,
datad => \GRFPC0.RFA.ST\,
datac => N_63,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_1_RNIJ6151_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff3f0000")
port map (
combout => N_38008,
dataf => \GRFPC0.N_21137_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_1_RNIJ6151_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff003f00")
port map (
combout => N_38007,
dataf => \GRFPC0.N_21137_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.EXEC\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11247\,
dataf => \GRFPU0.GRFPU_X0.N_4045\,
datae => \GRFPU0.GRFPU_X0.N_7680\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(1));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11248\,
dataf => \GRFPU0.GRFPU_X0.N_4045\,
datae => \GRFPU0.GRFPU_X0.N_7680\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(2));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11250\,
dataf => \GRFPU0.GRFPU_X0.N_4045\,
datae => \GRFPU0.GRFPU_X0.N_7680\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(4));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11251\,
dataf => \GRFPU0.GRFPU_X0.N_4045\,
datae => \GRFPU0.GRFPU_X0.N_7680\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c033f0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(45),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(45),
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c033f0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(46),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(46),
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c303fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(47),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f333fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(48),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f333fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(49),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f333fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(50),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f333fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(51),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
GRFPC0_D_FSTLCK_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff5444fffffccc")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_14\,
dataf => \GRFPC0.FP_PIPELINE.UN105_HOLDN\,
datae => \GRFPC0.D.FSTLCK_0_0_G1_12\,
datad => \GRFPC0.RFA.LD_0\,
datac => \GRFPC0.RFA.AFSR\,
datab => \GRFPC0.RFA.STDFQ\,
dataa => N_63);
\GRFPC0_D_STDLCK_RNO_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f888f00088880000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_5_TZ\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_4\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_3\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_8_4_2\,
dataa => \GRFPC0.N_78_I_I_0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_2_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(61),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(61),
datae => \GRFPU0.GRFPU_X0.N_19803\,
datad => \GRFPU0.GRFPU_X0.N_19829\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(10),
datab => \GRFPU0.GRFPU_X0.N_19832\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_2_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(62),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(62),
datae => \GRFPU0.GRFPU_X0.N_19808\,
datad => \GRFPU0.GRFPU_X0.N_19829\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(11),
datab => \GRFPU0.GRFPU_X0.N_19832\);
\GRFPC0_D_STDLCK_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0fffffff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_4\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.N_180\,
datad => \GRFPC0.D.STDLCK_0_0_0__G1_2\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STDLCK_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0fff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1\,
dataf => \GRFPC0.N_21598\,
datae => \GRFPC0.N_22811\,
datad => \GRFPC0.D.STDLCK_0_0_7__G1_5\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_O2_3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0fffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_2\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_0\,
datad => N_100325,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
GRFPU0_GRFPU_X0_UN3_EXP_ANC7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_36269,
dataf => N_36249,
datae => \FPI.OP1\(58),
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(56),
datab => \FPI.OP1\(57));
\GRFPC0_FIFO_VCNT_0_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0c3c3fcf0cf0f")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0_2__G2\,
dataf => N_52020_1,
datae => \GRFPC0.FP_PIPELINE.VFIFO.VCNT_0_1_F1_0_O4_1\(2),
datad => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datac => \GRFPC0.FIFO.VCNT_0\(2),
datab => N_61);
\GRFPC0_D_STDLCK_RNO_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_4\,
dataf => \GRFPC0.N_150\,
datae => \GRFPC0.N_17302\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.D.STDLCK_0_0_12__G1_1\,
datab => \GRFPC0.N_24443\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0f000f0")
port map (
combout => \GRFPC0.N_23137\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ff00ff")
port map (
combout => \GRFPC0.N_23347\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_D_STLCK_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fcffff00f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_5\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datae => \GRFPC0.D.STLCK_0_0_11__G1_4\,
datad => \GRFPC0.N_22542\,
datac => N_128,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_D_STLCK_RNO_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0c0f00")
port map (
combout => \GRFPC0.N_22053\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.N_21998\,
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
GRFPC0_FP_PIPELINE_VRFA_ST4_I_O4_I_A2_0_A2_RNIDDGC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff0ff00")
port map (
combout => \GRFPC0.N_22486_1\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffc0ff00")
port map (
combout => \GRFPC0.N_22721\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\(0),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_I_A3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003000f0")
port map (
combout => \GRFPC0.N_21942\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_FP_PIPELINE_4_STDEP_180_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f3f0fff")
port map (
combout => \GRFPC0.N_17183\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_FP_PIPELINE_4_STDEP_180_0_IV_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3f0fff0f")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_180_0_IV_TZ\(0),
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
datad => N_128,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datab => \GRFPC0.FP_PIPELINE.VRFA.ST4\);
\GRFPC0_D_STDLCK_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fffffffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_3\,
dataf => \GRFPC0.N_22811\,
datae => \GRFPC0.STDDEP_0_SQMUXA_87\,
datad => \GRFPC0.STDDEP_0_SQMUXA_125\,
datac => \GRFPC0.D.STDLCK_0_0_2__G1_0\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(2),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_O2_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcff88")
port map (
combout => \GRFPU0.GRFPU_X0.N_19853\,
dataf => N_100290,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.N_19890\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datab => \GRFPU0.GRFPU_X0.N_4066_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_A2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0c0000cf0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_389\,
dataf => \GRFPU0.GRFPU_X0.N_19722\,
datae => \GRFPU0.GRFPU_X0.N_19767\,
datad => \GRFPU0.GRFPU_X0.N_19768\,
datac => \FPI.FLOP_1_0\(1),
datab => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_UN3_EXP_ANC8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36274,
dataf => N_36259,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(60));
\GRFPC0_D_STDLCK_RNO_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffdffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_8\,
dataf => \GRFPC0.D.STDLCK_0_0_15__G1_6\,
datae => \GRFPC0.STDDEP_0_SQMUXA_129_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_12_7\,
datac => \GRFPC0.D.STDLCK_0_0_15__G1_2\,
datab => \GRFPC0.N_23148\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_117_I_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_402_0_IV_I_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000300")
port map (
combout => \GRFPC0.N_22113\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datae => \GRFPC0.N_22811\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datac => \GRFPC0.N_21996\,
datab => N_128);
\GRFPC0_D_STLCK_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff20")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1\,
dataf => \GRFPC0.N_22709\,
datae => \GRFPC0.D.STLCK_0_0_6__G1_2\,
datad => \GRFPC0.N_22757\,
datac => \GRFPC0.N_83\,
datab => N_128,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_O2_RNIAHLCN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c000ff33cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G4\,
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.N_19722\,
datad => \GRFPU0.GRFPU_X0.N_19768\,
datac => \FPI.OP1\(51),
datab => \FPI.FLOP\(1));
\GRFPC0_D_STDLCK_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1\,
dataf => \GRFPC0.N_21746\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.N_21763\,
datac => \GRFPC0.D.STDLCK_0_0_6__G1_4\,
datab => \GRFPC0.N_21760\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6));
\GRFPC0_D_STDLCK_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1\,
dataf => \GRFPC0.N_21525\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.N_21973\,
datac => \GRFPC0.N_21523\,
datab => \GRFPC0.D.STDLCK_0_0_11__G1_3\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11));
\GRFPC0_D_STLCK_RNO_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.N_20968\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datae => \GRFPC0.N_22811\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => N_128);
\GRFPC0_FP_PIPELINE_15_STDEP_604_0_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000f000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_604\(0),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.N_23535_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
\GRFPC0_FP_PIPELINE_15_STDEP_604_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000cc0000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_604\(1),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.N_23535_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_11_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_7_7_3\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(6),
datac => \GRFPC0.INST\(7));
\GRFPC0_D_LDLCK_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1\,
dataf => \GRFPC0.N_25519\,
datae => \GRFPC0.N_25495_2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_11\(0),
datac => \GRFPC0.D.LDLCK_0_0_4__G1_4\,
datab => \GRFPC0.N_22835\);
GRFPC0_D_FLDLCK_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\,
datad => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datab => \GRFPC0.D.FLDLCK_0_0_G1_1\);
\GRFPC0_RFA2_FOP_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_1__G0_0\,
dataf => \GRFPC0.INST\(19),
datae => \GRFPC0.INST\(24),
datad => \GRFPC0.INST\(23),
datac => \GRFPC0.INST\(31),
datab => \GRFPC0.INST\(21));
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15_RNIK1992: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f444fccc4444cccc")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datae => \GRFPC0.FP_PIPELINE.UN108_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\,
datac => \GRFPC0.V.STDATA_14\(31),
datab => \GRFPC0.RFA.RDD\,
dataa => N_63);
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeeccc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3_0\,
dataf => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_8\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(6),
datab => \GRFPC0.INST\(9),
dataa => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_RS1V13_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_1_0\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(6),
datad => \GRFPC0.INST\(8),
datac => \GRFPC0.INST\(13));
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcf0f0f00cc0000")
port map (
combout => \GRFPC0.N_22307\,
dataf => \GRFPC0.N_22422\,
datae => \GRFPC0.N_94\,
datad => \GRFPC0.N_22811\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7));
\GRFPC0_FP_PIPELINE_0_STDEP_562_0_IV_I_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000c000c000")
port map (
combout => \GRFPC0.N_23337\,
dataf => \GRFPC0.N_94\,
datae => \GRFPC0.N_22811\,
datad => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.N_22942_1\);
\GRFPC0_D_STLCK_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfdfcfc")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1\,
dataf => \GRFPC0.N_22013\,
datae => \GRFPC0.N_94\,
datad => \GRFPC0.N_22811\,
datac => \GRFPC0.N_109\,
datab => \GRFPC0.D.STLCK_0_0_20__G1_3\,
dataa => \GRFPC0.N_21998\);
\GRFPC0_D_STLCK_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8f8f8fc")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1\,
dataf => \GRFPC0.N_23257\,
datae => \GRFPC0.N_23443\,
datad => \GRFPC0.N_22811\,
datac => \GRFPC0.D.STLCK_0_0_29__G1_0\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14),
dataa => \GRFPC0.N_22485_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21683\,
dataf => \GRFPC0.N_21553\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
datac => \GRFPC0.N_21620\,
datab => \GRFPC0.N_21622\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(28),
datad => \FPI.OP1\(20),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPC0_RFA2_FOP_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0c0c0c000")
port map (
combout => \GRFPC0.N_10172\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8\,
datac => \GRFPC0.N_10173_2\,
datab => \GRFPC0.INST\(31));
GRFPC0_RFA_WRITE_RD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00c0000000")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
dataf => \GRFPC0.N_20674\,
datae => \GRFPC0.N_20672\,
datad => \GRFPC0.N_10173_2\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_1\,
datab => \GRFPC0.INST\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
datad => \FPI.OP2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(10),
datad => \FPI.OP1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(20),
datad => \FPI.OP1\(12),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(31),
datad => \FPI.OP1\(23),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
datad => \FPI.OP2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
datad => \FPI.OP2\(20),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
datad => \FPI.OP2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(23),
datad => \FPI.OP1\(15),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(27),
datad => \FPI.OP1\(19),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20889_I\,
datad => \FPI.OP2\(8),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(29),
datad => \FPI.OP1\(21),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
datad => \FPI.OP2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPC0_FP_PIPELINE_1_REGDEP172: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ca35000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP172\,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEP172_1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP172_0\,
datad => RFI2_RD2ADDRZ(2),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datab => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
dataa => \GRFPC0.RFA.RD\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
datad => \FPI.OP2\(12),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
datad => \FPI.OP2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(16),
datad => \FPI.OP1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPC0_D_STLCK_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefcfaf0")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1\,
dataf => \GRFPC0.N_22225\,
datae => \GRFPC0.N_132\,
datad => \GRFPC0.N_23347\,
datac => \GRFPC0.D.STLCK_0_0_16__G1_3\,
datab => \GRFPC0.N_20833\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
datad => \FPI.OP2\(15),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20887_I\,
datad => \FPI.OP2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
datad => \FPI.OP2\(13),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
datad => \FPI.OP2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPC0_STDDEP_0_SQMUXA_182: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"07770fff04440000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_182\,
dataf => \GRFPC0.UN1_STDDEP_0_SQMUXA_100\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\,
dataa => \GRFPC0.MEM.CTRL.RDD\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
datad => \FPI.OP2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(17),
datad => \FPI.OP1\(9),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
datad => \FPI.OP2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(15),
datad => \FPI.OP1\(7),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(22),
datad => \FPI.OP1\(14),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(8),
datad => \FPI.OP1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(9),
datad => \FPI.OP1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(24),
datad => \FPI.OP1\(16),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20893_I\,
datad => \FPI.OP2\(23),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20890_I\,
datad => \FPI.OP2\(1),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
datad => \FPI.OP2\(11),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(13),
datad => \FPI.OP1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
datad => \FPI.OP2\(27),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(26),
datad => \FPI.OP1\(18),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(32),
datad => \FPI.OP1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
datad => \FPI.OP2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
datad => \FPI.OP2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
datad => \FPI.OP2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(34),
datad => \FPI.OP1\(26),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20888_I\,
datad => \FPI.OP2\(22),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.N_20886_I\,
datad => \FPI.OP2\(21),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(36),
datad => \FPI.OP1\(28),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
datad => \FPI.OP2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPC0_D_STLCK_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffaaff00ffefffcf")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1\,
dataf => \GRFPC0.N_22\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.D.STLCK_0_0_13__G1_5\,
datac => \GRFPC0.N_21710\,
datab => \GRFPC0.N_22439\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(12),
datad => \FPI.OP1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
datad => \FPI.OP2\(10),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPC0_D_STLCK_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1\,
dataf => \GRFPC0.N_21963\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_21942\,
datac => \GRFPC0.N_21973\,
datab => \GRFPC0.D.STLCK_0_0_22__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(21),
datad => \FPI.OP1\(13),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
datad => \FPI.OP2\(25),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(25),
datad => \FPI.OP1\(17),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(14),
datad => \FPI.OP1\(6),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
datad => \FPI.OP2\(7),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(18),
datad => \FPI.OP1\(10),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(30),
datad => \FPI.OP1\(22),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(11),
datad => \FPI.OP1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(35),
datad => \FPI.OP1\(27),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(33),
datad => \FPI.OP1\(25),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
datad => \FPI.OP2\(3),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_19713\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(19),
datad => \FPI.OP1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
datad => \FPI.OP2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPC0_UN1_EX_CTRL_RDD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3c3c3c3ccccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP74\,
dataf => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
datac => \GRFPC0.INST\(31),
datab => \GRFPC0.N_78_I_I\);
\GRFPC0_D_STLCK_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffbfff5fff1ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1\,
dataf => \GRFPC0.N_17424\,
datae => \GRFPC0.FP_PIPELINE.4.STDEP_172\(1),
datad => \GRFPC0.N_17183\,
datac => \GRFPC0.D.STLCK_0_0_9__G1_3\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL0\,
dataa => \GRFPC0.N_17422\);
\GRFPC0_D_STLCK_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffca8")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1\,
dataf => \GRFPC0.D.STLCK_0_0_17__G1_1\,
datae => \GRFPC0.N_22207\,
datad => \GRFPC0.N_22183\,
datac => \GRFPC0.N_22486_1\,
datab => \GRFPC0.N_22485_1\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_16_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(1),
dataf => \GRFPC0.N_24276\,
datae => \GRFPC0.N_16961\,
datad => \GRFPC0.N_16955\,
datac => \GRFPC0.N_16975\,
datab => \GRFPC0.INST\(28),
dataa => \GRFPC0.INST\(29));
\GRFPC0_D_LDLCK_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
datae => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
datad => \GRFPC0.N_23412\,
datac => \GRFPC0.N_91_1\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffff3f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_89\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_1\(0),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPU0_GRFPU_X0_L1_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcffff0000")
port map (
combout => N_124847,
dataf => \GRFPU0.GRFPU_X0.N_10583\,
datae => \GRFPU0.GRFPU_X0.N_3533\,
datad => \GRFPU0.GRFPU_X0.TZI\(4),
datac => \GRFPU0.GRFPU_X0.TZI\(5),
datab => \GRFPU0.GRFPU_X0.N_3336\);
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f3f003f")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX_102_I_A4_1\(0),
dataf => \GRFPC0.N_22603\,
datae => \GRFPC0.N_22560\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.N_22443\,
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000a0008")
port map (
combout => \GRFPU0.GRFPU_X0.N_11283\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.N_5430\,
datad => \GRFPU0.GRFPU_X0.N_19408\,
datac => \GRFPU0.GRFPU_X0.N_19318_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
dataa => N_61);
GRFPC0_FP_PIPELINE_RSDEC_RS1V7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7_1\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(12),
datab => \GRFPC0.INST\(10),
dataa => \GRFPC0.INST\(9));
GRFPC0_LDLOCK_6_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23489\,
dataf => \GRFPC0.D.STDLCK\(1),
datae => \GRFPC0.D.STDLCK\(5),
datad => \GRFPC0.D.STDLCK\(13),
datac => \GRFPC0.D.STDLCK\(9),
datab => N_131,
dataa => N_132);
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIHU5C2_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0040000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_8\,
dataf => \GRFPU0.GRFPU_X0.N_6661_6\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI1R171_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00fffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(21));
GRFPC0_LDLOCK_1_3_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23500\,
dataf => \GRFPC0.D.STLCK\(0),
datae => \GRFPC0.D.STLCK\(16),
datad => \GRFPC0.D.STLCK\(17),
datac => \GRFPC0.D.STLCK\(1),
datab => N_132,
dataa => N_128);
GRFPC0_VFIFO_WR_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR\(0));
\GRFPC0_STDATA_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(21),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(21),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(21),
dataa => \GRFPC0.EX.RREG.RES\(53));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000d00000000")
port map (
combout => \GRFPC0.N_24967\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.N_23741\,
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.RDD_1\,
dataa => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_DBGDATA_4_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(8),
dataf => N_660,
datae => N_724,
datad => N_451,
datac => \GRFPC0.R.FSR.AEXC\(3),
datab => N_450);
\GRFPC0_FP_PIPELINE_DBGDATA_4_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(6),
dataf => N_658,
datae => N_722,
datad => N_451,
datac => \GRFPC0.R.FSR.AEXC\(1),
datab => N_450);
GRFPU0_GRFPU_X0_COMB_VST2_REG107: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000004000004040")
port map (
combout => \GRFPU0.GRFPU_X0.N_4352\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_I_M3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23595\,
dataf => \GRFPC0.D.LDLCK\(1),
datae => \GRFPC0.D.LDLCK\(9),
datad => \GRFPC0.D.LDLCK\(25),
datac => \GRFPC0.D.LDLCK\(17),
datab => N_131,
dataa => N_132);
GRFPC0_LDLOCK_1_18_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23511\,
dataf => \GRFPC0.D.STLCK\(8),
datae => \GRFPC0.D.STLCK\(24),
datad => \GRFPC0.D.STLCK\(25),
datac => \GRFPC0.D.STLCK\(9),
datab => N_132,
dataa => N_128);
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffff0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
dataf => \GRFPC0.FPR.RDY\,
datae => \GRFPC0.EX.CTRL.ID\(5),
datad => \GRFPC0.FPR.ID\(5),
datac => \GRFPC0.EX.CTRL.ID\(7));
GRFPC0_LDLOCK_1_10_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23506\,
dataf => \GRFPC0.D.STLCK\(4),
datae => \GRFPC0.D.STLCK\(20),
datad => \GRFPC0.D.STLCK\(21),
datac => \GRFPC0.D.STLCK\(5),
datab => N_132,
dataa => N_128);
\GRFPU0_GRFPU_X0_L1_5_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffafaffccffcc")
port map (
combout => N_124820,
dataf => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3806\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
GRFPU0_GRFPU_X0_COMB_UINT17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc000000cc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_4296\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_I_M3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23602\,
dataf => \GRFPC0.D.LDLCK\(5),
datae => \GRFPC0.D.LDLCK\(13),
datad => \GRFPC0.D.LDLCK\(29),
datac => \GRFPC0.D.LDLCK\(21),
datab => N_131,
dataa => N_132);
GRFPC0_D_FSTLCK_RNO_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_7\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.MEM.CTRL.AFSR\,
datab => \GRFPC0.EX.CTRL.AFSR\);
GRFPU0_GRFPU_X0_UN98_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10901\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_NXX_1_I_A2_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_16\,
dataf => \GRFPU0.GRFPU_X0.N_19652_9\,
datae => \GRFPU0.MULO.MRES\(62),
datad => \GRFPU0.MULO.MRES\(61),
datac => \GRFPU0.MULO.MRES\(57),
datab => \GRFPU0.MULO.MRES\(56));
GRFPC0_FP_PIPELINE_VRFA_ST_1_U_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000008000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1_U_2\,
dataf => N_126,
datae => N_125,
datad => N_134,
datac => N_133,
datab => N_127,
dataa => N_124);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_I_M3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23598\,
dataf => \GRFPC0.D.LDLCK\(3),
datae => \GRFPC0.D.LDLCK\(11),
datad => \GRFPC0.D.LDLCK\(27),
datac => \GRFPC0.D.LDLCK\(19),
datab => N_131,
dataa => N_132);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_I_M3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23605\,
dataf => \GRFPC0.D.LDLCK\(7),
datae => \GRFPC0.D.LDLCK\(15),
datad => \GRFPC0.D.LDLCK\(31),
datac => \GRFPC0.D.LDLCK\(23),
datab => N_131,
dataa => N_132);
\GRFPC0_FP_PIPELINE_DBGDATA_4_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(11),
dataf => N_663,
datae => N_727,
datad => N_451,
datac => \GRFPC0.R.FSR.FCC\(1),
datab => N_450);
GRFPC0_LDLOCK_1_13_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23508\,
dataf => \GRFPC0.D.STLCK\(6),
datae => \GRFPC0.D.STLCK\(22),
datad => \GRFPC0.D.STLCK\(23),
datac => \GRFPC0.D.STLCK\(7),
datab => N_132,
dataa => N_128);
\GRFPC0_FP_PIPELINE_DBGDATA_4_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => CPO_DBG_DATAZ(28),
dataf => N_680,
datae => N_744,
datad => N_451,
datac => N_450);
GRFPC0_LDLOCK_3_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23486\,
dataf => \GRFPC0.D.STDLCK\(0),
datae => \GRFPC0.D.STDLCK\(4),
datad => \GRFPC0.D.STDLCK\(12),
datac => \GRFPC0.D.STDLCK\(8),
datab => N_131,
dataa => N_132);
GRFPC0_LDLOCK_13_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23496\,
dataf => \GRFPC0.D.STDLCK\(3),
datae => \GRFPC0.D.STDLCK\(7),
datad => \GRFPC0.D.STDLCK\(15),
datac => \GRFPC0.D.STDLCK\(11),
datab => N_131,
dataa => N_132);
GRFPC0_STDDEP_0_SQMUXA_4_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_22006\,
dataf => \GRFPC0.RFA.LD\,
datae => N_200,
datad => N_198,
datac => N_201,
datab => N_199);
\GRFPC0_FP_PIPELINE_DBGDATA_4_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(2),
dataf => N_654,
datae => N_718,
datad => N_451,
datac => \GRFPC0.R.FSR.CEXC\(2),
datab => N_450);
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_UN28_BCO_LSB_RNI72M32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10484\,
dataf => \GRFPU0.GRFPU_X0.N_10489\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1));
GRFPC0_FP_PIPELINE_UN5_SHARE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0fff0ccc0ccc0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN5_SHARE\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.EX.CTRL.VCNT\(1),
datac => \GRFPC0.EX.CTRL.VCNT\(0),
datab => \GRFPC0.EX.CTRL.CCWR\);
\GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_ALTB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff000f0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(1),
dataf => \FPI.FLUSHID\(0),
datae => \FPI.FLUSHID\(1),
datad => \GRFPU0.GRFPU_X0.ST1.ID\(0),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(1));
GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_UN3008_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_LDLOCK_1_6_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23503\,
dataf => \GRFPC0.D.STLCK\(2),
datae => \GRFPC0.D.STLCK\(18),
datad => \GRFPC0.D.STLCK\(19),
datac => \GRFPC0.D.STLCK\(3),
datab => N_132,
dataa => N_128);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1567_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
dataf => N_104,
datae => N_107,
datad => N_105,
datac => N_106);
\GRFPC0_FP_PIPELINE_DBGDATA_4_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(31),
dataf => N_683,
datae => N_747,
datad => N_451,
datac => \FPI.RNDMODE\(1),
datab => N_450);
GRFPC0_RFA_ST_0_0_G1_0_2289_A2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000200000000000")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_2289_A2_4\,
dataf => N_127,
datae => N_126,
datad => N_134,
datac => N_124,
datab => N_125,
dataa => N_133);
\GRFPU0_GRFPU_X0_L1_4_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000ff00f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
GRFPC0_FP_PIPELINE_11_0_IS_RDD_TMP_1_0_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeffeefdeeccaa00")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(11),
datad => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(7),
datab => \GRFPC0.FIFO.INST_0\(10),
dataa => \GRFPC0.FIFO.INST_0\(8));
\GRFPC0_STDATA_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00caffcaff")
port map (
combout => CPO_DATAZ(18),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(18),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(18),
dataa => \GRFPC0.EX.RREG.RES\(50));
\GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_ALTB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7310f73173107310")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(2),
dataf => \FPI.FLUSHID\(0),
datae => \GRFPU0.GRFPU_X0.ST3.ID\(0),
datad => \FPI.FLUSHID\(2),
datac => \FPI.FLUSHID\(1),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(2),
dataa => \GRFPU0.GRFPU_X0.ST3.ID\(1));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_21338\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_22026\,
dataf => \GRFPC0.D.LDLCK\(6),
datae => \GRFPC0.D.LDLCK\(14),
datad => \GRFPC0.D.LDLCK\(30),
datac => \GRFPC0.D.LDLCK\(22),
datab => N_131,
dataa => N_132);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_O2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_20974\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(4),
datab => \GRFPC0.WR.CTRL.RD\(3));
GRFPC0_LDLOCK_1_21_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23514\,
dataf => \GRFPC0.D.STLCK\(10),
datae => \GRFPC0.D.STLCK\(26),
datad => \GRFPC0.D.STLCK\(27),
datac => \GRFPC0.D.STLCK\(11),
datab => N_132,
dataa => N_128);
GRFPC0_LDLOCK_10_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23493\,
dataf => \GRFPC0.D.STDLCK\(2),
datae => \GRFPC0.D.STDLCK\(6),
datad => \GRFPC0.D.STDLCK\(14),
datac => \GRFPC0.D.STDLCK\(10),
datab => N_131,
dataa => N_132);
\GRFPU0_SQRTROM0_DATA_1_6_0__M17\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1ca5cb61af0fc168")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_18\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPC0_STDATA_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(20),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(20),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(20),
dataa => \GRFPC0.EX.RREG.RES\(52));
\GRFPC0_FP_PIPELINE_DBGDATA_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(3),
dataf => N_655,
datae => N_719,
datad => N_451,
datac => \GRFPC0.R.FSR.CEXC\(3),
datab => N_450);
\GRFPC0_STDATA_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(19),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(19),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(19),
dataa => \GRFPC0.EX.RREG.RES\(51));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3424_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
dataf => N_119,
datae => N_121,
datad => N_120,
datac => N_118);
GRFPC0_RFA_RDWR_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00f00000000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_3\,
dataf => N_127,
datae => N_125,
datad => N_123,
datac => N_122);
\GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_ALTB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f37130177331100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\(2),
dataf => \FPI.FLUSHID\(0),
datae => \FPI.FLUSHID\(2),
datad => \FPI.FLUSHID\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST2.ID\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.ID\(1));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8008400420021001")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datad => \GRFPU0.DIVROM0.RADDR\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_56\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_STDATA_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(29),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(29),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(29),
dataa => \GRFPC0.EX.RREG.RES\(61));
\GRFPC0_STDATA_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(17),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(17),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(17),
dataa => \GRFPC0.EX.RREG.RES\(49));
\GRFPC0_STDATA_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(12),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(12),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(12),
dataa => \GRFPC0.EX.RREG.RES\(44));
\GRFPC0_FP_PIPELINE_DBGDATA_4_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(23),
dataf => N_675,
datae => N_739,
datad => N_451,
datac => \GRFPC0.R.FSR.TEM\(0),
datab => N_450);
\GRFPU0_GRFPU_X0_BCO_MSB_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPC0_FIFO_INST_1_RNIPGJ61_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_106_I_I_A2_0_A4_1\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_1\(27));
GRFPU0_GRFPU_X0_UN8_C_CARRY_2_RNIVHQH: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_19212\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(5),
datae => \GRFPU0.GRFPU_X0.UN8_C\(6),
datad => \GRFPU0.GRFPU_X0.UN8_C\(4),
datac => \GRFPU0.GRFPU_X0.UN8_C\(3),
datab => \GRFPU0.GRFPU_X0.UN8_C\(2));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffefffffffffff")
port map (
combout => \GRFPC0.N_23540\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.N_131_1\,
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(4),
dataa => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_RFA_RDWR_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_2445_A2_4\,
dataf => N_124,
datae => N_134,
datad => N_133,
datac => N_126,
datab => N_137);
\GRFPC0_STDATA_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(28),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(28),
datad => \GRFPC0.STDATA_SN_N_3\,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(28),
dataa => \GRFPC0.EX.RREG.RES\(60));
GRFPC0_FP_PIPELINE_STDBL_1_1_U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88f0880088008800")
port map (
combout => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
dataf => N_192,
datae => \GRFPC0.RFA.ST_0\,
datad => N_63,
datac => N_191,
datab => N_123,
dataa => N_122);
\GRFPC0_FIFO_INST_1_RNIRP7E1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fafffafdfaf0aa00")
port map (
combout => \GRFPC0.N_22858\,
dataf => \GRFPC0.FIFO.INST_1_0\(6),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_1\(7),
dataa => \GRFPC0.FIFO.INST_1\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17666\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31424,
datab => N_31372,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17665\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31422,
datab => N_31370,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPU0.GRFPU_X0.N_7028\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPU0_GRFPU_X0_ITER_NX_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff27ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.NX_1_0_N_13\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.ITER.V_3\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.LOB\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_20927\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31406,
datab => N_31354,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
GRFPU0_GRFPU_X0_ITER_EMIN_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaaaaae000c")
port map (
combout => N_29620,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.N_5437\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.EMIN\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0eca0a000000000")
port map (
combout => \GRFPC0.N_25508\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_25277\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datab => \GRFPC0.N_23822\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5298_REGDEPX2\);
\GRFPU0_GRFPU_X0_VST3_REG_37_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000000aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
\GRFPC0_DIV_RESULT_0_0_14__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(14),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(14),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(14),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000200000000")
port map (
combout => \GRFPC0.N_24503\,
dataf => \GRFPC0.N_25795_2\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0));
GRFPC0_VFIFO_WR_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17670\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31432,
datab => N_31380,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
GRFPU0_GRFPU_X0_COMB_TMP316_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000400000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9852\,
dataf => \GRFPU0.GRFPU_X0.N_7229_3\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17661\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31414,
datab => N_31362,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7f5f5f5f3000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_1_1\(0),
datac => \GRFPC0.MEM.CTRL.RDD_0\,
datab => \GRFPC0.MEM.CTRL.INST\(25),
dataa => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"acacfc0caaaafa0a")
port map (
combout => \GRFPU0.GRFPU_X0.N_17671\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31434,
datac => N_174935,
datab => N_31382,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(53));
\GRFPC0_DIV_RESULT_0_0_8__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(8),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(8),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(8),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cccacacaca")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17664\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31420,
datab => N_31368,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17669\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31430,
datab => N_31378,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_L1_1_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0eeeeeeee")
port map (
combout => N_124817,
dataf => \GRFPU0.GRFPU_X0.N_10907\,
datae => \GRFPU0.GRFPU_X0.N_3826\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fcccf000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(28),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.MULO.DRES_1\(88));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17663\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31418,
datab => N_31366,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_2_2\,
dataf => N_50421_2,
datae => N_127,
datad => \GRFPC0.N_23533\,
datac => N_122,
datab => N_126,
dataa => N_125);
\GRFPC0_D_STLCK_RNO_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8080000080ff00ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_0\,
dataf => \GRFPC0.N_23044\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_22719\,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2_3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000008080000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
dataf => \FPI.FLOP_1_0\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(2),
datab => \FPI.FLOP\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17656\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31404,
datab => N_31352,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPC0_DIV_RESULT_0_0_26__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(26),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(26),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17662\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31416,
datab => N_31364,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPC0_DIV_RESULT_0_0_6__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(6),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(6),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(6),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6));
\GRFPC0_DIV_RESULT_0_0_24__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(24),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(24),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(24),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17659\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31410,
datab => N_31358,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPC0_DIV_RESULT_0_0_9__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(9),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(9),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(9),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9));
\GRFPC0_DIV_RESULT_0_0_22__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(22),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(22),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22));
\GRFPC0_DIV_RESULT_0_0_27__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(27),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(27),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27));
\GRFPC0_DIV_RESULT_0_0_0__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(0),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(0),
datab => \FPO.CC\(0),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19199\,
dataf => \GRFPU0.GRFPU_X0.N_53\,
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_8_RNIEVU51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f000f000f0")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_2497_A2_1\,
dataf => N_127,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\,
datad => N_138,
datac => \GRFPC0.N_290\);
\GRFPC0_DIV_RESULT_0_0_20__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(20),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(20),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(20),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25029\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_24030_2\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_2\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX_RNIG7M71: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_83\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
datad => \GRFPC0.FIFO.INST_1\(19));
\GRFPU0_GRFPU_X0_VST3_REG_37_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000000aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3222000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8b8fc30aaaaee22")
port map (
combout => \GRFPU0.GRFPU_X0.N_17675\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31442,
datac => N_31390,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(57));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX_1_RNI0OUI1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_21749\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8b8fc30aaaaee22")
port map (
combout => \GRFPU0.GRFPU_X0.N_17676\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31444,
datac => N_31392,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8b8fc30aaaaee22")
port map (
combout => \GRFPU0.GRFPU_X0.N_17677\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31446,
datac => N_31394,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(59));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"40400000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_2\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.N_7795_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8b8fc30aaaaee22")
port map (
combout => \GRFPU0.GRFPU_X0.N_17673\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31438,
datac => N_31386,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cccacacaca")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa2aaaaaff3fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_0\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_9_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_25164\,
datac => \GRFPC0.N_25786_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0),
dataa => \GRFPC0.N_24642\);
\GRFPC0_DIV_RESULT_0_0_15__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(15),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(15),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(15),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17667\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31426,
datab => N_31374,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPC0_DIV_RESULT_0_0_2__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(2),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(2),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(2),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0eac00000aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.N_25277\,
datad => \GRFPC0.N_23813_1\,
datac => \GRFPC0.N_25433_1\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_A3_4_0\(1),
dataa => \GRFPC0.N_23819\);
\GRFPC0_WR_RREG_RES_0_0_29__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(29),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(29),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29));
\GRFPC0_DIV_RESULT_0_0_25__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(25),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(25),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25));
\GRFPC0_DIV_RESULT_0_0_17__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(17),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(17),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(17),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17));
GRFPU0_GRFPU_X0_UN242_BCO_MSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003f300000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN242_BCO_MSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_3256\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(2),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35));
\GRFPC0_DIV_RESULT_0_0_13__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(13),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(13),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(13),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13));
\GRFPC0_DIV_RESULT_0_0_1__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(1),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(1),
datab => \FPO.CC\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1));
\GRFPC0_DIV_RESULT_0_0_23__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(23),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(23),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(23),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23));
\GRFPC0_DIV_RESULT_0_0_10__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(10),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(10),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(10),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10));
\GRFPC0_DIV_RESULT_0_0_30__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(30),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(30),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_22924_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_DIV_RESULT_0_0_5__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(5),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(5),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(5),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5));
\GRFPC0_DIV_RESULT_0_0_31__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(31),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f03300f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_25703_3\,
datad => \GRFPC0.N_24795_2\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2\,
datab => \GRFPC0.MEM.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_0_STDDEP_92_IV_0_A2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_21015\,
dataf => \GRFPC0.N_45\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_DIV_RESULT_0_0_28__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(28),
dataf => \GRFPU0.GRFPU_X0.N_21448_1\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(28),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(28),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccf0ccaaaaf0aa")
port map (
combout => \GRFPU0.GRFPU_X0.N_17655\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31402,
datab => N_31350,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8b8fc30aaaaee22")
port map (
combout => \GRFPU0.GRFPU_X0.N_17672\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_31436,
datac => N_31384,
datab => N_174935,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_VST3_REG_37_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000000aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_01\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27));
\GRFPC0_DIV_RESULT_0_0_12__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(12),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(12),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(12),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12));
\GRFPC0_DIV_RESULT_0_0_7__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(7),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(7),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(7),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7));
\GRFPC0_DIV_RESULT_0_0_21__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(21),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(21),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(21),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cccacacaca")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(30));
\GRFPC0_FP_PIPELINE_12_STDEP_510_0_IV_I_A2_1_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0004000000000000")
port map (
combout => \GRFPC0.N_150\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.FIFO.INST_1_0\(29),
dataa => \GRFPC0.FIFO.INST_1\(27));
GRFPU0_GRFPU_X0_UN258_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003f30000")
port map (
combout => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_21048\,
datae => \GRFPU0.GRFPU_X0.N_3266\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPC0_DIV_RESULT_0_0_16__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(16),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(16),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(16),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16));
\GRFPU0_GRFPU_X0_TZI_RNIR59R2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10569\,
dataf => \GRFPU0.GRFPU_X0.N_10583\,
datae => \GRFPU0.GRFPU_X0.TZI\(4),
datad => \GRFPU0.GRFPU_X0.TZI\(5),
datac => \GRFPU0.GRFPU_X0.N_3336\);
\GRFPC0_DIV_RESULT_0_0_11__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(11),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(11),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(11),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11));
\GRFPC0_DIV_RESULT_0_0_4__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(4),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(4),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(4),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23446\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25271\,
datad => \GRFPC0.N_25309_1\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(17));
\GRFPC0_DIV_RESULT_0_0_3__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(3),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428_0\,
datad => \GRFPU0.GRFPU_X0.N_427_0\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(3),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(3),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3));
\GRFPC0_DIV_RESULT_0_0_19__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(19),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(19),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(19),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19));
\GRFPU0_GRFPU_X0_VST3_REG_37_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000000aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_01\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26));
\GRFPC0_DIV_RESULT_0_0_18__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefceeccfaf0aa00")
port map (
combout => \FPO.RES\(18),
dataf => \GRFPU0.GRFPU_X0.N_21448_0\,
datae => \GRFPU0.GRFPU_X0.N_428\,
datad => \GRFPU0.GRFPU_X0.N_427\,
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(18),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31199,
datab => N_31250,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(35));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31211,
datab => N_31262,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(41));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_254_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff8000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_254_IV\(0),
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.UN1_FIFO.INST_0_9\,
datad => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_0\(27),
dataa => \GRFPC0.FIFO.INST_0\(28));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31193,
datab => N_31244,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(32));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31213,
datab => N_31264,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(42));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_O2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0_0\(1),
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.N_25755\,
datad => \GRFPC0.N_25223_2\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_1\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31197,
datab => N_31248,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(34));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4c5f4c5f00004c5f")
port map (
combout => \GRFPC0.N_24364\,
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.N_24443\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.N_21957_1\,
datab => \GRFPC0.N_24356\,
dataa => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A2_2_0\(0));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31187,
datab => N_31238,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31219,
datab => N_31270,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(45));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31191,
datab => N_31242,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(31));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeac0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_O2_1\(1),
dataf => \GRFPC0.N_25303\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_8_0\(1),
dataa => \GRFPC0.N_25325_1\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8800f8f088008800")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_25164\,
datad => \GRFPC0.N_25808_2\,
datac => \GRFPC0.N_25835_2\,
datab => \GRFPC0.EX.CTRL.RS1V\,
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c088ccf0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_31__G3_0_1705_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(39));
\GRFPC0_D_STLCK_RNO_4_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000550000004500")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A2_0_0\(1),
dataf => \GRFPC0.N_21043\,
datae => \GRFPC0.N_21039\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\,
dataa => \GRFPC0.MEM.CTRL.RDD\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31231,
datab => N_31282,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(51));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31203,
datab => N_31254,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(37));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31205,
datab => N_31256,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(38));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc008c8cff00afaf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_25__G3_0_1653_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(33));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0060000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G2_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datae => \GRFPU0.GRFPU_X0.N_19264\,
datad => \GRFPU0.GRFPU_X0.N_19212\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(10),
datab => \GRFPU0.GRFPU_X0.UN8_C\(1),
dataa => \GRFPU0.GRFPU_X0.UN8_C\(0));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31189,
datab => N_31240,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(30));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_2_0_RNIB2JT_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_0\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A3_2_0\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A2_3_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff008000")
port map (
combout => \GRFPC0.N_25416\,
dataf => \GRFPC0.N_25420\,
datae => \GRFPC0.N_25421\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datab => \GRFPC0.N_23821\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN859_REGDEPX2_2\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31209,
datab => N_31260,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(40));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_25367_I\,
datad => \GRFPC0.N_24030_2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc008c8cff00afaf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_18__G3_0_1601_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff33ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(14),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_19404_I\,
datac => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.MULO.MRES\(75));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_2_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333f8f033338800")
port map (
combout => \GRFPU0.GRFPU_X0.N_18280\,
dataf => \GRFPU0.GRFPU_X0.N_4961_0\,
datae => \GRFPU0.GRFPU_X0.N_4285\,
datad => \GRFPU0.GRFPU_X0.N_4458_1\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
dataa => \GRFPU0.GRFPU_X0.ST1.V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0cc0000000000")
port map (
combout => \GRFPC0.N_23216\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.N_23821\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6621_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_14_0\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c088ccf0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_47__G3_0_1887_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(55));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31201,
datab => N_31252,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(36));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31215,
datab => N_31266,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(43));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31217,
datab => N_31268,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(44));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa008a8aff00cfcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_15__G3_0_1523_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc008c8cff00afaf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_17__G3_0_1575_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc008c8cff00afaf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_22__G3_0_1627_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0a0f0ccccaaff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_44__G3_0_1835_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_O4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPC0.N_23391\,
dataf => \GRFPC0.N_23462_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.N_23463_1\,
datac => \GRFPC0.N_22619_2\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX_228_0_A2_2_0\(0));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31207,
datab => N_31258,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(39));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31223,
datab => N_31274,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(47));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31229,
datab => N_31280,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(50));
\GRFPU0_GRFPU_X0_L1_4_1_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcacacaff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3593\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(101),
dataa => \GRFPU0.MULO.DRES_1S\(100));
\GRFPU0_GRFPU_X0_ITER_EXPOP_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a2aaf2aaa2aa02aa")
port map (
combout => N_91847,
dataf => \GRFPU0.GRFPU_X0.N_6498\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31221,
datab => N_31272,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(46));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0a088aaf0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_42__G3_0_1783_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
GRFPC0_WR2_CTRL_RDWR_RNI5KJE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030300ff03ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1_1\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.RREG.RESV_1_0\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31227,
datab => N_31278,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(49));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_O2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_23788\,
datad => \GRFPC0.N_24701_1\,
datac => \GRFPC0.N_25433_1\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31225,
datab => N_31276,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(48));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaaccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_31286,
datac => N_31195,
datab => N_31246,
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f0f00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(18),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa008a8aff00cfcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_14__G3_0_1497_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000010000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_4\,
dataf => \GRFPU0.GRFPU_X0.N_4369\,
datae => \GRFPU0.GRFPU_X0.N_4997\,
datad => \GRFPU0.GRFPU_X0.N_4355\,
datac => \GRFPU0.GRFPU_X0.REST_1_1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aa00ccccaa00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_4961_0\,
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc008c8cff00afaf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_27__G3_0_1679_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f222f00022220000")
port map (
combout => \GRFPC0.N_25379\,
dataf => \GRFPC0.N_25450_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.N_24487\,
dataa => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1\(1));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_74_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000400000000")
port map (
combout => \GRFPC0.N_22674\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.FIFO.INST_0_0\(19),
datad => \GRFPC0.FIFO.INST_0_0\(27),
datac => \GRFPC0.FIFO.INST_0_0\(29),
datab => \GRFPC0.FIFO.INST_0_0\(28),
dataa => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaa00f0f0aa00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_4961_0\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(24));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIDQOD2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000088a0aaa0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_0__G0_2\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.N_19434\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
dataa => N_61);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff33ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(17),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_19404_I\,
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c088ccf0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_39__G3_0_1757_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8040201008040201")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
dataf => \FPO.IDOUT\(3),
datae => \FPO.IDOUT\(2),
datad => \FPO.IDOUT\(1),
datac => \GRFPC0.MEM.CTRL.ID\(3),
datab => \GRFPC0.MEM.CTRL.ID\(2),
dataa => \GRFPC0.MEM.CTRL.ID\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(87),
datac => \GRFPU0.MULO.DRES_S\(86),
datab => \GRFPU0.MULO.DRES_1S\(86),
dataa => \GRFPU0.MULO.DRES_1\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(68),
datac => \GRFPU0.MULO.DRES_S\(67),
datab => \GRFPU0.MULO.DRES_1S\(67),
dataa => \GRFPU0.MULO.DRES_1\(68));
\GRFPC0_FP_PIPELINE_DBGDATA_4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(13),
dataf => N_665,
datae => N_729,
datad => N_451,
datac => \GRFPC0.FP_PIPELINE.QNE2\,
datab => N_450);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.MULO.DRES_S\(73),
datab => \GRFPU0.MULO.DRES_1S\(73),
dataa => \GRFPU0.MULO.DRES_1\(74));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datab => \GRFPU0.MULO.MRES\(65),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c088ccf0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_33__G3_0_1731_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_21179\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(41));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.PC\(16),
dataa => \GRFPC0.MEM.CTRL.PC\(16));
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_60_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fafaeaaaf0f0c000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(0),
dataf => \GRFPC0.N_22749_1\,
datae => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60_0_A5_0\(0),
datad => \GRFPC0.N_22750_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8020401008020401")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_3\,
dataf => \FPO.IDOUT\(4),
datae => \FPO.IDOUT\(2),
datad => \FPO.IDOUT\(0),
datac => \GRFPC0.DIV.ID\(4),
datab => \GRFPC0.DIV.ID\(0),
dataa => \GRFPC0.DIV.ID\(2));
\GRFPC0_D_STDLCK_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffa0ffb3")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_2\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_124\,
datae => \GRFPC0.N_22998\,
datad => \GRFPC0.N_194\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.FIFO.INST_0_0\(19),
dataa => \GRFPC0.STDDEP_0_SQMUXA_31_I_I_A3_0\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f03300fff0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(38),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(99),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
dataf => \FPO.IDOUT\(4),
datae => \FPO.IDOUT\(3),
datad => \GRFPC0.WR2.CTRL.ID\(4),
datac => \GRFPC0.WR2.CTRL.ID\(3));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datab => \GRFPU0.MULO.MRES\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f1f7f7f0f0f5f5")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_0_SQMUXA_0.N_5\,
dataf => \GRFPU0.GRFPU_X0.N_21896\,
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.MULO.MRES\(98),
datac => \GRFPU0.GRFPU_X0.N_19606\,
datab => \GRFPU0.MULO.MRES\(96),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0037000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20599\,
dataf => \GRFPU0.GRFPU_X0.N_20764_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.REST_2\(5),
datab => \GRFPU0.GRFPU_X0.N_4997\,
dataa => \GRFPU0.GRFPU_X0.N_4313\);
GRFPC0_VFIFO_WR_0_SQMUXA_1_RNIBIDV1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000c00cc000000")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
dataf => \GRFPC0.VFIFO.WR_1_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => N_52981_2);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5accaaccaaccaacc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18099\,
dataf => N_35944,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(8));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a0c0f088aaccff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(38));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
GRFPU0_GRFPU_X0_ST2_V_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0000000c000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11230\,
dataf => \GRFPU0.GRFPU_X0.N_18972\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \FPI.FLUSH\,
datab => N_61);
\GRFPU0_GRFPU_X0_L4_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f055005500")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(3),
dataf => N_174934,
datae => \GRFPU0.GRFPU_X0.N_7365\,
datad => \GRFPU0.GRFPU_X0.L1_4\(3),
datac => \GRFPU0.GRFPU_X0.N_7370\,
datab => \GRFPU0.GRFPU_X0.L1_2\(3),
dataa => \GRFPU0.GRFPU_X0.N_20965\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.N_24502\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(49));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a0c0f088aaccff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f080")
port map (
combout => \GRFPC0.N_25618\,
dataf => \GRFPC0.N_25620\,
datae => \GRFPC0.N_25621\,
datad => \GRFPC0.N_25624\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.N_25648_1\,
dataa => \GRFPC0.N_25648_2\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_153_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeceaa0acccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(0),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2\,
datae => \GRFPC0.N_23728\,
datad => \FPI.FLOP_0\(1),
datac => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.N_23712\,
dataa => \FPI.FLOP_0\(6));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPC0_D_LDLCK_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000f000f000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datae => \GRFPC0.N_21055_I\,
datad => \GRFPC0.N_91_1\,
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3616_REGDEPX\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1181_REGDEPX2_0_A2_0_A2_RNI9DG81: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeac0aa00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_5\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5_1\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datad => \GRFPC0.N_25458\,
datac => \GRFPC0.N_25433_1\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1314_REGDEPX2\);
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_112_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fcf0f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_112\(1),
dataf => \GRFPC0.N_228\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.N_24444\,
datab => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1968_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbfaf3f0f3f0f3f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(24),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(84),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(85),
datac => \GRFPU0.MULO.DRES_S\(84),
datab => \GRFPU0.MULO.DRES_1S\(84),
dataa => \GRFPU0.MULO.DRES_1\(85));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8088c0cca0aaf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_0_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(44));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffe0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_4\,
dataf => \GRFPU0.GRFPU_X0.N_19259_1\,
datae => \GRFPU0.GRFPU_X0.N_96\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C\(9),
datab => \GRFPU0.GRFPU_X0.UN8_C\(8),
dataa => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f000f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPC0_D_LDLCK_RNO_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1_4\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.N_89_1\,
datad => \GRFPC0.N_22305\,
datac => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3023_REGDEPX\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.WR.CTRL.PC\(3),
dataa => \GRFPC0.MEM.CTRL.PC\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa00ba30faf0faf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.N_20843_1\,
datac => \GRFPU0.GRFPU_X0.N_20773\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(41));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_185_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff4ff44f4f44444")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_185\(0),
dataf => \GRFPC0.FP_PIPELINE.0.STDEP_30_0_IV_I_A3_1_0\(0),
datae => \GRFPC0.N_23463_1\,
datad => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1_0\(1),
datab => \GRFPC0.N_24446\,
dataa => \GRFPC0.N_24352\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"555500ff0f0f3333")
port map (
combout => \GRFPU0.GRFPU_X0.N_20620\,
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.MULO.DRES_1S\(81),
datab => \GRFPU0.MULO.DRES_1\(82),
dataa => \GRFPU0.MULO.DRES_S\(81));
\GRFPU0_GRFPU_X0_L4_6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44444444ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(3),
dataf => \GRFPU0.GRFPU_X0.N_10514\,
datae => \GRFPU0.GRFPU_X0.N_10558\,
datad => \GRFPU0.GRFPU_X0.N_10519\,
datac => \GRFPU0.GRFPU_X0.N_10569\,
datab => \GRFPU0.GRFPU_X0.L1_4_4\(3),
dataa => \GRFPU0.GRFPU_X0.N_10484\);
\GRFPC0_FP_PIPELINE_2_1_REGDEPX_44_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00020000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.REGDEPX_44\(1),
dataf => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_42\(1),
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1_0\(19),
dataa => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_D_STLCK_RNO_2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03ab03ff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_O3_1_1\(1),
dataf => \GRFPC0.N_23172\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.N_23175\,
datac => \GRFPC0.N_23044\,
datab => \GRFPC0.N_23178\,
dataa => \GRFPC0.FIFO.INST_0\(25));
GRFPU0_GRFPU_X0_COMB_UN138_RNDOP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"baaab800f8f0b800")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_20599\,
datad => \GRFPU0.GRFPU_X0.N_242\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPC0_D_STLCK_RNO_6_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000ffff80008000")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.N_23282\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => N_174895,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_D_LDLCK_RNO_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"808080808080ff80")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_0\,
dataf => N_122,
datae => \GRFPC0.N_21998\,
datad => \GRFPC0.N_22737_2\,
datac => \GRFPC0.N_92_1\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_1\,
dataa => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_0\);
GRFPC0_FPEXC_0_SQMUXA_RNIUCD24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefefffefefe")
port map (
combout => N_52829,
dataf => \GRFPC0.FPEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datab => N_52826,
dataa => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPU0_GRFPU_X0_VALLOW_3_SQMUXA_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffe0000")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5\,
dataf => N_174933,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(17));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5500000055004000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G0_0_1\,
dataf => \GRFPU0.GRFPU_X0.N_19213\,
datae => \GRFPU0.GRFPU_X0.N_19253_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.N_19264\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(10),
dataa => \GRFPU0.GRFPU_X0.UN8_C\(1));
\GRFPC0_D_STLCK_RNO_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8f8f88888fff88ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_1\,
dataf => \GRFPC0.N_23044\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_22313\,
datac => \GRFPC0.N_22324\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7),
dataa => \GRFPC0.N_22485_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(53),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
\GRFPC0_D_LDLCK_RNO_3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff020002000200")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
dataf => \GRFPC0.N_22325_2\,
datae => \GRFPC0.N_22329_1\,
datad => \GRFPC0.N_167_1\,
datac => \GRFPC0.N_24280\,
datab => N_107,
dataa => N_106);
\GRFPC0_D_STLCK_RNO_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.N_20847\,
datad => \GRFPC0.N_22649\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPC0_D_STLCK_RNO_5_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.N_22077\,
datad => \GRFPC0.N_22485_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datab => \GRFPC0.N_21996\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(54),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_IV_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefaeeaafcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(7));
GRFPC0_V_FSR_FTT_1_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000a0200000000")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.WR2.CTRL.AFSR\,
dataa => N_61);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(55),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
\GRFPC0_D_LDLCK_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff888f888f888")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_1\,
dataf => \GRFPC0.N_169_1\,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX\,
datac => \GRFPC0.N_167_1\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(2),
dataa => \GRFPC0.N_23195_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
GRFPU0_GRFPU_X0_COMB_IEXC25_NE_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bebebbee7d7d77dd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_3\,
dataf => N_124895,
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L3_0_5\(0),
datac => \GRFPU0.GRFPU_X0.L3_1_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPC0_D_STLCK_RNO_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_11_1\(1),
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datac => \GRFPC0.N_21339\,
datab => \GRFPC0.N_21338\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPC0_D_LDLCK_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1_0\,
dataf => \GRFPC0.N_22737_2\,
datae => \GRFPC0.N_22918_1\,
datad => \GRFPC0.N_92_1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX_0\,
datab => N_105);
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0_0_A2_1_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\,
dataf => \FPI.OP2\(57),
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(59),
datac => \FPI.OP2\(61),
datab => \FPI.OP2\(60),
dataa => \FPI.OP2\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.MULO.MRES\(65),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(5));
\GRFPU0_GRFPU_X0_UN38_EXP_M_RNI3HO4_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_5\,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(57),
datad => \FPI.OP2\(61),
datac => \FPI.OP2\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(48),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c0a0f088ccaaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.MULO.MRES\(72),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(56),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(57),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(57));
\GRFPC0_D_STLCK_RNO_5_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4f4f44444fff44ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_1\,
dataf => \GRFPC0.N_23044\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_162\,
datac => \GRFPC0.N_22006\,
datab => \GRFPC0.N_22485_1\,
dataa => \GRFPC0.N_21998\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_47_U_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbbbc8883bbb0888")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_33\(63),
datad => \GRFPU0.GRFPU_X0.N_4325\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_I_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f77dd0f0f33cc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_9_0_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_19652\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
dataa => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_ALTB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"008880c8cceeecfe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(2),
dataf => \FPI.OPID\(2),
datae => \FPI.OPID\(0),
datad => \FPI.OPID\(1),
datac => \FPI.FLUSHID\(0),
datab => \FPI.FLUSHID\(2),
dataa => \FPI.FLUSHID\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_I_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1133103055ff50f0")
port map (
combout => N_100153,
dataf => \GRFPC0.N_23719\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_I_A2_0\(1),
datad => \GRFPC0.N_23717\,
datac => \GRFPC0.N_23623\,
datab => \GRFPC0.V.STDATA_14\(14),
dataa => N_50656_0);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(59),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(59));
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F0_I_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2a00aa002200aa00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19310\,
dataf => \GRFPU0.GRFPU_X0.L4_3_I\(1),
datae => \GRFPU0.GRFPU_X0.L4_3\(3),
datad => N_174934,
datac => \GRFPU0.GRFPU_X0.L3_0\(2),
datab => \GRFPU0.GRFPU_X0.L4_3\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2));
\GRFPC0_FP_PIPELINE_0_0_REGDEPX_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0cc00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5\(1),
dataf => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_2_IV\(1),
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ace0a0a0aceffff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_21544\,
datad => \GRFPC0.N_21545\,
datac => \GRFPC0.N_21556\,
datab => \GRFPC0.N_131_1\,
dataa => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.MULO.MRES\(64),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.MULO.MRES\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(3));
GRFPC0_WR_CTRL_DIV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_52989,
dataf => N_50233,
datae => N_52987_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => N_64);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(55),
datab => \FPI.FLOP\(1));
\GRFPC0_UN1_VFIFO_FULL_0_SQMUXA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30f030f03fff30f0")
port map (
combout => \GRFPC0.UN1_VFIFO.FULL_0_SQMUXA\(0),
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
datad => \GRFPC0.FP_PIPELINE.CNTX14\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\);
\GRFPC0_D_STLCK_RNO_3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8fff8f8")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_2\,
dataf => \GRFPC0.N_21974\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_21896\,
datac => \GRFPC0.N_21967\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11),
dataa => \GRFPC0.N_22485_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000007f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_21467\,
datad => \GRFPC0.N_21459\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.N_131_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c0a0f088ccaaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.MULO.MRES\(70),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.MULO.MRES\(61),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.MULO.MRES\(66),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.MULO.MRES\(62),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNI56AS6_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c088cca0f0aaff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19510_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES_0\(120),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(60));
GRFPC0_DIV_EXC_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffdff55")
port map (
combout => \GRFPC0.DIV.EXC_1_0_G0_I\,
dataf => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\,
datac => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.EXC\,
dataa => N_52981_2);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_19292_I\,
datae => \GRFPU0.GRFPU_X0.N_15508\,
datad => \GRFPU0.GRFPU_X0.N_19293_I\,
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
GRFPC0_VMEM_CTRL_PEND_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0007000000000000")
port map (
combout => \GRFPC0.VMEM.CTRL.PEND_0_SQMUXA_1\,
dataf => N_52020,
datae => \GRFPC0.D.FLDLCK_0_0_G1_0\,
datad => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.MEM.CTRL.VCNT\(1),
datab => \GRFPC0.MEM.CTRL.VCNT\(0),
dataa => N_64);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a088aac0f0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datae => \GRFPU0.GRFPU_X0.N_15508_0\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_1\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feeefaaafcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datae => \GRFPU0.GRFPU_X0.VITER.ND_I_3_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19293_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datab => \GRFPU0.MULO.MRES\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(0));
GRFPC0_WR_CTRL_SEQERR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_52987,
dataf => N_50233,
datae => N_52987_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.SEQERR\,
datab => N_64);
GRFPU0_GRFPU_X0_UN1_VST1_ID3_3_0_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_388\,
dataf => \GRFPU0.GRFPU_X0.N_388_3_0\,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(60),
datab => \FPI.OP1\(61),
dataa => \FPI.OP1\(62));
\GRFPC0_D_LDLCK_RNO_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff888f888f888")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_1\,
dataf => \GRFPC0.N_167_1\,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
datad => \GRFPC0.N_23195_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
dataa => \GRFPC0.N_169_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000f0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_55_LI\,
datad => \GRFPC0.N_59\,
datac => \GRFPC0.N_56\,
datab => \GRFPC0.N_131_0\);
\GRFPC0_D_LDLCK_RNO_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffeeefeeefeee")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1_2\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
datad => \GRFPC0.N_22473_1\,
datac => \GRFPC0.N_22473_2\,
datab => \GRFPC0.N_22467\,
dataa => \GRFPC0.N_22470\);
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA_1_RNIJHNE3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6575_1\,
dataf => \GRFPU0.GRFPU_X0.N_7439\,
datae => \GRFPU0.GRFPU_X0.N_6576_1\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_0_S_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_2\(0),
dataf => \GRFPC0.N_25203_1\,
datae => \GRFPC0.N_24483_I\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_0_1\(0),
datac => \GRFPC0.N_23660\,
datab => N_174891);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"6aaaaaaa00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19808\,
dataf => \GRFPU0.GRFPU_X0.N_19836\,
datae => N_35944,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_6_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_6_2\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datab => \GRFPC0.N_21336\,
dataa => \GRFPC0.N_21338\);
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c0b3f38cccbfff")
port map (
combout => \GRFPC0.N_23009\,
dataf => \GRFPC0.N_22899\,
datae => \GRFPC0.N_22309\,
datad => \GRFPC0.N_21794\,
datac => \GRFPC0.N_21128\,
datab => \GRFPC0.N_22982\,
dataa => \GRFPC0.N_21121\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19803\,
dataf => \GRFPU0.GRFPU_X0.N_19836\,
datae => N_35944,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00080000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(62),
dataf => \GRFPU0.GRFPU_X0.N_18\,
datae => \GRFPU0.GRFPU_X0.N_19829\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0cc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_0_1\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\(1),
datad => \GRFPC0.FP_PIPELINE.1.STDEP178_1\,
datac => \GRFPC0.N_21146\,
datab => \GRFPC0.N_21785\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"002a00aa3b3bffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19711_I\,
dataf => \GRFPU0.GRFPU_X0.N_19777\,
datae => \GRFPU0.GRFPU_X0.N_19767\,
datad => N_36244,
datac => \GRFPU0.GRFPU_X0.N_19768\,
datab => \GRFPU0.GRFPU_X0.N_80_0\,
dataa => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00080000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(61),
dataf => \GRFPU0.GRFPU_X0.N_18\,
datae => \GRFPU0.GRFPU_X0.N_19829\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPC0_FP_PIPELINE_VFIFO_VCNT_0_1_F1_0_O4_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccffffffcf")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.VCNT_0_1_F1_0_O4_1\(2),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => N_52826,
datad => \GRFPC0.FIFO.VCNT_0\(0),
datac => \GRFPC0.FIFO.VCNT_0\(2),
datab => \GRFPC0.FIFO.VCNT_0\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_0_A2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000080000000")
port map (
combout => \GRFPC0.N_20960\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\);
\GRFPC0_INST_U_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(21),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datac => \GRFPC0.FIFO.INST_0\(21),
datab => \GRFPC0.FIFO.INST_1\(21),
dataa => N_124);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9999ff0099990c0c")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G1\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(10),
datac => \GRFPU0.GRFPU_X0.N_7458\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(53),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(52));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eecceac0ccccc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_6575_1\,
datae => \GRFPU0.GRFPU_X0.N_6995\,
datad => \GRFPU0.GRFPU_X0.N_6577\,
datac => \GRFPU0.GRFPU_X0.N_7053\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.EXC\(5));
\GRFPC0_D_STDLCK_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000007000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_12_8\,
dataf => \GRFPC0.STDEP_2_SQMUXA_142\,
datae => \GRFPC0.N_21181\,
datad => \GRFPC0.N_17842_1\,
datac => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
dataa => \GRFPC0.WR.CTRL.RDWR\);
GRFPU0_GRFPU_X0_ST1_OP2NX_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000800a800")
port map (
combout => \GRFPU0.GRFPU_X0.N_11295\,
dataf => \GRFPU0.GRFPU_X0.N_231\,
datae => \GRFPU0.GRFPU_X0.N_221\,
datad => \GRFPU0.GRFPU_X0.N_80\,
datac => \FPI.FLOP\(1),
datab => \FPI.FLOP\(0),
dataa => \FPI.NONSTD\);
\GRFPC0_INST_U_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(31),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datac => \GRFPC0.FIFO.INST_0\(31),
datab => \GRFPC0.FIFO.INST_1\(31),
dataa => N_134);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8888888800000008")
port map (
combout => \GRFPC0.N_96\,
dataf => \GRFPC0.STDEP_2_SQMUXA_138\,
datae => N_174898,
datad => \GRFPC0.N_82\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.N_62\,
dataa => \GRFPC0.N_80\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeffe0ff0eff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
dataf => \GRFPU0.GRFPU_X0.N_9745\,
datae => \GRFPU0.GRFPU_X0.N_8197\,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.FLOP_1\(1),
datab => \FPI.FLOP\(6),
dataa => \FPI.FLOP\(5));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f00000000000000")
port map (
combout => \GRFPC0.N_21204\,
dataf => N_38026,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN676_DEP\,
datad => \GRFPC0.N_21176\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_17905_1\,
dataa => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_INST_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(10),
dataf => \GRFPC0.INST_0\,
datae => \GRFPC0.INST_SN_N_2\,
datad => \GRFPC0.FIFO.INST_1\(10),
datac => \GRFPC0.FIFO.INST_0\(10),
datab => N_113);
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21404\,
dataf => N_38025,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datab => \GRFPC0.N_21341\);
\GRFPC0_INST_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(13),
dataf => \GRFPC0.INST_0\,
datae => \GRFPC0.INST_SN_N_2\,
datad => \GRFPC0.FIFO.INST_1\(13),
datac => \GRFPC0.FIFO.INST_0\(13),
datab => N_116);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c6ffc60066ff6600")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(10),
dataf => N_36329,
datae => \GRFPU0.GRFPU_X0.N_16184\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(61),
datab => \FPI.OP2\(62),
dataa => \FPI.FLOP\(1));
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0cfff30c000c")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528\(1),
dataf => \GRFPC0.FP_PIPELINE.13.STDEP_524\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.N_17935\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_21076_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8880080008000800")
port map (
combout => \GRFPC0.N_21598\,
dataf => \GRFPC0.N_21683_1\,
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
datad => \GRFPC0.N_21716\,
datac => \GRFPC0.N_21540\,
datab => \GRFPC0.N_21542\,
dataa => \GRFPC0.N_21541\);
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000004000")
port map (
combout => \GRFPC0.N_20683\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(10),
datac => \GRFPC0.INST\(6),
datab => \GRFPC0.INST\(8),
dataa => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_1_REGDEP172_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ca0000ca35000035")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP172_1\,
dataf => RFI2_RD2ADDRZ(3),
datae => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datab => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
dataa => \GRFPC0.RFA.RD\(4));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8200d70022007700")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(10),
dataf => N_36274,
datae => N_36217,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.OP1\(61),
datab => \FPI.OP1\(62),
dataa => \FPI.FLOP\(1));
\GRFPC0_D_STLCK_RNO_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0b0f030f0")
port map (
combout => \GRFPC0.N_22207\,
dataf => \GRFPC0.N_22183\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.N_228\,
datac => \GRFPC0.N_112\,
datab => \GRFPC0.N_24606_2\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9_6\,
datae => \GRFPC0.INST\(6),
datad => \GRFPC0.INST\(8),
datac => \GRFPC0.INST\(13),
datab => \GRFPC0.INST\(7));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c003f00c000f300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(9),
dataf => N_36274,
datae => N_36217,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.OP1\(61),
datab => \FPI.FLOP\(1));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa00ffffaa00bfbf")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(10),
datab => \GRFPC0.INST\(8),
dataa => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_0_REGDEP30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000800000004")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
dataf => \GRFPC0.N_23611\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_4\,
datab => \GRFPC0.WR2.CTRL.RDWR\,
dataa => \GRFPC0.WR2.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_RSDEC_RS1V8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0100000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8_5\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(12),
datab => \GRFPC0.INST\(13),
dataa => \GRFPC0.INST\(7));
\GRFPC0_FPUSEL_6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330000000c0c0c0c")
port map (
combout => \GRFPC0.FPUSEL_6\(2),
dataf => \GRFPC0.N_21694\,
datae => \GRFPC0.FP_PIPELINE.0.MEMEN2\,
datad => \GRFPC0.FP_PIPELINE.0.MEMSEL4\,
datac => \GRFPC0.N_121_1\,
datab => N_63);
GRFPC0_RFA2_RS2DEP_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0200010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\,
dataf => \GRFPC0.REGDEP_2_SQMUXA_4\,
datae => \GRFPC0.RFA.RS2D_0_0_G1\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
dataa => \GRFPC0.N_131_0\);
GRFPC0_RFA2_RS2DEP_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0200010000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0\,
dataf => \GRFPC0.REGDEP_2_SQMUXA_6\,
datae => \GRFPC0.RFA.RS2D_0_0_G1\,
datad => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
dataa => \GRFPC0.WR2.CTRL.RDD_0\);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffcf300030cf30")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(28),
dataf => N_31291,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(28),
datac => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G5\,
datab => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11289\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(3),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11286\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIHA1H1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11269\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11271\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datab => N_61);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11285\,
dataf => \GRFPU0.GRFPU_X0.N_19405_1\,
datae => \GRFPU0.GRFPU_X0.N_19318_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datab => N_61);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(11));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(16));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(17));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(23));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(27));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(31));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(35));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(36));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(37));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(38));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(43));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(45));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(47));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(51));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(52));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_0\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_0\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4_1\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(2),
dataa => \GRFPU0.GRFPU_X0.L4_4\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
datab => \GRFPU0.GRFPU_X0.N_17_I\,
dataa => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaf0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(39),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(40),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(41),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(42),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(43),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(44),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(45),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(46),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(47),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(48),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(49),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(50),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(51),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(52),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(53),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(54),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(55),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(56),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(57),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(58),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(39),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(40),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(41),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(42),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(43),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(44),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(45),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(46),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(47),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(48),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(49),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(50),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(51),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(52),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(53),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(54),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(55),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(56),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(57),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(58),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M17_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M19_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M27_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M28_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M29_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M30_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_24_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M19_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M27_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M28_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M29_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M30_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(8),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(9),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(12),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(13),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(14),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(16),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(17),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00aaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00aaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaf0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_4_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"df9b5713ce8a4602")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f00033fff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_19842\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff3300f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(33),
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff3300f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(34),
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f00033fff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_7\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f00033fff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_19843\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff3300f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(37),
datad => \GRFPU0.GRFPU_X0.N_7297\,
datac => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_11\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_19844\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(40),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_19845\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_19846\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_19847\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030f0003f3fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_19848\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(45),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(46),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(47),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(48),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3030ff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(49),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(50),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(51),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(52),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(53),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(54),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_0\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(55),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(56),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(57),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(58),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(59),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(60),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(61),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(61),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0f3030f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(62),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(62),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff0fc0c0f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(63),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datac => \GRFPU0.GRFPU_X0.N_7297\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datab => \FPI.OP1_RETO\(2));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(3),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datab => \FPI.OP1_RETO\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(4),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datab => \FPI.OP1_RETO\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \FPI.OP1_RETO\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(6),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datab => \FPI.OP1_RETO\(6));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datab => \FPI.OP1_RETO\(7));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(8),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datab => \FPI.OP1_RETO\(8));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(9),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \FPI.OP1_RETO\(9),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datab => \FPI.OP1_RETO\(10));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(11),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \FPI.OP1_RETO\(11));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(12),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datab => \FPI.OP1_RETO\(12));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datab => \FPI.OP1_RETO\(13));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(14),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \FPI.OP1_RETO\(14),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(14));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(15),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datab => \FPI.OP1_RETO\(15));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \FPI.OP1_RETO\(16),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(16));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datab => \FPI.OP1_RETO\(17));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \FPI.OP1_RETO\(19),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(19));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(20),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(20),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(21),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(23),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000fc0cff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_1\(24),
datae => \GRFPU0.GRFPU_X0.N_20484\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
datac => \GRFPU0.GRFPU_X0.N_4296\,
datab => \FPI.OP1_RETO\(24));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(25),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(27),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(28),
datae => \GRFPU0.GRFPU_X0.N_4296\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(31),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(37),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(40),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(41),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(42),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(43),
datae => \GRFPU0.GRFPU_X0.N_20792\,
datad => \GRFPU0.GRFPU_X0.N_4296\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff0fff0ff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(44),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(24),
datac => \GRFPU0.GRFPU_X0.N_4296\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(45),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(47),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(48),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(49),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(50),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00fff0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(51),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
GRFPC0_R_FSR_NONSTD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \FPI.NONSTD\,
datad => \GRFPC0.WR2.RREG.RES\(22),
datac => N_478,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_RD_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0c0f3c0f3c0")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.WR2.RREG.RES\(30),
datad => \FPI.RNDMODE\(0),
datac => N_486,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_RD_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0c0f3c0f3c0")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.WR2.RREG.RES\(31),
datad => \FPI.RNDMODE\(1),
datac => N_487,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_TEM_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(0),
datad => \GRFPC0.WR2.RREG.RES\(23),
datac => N_479,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_TEM_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.WR2.RREG.RES\(24),
datac => N_480,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_TEM_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.WR2.RREG.RES\(25),
datac => N_481,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_TEM_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.WR2.RREG.RES\(26),
datac => N_482,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_TEM_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f3f3c0c0")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.WR2.RREG.RES\(27),
datac => N_483,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc3030ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.UN28_EXP\(3),
datad => \GRFPU0.GRFPU_X0.N_16177\,
datac => \FPI.OP2\(55),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cfff0ff3c00f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_16178\,
datae => N_36304,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(56),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff30c0000030c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_207\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datac => \GRFPU0.GRFPU_X0.N_80\,
datab => \FPI.OP2\(60));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cff3c00f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(6),
dataf => N_36314,
datae => \GRFPU0.GRFPU_X0.N_16180\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(58),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cff3c00f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(7),
dataf => N_36319,
datae => \GRFPU0.GRFPU_X0.N_16184\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(59),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cff3c00f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(8),
dataf => N_36324,
datae => \GRFPU0.GRFPU_X0.N_16184\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(60),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cff3c00f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(9),
dataf => N_36329,
datae => \GRFPU0.GRFPU_X0.N_16184\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datac => \FPI.OP2\(61),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_19545\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(3));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(4));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(6),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(5));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_19549\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(4),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(7));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_19550\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(3),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(8));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_19551\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(9));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_19552\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_19553\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.REST_1_2_IV_1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4));
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11221\,
dataf => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\,
datae => \GRFPU0.GRFPU_X0.VST2.EXC_2_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_4352\,
datac => \GRFPU0.GRFPU_X0.REST_2_IV_1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4));
\GRFPC0_D_LDLCK_RNO_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_16__G1_1\,
datae => \GRFPC0.D.LDLCK_0_0_16__G1_0\,
datad => \GRFPC0.N_165_1\,
datac => \GRFPC0.N_22249\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(1),
datae => \GRFPC0.D.LDLCK_0_0_1__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.REGDEPX_5\(1),
datac => \GRFPC0.N_23069\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
GRFPU0_GRFPU_X0_COMB_GETINF_UN9_MODE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0ffc0ffc0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_7654\,
dataf => \GRFPU0.GRFPU_X0.COMB.SIGN_1\,
datae => \GRFPU0.GRFPU_X0.COMB.RNDM_2\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RNDM_2\(0),
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_4\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_3\);
GRFPU0_GRFPU_X0_COMB_UN1_ST3_INF_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datae => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
datac => \GRFPU0.GRFPU_X0.ST3.EXC\(0));
GRFPU0_GRFPU_X0_COMB_UN1_ST3_INF_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.INF_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
datae => \GRFPU0.GRFPU_X0.ST3.INF\,
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(5));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000ccc000000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19517\,
dataf => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
\GRFPU0_GRFPU_X0_L1_4_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(3),
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3346\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52975,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_39__G3_0_1757_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(99));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_0\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(57));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0033000300")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3_1\,
datac => \GRFPU0.GRFPU_X0.N_19526_1\,
datab => \GRFPU0.GRFPU_X0.N_19495_I\);
\GRFPU0_GRFPU_X0_L1_4_5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(3),
dataf => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3306\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52976,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_42__G3_0_1783_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(102));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_A2_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20848\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_20876\,
datad => \GRFPU0.GRFPU_X0.N_20764_0\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18));
GRFPU0_GRFPU_X0_COMB_SWAP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\);
GRFPU0_GRFPU_X0_COMB_SWAP_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030003000303030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_18426\,
datac => \GRFPU0.GRFPU_X0.N_4458_1\,
datab => \GRFPU0.GRFPU_X0.ST1.V\);
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G5\,
datae => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_0\,
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_0_RNO_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4260_I_M\,
dataf => \GRFPU0.GRFPU_X0.N_4233\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_0_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff03f3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_0\(63),
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.N_4260_I_M\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff333f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_IV_0\(63),
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.N_4233\,
datab => \GRFPU0.GRFPU_X0.N_4227\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_19836\,
datae => \GRFPU0.GRFPU_X0.N_19800\,
datad => N_35934,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(58),
dataf => \GRFPU0.GRFPU_X0.N_19837\,
datae => \GRFPU0.GRFPU_X0.N_19798\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_1\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(58));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_2_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(56),
dataf => \GRFPU0.GRFPU_X0.N_19791\,
datae => \GRFPU0.GRFPU_X0.N_18\,
datad => \GRFPU0.GRFPU_X0.N_19794\,
datac => \GRFPU0.GRFPU_X0.N_19838\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_11\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(38),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(38));
\GRFPC0_D_LDLCK_RNO_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c000c000c00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.N_21904\,
datad => \GRFPC0.N_88_1_0\,
datac => \GRFPC0.N_24279\,
datab => \GRFPC0.N_21911_3\);
\GRFPC0_D_LDLCK_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(1),
datae => \GRFPC0.D.LDLCK_0_0_23__G1_3\,
datad => \GRFPC0.D.LDLCK_0_0_23__G1_2\);
\GRFPC0_D_STLCK_RNO_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_20__G1_2\,
datae => \GRFPC0.N_22718\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_D_STLCK_RNO_5_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_0\,
dataf => \GRFPC0.N_20965\,
datae => N_174895,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4));
\GRFPC0_D_STLCK_RNO_3_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00c0")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_2\,
dataf => \GRFPC0.N_137\,
datae => \GRFPC0.D.STLCK_0_0_25__G1_0\,
datad => \GRFPC0.N_23044\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4199_DEP\);
\GRFPC0_D_STLCK_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1\,
dataf => \GRFPC0.N_20913\,
datae => \GRFPC0.N_20968\,
datad => \GRFPC0.N_20967\,
datac => \GRFPC0.N_23412\,
datab => \GRFPC0.D.STLCK_0_0_25__G1_2\);
GRFPU0_GRFPU_X0_ST3_V_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19427_I\,
dataf => \GRFPU0.GRFPU_X0.N_19463\,
datae => \GRFPU0.GRFPU_X0.N_18975\,
datad => \FPI.FLUSH\,
datac => \GRFPU0.GRFPU_X0.ST2.V\,
datab => N_61);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_7459\,
datae => \GRFPU0.GRFPU_X0.N_7143\,
datad => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1\(4),
datac => \GRFPU0.GRFPU_X0.N_6759\,
datab => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_6575_1\,
datae => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_6759_1\,
datac => \GRFPU0.GRFPU_X0.N_6577\,
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(0));
GRFPU0_GRFPU_X0_ST3_RDY_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_11213\,
dataf => \GRFPU0.GRFPU_X0.N_7439\,
datae => \GRFPU0.GRFPU_X0.N_6576_1\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G5\,
datac => \GRFPU0.GRFPU_X0.N_6611\,
datab => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_6575_1\,
datae => \GRFPU0.GRFPU_X0.N_6577\,
datad => \GRFPU0.GRFPU_X0.ST2.EXC\(1));
GRFPU0_GRFPU_X0_ST3_INF_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0fff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_7028\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ST2.INF\);
GRFPU0_GRFPU_X0_ST3_INF_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_11211\,
dataf => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_1\,
datae => \GRFPU0.GRFPU_X0.N_7019\,
datad => \GRFPU0.GRFPU_X0.N_6995\,
datac => \GRFPU0.GRFPU_X0.VST3.INF_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6));
GRFPU0_GRFPU_X0_COMB_VST3_RDY9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7458\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_VST3_EXC_1_0_F1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffccccccff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F1\(4),
dataf => \GRFPU0.GRFPU_X0.N_6995\,
datae => \GRFPU0.GRFPU_X0.N_6577\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(4));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
dataf => \GRFPU0.GRFPU_X0.N_7645\,
datae => \GRFPU0.GRFPU_X0.N_6659\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_2\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_1\);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c0000c0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9\,
datae => \GRFPU0.GRFPU_X0.N_7053\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VST3_REG_1_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9\,
datae => \GRFPU0.GRFPU_X0.N_7053\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPU0_GRFPU_X0_L3_0_3_1_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_L3_0_3_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(5),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.L1_2_1\(3),
datac => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.L3_0_3_1\(5));
\GRFPU0_GRFPU_X0_L1_2_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10715\,
dataf => \GRFPU0.GRFPU_X0.N_10722\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_UN208_BCO_LSB_RNIT3BR1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10765\,
dataf => \GRFPU0.GRFPU_X0.N_10741\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPU0_GRFPU_X0_L1_4_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff000f0000fff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_21179\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_0\,
datac => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccffff00000000")
port map (
combout => N_52977,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_43__G3_0_1809_I_2\,
datae => \GRFPU0.GRFPU_X0.N_296\,
datad => \GRFPU0.GRFPU_X0.N_19499\,
datac => \GRFPU0.GRFPU_X0.N_16257\,
datab => \GRFPU0.GRFPU_X0.N_16309\);
GRFPU0_GRFPU_X0_UN148_BCO_LSB_RNIC8QE1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPC0_D_LDLCK_RNO_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccccfcccccc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_2\,
dataf => \GRFPC0.N_22354\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1_0\(19),
datab => \GRFPC0.D.LDLCK_0_0_28__G1_1\);
\GRFPC0_D_LDLCK_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_28__G1_2\,
datae => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(0),
datad => \GRFPC0.N_165_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\);
\GRFPU0_GRFPU_X0_ITER_ND_I_RNI5Q0L1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
GRFPU0_GRFPU_X0_UN18_BCO_LSB_RNI7T8QA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10514\,
dataf => \GRFPU0.GRFPU_X0.N_10558\,
datae => \GRFPU0.GRFPU_X0.N_10519\,
datad => \GRFPU0.GRFPU_X0.N_10521\,
datac => \GRFPU0.GRFPU_X0.L3_0_1\(5));
GRFPU0_GRFPU_X0_VITER_R_I_1_SQMUXA_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c3000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0ff0c3c33c3c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
datae => \GRFPU0.GRFPU_X0.N_10514\,
datad => \GRFPU0.GRFPU_X0.L4_6\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_L1_2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10894\,
dataf => \GRFPU0.GRFPU_X0.N_10901\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c0c0cc00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_19526_1\,
datae => \GRFPU0.GRFPU_X0.N_19495_I\,
datad => \GRFPU0.GRFPU_X0.N_19502\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_1\,
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3_0\,
datac => \GRFPU0.MULO.MRES\(66));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(55));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ff33fff3")
port map (
combout => \GRFPU0.GRFPU_X0.N_11267\,
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_1_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19405\,
datad => \GRFPU0.GRFPU_X0.N_19318_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => N_61);
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I_RNIAHSQ7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc0000000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11255\,
dataf => \GRFPU0.GRFPU_X0.VITER.V_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.N_19405\,
datad => \GRFPU0.GRFPU_X0.VITER.V_0_SQMUXA_1\,
datac => \FPI.FLUSH\,
datab => N_61);
\GRFPC0_D_LDLCK_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_29__G3\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_9\(1),
datad => \GRFPC0.N_24749\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_7\(1),
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A4_0_0\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff00000c0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(41),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3_1\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52980,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_47__G3_0_1887_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(107));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19197\,
dataf => \GRFPU0.GRFPU_X0.N_59\,
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
GRFPC0_EX_RREG_RESV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_10185\,
dataf => \GRFPC0.N_121_1\,
datae => N_61,
datad => N_63);
GRFPC0_FP_PIPELINE_VDIV_VALID2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
dataf => \GRFPC0.FPR.ID\(0),
datae => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.DIV.ID\(0),
datac => \GRFPC0.DIV.ID\(4));
GRFPC0_FP_PIPELINE_VDIV_VALID2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
datae => \GRFPC0.FPR.ID\(5),
datad => \GRFPC0.FPR.ID\(3),
datac => \GRFPC0.DIV.ID\(5),
datab => \GRFPC0.DIV.ID\(3));
GRFPC0_FP_PIPELINE_VDIV_VALID2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(2),
datad => \GRFPC0.DIV.ID\(1),
datac => \GRFPC0.DIV.ID\(2));
GRFPC0_FP_PIPELINE_VDIV_VALID2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.DIV.ID\(7));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff00000c0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(51),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3_1\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(111));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0fccff00000000")
port map (
combout => N_52974,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_33__G3_0_1731_I_1\,
datae => \GRFPU0.GRFPU_X0.N_20609\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f000c000f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_0\,
datab => \GRFPU0.MULO.MRES\(64));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3_2\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(4),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0033000300")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3_1\,
datac => \GRFPU0.GRFPU_X0.N_19526_1\,
datab => \GRFPU0.GRFPU_X0.N_19495_I\);
\GRFPU0_GRFPU_X0_L1_4_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(3),
dataf => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeeeeeeeeeeeeeec")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_44\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_0_18__G0_0_0\,
dataa => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\);
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F0_I_O2_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_O2_0_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F0_I_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => N_174934,
dataf => \GRFPU0.GRFPU_X0.N_7365\,
datae => \GRFPU0.GRFPU_X0.L1_2\(3),
datad => \GRFPU0.GRFPU_X0.N_19295\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_O2_0_2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff003c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(52),
dataf => \GRFPU0.GRFPU_X0.N_244\,
datae => \GRFPU0.GRFPU_X0.N_19890\,
datad => \GRFPU0.GRFPU_X0.N_19840\,
datac => \GRFPU0.GRFPU_X0.N_7654\,
datab => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff300c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_0_0\(52),
datae => \GRFPU0.GRFPU_X0.N_17600\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f33300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_244\,
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_19890\,
datad => \GRFPU0.GRFPU_X0.N_4066_0\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f030000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303030303ff")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.N_4997\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11232\,
dataf => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_1\,
datad => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
datac => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3_1\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_TZ_TZ\,
datae => \GRFPU0.GRFPU_X0.N_19465\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(54),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.N_19397\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(38),
dataf => \GRFPU0.GRFPU_X0.N_21049\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(38),
datac => \GRFPU0.GRFPU_X0.N_242\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(38));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_2\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(53),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_21179\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_0\,
datac => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cffff00000000")
port map (
combout => N_52979,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_46__G3_0_1861_I_2\,
datae => \GRFPU0.GRFPU_X0.N_296\,
datad => \GRFPU0.GRFPU_X0.N_16260\,
datac => \GRFPU0.GRFPU_X0.N_19499\,
datab => \GRFPU0.GRFPU_X0.N_16312\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52978,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_44__G3_0_1835_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(104));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52973,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_31__G3_0_1705_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52972,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_27__G3_0_1679_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52971,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_25__G3_0_1653_I_1\,
datae => \GRFPU0.GRFPU_X0.N_20910_I\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52970,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_22__G3_0_1627_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(82));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52969,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_18__G3_0_1601_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52968,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_17__G3_0_1575_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52966,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_15__G3_0_1523_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(75));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => N_52965,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_14__G3_0_1497_I_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_296\,
datab => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_21179\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_11__G3_0_1471_I_0\,
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPC0_D_LDLCK_RNO_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1_2\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\,
datad => \GRFPC0.D.LDLCK_0_0_21__G1_0\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
datab => \GRFPC0.N_88_1_0\);
\GRFPC0_D_LDLCK_RNO_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
datae => \GRFPC0.N_92_1\,
datad => \GRFPC0.N_20860\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX\,
datab => \GRFPC0.N_88_1_0\);
\GRFPC0_D_LDLCK_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1_0\,
dataf => \GRFPC0.N_22918_1\,
datae => \GRFPC0.N_22325_2\,
datad => \GRFPC0.N_167_1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN631_REGDEPX_0\,
datab => N_105);
\GRFPC0_D_LDLCK_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1_2\,
dataf => \GRFPC0.N_22924_1\,
datae => \GRFPC0.N_22619_2\,
datad => \GRFPC0.D.LDLCK_0_0_2__G1_0\,
datac => \GRFPC0.N_22925_1\,
datab => \GRFPC0.N_22466_2\);
\GRFPC0_D_LDLCK_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
datae => \GRFPC0.N_22914\,
datad => \GRFPC0.D.LDLCK_0_0_2__G1_2\,
datac => \GRFPC0.N_22913\,
datab => \GRFPC0.N_22912\);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(58));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(56));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(54));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\,
dataf => \GRFPU0.GRFPU_X0.N_19525\,
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(53));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf00ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3_0\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(52));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G0_0_A4_0_1\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(10),
datae => \GRFPU0.GRFPU_X0.UN8_C\(7),
datad => \GRFPU0.GRFPU_X0.UN8_C\(1),
datac => \GRFPU0.GRFPU_X0.UN8_C\(0));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__N_5\,
dataf => \GRFPU0.GRFPU_X0.N_19253_1\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_2__G0_0_A4_0_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(9),
datab => \GRFPU0.GRFPU_X0.UN8_C\(8));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_11258\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G0_0_1\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3\,
datad => \GRFPU0.GRFPU_X0.N_19250\,
datac => \GRFPU0.GRFPU_X0.N_19221\,
datab => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_A5_1_0\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ff33fff0ff30")
port map (
combout => \GRFPU0.GRFPU_X0.N_11257\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.N_19272\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__N_6\,
datac => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G2_1\,
datab => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\);
GRFPU0_GRFPU_X0_ST2_EMINM1_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_A2_0_G0_1\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(10),
datae => \GRFPU0.GRFPU_X0.N_4352\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(0));
GRFPU0_GRFPU_X0_ST2_EMINM1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11261\,
dataf => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_A2_0_G0_1\,
datae => N_124830,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.N_19212\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_0\,
datac => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(40),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(100));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(38),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(98));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_0\,
datac => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffcfff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3_2\,
datae => \GRFPU0.GRFPU_X0.N_20608\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff0c0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(36),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_0\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_0\,
datac => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff00000c0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3_1\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_0\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_0\,
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_0\,
datac => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_2\,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => \GRFPU0.GRFPU_X0.N_19526_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_0\,
datac => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff00000c0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(8),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3_1\,
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.N_19495_I\,
datab => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11_I_M\(2),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_0\,
datac => \GRFPU0.MULO.MRES\(62));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffc0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3_2\,
datae => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(2),
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0f000c000f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
datae => \GRFPU0.GRFPU_X0.N_20_I\,
datad => \GRFPU0.GRFPU_X0.N_19526_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_0\,
datab => \GRFPU0.MULO.MRES\(61));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0000c0ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3\,
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(1),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3_2\,
datad => \GRFPU0.GRFPU_X0.N_19495_I\,
datac => \GRFPU0.GRFPU_X0.N_19502_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17_I_M\(0),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11_I_M\(0),
datad => \GRFPU0.GRFPU_X0.N_20_I\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3_0\,
datab => \GRFPU0.MULO.MRES\(60));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3\,
dataf => \GRFPU0.GRFPU_X0.N_19213\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_1__G3_2\,
datad => \GRFPU0.GRFPU_X0.N_19264\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(1),
datab => \GRFPU0.GRFPU_X0.UN8_C\(0));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G2_1\,
dataf => \GRFPU0.GRFPU_X0.N_19264\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19250\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_O2_0_0\(1),
datad => \GRFPU0.GRFPU_X0.N_96\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(10),
datab => \GRFPU0.GRFPU_X0.UN8_C\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003ff030000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(44));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19848\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(44),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003ff030000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(42));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19846\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(42),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003ff030000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(36));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19843\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0_0\(36),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19844\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(39),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(39));
\GRFPU0_GRFPU_X0_L1_0_15_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7370\,
dataf => \GRFPU0.GRFPU_X0.N_7376\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_L2_0_10_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_10_2\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_L2_0_10_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7365\,
dataf => \GRFPU0.GRFPU_X0.N_7370\,
datae => \GRFPU0.GRFPU_X0.L2_0_10_2\(4),
datad => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19842\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(32),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(32));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_7\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(35),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(35));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19845\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(41),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(41));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030ff300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_I_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19847\,
dataf => \GRFPU0.GRFPU_X0.N_19853\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_I_0\(43),
datad => \GRFPU0.GRFPU_X0.N_19899\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(46),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(46),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(46));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(29),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(29),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(29));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(30),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(30),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(30));
GRFPU0_GRFPU_X0_UN73_BCO_LSB_RNIHNBB1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNIAVBA1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_1\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_L1_4_1_0_0_RNI57UI3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0\(4),
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => \GRFPU0.GRFPU_X0.N_3846\,
datad => \GRFPU0.GRFPU_X0.L2_1_1\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNICJOD2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0\(3),
dataf => \GRFPU0.GRFPU_X0.N_10920\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
GRFPU0_GRFPU_X0_UN93_BCO_LSB_RNI3N1Q3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10895\,
dataf => \GRFPU0.GRFPU_X0.L1_0\(3),
datae => \GRFPU0.GRFPU_X0.N_10907\,
datad => \GRFPU0.GRFPU_X0.N_3826\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNI07BA1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
GRFPU0_GRFPU_X0_UN103_BCO_LSB_RNIMEPP5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10889\,
dataf => \GRFPU0.GRFPU_X0.N_10895\,
datae => \GRFPU0.GRFPU_X0.N_10894\,
datad => \GRFPU0.GRFPU_X0.N_10896\,
datac => \GRFPU0.GRFPU_X0.L3_1\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(35),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(35),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(25),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(25),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \FPI.OP1_RETO\(25),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(25));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000ffff30f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_0\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(24),
datae => \GRFPU0.GRFPU_X0.N_20562_1\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_0\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(24));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(19),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(19),
datae => \GRFPU0.GRFPU_X0.N_20487\,
datad => \GRFPU0.GRFPU_X0.N_20488\,
datac => \FPI.OP1_RETO\(19),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(19));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(14),
dataf => \GRFPU0.GRFPU_X0.N_20487\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(14),
datad => \GRFPU0.GRFPU_X0.N_20488\,
datac => \FPI.OP1_RETO\(14),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(5),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(5),
datae => \GRFPU0.GRFPU_X0.N_20487\,
datad => \GRFPU0.GRFPU_X0.N_20488\,
datac => \FPI.OP1_RETO\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(31),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(31),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(31));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(16),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(16),
datae => \GRFPU0.GRFPU_X0.N_20487\,
datad => \GRFPU0.GRFPU_X0.N_20488\,
datac => \FPI.OP1_RETO\(16),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(16));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(9),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_0\(9),
datae => \GRFPU0.GRFPU_X0.N_20487\,
datad => \GRFPU0.GRFPU_X0.N_20488\,
datac => \FPI.OP1_RETO\(9),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_20485\,
datae => \GRFPU0.GRFPU_X0.N_20484\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(44));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(45),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(45),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(45));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_34\,
dataf => \GRFPU0.DIVROM0.RADDR\(2),
datae => \GRFPU0.DIVROM0.RADDR\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_43: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c300300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_43\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_34\,
datae => \GRFPU0.DIVROM0.RADDR\(1),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_21\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_42: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_42\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_20\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_21\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_15\,
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_16\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_30\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_16\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_23\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_1\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_45: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_45\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_37\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_13\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_12\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_11\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_10\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_36\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3_44: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_44\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_9\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_6\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_8\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_7\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_36\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_46\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_45\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_44\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_42\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0_A3_43\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(55),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.N_20816_1\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(32),
dataf => \GRFPU0.GRFPU_X0.N_20479\,
datae => \GRFPU0.GRFPU_X0.N_20480\,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(32),
datae => \GRFPU0.GRFPU_X0.N_20485\,
datad => \GRFPU0.GRFPU_X0.N_20484\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(32));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(61),
dataf => \GRFPU0.GRFPU_X0.N_19837\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_6_0_2\(61),
datad => \GRFPU0.GRFPU_X0.N_19804\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61));
GRFPU0_GRFPU_X0_UN123_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000035")
port map (
combout => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(101),
dataa => \GRFPU0.MULO.DRES_1S\(100));
GRFPU0_GRFPU_X0_UN128_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(14));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNIG11L1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
GRFPU0_GRFPU_X0_UN8_BCO_LSB_RNIJ0JF6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10558\,
dataf => \GRFPU0.GRFPU_X0.N_10569\,
datae => \GRFPU0.GRFPU_X0.N_10570\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.L2_0_0_1\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_4\(41),
dataf => \GRFPU0.GRFPU_X0.N_20863\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_1\(41),
datad => \GRFPU0.GRFPU_X0.N_20846\,
datac => \GRFPU0.GRFPU_X0.N_20842\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_4\(41),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_A2_3_0\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_1\,
dataf => \GRFPU0.GRFPU_X0.C\(7),
datae => \GRFPU0.GRFPU_X0.C\(1),
datad => \GRFPU0.GRFPU_X0.C\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_1\,
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(9),
datac => \GRFPU0.GRFPU_X0.C\(8));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000ff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_1\,
dataf => \GRFPU0.GRFPU_X0.N_19554_5\,
datae => \GRFPU0.GRFPU_X0.N_47\,
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330f3300000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_0_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_2_3\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.N_47\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_1\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_99\,
dataf => \GRFPU0.GRFPU_X0.N_53\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.C\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_99\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_0_A2_1\,
datac => \GRFPU0.GRFPU_X0.N_19191\,
datab => \GRFPU0.GRFPU_X0.N_47\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.N_89\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.N_47\,
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2\(1),
dataf => \GRFPU0.GRFPU_X0.N_6243_7\,
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(4),
datac => \GRFPU0.GRFPU_X0.C\(3),
datab => \GRFPU0.GRFPU_X0.C\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_19199\,
datae => N_100078,
datad => \GRFPU0.GRFPU_X0.N_89\,
datac => \GRFPU0.GRFPU_X0.N_52\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2\(1));
\GRFPC0_WR_CTRL_ID_RNINCCHF_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_1__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_1__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(1),
datab => N_64);
\GRFPC0_MEM_CTRL_ID_RNII02JG_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(1),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_1__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(1),
datab => \GRFPC0.MEM.CTRL.ID\(1));
GRFPC0_WR_CTRL_SEQERR_RNILTIS5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => N_50070,
dataf => N_50070_3,
datae => \GRFPC0.WR.CTRL.SEQERR\,
datad => N_414,
datac => N_413,
datab => N_64);
GRFPC0_WR2_CTRL_AFSR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => N_50084,
dataf => N_50070_3,
datae => \GRFPC0.WR.CTRL.AFSR\,
datad => N_414,
datac => N_413,
datab => N_64);
GRFPC0_WR2_CTRL_STDFQ_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => N_50098,
dataf => N_50097,
datae => \GRFPC0.WR.CTRL.STDFQ\,
datad => N_414,
datac => N_413,
datab => N_64);
\GRFPC0_EX_CTRL_PC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfff0")
port map (
combout => N_53031,
dataf => N_51770,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51763,
datab => \GRFPC0.EX.CTRL.PC\(3));
\GRFPC0_D_STLCK_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff30")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_4\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.D.STLCK_0_0_22__G1_2\,
datad => \GRFPC0.N_21921\,
datac => \GRFPC0.STDDEP_0_SQMUXA_93\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
\GRFPC0_D_STLCK_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1\,
dataf => \GRFPC0.N_22001\,
datae => \GRFPC0.N_22053\,
datad => \GRFPC0.N_22045\,
datac => \GRFPC0.D.STLCK_0_0_21__G1_2\,
datab => \GRFPC0.N_177\);
\GRFPC0_D_STLCK_RNO_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_4\,
dataf => \GRFPC0.N_22452_1\,
datae => \GRFPC0.N_21749\,
datad => \GRFPC0.D.STLCK_0_0_13__G1_1\,
datac => \GRFPC0.N_22457\,
datab => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_4_2\(1));
\GRFPC0_D_STDLCK_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_6\,
dataf => \GRFPC0.N_83\,
datae => N_100325,
datad => \GRFPC0.N_21010\,
datac => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3));
\GRFPC0_D_STDLCK_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcf0fcf0fcf0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_A2_7_1\,
datae => \GRFPC0.N_21553\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_92_IV_0_O2_3_2\,
datac => \GRFPC0.D.STDLCK_0_0_3__G1_6\,
datab => \GRFPC0.N_46\);
\GRFPC0_FPR_ALLOW_RNI872M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffff0fff0ff")
port map (
combout => \GRFPC0.INST_1387_I_O3_1_1\,
dataf => \GRFPC0.RFA2.FOP\(0),
datae => \GRFPC0.FPR.ALLOW\(1),
datad => N_63,
datac => N_64);
GRFPC0_RFA2_RS2DEP_RNIU0653_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffffffffff")
port map (
combout => N_49622,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => N_50504_4,
datad => \FPI.START_1\,
datac => N_50504_3,
datab => \GRFPC0.INST_1387_I_O3_1_1\,
dataa => \GRFPC0.RFA2.RS2DEP\);
\GRFPC0_EX_CTRL_PC_RNO_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_30__G1_0_5717_I_A4_1_0\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datae => \GRFPC0.FIFO.RD_1_0\(0),
datad => \GRFPC0.FIFO.PC_1\(30),
datac => \GRFPC0.FIFO.PC_0\(30));
\GRFPC0_EX_CTRL_PC_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c000fcccc00ff")
port map (
combout => N_53058,
dataf => N_52733,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.PC_0_0_30__G1_0_5717_I_A4_1_0\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(30));
\GRFPC0_D_STDLCK_RNO_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c0ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_1\,
dataf => \GRFPC0.N_23178\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.STDDEP_0_SQMUXA_3_I_O5_0\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STDLCK_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ff0fff03")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_5\,
dataf => \GRFPC0.N_21319\,
datae => \GRFPC0.N_21291_1\,
datad => \GRFPC0.D.STDLCK_0_0_14__G1_3\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\,
datab => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STDLCK_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cff0cff0c")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\,
datae => \GRFPC0.N_21553\,
datad => \GRFPC0.D.STDLCK_0_0_14__G1_5\,
datac => \GRFPC0.N_22811\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_2\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.N_21317\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datac => \GRFPC0.N_21268\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\);
\GRFPC0_D_STDLCK_RNO_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_6\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4994_DEP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STDLCK_RNO_4_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_2\,
dataf => \GRFPC0.N_17377\,
datae => \GRFPC0.STDDEP_0_SQMUXA_1_I_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_I_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STDLCK_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff4cff40")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_12_8\,
datae => \GRFPC0.UN1_STDDEP_0_SQMUXA_108\,
datad => \GRFPC0.D.STDLCK_0_0_15__G1_8\,
datac => \GRFPC0.N_17842_1\,
datab => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\,
dataa => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STDLCK_RNO_7_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12_2\,
dataf => \GRFPC0.N_17842_1\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_0\);
\GRFPC0_D_STDLCK_RNO_6_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_12_2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\);
\GRFPC0_D_STLCK_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff30ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_3\,
dataf => \GRFPC0.N_23107\,
datae => \GRFPC0.N_23116\,
datad => \GRFPC0.D.STLCK_0_0_30__G1_1\,
datac => \GRFPC0.STDDEP_0_SQMUXA_117_1\,
datab => \GRFPC0.FIFO.INST_0_0\(19));
\GRFPC0_D_STLCK_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffdfffff3f1")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1\,
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_612\(0),
datae => \GRFPC0.N_23137\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datac => \GRFPC0.D.STLCK_0_0_30__G1_3\,
datab => \GRFPC0.FP_PIPELINE.15.STDEP_616_SEL0\,
dataa => \GRFPC0.N_17377\);
\GRFPC0_D_STDLCK_RNO_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c00000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_0\,
dataf => \GRFPC0.N_20847\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_267,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\,
datab => N_270);
\GRFPC0_D_STDLCK_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffffcffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_2\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_22179\,
datad => \GRFPC0.N_112\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0_2\,
datab => \GRFPC0.D.STDLCK_0_0_8__G1_0\);
\GRFPC0_D_STDLCK_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1\,
dataf => \GRFPC0.N_20839\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.N_20880\,
datac => \GRFPC0.D.STDLCK_0_0_8__G1_2\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8));
\GRFPC0_D_STLCK_RNO_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_3\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_112\,
datad => \GRFPC0.N_22226\,
datac => \GRFPC0.N_20866\,
datab => \GRFPC0.D.STLCK_0_0_16__G1_0\);
\GRFPC0_D_STDLCK_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3f3f3f")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_2\,
dataf => \GRFPC0.N_55_LI\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datac => \GRFPC0.N_162\,
datab => \GRFPC0.N_22006\);
\GRFPC0_D_STDLCK_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3fff0ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1\,
dataf => \GRFPC0.N_84\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.N_109\,
datac => \GRFPC0.D.STDLCK_0_0_10__G1_2\,
datab => \GRFPC0.N_21998\);
\GRFPC0_D_STLCK_RNO_6_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0fcf0")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_1\,
dataf => \GRFPC0.N_21409\,
datae => \GRFPC0.N_23044\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.N_21382\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1903_DEP\);
\GRFPC0_D_STLCK_RNO_5_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff30")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.D.STLCK_0_0_11__G1_1\,
datad => \GRFPC0.N_21386\,
datac => \GRFPC0.N_21339\,
datab => \GRFPC0.N_21361_1\);
\GRFPC0_D_STLCK_RNO_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1_4\,
dataf => \GRFPC0.N_21423\,
datae => \GRFPC0.D.STLCK_0_0_11__G1_3\,
datad => \GRFPC0.N_22607\,
datac => \GRFPC0.N_21425\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_3_0\(1));
\GRFPC0_D_STLCK_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccc0ffffcc00")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1\,
dataf => N_38026,
datae => \GRFPC0.D.STLCK_0_0_11__G1_5\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_1\(1),
datac => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_11_1\(1),
datab => \GRFPC0.N_21361_1\);
\GRFPC0_D_STDLCK_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3ff03")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1\,
dataf => \GRFPC0.N_172\,
datae => \GRFPC0.N_21141\,
datad => \GRFPC0.D.STDLCK_0_0_0__G1_4\,
datac => \GRFPC0.N_22981\,
datab => \GRFPC0.N_78_I_I_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc000000c000")
port map (
combout => \GRFPC0.N_172\,
dataf => \GRFPC0.N_21141\,
datae => N_174898,
datad => \GRFPC0.N_193\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_1_1\,
datab => \GRFPC0.N_22981\);
\GRFPC0_D_STLCK_RNO_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fff3fff3fff")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_2\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
datae => \GRFPC0.N_21956_1\,
datad => \GRFPC0.N_17073\,
datac => \GRFPC0.N_17107\,
datab => \GRFPC0.N_17057\);
\GRFPC0_D_STDLCK_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_5\,
dataf => \GRFPC0.N_21600\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.N_21612\,
datac => \GRFPC0.D.STDLCK_0_0_7__G1_2\,
datab => \GRFPC0.N_22289\);
\GRFPC0_D_LDLCK_RNO_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
datae => \GRFPC0.N_167_1\,
datad => \GRFPC0.N_23304\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
datab => \GRFPC0.N_169_1\);
\GRFPC0_D_LDLCK_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_3\,
dataf => \GRFPC0.N_23358\,
datae => \GRFPC0.N_23309_1\,
datad => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_O2_0\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_D_LDLCK_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(0),
datae => \GRFPC0.D.LDLCK_0_0_26__G1_3\,
datad => \GRFPC0.N_23310\,
datac => \GRFPC0.N_23302\,
datab => \GRFPC0.D.LDLCK_0_0_26__G1_4\);
\GRFPC0_D_STLCK_RNO_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffffffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_5\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_23322\,
datad => \GRFPC0.N_22600\,
datac => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A2_0_0\(1),
datab => \GRFPC0.D.STLCK_0_0_27__G1_2\);
\GRFPC0_D_STLCK_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1\,
dataf => \GRFPC0.N_23291\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.D.STLCK_0_0_27__G1_5\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_D_LDLCK_RNO_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1_2\,
dataf => \GRFPC0.N_165_1\,
datae => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX\,
datad => \GRFPC0.D.LDLCK_0_0_30__G1_0\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
datab => \GRFPC0.N_169_1\);
\GRFPC0_D_LDLCK_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1\,
dataf => \GRFPC0.N_25173\,
datae => \GRFPC0.D.LDLCK_0_0_30__G1_3\,
datad => \GRFPC0.D.LDLCK_0_0_30__G1_2\,
datac => \GRFPC0.N_168_1\,
datab => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4880_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0),
datae => \GRFPC0.N_23195_1\,
datad => \GRFPC0.N_167_1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN317_REGDEPX_1\);
\GRFPC0_D_LDLCK_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(0),
datae => \GRFPC0.N_23064\,
datad => \GRFPC0.D.LDLCK_0_0_0__G1_3_0\,
datac => \GRFPC0.N_23030\,
datab => \GRFPC0.N_23029\);
\GRFPC0_D_STLCK_RNO_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffccccccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_1\,
dataf => \GRFPC0.N_23420\,
datae => \GRFPC0.N_20852\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4199_DEP\,
datab => \GRFPC0.N_23423\);
\GRFPC0_D_STLCK_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fcffff0030")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_6\,
dataf => \GRFPC0.STDEP_2_SQMUXA_135\,
datae => \GRFPC0.D.STLCK_0_0_24__G1_5\,
datad => \GRFPC0.N_23381\,
datac => \GRFPC0.N_21794\,
datab => \GRFPC0.N_20925\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000ccc0000")
port map (
combout => \GRFPC0.N_23453\,
dataf => N_174898,
datae => \GRFPC0.FP_PIPELINE.12.STDEP2026\,
datad => \GRFPC0.N_23381\,
datac => \GRFPC0.N_23403\,
datab => \GRFPC0.N_20925\);
\GRFPC0_D_STLCK_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1\,
dataf => \GRFPC0.D.STLCK_0_0_24__G1_6\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_23453\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4));
\GRFPC0_D_STLCK_RNO_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff00ff00ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.N_21372\,
datac => \GRFPC0.N_21092\,
datab => N_201);
\GRFPC0_D_STLCK_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_2\,
dataf => \GRFPC0.N_22612\,
datae => \GRFPC0.D.STLCK_0_0_10__G1_0\,
datad => \GRFPC0.N_20852\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1903_DEP\);
\GRFPC0_D_STLCK_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1\,
dataf => \GRFPC0.N_21327\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.D.STLCK_0_0_10__G1_2\,
datac => \GRFPC0.N_22614\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_0_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000cc00")
port map (
combout => \GRFPC0.N_22597\,
dataf => \GRFPC0.N_21404\,
datae => \GRFPC0.N_21794\,
datad => \GRFPC0.N_21337\,
datac => \GRFPC0.N_21341\,
datab => \GRFPC0.N_21353\);
\GRFPC0_D_STDLCK_RNO_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_0\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(5),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1903_DEP\);
\GRFPC0_D_STDLCK_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1\,
dataf => \GRFPC0.N_21414\,
datae => \GRFPC0.N_22542\,
datad => \GRFPC0.N_21420\,
datac => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_1\);
\GRFPC0_D_STLCK_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefafcf0")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1\,
dataf => \GRFPC0.N_22418_1\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A3_0_0\(1),
datac => \GRFPC0.D.STLCK_0_0_15__G1_1\,
datab => \GRFPC0.N_24408\,
dataa => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(7));
\GRFPC0_D_STLCK_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff8880")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1\,
dataf => \GRFPC0.N_22307\,
datae => \GRFPC0.D.STLCK_0_0_14__G1_3\,
datad => \GRFPC0.N_22364\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O3_10_1\(0),
datab => \GRFPC0.N_22718\,
dataa => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
\GRFPC0_D_STLCK_RNO_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.D.STLCK_0_0_5__G1_2\,
datad => \GRFPC0.N_22850\,
datac => \GRFPC0.N_21182\,
datab => \GRFPC0.N_17250\);
\GRFPC0_D_STLCK_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1\,
dataf => \GRFPC0.N_22804\,
datae => \GRFPC0.N_22806\,
datad => \GRFPC0.N_22878\,
datac => \GRFPC0.D.STLCK_0_0_5__G1_4\,
datab => N_128);
\GRFPC0_D_STLCK_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1\,
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_132\(1),
datae => \GRFPC0.D.STLCK_0_0_7__G1_4\,
datad => \GRFPC0.N_22774\,
datac => \GRFPC0.N_21016_1\,
datab => \GRFPC0.N_21012\);
\GRFPC0_D_STDLCK_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f03fffffff3")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1\,
dataf => \GRFPC0.N_21168_3\,
datae => \GRFPC0.D.STDLCK_0_0_2__G1_3\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datac => \GRFPC0.N_21177\,
datab => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STDLCK_RNO_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_0\,
dataf => \GRFPC0.N_22448\,
datae => \GRFPC0.RFA.LD_0\,
datad => N_198,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\,
datab => N_201);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f000000ff00")
port map (
combout => \GRFPC0.N_21760\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datad => \GRFPC0.N_21703\,
datac => \GRFPC0.MEM.CTRL.RDD_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21746\,
dataf => \GRFPC0.N_25876\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datac => \GRFPC0.N_21704\,
datab => \GRFPC0.N_21703\);
\GRFPC0_D_LDLCK_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
datae => \GRFPC0.N_22922\,
datad => \GRFPC0.D.LDLCK_0_0_3__G1_2\,
datac => \GRFPC0.N_22921\,
datab => \GRFPC0.N_22920\);
\GRFPC0_D_STLCK_RNO_6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.N_21791\,
datad => \GRFPC0.N_22485_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_D_STLCK_RNO_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0fcffff00fc")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_2\,
dataf => \GRFPC0.N_21821\,
datae => \GRFPC0.D.STLCK_0_0_3__G1_0\,
datad => \GRFPC0.N_22896\,
datac => \GRFPC0.N_78_I_I_0\,
datab => N_266);
\GRFPC0_D_STLCK_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_5\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_22943\,
datad => \GRFPC0.D.STLCK_0_0_3__G1_2\,
datac => \GRFPC0.N_22920\,
datab => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_2_0\(1));
\GRFPC0_D_STLCK_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1\,
dataf => \GRFPC0.N_22901\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.D.STLCK_0_0_3__G1_5\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_D_STLCK_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffccffcfcfcccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_1\,
dataf => \GRFPC0.N_20852\,
datae => \GRFPC0.N_22455\,
datad => \GRFPC0.N_22896\,
datac => \GRFPC0.N_21791\,
datab => \GRFPC0.N_22942\);
\GRFPC0_D_STLCK_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffcc")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_22939\,
datad => \GRFPC0.N_22912\,
datac => \GRFPC0.N_21821\,
datab => \GRFPC0.D.STLCK_0_0_2__G1_1\);
\GRFPC0_D_STLCK_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1\,
dataf => \GRFPC0.N_22902\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.D.STLCK_0_0_2__G1_4\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_D_STLCK_RNO_5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_A2_2_0\(1),
dataf => \GRFPC0.N_22964\,
datae => \GRFPC0.N_21783\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_2\);
\GRFPC0_D_STLCK_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1\,
dataf => \GRFPC0.N_21711\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_22495\,
datac => \GRFPC0.D.STLCK_0_0_12__G1_3\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(6));
\GRFPC0_D_STLCK_RNO_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_1\,
dataf => \GRFPC0.N_20852\,
datae => \GRFPC0.FP_PIPELINE.0.STDEP_202_0_IV_I_A2_0_0\(0),
datad => \GRFPC0.N_22690\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(4),
datab => \GRFPC0.N_22942_1\);
\GRFPC0_D_STLCK_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffdfffff3f1ffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1\,
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_172\(0),
datae => \GRFPC0.FP_PIPELINE.4.STDEP_180_0_IV_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datac => \GRFPC0.D.STLCK_0_0_8__G1_3\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_176_SEL0\,
dataa => \GRFPC0.N_17422\);
\GRFPC0_D_STLCK_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffccffcfcfcccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_1\,
dataf => \GRFPC0.N_20852\,
datae => \GRFPC0.N_22455\,
datad => \GRFPC0.N_22807\,
datac => \GRFPC0.N_22809\,
datab => \GRFPC0.N_22839\);
\GRFPC0_D_STLCK_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1\,
dataf => \GRFPC0.N_21193\,
datae => \GRFPC0.N_22806\,
datad => \GRFPC0.N_22878\,
datac => \GRFPC0.D.STLCK_0_0_4__G1_4\,
datab => N_128);
\GRFPC0_R_FSR_CEXC_RNO_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(0),
datae => N_456,
datad => N_61,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffff0000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
datad => \GRFPC0.R.FSR.TEM\(0),
datac => \GRFPC0.WR2.RREG.EXCT\(0));
\GRFPC0_R_FSR_CEXC_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffff0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(0),
datad => \GRFPC0.R.FSR.CEXC_0_0_0__G1_1\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(0),
datab => \GRFPC0.DIV.EXCT\(0));
\GRFPC0_R_FSR_CEXC_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datae => \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.R.FSR.CEXC\(0));
\GRFPC0_R_FSR_FTT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f000cc0000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datae => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.FTT\(1),
datab => N_61);
GRFPC0_WR_RREG_RESV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f00000f0f0")
port map (
combout => \GRFPC0.N_10179\,
dataf => \GRFPC0.FP_PIPELINE.UN1_CPI_12\,
datae => \GRFPC0.N_47\,
datad => N_63,
datac => N_61);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(3),
dataf => \GRFPU0.GRFPU_X0.ST1.OP1NX_0_0_G4\,
datae => \GRFPU0.GRFPU_X0.N_19767_6\,
datad => \GRFPU0.GRFPU_X0.N_19767_5\,
datac => \GRFPU0.GRFPU_X0.N_80\,
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_0_RNIQAMH2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_I_I_0_0__G0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_126_I\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.OP2\(55),
datac => \FPI.OP1\(55),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_RNIOUMHA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20280\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_I_I_0_0__G0_0_0\,
datae => \GRFPU0.GRFPU_X0.N_125_I\,
datad => \GRFPU0.GRFPU_X0.N_20313_I\,
datac => \FPI.OP2\(52),
datab => \FPI.OP1\(52));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_0_RNIQAMH2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_0_1__G0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_126_I\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.OP2\(55),
datac => \FPI.OP1\(55),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_RNIOUMHA_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_0_1__G0_0_0\,
datae => \GRFPU0.GRFPU_X0.N_125_I\,
datad => \GRFPU0.GRFPU_X0.N_20313_I\,
datac => \FPI.OP2\(52),
datab => \FPI.OP1\(52));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00c0")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(7),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_4\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_5\,
datad => \GRFPU0.GRFPU_X0.N_219\,
datac => \GRFPU0.GRFPU_X0.N_20295\,
datab => \GRFPU0.GRFPU_X0.N_80\);
\GRFPC0_D_STDLCK_RNO_4_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_0\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4199_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4));
\GRFPC0_D_STDLCK_RNO_3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_1\,
dataf => \GRFPC0.D.STDLCK_0_0_12__G1_0\,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
datac => N_201,
datab => N_200);
\GRFPC0_D_STDLCK_RNO_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_6\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_21291_1\,
datad => \GRFPC0.D.STDLCK_0_0_12__G1_4\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_0_A3_0_2\,
datab => \GRFPC0.N_20961_2\);
\GRFPC0_D_STDLCK_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffc0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_8\,
dataf => \GRFPC0.N_144\,
datae => \GRFPC0.N_22811\,
datad => \GRFPC0.D.STDLCK_0_0_12__G1_6\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4));
\GRFPC0_D_STDLCK_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fff0000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_12__G1_8\,
datae => \GRFPC0.N_155_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datac => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STDLCK_RNO_6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0fff0fff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_0\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.RFA.LD_0\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\);
\GRFPC0_D_STDLCK_RNO_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f33ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_2\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_0\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_5_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc0ff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_114_2\,
datae => \GRFPC0.N_17422\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\);
\GRFPC0_D_STDLCK_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_3_0\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_131\,
datae => \GRFPC0.D.STDLCK_0_0_4__G1_5_TZ\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5\,
datac => \GRFPC0.D.STDLCK_0_0_4__G1_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_114_2\);
\GRFPC0_D_STDLCK_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff2f0f0f0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_182\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_5\,
datad => \GRFPC0.N_21137_0\,
datac => \GRFPC0.D.STDLCK_0_0_4__G1_3_0\,
datab => \GRFPC0.STDDEP_0_SQMUXA_131\,
dataa => \GRFPC0.STDEP_2_SQMUXA_133_0\);
GRFPC0_FP_PIPELINE_V_STATE2_0_RNI55BV1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c000c")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
dataf => \GRFPC0.FIFO_INC_5_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datad => \GRFPC0.FP_PIPELINE.V.STATE2_0\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => N_52981_2);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_RNIKBCI7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c300cc00")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3\,
dataf => N_52020_1,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datad => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
datac => N_52826,
datab => \GRFPC0.FIFO.WR_0\(0));
\GRFPC0_UN1_PENDEXC_2_RNIIKTOA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffc0")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1\,
dataf => \GRFPC0.FIFO.WR_0_0_0__G3\,
datae => N_124905,
datad => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => N_52981_2);
GRFPC0_FIFO_INC_5_SQMUXA_RNIN5GL6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FIFO.RD_I_M\(0),
dataf => N_52020_1,
datae => \GRFPC0.FIFO_INC_5_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datac => \GRFPC0.FIFO.RD_1_0\(0),
datab => N_52981_2);
GRFPC0_UN1_VFIFO_RD10_RNIQQ3PE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FIFO.RD_0_0_0__G1\,
dataf => \GRFPC0.FIFO.RD_I_M\(0),
datae => \GRFPC0.FIFO.RD_0_0_0__G3\,
datad => \GRFPC0.UN1_VFIFO.RD10\,
datac => \GRFPC0.FIFO.RD_1_0\(0),
datab => N_52981_2);
GRFPC0_FIFO_FULL_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1_0\,
dataf => N_52020_1,
datae => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
datad => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => N_52981_2);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_1_IV_0\(2),
dataf => \GRFPC0.UN1_REN130\(0),
datae => \GRFPC0.REN1_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datab => \GRFPC0.FP_PIPELINE.RS1_6\(0));
\GRFPC0_FP_PIPELINE_REN1_1_IV_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffffcf")
port map (
combout => RFI2_REN1Z,
dataf => \GRFPC0.FP_PIPELINE.REN1_1_IV_0\(2),
datae => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datab => N_448);
\GRFPC0_D_LDLCK_RNO_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfcfcfcfcfcfc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_2\,
dataf => \GRFPC0.N_22750_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.D.LDLCK_0_0_7__G1_0\,
datab => \GRFPC0.N_22745\);
\GRFPC0_D_LDLCK_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\(1),
datae => \GRFPC0.D.LDLCK_0_0_7__G1_5\,
datad => \GRFPC0.N_22760\,
datac => \GRFPC0.N_89_1_0\,
datab => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1136_REGDEPX\);
\GRFPC0_D_STLCK_RNO_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_6\,
dataf => \GRFPC0.N_22486_1\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datad => \GRFPC0.D.STLCK_0_0_23__G1_4\,
datac => \GRFPC0.N_21981\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(11));
\GRFPC0_D_STLCK_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffcfff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1\,
dataf => \GRFPC0.N_21939\,
datae => \GRFPC0.FP_PIPELINE.11.STDEP_452\(1),
datad => \GRFPC0.D.STLCK_0_0_23__G1_6\,
datac => \GRFPC0.N_21981\,
datab => \GRFPC0.N_78_I_I_0\);
\GRFPC0_D_STDLCK_RNO_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffffcfcffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_2\,
dataf => \GRFPC0.N_21104\,
datae => \GRFPC0.N_21036\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_1_0\,
datac => \GRFPC0.STDDEP_0_SQMUXA_92\,
datab => \GRFPC0.N_23365\);
\GRFPC0_D_STDLCK_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_4\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.D.STDLCK_0_0_13__G1_2\,
datad => \GRFPC0.N_21076\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
datab => \GRFPC0.N_21104\);
\GRFPC0_D_STDLCK_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1\,
dataf => \GRFPC0.N_21090\,
datae => \GRFPC0.D.STDLCK_0_0_13__G1_4\,
datad => \GRFPC0.N_83\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c0c00000c0c0")
port map (
combout => \GRFPC0.N_21076\,
dataf => \GRFPC0.N_21104\,
datae => \GRFPC0.N_21036\,
datad => \GRFPC0.N_21052\,
datac => \GRFPC0.N_21716\,
datab => \GRFPC0.N_21076_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_21090\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.N_21054\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_2_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_3_1\,
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.N_21039\,
datab => \GRFPC0.N_21076_1\);
\GRFPC0_FPR_ALLOW_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FPRIN.ALLOW\(0),
dataf => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
datae => \GRFPC0.N_21137_1\,
datad => \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\,
datac => N_61);
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_276_0_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24605\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_21957_1\,
datad => \GRFPC0.N_23613_I_0\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_D_LDLCK_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_5\,
dataf => \GRFPC0.D.LDLCK_0_0_31__G1_3\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.N_91_1\,
datac => \GRFPC0.N_24606_1\,
datab => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX\);
\GRFPC0_EX_CTRL_PC_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53036,
dataf => N_51941,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51943,
datab => \GRFPC0.EX.CTRL.PC\(8));
\GRFPC0_EX_CTRL_PC_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53039,
dataf => N_52049,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(11),
datab => \GRFPC0.EX.CTRL.PC\(11));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21817\,
dataf => \GRFPC0.N_25877\,
datae => \GRFPC0.N_193\,
datad => \GRFPC0.N_21128\,
datac => \GRFPC0.N_22982\,
datab => \GRFPC0.N_21121\);
\GRFPC0_D_STLCK_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfff0ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1\,
dataf => \GRFPC0.N_21817\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_23009\,
datac => \GRFPC0.D.STLCK_0_0_0__G1_3\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(0));
\GRFPC0_D_STLCK_RNO_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.STDDEP_0_SQMUXA_1_I_1\,
datad => N_174895,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(15),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STLCK_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfffcfef")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1\,
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_616\(1),
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_129_I_1\,
datac => \GRFPC0.N_17173\,
datab => \GRFPC0.D.STLCK_0_0_31__G1_2\,
dataa => N_128);
GRFPC0_FP_PIPELINE_UN105_HOLDN_RNI684H6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00ccf0")
port map (
combout => N_52982,
dataf => \GRFPC0.FP_PIPELINE.UN105_HOLDN\,
datae => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1934_I_A5_0\,
datad => N_49622_0,
datac => \GRFPC0.V.STDATA_14\(31),
datab => \GRFPC0.RFA.RDD\);
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15_3_0_RNIS47U1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff30ffff")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1934_I_A5_0\,
dataf => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15_3_0\,
datae => \FPI.FLOP_0\(1),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(3),
datab => \FPI.FLOP\(2));
\GRFPC0_R_FSR_CEXC_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(2),
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(2),
datad => N_458,
datac => N_61,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datab => \GRFPC0.R.FSR.CEXC\(2));
GRFPC0_FP_PIPELINE_UN68_HOLDN_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
dataf => \GRFPC0.WR2.CTRL.DIV\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.WR2.CTRL.RDWR\,
datab => N_63);
GRFPC0_FP_PIPELINE_0_EXEN2_I_S_4_RNIMONR1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0003000")
port map (
combout => \GRFPC0.FPUSEL_6\(1),
dataf => \GRFPC0.N_21695_3\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datad => \GRFPC0.FPUSEL_6_0_1__G0_0\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIDKLP1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccfffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
GRFPU0_GRFPU_X0_UN1_VALLOW_2_SQMUXA_4_RNIBOSBE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffcf")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_S3_1\,
dataf => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
datae => N_174933,
datad => \GRFPU0.GRFPU_X0.N_5430\,
datac => \GRFPU0.GRFPU_X0.N_19434\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_82_2\);
\GRFPC0_FPRIN_ALLOW_0_0__G5\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0030")
port map (
combout => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
dataf => \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_S3_1\,
datae => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_1_1_S4\,
datad => N_174933,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0cff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.REN1_1_IV_0\(1),
dataf => \GRFPC0.UN1_REN130\(0),
datae => \GRFPC0.REN1_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datab => \GRFPC0.FP_PIPELINE.RS1_6\(0));
\GRFPC0_FP_PIPELINE_REN1_1_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffcfff")
port map (
combout => RFI1_REN1Z,
dataf => \GRFPC0.FP_PIPELINE.REN1_1_IV_0\(1),
datae => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datab => N_448);
GRFPC0_FP_PIPELINE_RSDEC_RS1V12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_6\,
datae => \GRFPC0.INST\(10),
datad => \GRFPC0.INST\(6),
datac => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(13));
GRFPC0_RFA_READ_RS1_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0ccc0ccc0cc00")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1_1\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12\,
datad => \GRFPC0.N_10173_2\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
datab => \GRFPC0.INST\(31));
GRFPC0_RFA_READ_RS1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc00000000")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1\,
dataf => \GRFPC0.RFA.READ_RS1_0_0_G1_1\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V6\,
datac => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\);
\GRFPC0_D_STLCK_RNO_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffc0c0")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_1\,
dataf => \GRFPC0.N_23243\,
datae => \GRFPC0.N_20852\,
datad => \GRFPC0.N_23178\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14),
datab => \GRFPC0.N_22942_1\);
\GRFPC0_D_STLCK_RNO_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_2\,
dataf => \GRFPC0.N_22354\,
datae => \GRFPC0.D.STLCK_0_0_28__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_D_STLCK_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1\,
dataf => \GRFPC0.N_23185\,
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_23172\,
datac => \GRFPC0.D.STLCK_0_0_28__G1_3\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(14));
GRFPC0_D_FLDLCK_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1_1\,
dataf => \GRFPC0.D.FLDLCK_0_0_G1_0\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.CCWR\,
datab => \GRFPC0.WR.CTRL.CCWR\);
\GRFPC0_R_FSR_CEXC_RNO_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(3),
datae => N_459,
datad => N_61,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.R.FSR.CEXC_0_0_3__G1_2\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(3),
datac => \GRFPC0.DIV.EXCT\(3));
\GRFPC0_R_FSR_CEXC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
dataf => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datae => \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.R.FSR.CEXC\(3));
\GRFPC0_RFA2_RS2SEL_RNIHK61_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP2_SN_N_9\,
dataf => \GRFPC0.RFA2.RS2SEL\(1),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.RFA2.RS2SEL\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ff00f0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54),
dataf => \GRFPU0.GRFPU_X0.N_427\,
datae => \GRFPU0.GRFPU_X0.N_429\,
datad => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(51));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0ff00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54),
dataf => \GRFPU0.GRFPU_X0.N_428\,
datae => \GRFPU0.GRFPU_X0.N_430\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(2));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f30000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_68_I_0_G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_80_0\,
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(4));
GRFPC0_D_FSTLCK_RNO_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_3\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.WR.CTRL.STDFQ\);
GRFPC0_D_FSTLCK_RNO_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_0\,
dataf => \GRFPC0.MEM.CTRL.STDFQ\,
datae => N_124,
datad => N_122,
datac => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datab => N_126);
GRFPC0_D_FSTLCK_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_11\,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => \GRFPC0.D.FSTLCK_0_0_G1_8\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_7\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.CCWR\);
GRFPC0_D_FSTLCK_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff0fff0c")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_12\,
dataf => \GRFPC0.N_21157\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_11\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_D_FSTLCK_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.STDFQ_1\,
datae => \GRFPC0.D.FSTLCK_0_0_G1_14\,
datad => \GRFPC0.N_21137_1\,
datac => \GRFPC0.N_22811\,
datab => \GRFPC0.N_20796\);
GRFPC0_RFA_STDFQ_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => N_50421,
dataf => N_52020,
datae => \GRFPC0.RFA.STDFQ_0_0_G1_0_2421_A2_1\,
datad => N_138,
datac => N_126,
datab => N_125);
\GRFPC0_R_FSR_CEXC_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(1),
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(1),
datad => N_457,
datac => N_61,
datab => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_4\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(1),
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(1),
datab => \GRFPC0.DIV.EXCT\(1));
\GRFPC0_R_FSR_CEXC_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_1__G1_4\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.R.FSR.CEXC\(1));
\GRFPC0_R_FSR_CEXC_RNO_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(4),
datae => N_460,
datad => N_61,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\);
\GRFPC0_R_FSR_CEXC_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.R.FSR.CEXC_0_0_4__G1_2\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(4),
datac => \GRFPC0.DIV.EXCT\(4));
\GRFPC0_R_FSR_CEXC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
dataf => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datae => \GRFPC0.R.FSR.CEXC_0_0_4__G1_4\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(4),
datab => \GRFPC0.R.FSR.CEXC\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000f00000")
port map (
combout => \GRFPC0.N_21841\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21783\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datab => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STDLCK_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_5\,
dataf => \GRFPC0.N_21832\,
datae => \GRFPC0.N_21793\,
datad => \GRFPC0.N_21789\,
datac => \GRFPC0.N_21841\,
datab => \GRFPC0.D.STDLCK_0_0_1__G1_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A2_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_A2_1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21039\,
datad => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_D_LDLCK_RNO_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1_1\,
dataf => \GRFPC0.D.LDLCK_0_0_18__G1_0\,
datae => N_128,
datad => \GRFPC0.N_22573_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datab => \GRFPC0.N_21996\);
\GRFPC0_D_STLCK_RNO_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f00030")
port map (
combout => \GRFPC0.N_23046\,
dataf => N_100346_TZ,
datae => \GRFPC0.N_22981\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.FIFO.INST_0_0\(19),
datab => \GRFPC0.N_78_I_I_1\);
\GRFPC0_D_STLCK_RNO_4_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_4_2\(1),
dataf => \GRFPC0.FIFO.INST_1_0\(6),
datae => \GRFPC0.FIFO.INST_1\(25),
datad => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_1\(8));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_20880\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_20833\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datab => \GRFPC0.N_131_0\);
\GRFPC0_D_LDLCK_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffcc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1_4\,
dataf => \GRFPC0.N_21917\,
datae => \GRFPC0.N_165_1\,
datad => \GRFPC0.N_21919\,
datac => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\,
datab => \GRFPC0.D.LDLCK_0_0_22__G1_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_21666\,
dataf => \GRFPC0.N_21716\,
datae => \GRFPC0.N_21620\,
datad => \GRFPC0.N_21622\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1\);
\GRFPC0_D_STDLCK_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1\,
dataf => \GRFPC0.N_21669\,
datae => \GRFPC0.N_21668\,
datad => \GRFPC0.N_21666\,
datac => \GRFPC0.N_21629\,
datab => \GRFPC0.D.STDLCK_0_0_9__G1_3\);
\GRFPC0_D_STLCK_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff00ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1\,
dataf => \GRFPC0.N_22075\,
datae => \GRFPC0.N_22486_1\,
datad => \GRFPC0.D.STLCK_0_0_19__G1_4\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datab => \GRFPC0.N_21996\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff0000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_2\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_1\,
datad => \GRFPC0.N_130\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c000000000")
port map (
combout => \GRFPC0.N_21525\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_1_2\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.N_21474\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_EX_CTRL_PC_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53038,
dataf => N_52013,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_52015,
datab => \GRFPC0.EX.CTRL.PC\(10));
GRFPC0_RFA_SEQERR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0c0000000000")
port map (
combout => N_50374,
dataf => N_50374_4,
datae => N_50375,
datad => N_50667_1,
datac => N_137,
datab => \GRFPC0.FP_PIPELINE.UN26_OP\);
GRFPC0_EX_CTRL_CCWR_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_4\,
dataf => N_50504_3,
datae => \GRFPC0.RFA.LD_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_EX_CTRL_CCWR_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000c0c")
port map (
combout => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_3\,
dataf => \GRFPC0.RFA.ST_0\,
datae => \GRFPC0.RFA2.FOP\(0),
datad => \GRFPC0.FPR.ALLOW\(1),
datac => \GRFPC0.RFA.WRITE_RD\,
datab => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\);
GRFPC0_EX_CTRL_CCWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000330003003300")
port map (
combout => N_50359,
dataf => \GRFPC0.FPEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_2331_A2_8\,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10_0\);
GRFPC0_RFA_RDD_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_2475_A2_1\,
dataf => N_50421_11,
datae => N_123,
datad => N_122,
datac => N_124,
datab => N_127);
GRFPC0_RFA_RDD_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => N_50456,
dataf => N_52020,
datae => \GRFPC0.RFA.RDD_0_0_G1_0_2475_A2_1\,
datad => N_138,
datac => N_126,
datab => N_125);
\GRFPC0_FPR_ALLOW_RNI6NQJ1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f0ffffffff")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_10__G1_0_4697_I_O4_1_1\,
dataf => N_50504_3,
datae => \GRFPC0.RFA2.FOP\(0),
datad => \GRFPC0.FPR.ALLOW\(1),
datac => N_64);
\GRFPC0_WR_CTRL_ID_RNIK4CHF_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_0__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_0__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(0),
datab => N_64);
\GRFPC0_MEM_CTRL_ID_RNIDK1JG_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(0),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_0__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.MEM.CTRL.ID\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.N_22598\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21336\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_2\);
\GRFPC0_FIFO_VCNT_0_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cc0000cccc0000")
port map (
combout => N_53061,
dataf => N_52880_2,
datae => N_52831,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => N_61);
\GRFPC0_FIFO_VCNT_1_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc0000cccc0000")
port map (
combout => N_53063,
dataf => N_52880_2,
datae => N_52879,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => N_61);
\GRFPC0_EX_CTRL_PC_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53044,
dataf => N_52229,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(16),
datab => \GRFPC0.EX.CTRL.PC\(16));
\GRFPC0_FIFO_VCNT_1_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c00000c00c")
port map (
combout => N_53062,
dataf => N_52804,
datae => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_5877_I_A4_0\,
datad => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datac => \GRFPC0.FIFO.VCNT_1\(0),
datab => N_61);
\GRFPC0_FIFO_VCNT_1_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_2_5877_I_A4_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
datae => \GRFPC0.FIFO.WR_0\(0),
datad => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datac => N_126,
datab => N_124);
\GRFPC0_FIFO_VCNT_0_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c00000c00c")
port map (
combout => N_53060,
dataf => N_52804,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_A4_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
datac => \GRFPC0.FIFO.VCNT_0\(0),
datab => N_61);
\GRFPC0_FIFO_VCNT_0_RNO_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_A4_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
datae => \GRFPC0.FIFO.WR_0\(0),
datad => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datac => N_126,
datab => N_124);
\GRFPC0_EX_CTRL_PC_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53059,
dataf => N_52769,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(31),
datab => \GRFPC0.EX.CTRL.PC\(31));
\GRFPC0_EX_CTRL_PC_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52708,
dataf => N_52020_1,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(29),
datab => \GRFPC0.FIFO.PC_0\(29));
\GRFPC0_EX_CTRL_PC_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52672,
dataf => N_52020_1,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(28),
datab => \GRFPC0.FIFO.PC_0\(28));
\GRFPC0_EX_CTRL_PC_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52636,
dataf => N_52020_1,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(27),
datab => \GRFPC0.FIFO.PC_0\(27));
\GRFPC0_EX_CTRL_PC_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfff0")
port map (
combout => N_53054,
dataf => N_52598,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
datab => \GRFPC0.EX.CTRL.PC\(26));
\GRFPC0_EX_CTRL_PC_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfff0")
port map (
combout => N_53053,
dataf => N_52562,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
datab => \GRFPC0.EX.CTRL.PC\(25));
\GRFPC0_EX_CTRL_PC_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53052,
dataf => N_52528,
datae => N_52517,
datad => N_52020_1,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(24));
\GRFPC0_EX_CTRL_PC_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52528,
dataf => N_52020_1,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(24),
datab => \GRFPC0.FIFO.PC_0\(24));
\GRFPC0_EX_CTRL_PC_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfff0")
port map (
combout => N_53051,
dataf => N_52490,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(23),
datab => \GRFPC0.EX.CTRL.PC\(23));
\GRFPC0_EX_CTRL_PC_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53050,
dataf => N_52445,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(22),
datab => \GRFPC0.EX.CTRL.PC\(22));
\GRFPC0_EX_CTRL_PC_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53049,
dataf => N_52409,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(21),
datab => \GRFPC0.EX.CTRL.PC\(21));
\GRFPC0_EX_CTRL_PC_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53048,
dataf => N_52373,
datae => N_52020_1,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(20),
datab => \GRFPC0.EX.CTRL.PC\(20));
\GRFPC0_EX_CTRL_PC_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53047,
dataf => N_52337,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(19),
datab => \GRFPC0.EX.CTRL.PC\(19));
\GRFPC0_EX_CTRL_PC_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53046,
dataf => N_52312,
datae => N_52301,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(18));
\GRFPC0_EX_CTRL_PC_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52312,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(18),
datab => \GRFPC0.FIFO.PC_0\(18));
\GRFPC0_EX_CTRL_PC_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53045,
dataf => N_52265,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(17),
datab => \GRFPC0.EX.CTRL.PC\(17));
\GRFPC0_EX_CTRL_PC_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53043,
dataf => N_52204,
datae => N_52193,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(15));
\GRFPC0_EX_CTRL_PC_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52204,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(15),
datab => \GRFPC0.FIFO.PC_0\(15));
\GRFPC0_EX_CTRL_PC_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53042,
dataf => N_52168,
datae => N_52157,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(14));
\GRFPC0_EX_CTRL_PC_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52168,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(14),
datab => \GRFPC0.FIFO.PC_0\(14));
\GRFPC0_EX_CTRL_PC_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53041,
dataf => N_52132,
datae => N_52121,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(13));
\GRFPC0_EX_CTRL_PC_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52132,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(13),
datab => \GRFPC0.FIFO.PC_0\(13));
\GRFPC0_EX_CTRL_PC_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53040,
dataf => N_52096,
datae => N_52085,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(12));
\GRFPC0_EX_CTRL_PC_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_52096,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(12),
datab => \GRFPC0.FIFO.PC_0\(12));
\GRFPC0_EX_CTRL_PC_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53037,
dataf => N_51988,
datae => N_51977,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(9));
\GRFPC0_EX_CTRL_PC_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_51988,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(9),
datab => \GRFPC0.FIFO.PC_0\(9));
\GRFPC0_EX_CTRL_PC_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53035,
dataf => N_51916,
datae => N_51905,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(7));
\GRFPC0_EX_CTRL_PC_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_51916,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(7),
datab => \GRFPC0.FIFO.PC_0\(7));
\GRFPC0_EX_CTRL_PC_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53034,
dataf => N_51869,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51871,
datab => \GRFPC0.EX.CTRL.PC\(6));
\GRFPC0_EX_CTRL_PC_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c0fccff")
port map (
combout => N_53033,
dataf => N_51844,
datae => N_51833,
datad => CPO_EXCZ,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(5));
\GRFPC0_EX_CTRL_PC_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => N_51844,
dataf => CPO_EXCZ,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.PC_1\(5),
datab => \GRFPC0.FIFO.PC_0\(5));
\GRFPC0_EX_CTRL_PC_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00f0ccccfff0")
port map (
combout => N_53032,
dataf => N_51797,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datac => N_51799,
datab => \GRFPC0.EX.CTRL.PC\(4));
\GRFPC0_EX_CTRL_PC_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c000fcccc00ff")
port map (
combout => N_53030,
dataf => N_51725,
datae => CPO_EXCZ,
datad => \GRFPC0.EX.CTRL.PC_0_0_2__G1_0_4289_I_A4_1_0\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datab => \GRFPC0.EX.CTRL.PC\(2));
\GRFPC0_EX_CTRL_PC_RNO_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_2__G1_0_4289_I_A4_1_0\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.PC_1\(2),
datac => \GRFPC0.FIFO.PC_0\(2));
\GRFPC0_D_STLCK_RNO_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_0\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.N_22077\,
datad => \GRFPC0.N_22942_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datab => \GRFPC0.N_21996\);
\GRFPC0_D_STLCK_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000f3ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_18__G1_2\,
datae => \GRFPC0.N_31\,
datad => \GRFPC0.N_22697\,
datac => \GRFPC0.N_22698\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
\GRFPC0_D_STLCK_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1\,
dataf => \GRFPC0.N_22083\,
datae => \GRFPC0.N_22113\,
datad => \GRFPC0.D.STLCK_0_0_18__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datab => \GRFPC0.N_21663\);
\GRFPC0_D_LDLCK_RNO_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_1\,
dataf => \GRFPC0.N_23414\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
datad => \GRFPC0.N_88_1_0\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A4_0\(25),
datab => \GRFPC0.N_22737_2\);
\GRFPC0_D_LDLCK_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcccccfffcffcc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
dataf => \GRFPC0.N_24364\,
datae => \GRFPC0.N_23462_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.N_23417_2\,
datab => \GRFPC0.D.LDLCK_0_0_25__G1_1\);
\GRFPC0_D_LDLCK_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_24__G1\,
dataf => \GRFPC0.N_25259\,
datae => \GRFPC0.N_24272\,
datad => \GRFPC0.N_24289\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
datab => \GRFPC0.N_169_1\);
\GRFPC0_D_LDLCK_RNO_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1_2\,
dataf => \GRFPC0.N_163\,
datae => \GRFPC0.N_22039\,
datad => \GRFPC0.N_167\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
datab => \GRFPC0.N_169_1\);
\GRFPC0_D_LDLCK_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfcfffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1_3\,
dataf => \GRFPC0.N_22074\,
datae => \GRFPC0.N_22082\,
datad => \GRFPC0.N_22146\,
datac => \GRFPC0.D.LDLCK_0_0_19__G3\,
datab => \GRFPC0.D.LDLCK_0_0_19__G1_0\);
\GRFPC0_D_LDLCK_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(1),
datae => \GRFPC0.D.LDLCK_0_0_19__G1_3\,
datad => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167\(1),
datac => \GRFPC0.D.LDLCK_0_0_19__G1_4\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
\GRFPC0_D_LDLCK_RNO_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_3\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.N_89_1\,
datad => \GRFPC0.N_22305\,
datac => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2384_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2399_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
datae => \GRFPC0.D.LDLCK_0_0_15__G1_2\,
datad => \GRFPC0.N_22372\,
datac => \GRFPC0.D.LDLCK_0_0_15__G1_3\);
\GRFPC0_D_LDLCK_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffc0c0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_14__G1_2\,
datae => \GRFPC0.N_21612\,
datad => \GRFPC0.N_22354\,
datac => \GRFPC0.D.LDLCK_0_0_14__G1_3_TZ\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\);
\GRFPC0_D_LDLCK_RNO_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX\,
datae => \GRFPC0.N_167_1\,
datad => \GRFPC0.N_22461\,
datac => \GRFPC0.N_22473_1\,
datab => \GRFPC0.N_22466_2\);
\GRFPC0_D_LDLCK_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffccccccc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1_3\,
dataf => \GRFPC0.N_22463\,
datae => \GRFPC0.N_89_1\,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
datac => \GRFPC0.N_22440\,
datab => \GRFPC0.D.LDLCK_0_0_12__G1_1\);
\GRFPC0_D_LDLCK_RNO_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccccccffccfccc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_3\,
dataf => \GRFPC0.N_22558\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_1\(11),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.D.LDLCK_0_0_11__G1_1\);
\GRFPC0_D_LDLCK_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_5\,
dataf => \GRFPC0.D.LDLCK_0_0_11__G1_3\,
datae => \GRFPC0.N_91_1\,
datad => \GRFPC0.N_22619_1\,
datac => \GRFPC0.N_23417_2\,
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
datae => \GRFPC0.D.LDLCK_0_0_11__G1_5\,
datad => \GRFPC0.N_22607\,
datac => \GRFPC0.N_21386\);
\GRFPC0_D_LDLCK_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_10\(0),
datae => \GRFPC0.D.LDLCK_0_0_10__G3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_9\(0));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0_0_O2_RNIOKVJ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\,
datae => \GRFPU0.GRFPU_X0.N_343_3\,
datad => \GRFPU0.GRFPU_X0.N_20316\,
datac => \FPI.OP2\(54),
datab => \GRFPU0.GRFPU_X0.N_80\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_388\,
datae => \GRFPU0.GRFPU_X0.N_307\,
datad => \FPI.OP1\(54),
datac => \GRFPU0.GRFPU_X0.N_80\,
datab => \FPI.FLOP\(1));
\GRFPC0_RFA2_FID_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_5__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_5__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(5),
datab => N_64);
\GRFPC0_RFA2_FID_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(5),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_5__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.MEM.CTRL.ID\(5));
\GRFPC0_RFA2_FID_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_4__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_4__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(4),
datab => N_64);
\GRFPC0_RFA2_FID_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(4),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_4__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.MEM.CTRL.ID\(4));
\GRFPC0_RFA2_FID_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_3__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_3__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(3),
datab => N_64);
\GRFPC0_RFA2_FID_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(3),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_3__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(3),
datab => \GRFPC0.MEM.CTRL.ID\(3));
\GRFPC0_WR_CTRL_ID_RNIQKCHF_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.FID_1_IV_0_2__G0_1\,
dataf => N_52020_1,
datae => \GRFPC0.FID_1_IV_0_2__G0_0\,
datad => \GRFPC0.N_16912_I_0_I1_I_3\,
datac => \GRFPC0.WR.CTRL.ID\(2),
datab => N_64);
\GRFPC0_MEM_CTRL_ID_RNINC2JG_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(2),
dataf => \GRFPC0.FID_2_SQMUXA\,
datae => \GRFPC0.FID_1_SQMUXA\,
datad => \GRFPC0.FID_1_IV_0_2__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(2),
datab => \GRFPC0.MEM.CTRL.ID\(2));
GRFPC0_MEM_RREG_RESV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c00000ccc")
port map (
combout => \GRFPC0.N_10181\,
dataf => \GRFPC0.FP_PIPELINE.UN1_PENDEXC_2\,
datae => \GRFPC0.N_70\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_7\,
datac => N_63,
datab => N_61);
GRFPC0_FP_PIPELINE_UN1_HOLDN_0_RNIONQO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f030f0")
port map (
combout => \GRFPC0.WR2.RREG.RESV_0_0_G0_0\,
dataf => \GRFPC0.N_61\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\,
datad => \GRFPC0.N_131\,
datac => N_61,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_21523\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21467\,
datad => \GRFPC0.N_21459\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000fc0000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_8197\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(5));
GRFPC0_FID_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FID_2_SQMUXA\,
dataf => N_52020_1,
datae => \GRFPC0.N_16912_I_0_I1_I_3\,
datad => \GRFPC0.FP_PIPELINE.UN5_SHARE\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datab => N_64);
GRFPC0_FP_PIPELINE_RSDEC_RS1V6_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V6_0\,
dataf => \GRFPC0.INST\(10),
datae => \GRFPC0.INST\(6),
datad => \GRFPC0.INST\(13));
GRFPC0_FP_PIPELINE_RSDEC_RS1V6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V6\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V6_0\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(12),
datab => \GRFPC0.INST\(9));
GRFPC0_V_FSR_CEXC_6_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
dataf => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_2\,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_RFA2_RS1SEL_RNI0M11_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP1_SN_N_9\,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_21832\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_A2_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff333")
port map (
combout => \GRFPC0.N_21860\,
dataf => \GRFPC0.N_21793\,
datae => \GRFPC0.N_21789\,
datad => \GRFPC0.N_21803\,
datac => \GRFPC0.N_21783\,
datab => \GRFPC0.N_21791\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_24285\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
datae => N_107,
datad => \GRFPC0.N_24280\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => N_106);
GRFPU0_GRFPU_X0_UN8_C_CARRY_2_RNIOAMA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0_0__G0_0_A4_0_1_2\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(6),
datae => \GRFPU0.GRFPU_X0.UN8_C\(3),
datad => \GRFPU0.GRFPU_X0.UN8_C\(2));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_8_RNI5F5I7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => N_50471,
dataf => N_52020,
datae => N_50421_9,
datad => \GRFPC0.RFA.LD_0_0_G1_0_2497_A2_1\,
datac => N_137,
datab => N_124);
GRFPC0_EX_CTRL_RDWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0c0cc00")
port map (
combout => N_52983,
dataf => N_52020_1,
datae => N_49622_0,
datad => \GRFPC0.RFA.WRITE_RD\,
datac => \GRFPC0.RFA.RDWR\,
datab => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\);
GRFPC0_WR2_CTRL_CCWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => N_52986,
dataf => N_50149,
datae => N_52984_2,
datad => \GRFPC0.WR.CTRL.CCWR\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_WR2_CTRL_DIV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => N_52985,
dataf => N_50149,
datae => N_52984_2,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_WR2_CTRL_RDWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => N_52984,
dataf => N_50149,
datae => N_52984_2,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_RFA2_RS2SEL_RET_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.N_10170\,
dataf => \GRFPC0.UN1_WRENX10_1\,
datae => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datac => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
datab => \GRFPC0.RFA2.RS2SEL_0_0_6__G0_0\);
GRFPC0_DIV_EXC_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c00000c0c0000")
port map (
combout => N_29701,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datac => \GRFPC0.WR2.CTRL.SEQERR_0\,
datab => N_52981_2);
GRFPC0_RFA_AFSR_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_4\,
dataf => N_122,
datae => N_134,
datad => N_127,
datac => N_125,
datab => N_123);
GRFPC0_RFA_AFSR_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_3\,
dataf => N_64,
datae => N_137,
datad => N_126,
datac => N_133);
GRFPC0_RFA_AFSR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => N_50487,
dataf => N_52020,
datae => CPO_LDLOCKZ,
datad => N_138,
datac => \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_4\,
datab => \GRFPC0.RFA.AFSR_0_0_G1_0_2520_A2_3\);
GRFPC0_MEM_CTRL_RDWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f000000000000")
port map (
combout => N_52993,
dataf => N_52992_1,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.VCNT\(1),
datac => \GRFPC0.EX.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_MEM_CTRL_SEQERR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030f000000000")
port map (
combout => N_52992,
dataf => N_52992_1,
datae => \GRFPC0.EX.CTRL.VCNT\(1),
datad => \GRFPC0.EX.CTRL.VCNT\(0),
datac => \GRFPC0.EX.CTRL.SEQERR\,
datab => N_64);
GRFPC0_MEM_CTRL_DIV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f000000000000")
port map (
combout => N_52994,
dataf => N_52992_1,
datae => \GRFPC0.EX.CTRL.DIV\,
datad => \GRFPC0.EX.CTRL.VCNT\(1),
datac => \GRFPC0.EX.CTRL.VCNT\(0),
datab => N_64);
GRFPC0_MEM_CTRL_AFSR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030f000000000")
port map (
combout => N_52996,
dataf => N_52992_1,
datae => \GRFPC0.EX.CTRL.VCNT\(1),
datad => \GRFPC0.EX.CTRL.VCNT\(0),
datac => \GRFPC0.EX.CTRL.AFSR\,
datab => N_64);
GRFPC0_MEM_CTRL_CCWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030f000000000")
port map (
combout => N_52995,
dataf => N_52992_1,
datae => \GRFPC0.EX.CTRL.VCNT\(1),
datad => \GRFPC0.EX.CTRL.VCNT\(0),
datac => \GRFPC0.EX.CTRL.CCWR\,
datab => N_64);
GRFPC0_WR_CTRL_RDWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_52988,
dataf => N_50233,
datae => N_52987_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => N_64);
GRFPC0_WR_CTRL_CCWR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_52990,
dataf => N_50233,
datae => N_52987_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.CCWR\,
datab => N_64);
GRFPC0_WR_CTRL_AFSR_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_52991,
dataf => N_50233,
datae => N_52987_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datac => \GRFPC0.MEM.CTRL.AFSR\,
datab => N_64);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20285_I\,
dataf => \GRFPU0.GRFPU_X0.N_231\,
datae => \GRFPU0.GRFPU_X0.N_221\,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \GRFPU0.GRFPU_X0.N_194\,
datab => \FPI.FLOP_1_0\(1));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_2_M4_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c333c03003030000")
port map (
combout => N_125011,
dataf => \GRFPU0.GRFPU_X0.N_6863\,
datae => \GRFPU0.GRFPU_X0.UN1_INCSP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_EXP38_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f000ff0000")
port map (
combout => N_174581,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_10_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10_2\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(10),
datad => \GRFPC0.INST\(6),
datac => \GRFPC0.INST\(8),
datab => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_10_2\,
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(7),
datab => \GRFPC0.INST\(13));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_4_0\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12));
GRFPC0_FP_PIPELINE_RSDEC_RS1V8_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8_5\,
dataf => \GRFPC0.INST\(10),
datae => \GRFPC0.INST\(6),
datad => \GRFPC0.INST\(8),
datac => \GRFPC0.INST\(9));
\GRFPC0_RFA2_FOP_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_1__G4_0\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_4_0\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V8_5\,
datac => \GRFPC0.INST\(7),
datab => \GRFPC0.INST\(13));
\GRFPC0_RFA2_FOP_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f030303000")
port map (
combout => \GRFPC0.N_10173\,
dataf => \GRFPC0.RFA2.FOP_0_0_1__G4_0\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_8_7\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_11_7\,
datac => \GRFPC0.RFA2.FOP_0_0_1__G0_0\,
datab => \GRFPC0.INST\(13));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ff0ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_80_0\,
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(55),
datac => \FPI.FLOP_1\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c003f00c000f300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(7),
dataf => N_36264,
datae => N_36217,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.OP1\(59),
datab => \FPI.FLOP_1\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c003f00c000f300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(8),
dataf => N_36269,
datae => N_36217,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.OP1\(60),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11227\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_1\,
datae => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11228\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_1\,
datae => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1));
\GRFPC0_EX_CTRL_INST_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0cc0000")
port map (
combout => N_53028,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => N_50653_I,
datac => \GRFPC0.EX.CTRL.INST\(30),
datab => N_202);
\GRFPC0_EX_CTRL_INST_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0cc0000")
port map (
combout => N_53020,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => N_50653_I,
datac => \GRFPC0.EX.CTRL.INST\(22),
datab => N_194);
\GRFPC0_EX_CTRL_INST_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0cc0000")
port map (
combout => N_53018,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
datad => N_50653_I,
datac => \GRFPC0.EX.CTRL.INST\(20),
datab => N_192);
\GRFPC0_EX_CTRL_VCNT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0cc0f330000")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
dataf => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
datad => \GRFPC0.FIFO.RD_1_0\(0),
datac => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_0\(0));
GRFPC0_FP_PIPELINE_1_DIVEN10_RNIIUQF1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c000cf")
port map (
combout => \GRFPC0.N_10169\,
dataf => \GRFPC0.UN1_WRENX10_1\,
datae => \GRFPC0.FP_PIPELINE.1.DIVEN10\,
datad => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datab => \GRFPC0.WR2SEL_1\(7));
GRFPU0_GRFPU_X0_UN1_VST4_SEL2_1_RNIRGS01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_11243\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1\,
datad => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
datac => \GRFPU0.GRFPU_X0.N_7767\);
GRFPU0_GRFPU_X0_UN1_VST4_SEL2_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003fffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_7795\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_5_0\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_0\,
datab => \GRFPU0.GRFPU_X0.N_8171_4\);
GRFPU0_GRFPU_X0_UN1_VST4_SEL2_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1_2\,
dataf => \GRFPU0.GRFPU_X0.N_7781_6\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_2\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL6_0_RNITP7E5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_11244\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.UN1_VST4.SEL2_1\,
datad => \GRFPU0.GRFPU_X0.N_7797\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL6_0\,
datab => \GRFPU0.GRFPU_X0.N_7781\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_2\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_2_RNI4KO52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7795\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_2\,
datae => \GRFPU0.GRFPU_X0.N_7942\,
datad => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datac => \GRFPU0.GRFPU_X0.N_7795_1\,
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_VST4_SEL6_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.SEL6_0\,
dataf => \GRFPU0.GRFPU_X0.N_7795\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_5_0\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_0\,
datab => \GRFPU0.GRFPU_X0.N_8171_4\);
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffcccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
datad => \GRFPU0.GRFPU_X0.N_7753\,
datac => \GRFPU0.GRFPU_X0.N_7767\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL6_0_RNI3D5C5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_11242\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_7797\,
datad => \GRFPU0.GRFPU_X0.N_7753\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.SEL6_0\,
datab => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\);
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11249\,
dataf => \GRFPU0.GRFPU_X0.N_4045\,
datae => \GRFPU0.GRFPU_X0.N_7680\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(3));
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_0_RNIP8QA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(56),
datae => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_55_RNIT4GJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
dataf => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(1),
datae => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNI3PCM: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11253\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY\);
\GRFPC0_R_STDATA_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0f000f0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datab => \GRFPC0.DIV.INST\(0));
\GRFPC0_R_STDATA_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0f000f0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.V.STDATA_0_SQMUXA_1\,
datab => \GRFPC0.DIV.INST\(1));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18104\,
datab => \GRFPU0.GRFPU_X0.N_18039\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffff0cff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.N_20957\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(1));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18106\,
datab => \GRFPU0.GRFPU_X0.N_18041\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffff0cff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.N_20985\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(3));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18108\,
datab => \GRFPU0.GRFPU_X0.N_18043\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18109\,
datab => \GRFPU0.GRFPU_X0.N_18044\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffff0cff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.N_246\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(6));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18111\,
datab => \GRFPU0.GRFPU_X0.N_18046\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18112\,
datab => \GRFPU0.GRFPU_X0.N_18047\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18113\,
datab => \GRFPU0.GRFPU_X0.N_18048\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18114\,
datab => \GRFPU0.GRFPU_X0.N_18049\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18115\,
datab => \GRFPU0.GRFPU_X0.N_18050\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18116\,
datab => \GRFPU0.GRFPU_X0.N_18051\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18117\,
datab => \GRFPU0.GRFPU_X0.N_18052\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18118\,
datab => \GRFPU0.GRFPU_X0.N_18053\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18119\,
datab => \GRFPU0.GRFPU_X0.N_18054\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18120\,
datab => \GRFPU0.GRFPU_X0.N_18055\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18121\,
datab => \GRFPU0.GRFPU_X0.N_18056\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18122\,
datab => \GRFPU0.GRFPU_X0.N_18057\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18123\,
datab => \GRFPU0.GRFPU_X0.N_18058\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18124\,
datab => \GRFPU0.GRFPU_X0.N_18059\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18125\,
datab => \GRFPU0.GRFPU_X0.N_18060\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18126\,
datab => \GRFPU0.GRFPU_X0.N_18061\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18127\,
datab => \GRFPU0.GRFPU_X0.N_18062\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18128\,
datab => \GRFPU0.GRFPU_X0.N_18063\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18129\,
datab => \GRFPU0.GRFPU_X0.N_18064\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18130\,
datab => \GRFPU0.GRFPU_X0.N_18065\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18131\,
datab => \GRFPU0.GRFPU_X0.N_18066\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18132\,
datab => \GRFPU0.GRFPU_X0.N_18067\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fffcfc3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0),
datad => \GRFPU0.GRFPU_X0.N_7654\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fffcfc3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1),
datad => \GRFPU0.GRFPU_X0.N_7654\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(30),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fffcfc3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19840\,
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2),
datad => \GRFPU0.GRFPU_X0.N_7654\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0330cffccffc0330")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(1),
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(56),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03cf30fccf03fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(2),
dataf => \GRFPU0.GRFPU_X0.N_19778_1\,
datae => \GRFPU0.GRFPU_X0.N_388_3\,
datad => \FPI.OP1\(54),
datac => \FPI.OP1\(57),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03cf30fccf03fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(3),
dataf => N_36244,
datae => \GRFPU0.GRFPU_X0.N_388_3_0\,
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(58),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03cf30fccf03fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(4),
dataf => N_36249,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(59),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03cf30fccf03fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(6),
dataf => N_36259,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(61),
datab => \FPI.FLOP_1_0\(1));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123465,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(27));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123463,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(26));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123462,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(25));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123459,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(24));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123458,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(23));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123455,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(22));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123454,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(21));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123451,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(20));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123450,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(19));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123447,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(18));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123446,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(17));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123443,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(16));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123442,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(15));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123439,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(14));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_123438,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(12));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123435,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(12));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123434,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(11));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123431,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(10));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123430,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(9));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123427,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(8));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123426,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(7));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123423,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(6));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_123422,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(4));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_123418,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(4));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_123417,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_123366,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(27));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000f000f000f0")
port map (
combout => N_123283,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_25\,
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(29));
GRFPU0_GRFPU_X0_EXPDEC_DP_0_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ff00")
port map (
combout => N_174627,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => N_31284,
datad => \GRFPU0.GRFPU_X0.N_9851\);
GRFPU0_GRFPU_X0_EXPDEC_SP_0_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_174628,
dataf => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(23),
datae => \GRFPU0.GRFPU_X0.N_9852\);
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000ff0fff00")
port map (
combout => N_123022,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000ff0fff00")
port map (
combout => N_123012,
dataf => \GRFPU0.DIVROM0.RADDR\(2),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000ff0fff00")
port map (
combout => N_123002,
dataf => \GRFPU0.DIVROM0.RADDR\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00ff0000")
port map (
combout => N_122993,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00ff0000")
port map (
combout => N_122965,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00ff0000")
port map (
combout => N_122946,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00ff0000")
port map (
combout => N_122945,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_S_0_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00ff0000")
port map (
combout => N_122935,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_RNIFOTO2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4066_0\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
GRFPC0_V_FSR_CEXC_0_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.PENDEXC_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\);
\GRFPC0_D_LDLCK_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff00f00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX_53\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX_48\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
GRFPC0_EX_CTRL_AFSR_0_0_G1_0_2388_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.WR.CTRL.LD_0_0_G1_0_2134_A2_0\,
dataf => N_64,
datae => N_61);
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000ff00ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\);
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4961\,
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0_RNIM6AB1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333330000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_19557\,
datae => \GRFPU0.GRFPU_X0.N_19554_5\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_2\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\);
\GRFPU0_GRFPU_X0_REST_2_2_RNIISI82_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00cc00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_1\,
dataf => \GRFPU0.GRFPU_X0.N_4352_0\,
datae => \GRFPU0.GRFPU_X0.N_4227_0\,
datad => \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.REST_1_2_0\(6),
datab => \GRFPU0.GRFPU_X0.N_18411\);
GRFPU0_GRFPU_X0_ST2_INF_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1_1\,
datae => \GRFPU0.GRFPU_X0.N_4997\,
datad => \GRFPU0.GRFPU_X0.REST_1_1_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_4355\,
datab => \GRFPU0.GRFPU_X0.N_18396\);
GRFPC0_MEM_CTRL_RDD_0_RNIUE4H: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_100260,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STDLCK_RNO_10_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5_0_2\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
datad => N_100260,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\);
\GRFPC0_D_STDLCK_RNO_4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_114_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_8_5_0_2\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_9_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_8_4_2\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\);
\GRFPC0_D_STDLCK_RNO_11_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_8_6_2\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_8_4\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.RFA.LD_0\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0cc0fcc00cc")
port map (
combout => N_108267,
dataf => N_108257,
datae => N_108261,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.N_20764\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0cc0fcc00cc")
port map (
combout => N_108266,
dataf => N_108258,
datae => N_108260,
datad => \GRFPU0.GRFPU_X0.N_20766\,
datac => \GRFPU0.GRFPU_X0.N_20764\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_D_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => N_108261,
dataf => \GRFPU0.GRFPU_X0.N_242\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_D_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => N_108260,
dataf => \GRFPU0.GRFPU_X0.N_242\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc00f0fff000")
port map (
combout => N_108258,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => N_108254,
datad => \GRFPU0.GRFPU_X0.N_19243_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc00f0fff000")
port map (
combout => N_108257,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => N_108255,
datad => \GRFPU0.GRFPU_X0.N_19243_2\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0ff00")
port map (
combout => N_108255,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datae => \GRFPU0.GRFPU_X0.N_21039\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datac => \FPI.OP1_RETO\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0ff00")
port map (
combout => N_108254,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datae => \GRFPU0.GRFPU_X0.N_21039\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datac => \FPI.OP1_RETO\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_1_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff3fff00003fff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O2_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN317_REGDEPX_1\);
\GRFPC0_FIFO_INST_1_RNICB3R1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_1_0_TZ\(1),
dataf => \GRFPC0.N_22858\,
datae => \GRFPC0.FIFO.INST_1\(25));
GRFPU0_GRFPU_X0_COMB_ANDV_TMP_7_0_A3_2_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6243_7\,
dataf => \GRFPU0.GRFPU_X0.C\(6),
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_1_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_6243_7\,
datae => \GRFPU0.GRFPU_X0.C\(4),
datad => \GRFPU0.GRFPU_X0.C\(3),
datac => \GRFPU0.GRFPU_X0.C\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_0_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A2_1_2_0\(0),
datae => \GRFPU0.GRFPU_X0.N_51\,
datad => \GRFPU0.GRFPU_X0.C\(10),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RNO_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000ffffffffff")
port map (
combout => N_100296_TZ,
dataf => \FPI.FLOP_1\(1),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000033330000")
port map (
combout => N_100078,
dataf => \GRFPU0.GRFPU_X0.N_19554_5\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.N_47\,
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f00f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_18_TZ_TZ\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPU0_GRFPU_X0_RNDOP_29_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0000f00000ff")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPC0_FP_PIPELINE_0_STDEP_402_0_IV_I_O2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffcfff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_402_0_IV_I_O2_0_0\(0),
dataf => \GRFPC0.N_22858\,
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1_0\(29),
datab => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_FP_PIPELINE_REN2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000f00000")
port map (
combout => RFI2_REN2Z,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datac => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\);
\GRFPC0_FP_PIPELINE_REN2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f0000000f0")
port map (
combout => RFI1_REN2Z,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datac => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\);
GRFPC0_FP_PIPELINE_DEBUG_UNIT: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
dataf => N_448,
datae => N_449);
GRFPC0_FP_PIPELINE_UN1_HOLDN_0_RNIPRFD1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\,
datac => \GRFPC0.N_131_0\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\);
GRFPC0_FP_PIPELINE_VWR2_RREG_RES13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\,
dataf => N_411,
datae => N_412);
GRFPC0_FP_PIPELINE_0_UN1_FPO_4_2_RNID6NC2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
dataf => \GRFPC0.N_70\,
datae => \GRFPU0.GRFPU_X0.N_19283_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_4\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\);
GRFPC0_FP_PIPELINE_UN1_CPI_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_7\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.EX.CTRL.VCNT\(1),
datad => \GRFPC0.EX.CTRL.VCNT\(0),
datac => N_64);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000c0000000")
port map (
combout => \GRFPC0.N_22372\,
dataf => \GRFPC0.FP_PIPELINE.7.0.REGDEPX_130\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.N_24438\,
datab => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX_1\);
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_41_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0000030f00000")
port map (
combout => \GRFPC0.N_24413\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
datac => \GRFPC0.N_24437\,
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_A3_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23029\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22619_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17));
GRFPC0_FP_PIPELINE_0_UN1_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataf => N_138,
datae => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP\,
datad => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datac => N_126,
datab => N_124);
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_11_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_11_7\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_7_7_3\,
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(10),
datac => \GRFPC0.INST\(8),
datab => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_8_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_8_7\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9_6\,
datae => \GRFPC0.INST\(10),
datad => \GRFPC0.INST\(6),
datac => \GRFPC0.INST\(8),
datab => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_UN1_INST_8_7_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.UN1_INST_9_6\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(9));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_22473_1\,
dataf => N_174900,
datae => N_121,
datad => N_118,
datac => N_120,
datab => N_119);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I_RNINMNI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => N_174895,
dataf => N_128,
datae => \GRFPC0.N_22782\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I_RNINMNI_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_22649\,
dataf => N_128,
datae => \GRFPC0.N_22782\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_11_I_O2_0_1_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
dataf => \GRFPC0.WR.CTRL.RD\(0),
datae => \GRFPC0.N_131_0\);
GRFPC0_EX_CTRL_AFSR_RNIU9P7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.STDATA_SN_N_3\,
dataf => \GRFPC0.EX.CTRL.AFSR\,
datae => \GRFPC0.EX.CTRL.STDFQ\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_3_RNIVJC52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.N_80_0\,
datae => \FPI.FLOP_1_0\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(5));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_3_0_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_307\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(51),
datad => \FPI.OP1\(53));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f0f0f0f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20316\,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53),
datad => \FPI.OP2\(51),
datac => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16178\,
dataf => \GRFPU0.GRFPU_X0.N_343_3\,
datae => \GRFPU0.GRFPU_X0.N_80\,
datad => \FPI.OP2\(57),
datac => \FPI.OP2\(58),
datab => \FPI.OP2\(59));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16180\,
dataf => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datae => \GRFPU0.GRFPU_X0.N_80\,
datad => \FPI.OP2\(61),
datac => \FPI.OP2\(60));
GRFPU0_GRFPU_X0_UN38_EXP_1_CO4_RNIPLQJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c333000033330000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16184\,
dataf => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datae => \GRFPU0.GRFPU_X0.N_80\,
datad => \FPI.OP2\(61),
datac => \FPI.OP2\(60),
datab => \FPI.OP2\(62));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_22922\,
dataf => \GRFPC0.N_91_1\,
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(3),
datac => \GRFPC0.FIFO.INST_1\(4),
datab => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2087_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_UN3023_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3023_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN3127_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
dataf => N_104,
datae => N_107,
datad => N_106,
datac => N_105);
GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_UN2399_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.1.CHECK_DEP.UN2399_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_3_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22253\,
dataf => \GRFPC0.N_22749_1\,
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2072_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_1_IV_I_A2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccc0ffffcfc3")
port map (
combout => \GRFPU0.GRFPU_X0.N_231\,
dataf => \GRFPU0.GRFPU_X0.N_20304\,
datae => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datad => \GRFPU0.GRFPU_X0.N_20294\,
datac => \FPI.OP2\(54),
datab => \FPI.FLOP_1_0\(1));
GRFPC0_RFA2_FLUSH_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPC0.N_16912_I\,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_16912_I_0_I1_I_3\,
datad => \GRFPC0.FP_PIPELINE.UN5_SHARE\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datab => N_64);
GRFPC0_RFA2_RS2DEP_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cf000000ff00")
port map (
combout => \GRFPC0.RFA2.RS2DEP_0_0_G1_2\,
dataf => \GRFPC0.REGDEP_2_SQMUXA_6\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0\,
datad => \GRFPC0.RFA2.RS2DEP_0_0_G1_0\,
datac => \GRFPC0.UN1_REGDEP119\,
datab => N_100355_TZ);
GRFPC0_FP_PIPELINE_1_REGDEP118_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118_1\,
dataf => RFI2_RD2ADDRZ(3),
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.WR2.CTRL.RD\(4),
datac => \GRFPC0.WR2.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_REGDEP118: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c03000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEP118_1\,
datae => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD_2_3\,
datad => RFI2_RD2ADDRZ(0),
datac => \GRFPC0.WR2.CTRL.RDWR\,
datab => \GRFPC0.WR2.CTRL.RD\(1));
GRFPC0_RFA2_RS2DEP_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30c0ffff30c030c0")
port map (
combout => \GRFPC0.N_10165\,
dataf => \GRFPC0.RFA2.RS2DEP_0_0_G1_2\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0\,
datad => \GRFPC0.RFA.RS2D_0_0_G1\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP172\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G1\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f30000003300")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_335\,
datae => \GRFPU0.GRFPU_X0.N_19722\,
datad => \GRFPU0.GRFPU_X0.N_19777\,
datac => N_36244,
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030003300330033")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_2_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_327\,
datae => \GRFPU0.GRFPU_X0.N_331\,
datad => \FPI.OP1\(54),
datac => \FPI.OP1\(51),
datab => \FPI.FLOP\(1));
\GRFPC0_D_LDLCK_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0cfc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_6__G3\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX_70\(0),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX_66\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_18\(0));
\GRFPC0_EX_CTRL_INST_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50688,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => N_173);
\GRFPC0_EX_CTRL_INST_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50858,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(6),
datab => N_178);
\GRFPC0_EX_CTRL_INST_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51028,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(11),
datab => N_183);
\GRFPC0_EX_CTRL_INST_RNICF895_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51130,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(14),
datab => N_186);
\GRFPC0_EX_CTRL_INST_RNIGN895_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51198,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => N_188);
\GRFPC0_EX_CTRL_INST_RNIKV895_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51266,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(18),
datab => N_190);
\GRFPC0_EX_CTRL_INST_RNIKR895_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51526,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => N_198);
\GRFPC0_EX_CTRL_INST_RNIO3995_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51594,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => N_200);
\GRFPC0_EX_CTRL_INST_RNIQ7995_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51628,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(29),
datab => N_201);
\GRFPC0_EX_CTRL_INST_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51690,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(31),
datab => N_203);
GRFPC0_WR2_CTRL_SEQERR_0_RNIUKMI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_O2_1\,
dataf => \GRFPC0.R.STATE_190\(0),
datae => \GRFPC0.R.STATE_1\(1),
datad => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_FPEXC_0_SQMUXA_RNIUCD24_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcfffcfcfc")
port map (
combout => N_52804,
dataf => \GRFPC0.FPEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datac => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
datab => \GRFPC0.FIFO.VCNT_0_0_0__G1_2_5816_I_O2_1\);
GRFPC0_MEM_CTRL_LD_RNIK5RQ4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => N_50233,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.MEM.CTRL.LD\,
datad => N_64);
\GRFPC0_D_LDLCK_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffc000c0ff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G3\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX_106\(0),
datae => \GRFPC0.N_22538\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0));
\GRFPC0_MEM_RREG_RES_RNO_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_63__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(63),
datad => \GRFPC0.EX.RREG.RES\(63));
\GRFPC0_MEM_RREG_RES_RNO_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_62__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(62),
datad => \GRFPC0.EX.RREG.RES\(62));
\GRFPC0_MEM_RREG_RES_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_49__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21429_I_0\,
datad => \GRFPC0.EX.RREG.RES\(49));
\GRFPC0_MEM_RREG_RES_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_45__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_20333_I_0\,
datad => \GRFPC0.EX.RREG.RES\(45));
\GRFPC0_MEM_RREG_RES_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_43__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21427_I_0\,
datad => \GRFPC0.EX.RREG.RES\(43));
\GRFPC0_MEM_RREG_RES_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_42__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(42),
datad => \GRFPC0.EX.RREG.RES\(42));
\GRFPC0_MEM_RREG_RES_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_41__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21430_I_0\,
datad => \GRFPC0.EX.RREG.RES\(41));
\GRFPC0_MEM_RREG_RES_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_40__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21441_I_0\,
datad => \GRFPC0.EX.RREG.RES\(40));
\GRFPC0_MEM_RREG_RES_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_36__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21443_I_0\,
datad => \GRFPC0.EX.RREG.RES\(36));
\GRFPC0_MEM_RREG_RES_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_34__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21439_I_0\,
datad => \GRFPC0.EX.RREG.RES\(34));
\GRFPC0_MEM_RREG_RES_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_30__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(30),
datad => \GRFPC0.EX.RREG.RES\(30));
\GRFPC0_MEM_RREG_RES_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_29__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(29),
datad => \GRFPC0.EX.RREG.RES\(29));
\GRFPC0_MEM_RREG_RES_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_26__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(26),
datad => \GRFPC0.EX.RREG.RES\(26));
\GRFPC0_MEM_RREG_RES_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_3__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(3),
datad => \GRFPC0.EX.RREG.RES\(3));
\GRFPC0_MEM_RREG_RES_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_2__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(2),
datad => \GRFPC0.EX.RREG.RES\(2));
\GRFPC0_OP1_3_RNI7J4L1_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc00fcff300030")
port map (
combout => \FPI.OP1\(63),
dataf => \GRFPC0.N_19243\,
datae => \GRFPC0.N_19309\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19178\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNIUE3L1_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(60),
dataf => \GRFPC0.N_19306\,
datae => \GRFPC0.N_19240\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19175\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNIMR6L1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(59),
dataf => \GRFPC0.N_19305\,
datae => \GRFPC0.N_19239\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19174\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNIJR6L1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(49),
dataf => \GRFPC0.N_19295\,
datae => \GRFPC0.N_19229\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19164\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNI7B5L1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(45),
dataf => \GRFPC0.N_19291\,
datae => \GRFPC0.N_19225\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19160\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNI1J4L1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(43),
dataf => \GRFPC0.N_19289\,
datae => \GRFPC0.N_19223\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19158\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNIRQ3L1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(41),
dataf => \GRFPC0.N_19287\,
datae => \GRFPC0.N_19221\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19156\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNIOE3L1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(40),
dataf => \GRFPC0.N_19286\,
datae => \GRFPC0.N_19220\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19155\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNI7N5L1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(36),
dataf => \GRFPC0.N_19282\,
datae => \GRFPC0.N_19216\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19151\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNI4B5L1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(35),
dataf => \GRFPC0.N_19281\,
datae => \GRFPC0.N_19215\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19150\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_RNI1V4L1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(34),
dataf => \GRFPC0.N_19280\,
datae => \GRFPC0.N_19214\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19149\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_UN1_REN130_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30303030000000ff")
port map (
combout => \GRFPC0.UN1_REN130\(0),
dataf => N_448,
datae => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datad => \GRFPC0.FP_PIPELINE.UN1_VFIFO.FULL10\,
datac => N_449,
datab => N_450);
\GRFPC0_INST_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPC0.INST\(26),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_0\(26),
datab => N_129);
\GRFPC0_FP_PIPELINE_7_0_REGDEPX_130_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000ffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.0.REGDEPX_130\(1),
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.N_24408\,
datad => N_174896,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.7.0.CHECK_DEP.DEP_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_M3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffff30")
port map (
combout => \GRFPC0.N_24272\,
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX_230_0_0\(0),
datae => \GRFPC0.N_23387\,
datad => \GRFPC0.N_23392\,
datac => \GRFPC0.N_23391\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_INST_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(7),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(7),
datac => \GRFPC0.FIFO.INST_1\(7),
datab => N_110);
\GRFPC0_INST_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPC0.INST\(8),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_1\(8),
datac => \GRFPC0.FIFO.INST_0\(8),
datab => N_111);
\GRFPC0_WRDATA_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(6),
dataf => N_462,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(6));
\GRFPC0_FP_PIPELINE_WRDATA_3_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(6),
dataf => \GRFPC0.DIV.RESULT\(6),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(6),
datab => \FPO.RES\(6));
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff030300fc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0_0\(0),
dataf => \GRFPC0.N_22899\,
datae => \GRFPC0.N_21794\,
datad => \GRFPC0.N_21627\,
datac => \GRFPC0.N_21620\,
datab => \GRFPC0.N_20995\);
\GRFPC0_FP_PIPELINE_0_STDEP_402_0_IV_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f303f3f3030")
port map (
combout => \GRFPC0.N_22083\,
dataf => N_38025,
datae => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_A2_1_1\(0),
datac => \GRFPC0.N_21663\,
datab => \GRFPC0.N_17407\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(30),
dataf => \FPI.RNDMODE\(0),
datae => N_450,
datad => N_451,
datac => N_746,
datab => N_682);
\GRFPC0_WRDATA_I_M4_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.N_23913\,
dataf => \GRFPC0.DIV.RESULT\(62),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(62),
datab => \FPO.RES\(62));
\GRFPC0_WRDATA_I_M4_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.N_23932\,
dataf => \GRFPC0.DIV.RESULT\(30),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(30),
datab => \FPO.RES\(30));
\GRFPC0_WRDATA_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(30),
dataf => N_486,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.N_23913\,
datab => \GRFPC0.N_23932\);
\GRFPC0_WRDATA_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(29),
dataf => N_485,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(29));
\GRFPC0_FP_PIPELINE_WRDATA_3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(29),
dataf => \GRFPC0.DIV.RESULT\(29),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(29),
datab => \FPO.RES\(29));
\GRFPC0_WRDATA_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(26),
dataf => N_482,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(26));
\GRFPC0_FP_PIPELINE_WRDATA_3_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(26),
dataf => \GRFPC0.DIV.RESULT\(26),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(26),
datab => \FPO.RES\(26));
\GRFPC0_WRDATA_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(24),
dataf => N_480,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(24));
\GRFPC0_FP_PIPELINE_WRDATA_3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(24),
dataf => \GRFPC0.DIV.RESULT\(24),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(24),
datab => \FPO.RES\(24));
\GRFPC0_WRDATA_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(17),
dataf => N_473,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(17));
\GRFPC0_FP_PIPELINE_WRDATA_3_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(17),
dataf => \GRFPC0.DIV.RESULT\(17),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(17),
datab => \FPO.RES\(17));
\GRFPC0_FP_PIPELINE_WRDATA_3_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
dataf => \GRFPC0.DIV.RESULT\(49),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(49),
datab => \GRFPU0.GRFPU_X0.N_21429_I_0\);
\GRFPC0_WRDATA_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(13),
dataf => N_469,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(13));
\GRFPC0_FP_PIPELINE_WRDATA_3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(13),
dataf => \GRFPC0.DIV.RESULT\(13),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(13),
datab => \FPO.RES\(13));
\GRFPC0_FP_PIPELINE_WRDATA_3_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
dataf => \GRFPC0.DIV.RESULT\(45),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(45),
datab => \GRFPU0.GRFPU_X0.N_20333_I_0\);
\GRFPC0_WRDATA_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(3),
dataf => N_459,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(3));
\GRFPC0_FP_PIPELINE_WRDATA_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(3),
dataf => \GRFPC0.DIV.RESULT\(3),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(3),
datab => \FPO.RES\(3));
\GRFPC0_WRDATA_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(2),
dataf => N_458,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(2),
dataf => \GRFPC0.DIV.RESULT\(2),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datab => \FPO.RES\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
dataf => \GRFPC0.DIV.RESULT\(34),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPU0.GRFPU_X0.N_21439_I_0\);
\GRFPC0_FP_PIPELINE_WRADDR_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(0),
dataf => N_452,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_WRADDR_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(2),
dataf => N_454,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_OP1_4_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19239\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_679,
datad => N_743);
\GRFPC0_OP1_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19174\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(59),
datad => \GRFPC0.WR.RREG.RES\(59));
\GRFPC0_OP1_3_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19160\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(45),
datad => \GRFPC0.WR.RREG.RES\(45));
\GRFPC0_OP1_3_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19156\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(41),
datad => \GRFPC0.WR.RREG.RES\(41));
\GRFPC0_OP1_4_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19216\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_656,
datad => N_720);
\GRFPC0_OP1_3_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19151\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(36),
datad => \GRFPC0.WR.RREG.RES\(36));
\GRFPC0_WRDATA_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(31),
dataf => N_487,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(31));
\GRFPC0_FP_PIPELINE_WRDATA_3_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(31),
dataf => \GRFPC0.DIV.RESULT\(31),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(31),
datab => \FPO.RES\(31));
\GRFPC0_FP_PIPELINE_WRDATA_3_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
dataf => \GRFPC0.DIV.RESULT\(63),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(63),
datab => \FPO.RES\(63));
\GRFPC0_OP1_4_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19243\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_683,
datad => N_747);
\GRFPC0_OP1_3_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19178\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(63),
datad => \GRFPC0.WR.RREG.RES\(63));
\GRFPC0_OP2_3_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19749\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(63),
datad => \GRFPC0.WR.RREG.RES\(63));
\GRFPC0_OP2_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fcfcff003030")
port map (
combout => \FPI.OP2\(63),
dataf => \GRFPC0.N_19814\,
datae => \GRFPC0.OP2_SN_N_9\,
datad => \GRFPC0.N_19880\,
datac => \GRFPC0.N_19749\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_OP1_4_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19240\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_680,
datad => N_744);
\GRFPC0_OP1_3_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19175\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(60),
datad => \GRFPC0.WR.RREG.RES\(60));
\GRFPC0_OP1_3_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19158\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(43),
datad => \GRFPC0.WR.RREG.RES\(43));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_6\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(8));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_8\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(10),
datab => \GRFPC0.INST\(8));
GRFPC0_FP_PIPELINE_DEPMUX_RES_U: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffaaa855570000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES\,
dataf => \GRFPC0.N_11185\,
datae => \GRFPC0.FP_PIPELINE.DEPMUX.RES_1_1\,
datad => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3_0\,
datac => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\,
datab => \GRFPC0.FP_PIPELINE.RSDEC.RS1V12_6\,
dataa => \GRFPC0.INST\(31));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25787\,
dataf => \GRFPC0.N_24306_1\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25824\,
dataf => \GRFPC0.N_25754\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25823\,
dataf => \GRFPC0.N_25758\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_4\(0),
dataf => \GRFPC0.N_23803\,
datae => \GRFPC0.N_23787\,
datad => \GRFPC0.N_25859\,
datac => \GRFPC0.N_23783_1\,
datab => \GRFPC0.N_25813_1\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_13_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25811\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23588\,
datad => \GRFPC0.N_24554\,
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.EX.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.N_25763\,
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_O2_8\(0),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.N_23660\,
datac => \GRFPC0.N_23712\,
datab => \GRFPC0.N_23662\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_378_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_378\(0),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_376\(0),
datae => \GRFPC0.WR.CTRL.RS1V\,
datad => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.N_25090\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23639\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380\(0),
dataf => \GRFPC0.FP_PIPELINE.12.REGDEPX2_378\(0),
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_375\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_25328\,
dataf => \GRFPC0.N_25754\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_O2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_I_O2_2_0\(0),
dataf => \GRFPC0.N_25328\,
datae => \GRFPC0.N_25758\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_1\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3fffff")
port map (
combout => \GRFPC0.N_25276\,
dataf => \GRFPC0.N_25271\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff3033cccf0003")
port map (
combout => \GRFPC0.N_16974\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(0),
datae => \GRFPC0.N_16972\,
datad => \GRFPC0.N_25259\,
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_11\(0),
dataf => \GRFPC0.N_24226\,
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_4_0_A3_0\(1),
datac => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.N_25549\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A3_1\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.N_25758\,
datac => \GRFPC0.N_25438_1\,
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\(0),
dataf => \GRFPC0.N_25715\,
datae => \GRFPC0.N_25711\,
datad => \GRFPC0.N_24297\,
datac => \GRFPC0.N_24323\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4857_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_10_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4fffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_10\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_5\(0),
datab => \GRFPC0.N_24252\,
dataa => \GRFPC0.EX.CTRL.RD_0_0_0__G3\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_11\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_10\(0),
datad => \GRFPC0.N_24242_2\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1106_REGDEPX2_1\,
datab => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_0_3_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_0\(0),
dataf => \GRFPC0.N_25352\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datac => \GRFPC0.N_25361\,
datab => \GRFPC0.N_25325_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_2\(0),
dataf => \GRFPC0.N_25296_1\,
datae => \GRFPC0.N_260\,
datad => \GRFPC0.N_25360\,
datac => \GRFPC0.N_25350\,
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25290\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_265_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.N_23754\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.8.REGDEPX2_260_0_A2_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPC0.N_16968\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_6_0\(0),
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_TZ_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff3fff00ff")
port map (
combout => \GRFPC0.N_24997_TZ_TZ\,
dataf => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_12\(0),
datae => \GRFPC0.N_25012\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_6_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_2\(0),
dataf => \GRFPC0.N_24997_TZ_TZ\,
datae => \GRFPC0.N_24664\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datac => \GRFPC0.N_25754\,
datab => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_A2_1_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25077\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_25758\,
datad => \GRFPC0.N_25745_I\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00001030000050f0")
port map (
combout => \GRFPC0.N_24997\,
dataf => \GRFPC0.N_303\,
datae => \GRFPC0.N_23867\,
datad => \GRFPC0.N_302\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_I_8\(0),
datab => \GRFPC0.N_250\,
dataa => \GRFPC0.N_23728\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f3ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_1\(0),
dataf => \GRFPC0.N_25445\,
datae => \GRFPC0.N_25443\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
datac => \GRFPC0.N_25385\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000333f1115")
port map (
combout => \GRFPC0.N_24\,
dataf => \GRFPC0.N_23737\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_A2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2_2_0\(0),
datac => \GRFPC0.N_25454\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23745\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_25758\,
datad => \GRFPC0.N_25745_I\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_10_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_2\(0),
dataf => \GRFPC0.N_23745\,
datae => \GRFPC0.N_24306_1\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_2\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_6_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_10_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_4\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_10_2\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_8_1\(0),
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6\(0),
datab => \GRFPC0.N_25657\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_23748\,
dataf => \GRFPC0.N_25217_1\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffccf0cc")
port map (
combout => \GRFPC0.N_16956\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_1\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_10\(0),
datad => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_9\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_2\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24926\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2_2\,
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_2_2_RNIC4881_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_2\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.N_24973_2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datab => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24959\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000c0000")
port map (
combout => N_4,
dataf => \GRFPC0.N_24959\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datad => \GRFPC0.N_24112\,
datac => \GRFPC0.N_24113\,
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_A3_RNIMAC45_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_8\(0),
dataf => \GRFPC0.N_24950\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_5\(0),
datad => N_4,
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_1\(0),
datab => \GRFPC0.N_24977\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300000000000")
port map (
combout => \GRFPC0.N_25127\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(0),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0),
datab => \GRFPC0.N_24633\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_1\(0),
dataf => \GRFPC0.N_25127\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.N_25758\,
datac => \GRFPC0.N_25438_1\,
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_4\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_1\(0),
datae => \GRFPC0.N_25747_I\,
datad => \GRFPC0.N_23584\,
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.N_25566\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.N_25128\,
dataf => \GRFPC0.N_25589\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_3\(0),
dataf => \GRFPC0.N_25128\,
datae => \GRFPC0.N_25217_1\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_25129\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A3_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A3_2_0\(0),
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_0\(0),
dataf => \GRFPC0.N_25129\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.N_25754\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_A3_2_0\(0),
datab => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8ffffff88")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_11\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_9\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5\(0),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_2\(0),
datab => \GRFPC0.N_23787\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_25546\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_25519\,
dataf => \GRFPC0.N_25495_2\,
datae => \GRFPC0.N_25546\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A2_3_1\(1),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5e6c4b391a280")
port map (
combout => \GRFPC0.N_16954\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(0),
datac => \GRFPC0.D.LDLCK_0_0_6__G3\,
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0cffcc3300f3c0")
port map (
combout => \GRFPC0.N_16962\,
dataf => \GRFPC0.N_16956\,
datae => N_124907,
datad => \GRFPC0.N_16954\,
datac => \GRFPC0.INST\(27),
datab => \GRFPC0.INST\(28));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_16_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3ff333cc0cc000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(0),
dataf => \GRFPC0.N_16962\,
datae => \GRFPC0.N_16968\,
datad => \GRFPC0.N_16974\,
datac => \GRFPC0.INST\(28),
datab => \GRFPC0.INST\(29));
\GRFPC0_INST_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(6),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => N_109);
\GRFPC0_OP1_3_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19150\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(35),
datad => \GRFPC0.WR.RREG.RES\(35));
\GRFPC0_OP1_3_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19149\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(34),
datad => \GRFPC0.WR.RREG.RES\(34));
\GRFPC0_OP1_3_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19164\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(49),
datad => \GRFPC0.WR.RREG.RES\(49));
\GRFPC0_OP2_3_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19735\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(49),
datad => \GRFPC0.WR.RREG.RES\(49));
\GRFPC0_OP2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(49),
dataf => \GRFPC0.N_19866\,
datae => \GRFPC0.N_19800\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19735\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_WRDATA_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(9),
dataf => N_465,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(9));
\GRFPC0_FP_PIPELINE_WRDATA_3_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
dataf => \GRFPC0.DIV.RESULT\(41),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(41),
datab => \GRFPU0.GRFPU_X0.N_21430_I_0\);
\GRFPC0_WRDATA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(0),
dataf => N_456,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(0),
dataf => \GRFPC0.DIV.RESULT\(0),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \FPO.RES\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(27),
dataf => \GRFPC0.R.FSR.TEM\(4),
datae => N_450,
datad => N_451,
datac => N_743,
datab => N_679);
\GRFPC0_OP1_3_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19155\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(40),
datad => \GRFPC0.WR.RREG.RES\(40));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_21_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc0c0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20953\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => N_174935_0,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31),
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000003f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(29),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_265\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(29),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_3_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(29),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(89));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_23_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000cc0cc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21005\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
datac => N_174935_0,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_21005\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ff3033f0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(31),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => N_174945,
datac => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(31),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.DRES_1\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(31),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20893_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(31),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(31),
datad => \GRFPU0.GRFPU_X0.N_21025\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(31),
datab => \GRFPU0.GRFPU_X0.N_296\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_24_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_20956\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ff3033f0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(32),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => N_174945,
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(32),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.DRES_1\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(32),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20887_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(32),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(32),
datad => \GRFPU0.GRFPU_X0.N_21025\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
datab => \GRFPU0.GRFPU_X0.N_296\);
\GRFPC0_OP1_I_M4_4_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_23923\,
dataf => \GRFPC0.RFA2.RS1SEL\(1),
datae => \GRFPC0.EX.RREG.RES\(62),
datad => \GRFPC0.WR.RREG.RES\(62));
\GRFPU0_GRFPU_X0_UN13_EXP_M_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(62),
dataf => \GRFPC0.N_23953\,
datae => \GRFPC0.N_23922\,
datad => \GRFPC0.OP1_SN_N_9\,
datac => \GRFPC0.N_23923\,
datab => \GRFPC0.RFA2.RS1SEL\(7));
\GRFPC0_OP2_I_M4_1_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_23928\,
dataf => \FPO.RES\(62),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(62));
\GRFPC0_OP2_I_M4_2_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_23929\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(62),
datad => \GRFPC0.MEM.RREG.RES\(62));
\GRFPU0_GRFPU_X0_UN38_EXP_M_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(62),
dataf => \GRFPC0.N_23928\,
datae => \GRFPC0.N_23948\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_23929\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPC0_OP2_3_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19746\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(60),
datad => \GRFPC0.WR.RREG.RES\(60));
\GRFPU0_GRFPU_X0_UN38_EXP_M_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(60),
dataf => \GRFPC0.N_19877\,
datae => \GRFPC0.N_19811\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19746\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_UN38_EXP_M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(56),
dataf => \GRFPC0.N_19873\,
datae => \GRFPC0.N_19807\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19742\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0aaffccf0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(4),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.DIV.INST\(4),
dataa => \GRFPC0.WR2.CTRL.PC\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(5),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(5),
datab => \GRFPC0.DIV.INST\(5),
dataa => \GRFPC0.WR2.CTRL.INST\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(6),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(6),
datab => \GRFPC0.DIV.INST\(6),
dataa => \GRFPC0.WR2.CTRL.INST\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(7),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(7),
datab => \GRFPC0.DIV.INST\(7),
dataa => \GRFPC0.WR2.CTRL.INST\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(8),
datab => \GRFPC0.DIV.INST\(8),
dataa => \GRFPC0.WR2.CTRL.INST\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(9),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(9),
datab => \GRFPC0.DIV.INST\(9),
dataa => \GRFPC0.WR2.CTRL.INST\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(12),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(12),
datab => \GRFPC0.DIV.INST\(12),
dataa => \GRFPC0.WR2.CTRL.INST\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(13),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(13),
datab => \GRFPC0.DIV.INST\(13),
dataa => \GRFPC0.WR2.CTRL.INST\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0aaffccf0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(15),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.DIV.INST\(15),
dataa => \GRFPC0.WR2.CTRL.PC\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaafff0ccaa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(17),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(17),
dataa => \GRFPC0.WR2.CTRL.PC\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0aaffccf0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(18),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.DIV.INST\(18),
dataa => \GRFPC0.WR2.CTRL.PC\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(21),
datab => \GRFPC0.WR2.CTRL.PC\(21),
dataa => \GRFPC0.DIV.INST\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(23),
datab => \GRFPC0.WR2.CTRL.PC\(23),
dataa => \GRFPC0.DIV.INST\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(24),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(24),
datab => \GRFPC0.WR2.CTRL.PC\(24),
dataa => \GRFPC0.DIV.INST\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(26),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.PC\(26),
dataa => \GRFPC0.DIV.INST\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(27),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.PC\(27),
dataa => \GRFPC0.DIV.INST\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(29),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.PC\(29),
dataa => \GRFPC0.DIV.INST\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(31),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(31),
datab => \GRFPC0.WR2.CTRL.PC\(31),
dataa => \GRFPC0.DIV.INST\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4),
datac => N_50792,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(4),
dataa => \GRFPC0.EX.CTRL.PC\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5),
datac => \FPI.FLOP\(0),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(5),
dataa => \GRFPC0.EX.CTRL.PC\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7),
datac => \FPI.FLOP\(2),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(7),
dataa => \GRFPC0.EX.CTRL.PC\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(8),
datac => \FPI.FLOP\(3),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(8),
dataa => \GRFPC0.EX.CTRL.PC\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9),
datac => \FPI.FLOP\(4),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(9),
dataa => \GRFPC0.EX.CTRL.PC\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12),
datac => \FPI.FLOP\(7),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(12),
dataa => \GRFPC0.EX.CTRL.PC\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13),
datac => \FPI.FLOP\(8),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(13),
dataa => \GRFPC0.EX.CTRL.PC\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(14),
datac => \GRFPC0.V.STDATA_14\(14),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(14),
dataa => \GRFPC0.EX.CTRL.PC\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15),
datac => \GRFPC0.V.STDATA_14\(15),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(15),
dataa => \GRFPC0.EX.CTRL.PC\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17),
datac => \GRFPC0.V.STDATA_14\(17),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(17),
dataa => \GRFPC0.EX.CTRL.PC\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18),
datac => \GRFPC0.V.STDATA_14\(18),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(18),
dataa => \GRFPC0.EX.CTRL.PC\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0aaaacccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(21),
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(21),
datab => N_51364,
dataa => \GRFPC0.EX.CTRL.PC\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0aaaacccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(23),
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(23),
datab => N_51426,
dataa => \GRFPC0.EX.CTRL.PC\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24),
datac => N_51460,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(24),
dataa => \GRFPC0.EX.CTRL.PC\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26),
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(26),
dataa => \GRFPC0.EX.CTRL.PC\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27),
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(27),
dataa => \GRFPC0.EX.CTRL.PC\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29),
datac => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(29),
dataa => \GRFPC0.EX.CTRL.PC\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31),
datac => \GRFPC0.V.STDATA_14\(31),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(31),
dataa => \GRFPC0.EX.CTRL.PC\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.PC\(4),
dataa => \GRFPC0.MEM.CTRL.PC\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(5),
datac => \GRFPC0.MEM.CTRL.INST\(5),
datab => \GRFPC0.WR.CTRL.PC\(5),
dataa => \GRFPC0.MEM.CTRL.PC\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(6),
datac => \GRFPC0.MEM.CTRL.INST\(6),
datab => \GRFPC0.WR.CTRL.PC\(6),
dataa => \GRFPC0.MEM.CTRL.PC\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(7),
datac => \GRFPC0.MEM.CTRL.INST\(7),
datab => \GRFPC0.WR.CTRL.PC\(7),
dataa => \GRFPC0.MEM.CTRL.PC\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(8),
datac => \GRFPC0.MEM.CTRL.INST\(8),
datab => \GRFPC0.WR.CTRL.PC\(8),
dataa => \GRFPC0.MEM.CTRL.PC\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(9),
datac => \GRFPC0.MEM.CTRL.INST\(9),
datab => \GRFPC0.WR.CTRL.PC\(9),
dataa => \GRFPC0.MEM.CTRL.PC\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(12),
datac => \GRFPC0.MEM.CTRL.INST\(12),
datab => \GRFPC0.WR.CTRL.PC\(12),
dataa => \GRFPC0.MEM.CTRL.PC\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.PC\(15),
dataa => \GRFPC0.MEM.CTRL.PC\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR.CTRL.PC\(17),
dataa => \GRFPC0.MEM.CTRL.PC\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.PC\(18),
dataa => \GRFPC0.MEM.CTRL.PC\(18));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(21),
datac => \GRFPC0.MEM.CTRL.INST\(21),
datab => \GRFPC0.WR.CTRL.PC\(21),
dataa => \GRFPC0.MEM.CTRL.PC\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(23),
datac => \GRFPC0.MEM.CTRL.INST\(23),
datab => \GRFPC0.WR.CTRL.PC\(23),
dataa => \GRFPC0.MEM.CTRL.PC\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(24),
datac => \GRFPC0.MEM.CTRL.INST\(24),
datab => \GRFPC0.WR.CTRL.PC\(24),
dataa => \GRFPC0.MEM.CTRL.PC\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.PC\(26),
dataa => \GRFPC0.MEM.CTRL.PC\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.PC\(27),
dataa => \GRFPC0.MEM.CTRL.PC\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.PC\(29),
dataa => \GRFPC0.MEM.CTRL.PC\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(31),
datac => \GRFPC0.MEM.CTRL.INST\(31),
datab => \GRFPC0.WR.CTRL.PC\(31),
dataa => \GRFPC0.MEM.CTRL.PC\(31));
\GRFPC0_EX_CTRL_PC_RNO_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51799,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(4),
datad => \GRFPC0.FIFO.PC_1\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(5),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(5),
datac => \GRFPC0.FIFO.PC_1\(5),
datab => \GRFPC0.FIFO.PC_0\(5));
\GRFPC0_EX_CTRL_PC_RNO_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51871,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(6),
datad => \GRFPC0.FIFO.PC_1\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(7),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(7),
datac => \GRFPC0.FIFO.PC_1\(7),
datab => \GRFPC0.FIFO.PC_0\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(9),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(9),
datac => \GRFPC0.FIFO.PC_1\(9),
datab => \GRFPC0.FIFO.PC_0\(9));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(12),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(12),
datac => \GRFPC0.FIFO.PC_1\(12),
datab => \GRFPC0.FIFO.PC_0\(12));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(13),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(13),
datac => \GRFPC0.FIFO.PC_1\(13),
datab => \GRFPC0.FIFO.PC_0\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(15),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.FIFO.PC_1\(15),
datab => \GRFPC0.FIFO.PC_0\(15));
\GRFPC0_EX_CTRL_PC_RNO_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(17),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(17),
datad => \GRFPC0.FIFO.PC_1\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(18),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.FIFO.PC_1\(18),
datab => \GRFPC0.FIFO.PC_0\(18));
\GRFPC0_EX_CTRL_PC_RNO_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(21),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(21),
datad => \GRFPC0.FIFO.PC_1\(21));
\GRFPC0_EX_CTRL_PC_RNO_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(23),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(23),
datad => \GRFPC0.FIFO.PC_1\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(24),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(24),
datac => \GRFPC0.FIFO.PC_1\(24),
datab => \GRFPC0.FIFO.PC_0\(24));
\GRFPC0_EX_CTRL_PC_RNO_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(26),
datad => \GRFPC0.FIFO.PC_1\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(27),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.FIFO.PC_1\(27),
datab => \GRFPC0.FIFO.PC_0\(27));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(29),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.FIFO.PC_1\(29),
datab => \GRFPC0.FIFO.PC_0\(29));
\GRFPC0_EX_CTRL_PC_RNO_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(31),
dataf => \GRFPC0.FIFO.RD_1_0\(0),
datae => \GRFPC0.FIFO.PC_0\(31),
datad => \GRFPC0.FIFO.PC_1\(31));
GRFPC0_DIV_PEND_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f333333333333")
port map (
combout => \GRFPC0.DIV.PEND_1_0_G0_I_O4_0\,
dataf => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
datae => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\,
datab => N_52981_2);
GRFPC0_DIV_PEND_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc0000000c")
port map (
combout => N_91848,
dataf => N_52981,
datae => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datad => \GRFPC0.DIV.PEND_1_0_G0_I_O4_0\,
datac => \GRFPC0.WR2.CTRL.SEQERR_0\,
datab => \GRFPC0.DIV.PEND\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.V.STDATA_14\(1),
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0cfcfc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(1),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datab => \GRFPC0.WR2.CTRL.INST\(1));
GRFPC0_WR2_EXC_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0cfc00f00")
port map (
combout => \GRFPC0.WR2.EXC_0_0_N_4\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.WR2.EXC\,
datac => N_63,
datab => N_52981_2);
GRFPC0_WR2_EXC_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000c")
port map (
combout => N_29747,
dataf => \GRFPC0.WR2.EXC_0_0_N_4\,
datae => \GRFPC0.PENDEXC_0_SQMUXA\,
datad => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
datab => \GRFPC0.WR2.EXC_0_0_G0_0_A3_1\);
GRFPC0_CCWR_0_SQMUXA_2_0_RNIOVOS4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => N_52880_2,
dataf => N_52829,
datae => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datad => N_126,
datac => N_124);
\GRFPC0_FIFO_VCNT_0_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f00f00")
port map (
combout => N_52831,
dataf => N_52829,
datae => \GRFPC0.FIFO.VCNT_0\(0),
datad => \GRFPC0.FIFO.VCNT_0\(2),
datac => \GRFPC0.FIFO.VCNT_0\(1));
\GRFPC0_FIFO_VCNT_1_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff0000f0")
port map (
combout => N_52879,
dataf => N_52829,
datae => \GRFPC0.FIFO.VCNT_1\(0),
datad => \GRFPC0.FIFO.VCNT_1\(1),
datac => \GRFPC0.FIFO.VCNT_1\(2));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_RNIQ8OE1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => N_49627,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4\,
datae => N_52826,
datad => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datac => N_126,
datab => N_124);
GRFPC0_FP_PIPELINE_0_UN1_OP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
dataf => N_138,
datae => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datad => N_126,
datac => N_124);
GRFPC0_UN1_VFIFO_VCNT_1_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfffc0000fff0")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\,
dataf => N_52020,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => N_52826,
datac => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datab => N_61);
GRFPC0_RFA_ST_RNIO6AQ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000cff0c000c00")
port map (
combout => \GRFPC0.OP1_SN_N_5\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => \GRFPC0.RFA.RS1D\,
datad => \GRFPC0.RFA.ST\,
datac => N_192,
datab => N_197);
\GRFPC0_EX_CTRL_INST_RNIEJ895_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51164,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => N_187);
GRFPC0_RFA2_RS1DEP_RNIBHRV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00ffffff")
port map (
combout => N_50504_3,
dataf => \GRFPC0.RFA.WRITE_RD\,
datae => \GRFPC0.RFA2.RS1DEP\,
datad => \GRFPC0.RFA.READ_RS1\,
datac => \GRFPC0.RFA2.DIVLCK\);
GRFPC0_FP_PIPELINE_FPUSTART_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0f3c0f3c0")
port map (
combout => \FPI.START_1\,
dataf => \GRFPC0.RFA2.FOP\(0),
datae => \GRFPC0.FPR.ALLOW\(1),
datad => \GRFPC0.FPR.ALLOW\(2),
datac => \GRFPC0.FPR.ALLOW\(0),
datab => \GRFPC0.RFA2.FOP\(1));
\GRFPC0_FP_PIPELINE_RS1_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6\(0),
dataf => \GRFPC0.N_18115\,
datae => \GRFPC0.RFA.RS1\(0),
datad => N_63);
GRFPC0_RFA_SEQERR_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => N_50375,
dataf => \GRFPC0.FP_PIPELINE.QNE2\,
datae => N_134,
datad => N_133,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST7_0\,
datab => N_50421_2);
GRFPC0_FP_PIPELINE_UN32_OP_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30000000000000")
port map (
combout => \GRFPC0.RFA.LD_0_0_I0_I_1\,
dataf => N_134,
datae => N_133,
datad => \GRFPC0.FP_PIPELINE.VRFA.ST4\,
datac => \GRFPC0.N_290\,
datab => N_124);
GRFPC0_FP_PIPELINE_UN26_OP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_OP\,
dataf => \GRFPC0.RFA.LD_0_0_I0_I_1\,
datae => \GRFPC0.CCWR_0_SQMUXA_2_0\,
datad => N_126,
datac => N_124);
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccccf0f0ccfc")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_372_3_0_0\(1),
dataf => \GRFPC0.N_21627\,
datae => \GRFPC0.N_21620\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.N_131_1\,
datab => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_7_STDEP_314_0_IV_I_I2_1_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_22354\,
dataf => \GRFPC0.N_22858\,
datae => \GRFPC0.FIFO.INST_1\(25));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_20893\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30003fff")
port map (
combout => \GRFPC0.N_20837\,
dataf => \GRFPC0.N_20893\,
datae => \GRFPC0.N_22192_I\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDD_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_8_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_8_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_22179\,
datad => \GRFPC0.N_112\,
datac => \GRFPC0.N_78_I_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff00f0c0f00")
port map (
combout => \GRFPC0.N_20839\,
dataf => \GRFPC0.N_20837\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O2_8_1\,
datac => \GRFPC0.N_20833\,
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(8));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcffffff")
port map (
combout => \GRFPC0.N_21353\,
dataf => \GRFPC0.N_20995\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_A2_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140_I_A2_1_1\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.N_23584\,
datae => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
dataf => \GRFPC0.N_24910\,
datae => \GRFPC0.N_24128\,
datad => \GRFPC0.N_24126\,
datac => \GRFPC0.N_24127_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_1_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_1_0_0\(1),
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff3fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_3\(0),
dataf => \GRFPC0.N_25228\,
datae => \GRFPC0.N_25217_1\,
datad => \GRFPC0.N_24637\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f33ffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_2\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23588\,
datad => \GRFPC0.N_24696_1\,
datac => \GRFPC0.N_24697_1\,
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_1\(0),
dataf => \GRFPC0.N_25214\,
datae => \GRFPC0.N_25747_I\,
datad => \GRFPC0.N_23584\,
datac => \GRFPC0.N_24119\,
datab => \GRFPC0.N_24487\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_7_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_7\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_0\(0),
datae => \GRFPC0.N_25169\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_25758\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7019_REGDEPX2\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_9_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_9\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_7\(0),
datae => \GRFPC0.N_25098\,
datad => \GRFPC0.WR.CTRL.INST\(4),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_11_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_11\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_9\(0),
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_3\(0),
datad => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_1\(0),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_2\(0),
datab => \GRFPC0.N_25211\,
dataa => \GRFPC0.N_25227\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_13_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a2f30000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_13\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_11\(0),
datad => \GRFPC0.N_24193\,
datac => \GRFPC0.N_24221\,
datab => \GRFPC0.N_23660\,
dataa => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000000")
port map (
combout => \GRFPC0.N_25173\,
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_I_A2_13\(0),
datae => \GRFPC0.N_24483_I\,
datad => N_174891,
datac => \GRFPC0.N_25491\,
datab => \GRFPC0.N_24490\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccfcc00000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_1\(0),
dataf => \GRFPC0.N_24330\,
datae => \GRFPC0.N_25271\,
datad => \GRFPC0.N_24324\,
datac => \GRFPC0.N_24278\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_14_0\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_13_0_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fcfffffffc")
port map (
combout => \GRFPC0.N_16972\,
dataf => \GRFPC0.N_25173\,
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(0),
datad => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O3_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX_12_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22718\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_182_IV_0_A3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_228\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3439_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_1\,
dataf => N_105,
datae => N_107);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3439_REGDEPX_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX_0\,
dataf => N_104,
datae => N_106);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_93\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22858\,
datad => \GRFPC0.N_22146\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.N_22074\,
dataf => \GRFPC0.N_93\,
datae => \GRFPC0.N_22782\,
datad => \GRFPC0.N_22573_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
datab => \GRFPC0.N_21996\);
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_166_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3333333f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_166\(1),
dataf => \GRFPC0.N_22697\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_1_0_A2_0\(1),
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1879_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX\,
dataf => N_106,
datae => N_104,
datad => N_107,
datac => N_105);
\GRFPC0_FIFO_INST_1_RNIR9UB_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(1),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25295_1\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A4_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c0c0c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datac => \GRFPC0.N_25585\,
datab => \GRFPC0.N_25664\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_10_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_10\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_5\(0),
datae => \GRFPC0.N_25593\,
datad => \GRFPC0.N_25314\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_1\(0),
datab => \GRFPC0.N_25317\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_0_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25594\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2_2\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_13_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_13\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_10\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(0),
datac => \GRFPC0.N_25310\,
datab => \GRFPC0.N_23728\,
dataa => \GRFPC0.N_25646_2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f4ffff0044")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
dataf => \GRFPC0.N_303\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_13\(0),
datad => \GRFPC0.N_24910\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_35_0_A2_1\(1),
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_1_0\(0),
dataa => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_24601\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_3_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN416_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffdfffc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_9\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_6\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_0_5\(0),
datab => \GRFPC0.N_25777\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_9_STDEP_372_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_21626\,
dataf => \GRFPC0.N_21620\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0ff000000ff")
port map (
combout => \GRFPC0.N_21793\,
dataf => \GRFPC0.N_83\,
datae => \GRFPC0.N_21783\,
datad => \GRFPC0.N_78_I_I_1\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(4),
dataf => \GRFPC0.DIV.RESULT\(4),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(4),
datab => \FPO.RES\(4));
\GRFPC0_WRDATA_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(4),
dataf => N_460,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(4));
\GRFPC0_FP_PIPELINE_WRDATA_3_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
dataf => \GRFPC0.DIV.RESULT\(36),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(36),
datab => \GRFPU0.GRFPU_X0.N_21443_I_0\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.TEM\(1),
datab => \GRFPC0.DIV.EXCT\(1));
\GRFPC0_MEM_RREG_RES_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_5__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(5),
datad => \GRFPC0.EX.RREG.RES\(5));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_12_M_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(1),
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPC0_R_STATE_0_0_0__G0_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.R.STATE_0_0_1__G0\,
dataf => N_63,
datae => N_61);
GRFPC0_FP_PIPELINE_VRFA_ST7_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST7_0\,
dataf => N_122,
datae => N_127,
datad => N_126,
datac => N_125);
GRFPC0_UN1_WRENX2_2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00030000c000300")
port map (
combout => \GRFPC0.UN1_WRENX2_2_5\,
dataf => \GRFPC0.N_23610\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_0_MEMEN2_0_A2_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000c0030000300")
port map (
combout => \GRFPC0.FP_PIPELINE.0.MEMEN2_0_A2_1\,
dataf => \GRFPC0.N_23610\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62_0\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_INST_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(5),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(5),
datac => \GRFPC0.FIFO.INST_1\(5),
datab => N_108);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_207\,
dataf => N_36304,
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(57),
datac => \FPI.FLOP\(1));
\GRFPC0_WRDATA_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(23),
dataf => N_479,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(23));
GRFPC0_MEM_CTRL_CCWR_RNIKAOR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1_0\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.CCWR\);
GRFPU0_GRFPU_X0_UN28_EXP_ANC5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_36314,
dataf => N_36304,
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(57));
\GRFPU0_GRFPU_X0_UN38_EXP_M_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(58),
dataf => \GRFPC0.N_19875\,
datae => \GRFPC0.N_19809\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19744\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19744\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(58),
datad => \GRFPC0.WR.RREG.RES\(58));
\GRFPC0_FP_PIPELINE_DBGDATA_4_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(26),
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => N_450,
datad => N_451,
datac => N_742,
datab => N_678);
\GRFPC0_FP_PIPELINE_WRDATA_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
dataf => \GRFPC0.DIV.RESULT\(58),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(58),
datab => \GRFPU0.GRFPU_X0.N_21424_I_0\);
\GRFPC0_OP1_4_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19238\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_678,
datad => N_742);
\GRFPC0_OP1_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19173\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(58),
datad => \GRFPC0.WR.RREG.RES\(58));
\GRFPC0_OP1_3_RNIJF6L1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(58),
dataf => \GRFPC0.N_19304\,
datae => \GRFPC0.N_19238\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19173\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_58__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21424_I_0\,
datad => \GRFPC0.EX.RREG.RES\(58));
\GRFPC0_MEM_RREG_RES_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_24__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(24),
datad => \GRFPC0.EX.RREG.RES\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c00c000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20956\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => N_174935_0,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPC0_FP_PIPELINE_WRDATA_3_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
dataf => \GRFPC0.DIV.RESULT\(38),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(38),
datab => \GRFPU0.GRFPU_X0.N_21435_I_0\);
\GRFPC0_OP1_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19021\,
dataf => \GRFPU0.GRFPU_X0.N_21435_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(38));
\GRFPC0_OP1_2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19087\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(38),
datad => \GRFPC0.MEM.RREG.RES\(38));
\GRFPC0_OP1_1_RNIC34E3_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(38),
dataf => \GRFPC0.N_19350\,
datae => \GRFPC0.N_19021\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19087\);
\GRFPC0_MEM_RREG_RES_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_6__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(6),
datad => \GRFPC0.EX.RREG.RES\(6));
\GRFPC0_MEM_RREG_RES_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_38__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21435_I_0\,
datad => \GRFPC0.EX.RREG.RES\(38));
\GRFPC0_FP_PIPELINE_WRDATA_3_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
dataf => \GRFPC0.DIV.RESULT\(40),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(40),
datab => \GRFPU0.GRFPU_X0.N_21441_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(8),
dataf => \GRFPC0.DIV.RESULT\(8),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(8),
datab => \FPO.RES\(8));
\GRFPC0_WRDATA_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(8),
dataf => N_464,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(8));
\GRFPC0_WRDATA_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(7),
dataf => N_463,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(7));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0ffffff00")
port map (
combout => \GRFPC0.N_18400\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(1),
datad => \GRFPC0.R.FSR.AEXC\(1),
datac => \GRFPC0.DIV.EXCT\(1));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fffff0f0")
port map (
combout => \GRFPC0.N_18403\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datad => \GRFPC0.DIV.EXCT\(4),
datac => \GRFPC0.R.FSR.AEXC\(4));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0ffffff00")
port map (
combout => \GRFPC0.N_18402\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
datad => \GRFPC0.R.FSR.AEXC\(3),
datac => \GRFPC0.DIV.EXCT\(3));
\GRFPC0_MEM_RREG_RES_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_8__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(8),
datad => \GRFPC0.EX.RREG.RES\(8));
\GRFPC0_FP_PIPELINE_WRDATA_3_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(9),
dataf => \GRFPC0.DIV.RESULT\(9),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(9),
datab => \FPO.RES\(9));
\GRFPC0_FP_PIPELINE_DBGDATA_4_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(9),
dataf => \GRFPC0.R.FSR.AEXC\(4),
datae => N_450,
datad => N_451,
datac => N_725,
datab => N_661);
\GRFPC0_MEM_RREG_RES_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_9__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(9),
datad => \GRFPC0.EX.RREG.RES\(9));
\GRFPC0_MEM_RREG_RES_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_10__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(10),
datad => \GRFPC0.EX.RREG.RES\(10));
\GRFPC0_MEM_RREG_RES_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_12__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(12),
datad => \GRFPC0.EX.RREG.RES\(12));
\GRFPC0_MEM_RREG_RES_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_13__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(13),
datad => \GRFPC0.EX.RREG.RES\(13));
\GRFPC0_MEM_RREG_RES_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_14__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(14),
datad => \GRFPC0.EX.RREG.RES\(14));
\GRFPC0_FP_PIPELINE_DBGDATA_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(1),
dataf => \GRFPC0.R.FSR.CEXC\(1),
datae => N_450,
datad => N_451,
datac => N_717,
datab => N_653);
\GRFPC0_OP1_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19016\,
dataf => \GRFPU0.GRFPU_X0.N_21442_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(33));
\GRFPC0_OP1_2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19082\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(33),
datad => \GRFPC0.MEM.RREG.RES\(33));
\GRFPC0_OP1_1_RNIT62E3_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(33),
dataf => \GRFPC0.N_19345\,
datae => \GRFPC0.N_19016\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19082\);
\GRFPC0_MEM_RREG_RES_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_18__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(18),
datad => \GRFPC0.EX.RREG.RES\(18));
\GRFPC0_MEM_RREG_RES_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_19__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(19),
datad => \GRFPC0.EX.RREG.RES\(19));
\GRFPC0_OP2_I_M2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(54),
dataf => \GRFPC0.N_24008\,
datae => \GRFPC0.N_23993\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_23994\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP1_I_M2_4_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_23989\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_674,
datad => N_738);
\GRFPC0_OP1_I_M2_5_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_23990\,
dataf => \GRFPC0.RFA2.RS1SEL\(1),
datae => \GRFPC0.EX.RREG.RES\(54),
datad => \GRFPC0.WR.RREG.RES\(54));
\GRFPC0_OP1_I_M2_1_RNITO97_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(54),
dataf => \GRFPC0.N_24010\,
datae => \GRFPC0.N_23989\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_23990\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_54__G2\,
dataf => \GRFPU0.GRFPU_X0.N_67_I_0\,
datae => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datad => \GRFPC0.EX.RREG.RES\(54));
\GRFPC0_FP_PIPELINE_DBGDATA_4_I_M2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(22),
dataf => \FPI.NONSTD\,
datae => N_450,
datad => N_451,
datac => N_738,
datab => N_674);
\GRFPC0_FP_PIPELINE_WRDATA_3_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(22),
dataf => \GRFPC0.DIV.RESULT\(22),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(22),
datab => \FPO.RES\(22));
\GRFPC0_WRDATA_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(22),
dataf => N_478,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.N_24006\,
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(22));
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0ffffff00")
port map (
combout => \GRFPC0.N_18399\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
datad => \GRFPC0.R.FSR.AEXC\(0),
datac => \GRFPC0.DIV.EXCT\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_I_M2_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.N_24006\,
dataf => \GRFPC0.DIV.RESULT\(54),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(54),
datab => \GRFPU0.GRFPU_X0.N_67_I_0\);
\GRFPC0_MEM_RREG_RES_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_22__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(22),
datad => \GRFPC0.EX.RREG.RES\(22));
\GRFPC0_OP2_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19742\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(56),
datad => \GRFPC0.WR.RREG.RES\(56));
\GRFPC0_FP_PIPELINE_DBGDATA_4_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(24),
dataf => \GRFPC0.R.FSR.TEM\(1),
datae => N_450,
datad => N_451,
datac => N_740,
datab => N_676);
\GRFPC0_FP_PIPELINE_WRDATA_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
dataf => \GRFPC0.DIV.RESULT\(56),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(56),
datab => \GRFPU0.GRFPU_X0.N_21438_I_0\);
\GRFPC0_MEM_RREG_RES_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_56__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21438_I_0\,
datad => \GRFPC0.EX.RREG.RES\(56));
\GRFPC0_FP_PIPELINE_WRDATA_3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(27),
dataf => \GRFPC0.DIV.RESULT\(27),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(27),
datab => \FPO.RES\(27));
\GRFPC0_WRDATA_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(27),
dataf => N_483,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(27));
\GRFPC0_MEM_RREG_RES_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_27__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(27),
datad => \GRFPC0.EX.RREG.RES\(27));
\GRFPC0_FP_PIPELINE_WRDATA_3_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
dataf => \GRFPC0.DIV.RESULT\(32),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(32),
datab => \FPO.RES\(32));
\GRFPC0_OP1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(32),
dataf => \GRFPC0.N_19344\,
datae => \GRFPC0.N_19015\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19081\);
\GRFPC0_OP1_2_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19081\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(32),
datad => \GRFPC0.MEM.RREG.RES\(32));
\GRFPC0_OP1_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19015\,
dataf => \FPO.RES\(32),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(32));
\GRFPC0_MEM_RREG_RES_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_0__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(0),
datad => \GRFPC0.EX.RREG.RES\(0));
\GRFPC0_MEM_RREG_RES_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_32__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(32),
datad => \GRFPC0.EX.RREG.RES\(32));
\GRFPU0_GRFPU_X0_UN38_EXP_M_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(57),
dataf => \GRFPC0.N_19874\,
datae => \GRFPC0.N_19808\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19743\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_UN38_EXP_M_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(61),
dataf => \GRFPC0.N_19878\,
datae => \GRFPC0.N_19812\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19747\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19747\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(61),
datad => \GRFPC0.WR.RREG.RES\(61));
\GRFPC0_FP_PIPELINE_WRDATA_3_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
dataf => \GRFPC0.DIV.RESULT\(61),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(61),
datab => \GRFPU0.GRFPU_X0.N_21425_I_0\);
\GRFPC0_OP1_4_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19241\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_681,
datad => N_745);
\GRFPC0_OP1_3_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19176\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(61),
datad => \GRFPC0.WR.RREG.RES\(61));
\GRFPC0_OP1_3_RNI1R3L1_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(61),
dataf => \GRFPC0.N_19307\,
datae => \GRFPC0.N_19241\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19176\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_61__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21425_I_0\,
datad => \GRFPC0.EX.RREG.RES\(61));
\GRFPC0_FP_PIPELINE_WRDATA_3_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(5),
dataf => \GRFPC0.DIV.RESULT\(5),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(5),
datab => \FPO.RES\(5));
\GRFPC0_WRDATA_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(5),
dataf => N_461,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(5));
\GRFPC0_FP_PIPELINE_DBGDATA_4_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(29),
dataf => N_450,
datae => N_451,
datad => N_745,
datac => N_681);
\GRFPC0_FP_PIPELINE_DBGDATA_4_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(5),
dataf => \GRFPC0.R.FSR.AEXC\(0),
datae => N_450,
datad => N_451,
datac => N_721,
datab => N_657);
\GRFPC0_FP_PIPELINE_WRDATA_3_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
dataf => \GRFPC0.DIV.RESULT\(37),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(37),
datab => \GRFPU0.GRFPU_X0.N_21440_I_0\);
\GRFPC0_OP1_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19020\,
dataf => \GRFPU0.GRFPU_X0.N_21440_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(37));
\GRFPC0_OP1_2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19086\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(37),
datad => \GRFPC0.MEM.RREG.RES\(37));
\GRFPC0_OP1_1_RNI9N3E3_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(37),
dataf => \GRFPC0.N_19349\,
datae => \GRFPC0.N_19020\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19086\);
\GRFPC0_MEM_RREG_RES_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_37__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21440_I_0\,
datad => \GRFPC0.EX.RREG.RES\(37));
\GRFPC0_FP_PIPELINE_WRDATA_3_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
dataf => \GRFPC0.DIV.RESULT\(44),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(44),
datab => \GRFPU0.GRFPU_X0.N_21431_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(12),
dataf => \GRFPC0.DIV.RESULT\(12),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(12),
datab => \FPO.RES\(12));
\GRFPC0_WRDATA_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(12),
dataf => N_468,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(12));
\GRFPC0_OP1_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19027\,
dataf => \GRFPU0.GRFPU_X0.N_21431_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(44));
\GRFPC0_OP1_2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19093\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(44),
datad => \GRFPC0.MEM.RREG.RES\(44));
\GRFPC0_OP1_1_RNI3J2E3_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(44),
dataf => \GRFPC0.N_19356\,
datae => \GRFPC0.N_19027\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19093\);
\GRFPC0_MEM_RREG_RES_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_44__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21431_I_0\,
datad => \GRFPC0.EX.RREG.RES\(44));
\GRFPC0_FP_PIPELINE_DBGDATA_4_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(12),
dataf => N_450,
datae => N_451,
datad => N_728,
datac => N_664);
\GRFPC0_FP_PIPELINE_DBGDATA_4_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(14),
dataf => \GRFPC0.R.FSR.FTT\(0),
datae => N_450,
datad => N_451,
datac => N_730,
datab => N_666);
\GRFPC0_FP_PIPELINE_WRDATA_3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
dataf => \GRFPC0.DIV.RESULT\(46),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPU0.GRFPU_X0.N_21428_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(14),
dataf => \GRFPC0.DIV.RESULT\(14),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(14),
datab => \FPO.RES\(14));
\GRFPC0_WRDATA_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(14),
dataf => N_470,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(14));
\GRFPC0_OP1_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19029\,
dataf => \GRFPU0.GRFPU_X0.N_21428_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(46));
\GRFPC0_OP1_2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19095\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(46),
datad => \GRFPC0.MEM.RREG.RES\(46));
\GRFPC0_OP1_1_RNI9B3E3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(46),
dataf => \GRFPC0.N_19358\,
datae => \GRFPC0.N_19029\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19095\);
\GRFPC0_MEM_RREG_RES_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_46__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21428_I_0\,
datad => \GRFPC0.EX.RREG.RES\(46));
\GRFPC0_RFA2_RS1SEL_RNIVDMT1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.OP1_SN_N_6\,
dataf => \GRFPC0.RFA2.RS1SEL\(6),
datae => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_FP_PIPELINE_DBGDATA_4_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(15),
dataf => \GRFPC0.R.FSR.FTT\(1),
datae => N_450,
datad => N_451,
datac => N_731,
datab => N_667);
\GRFPC0_OP1_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19030\,
dataf => \GRFPU0.GRFPU_X0.N_63_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(47));
\GRFPC0_OP1_2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19096\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(47),
datad => \GRFPC0.MEM.RREG.RES\(47));
\GRFPC0_OP1_1_RNICN3E3_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(47),
dataf => \GRFPC0.N_19359\,
datae => \GRFPC0.N_19030\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19096\);
\GRFPC0_MEM_RREG_RES_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_47__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_63_I_0\,
datad => \GRFPC0.EX.RREG.RES\(47));
\GRFPC0_OP1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(42),
dataf => \GRFPC0.N_19288\,
datae => \GRFPC0.N_19222\,
datad => \GRFPC0.OP1_SN_N_9\,
datac => \GRFPC0.N_19157\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19157\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(42),
datad => \GRFPC0.WR.RREG.RES\(42));
\GRFPC0_OP1_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19031\,
dataf => \GRFPU0.GRFPU_X0.N_21444_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(48));
\GRFPC0_OP1_2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19097\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(48),
datad => \GRFPC0.MEM.RREG.RES\(48));
\GRFPC0_OP1_1_RNIF34E3_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(48),
dataf => \GRFPC0.N_19360\,
datae => \GRFPC0.N_19031\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19097\);
\GRFPC0_MEM_RREG_RES_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_48__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21444_I_0\,
datad => \GRFPC0.EX.RREG.RES\(48));
\GRFPC0_R_FSR_FTT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00cfc00f00")
port map (
combout => N_30470,
dataf => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.FSR.FTT\(2),
datac => N_63,
datab => N_61);
\GRFPC0_FP_PIPELINE_DBGDATA_4_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(17),
dataf => N_450,
datae => N_451,
datad => N_733,
datac => N_669);
\GRFPC0_FP_PIPELINE_WRDATA_3_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
dataf => \GRFPC0.DIV.RESULT\(50),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(50),
datab => \GRFPU0.GRFPU_X0.N_21436_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(18),
dataf => \GRFPC0.DIV.RESULT\(18),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(18),
datab => \FPO.RES\(18));
\GRFPC0_WRDATA_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(18),
dataf => N_474,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(18));
\GRFPC0_OP1_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19033\,
dataf => \GRFPU0.GRFPU_X0.N_21436_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(50));
\GRFPC0_OP1_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19099\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(50),
datad => \GRFPC0.MEM.RREG.RES\(50));
\GRFPC0_OP1_1_RNIQ21E3_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(50),
dataf => \GRFPC0.N_19362\,
datae => \GRFPC0.N_19033\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19099\);
\GRFPC0_MEM_RREG_RES_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_50__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21436_I_0\,
datad => \GRFPC0.EX.RREG.RES\(50));
\GRFPC0_FP_PIPELINE_DBGDATA_4_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00f0f0")
port map (
combout => CPO_DBG_DATAZ(18),
dataf => N_450,
datae => N_451,
datad => N_734,
datac => N_670);
\GRFPC0_OP2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(51),
dataf => \GRFPC0.N_19868\,
datae => \GRFPC0.N_19802\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19737\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_FP_PIPELINE_WRDATA_3_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
dataf => \GRFPC0.DIV.RESULT\(51),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(51),
datab => \GRFPU0.GRFPU_X0.N_21432_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(19),
dataf => \GRFPC0.DIV.RESULT\(19),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(19),
datab => \FPO.RES\(19));
\GRFPC0_WRDATA_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(19),
dataf => N_475,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(19));
\GRFPC0_OP1_4_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19231\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_671,
datad => N_735);
\GRFPC0_OP1_3_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19166\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(51),
datad => \GRFPC0.WR.RREG.RES\(51));
\GRFPC0_OP1_3_RNIUQ3L1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(51),
dataf => \GRFPC0.N_19297\,
datae => \GRFPC0.N_19231\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19166\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_51__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21432_I_0\,
datad => \GRFPC0.EX.RREG.RES\(51));
\GRFPC0_FP_PIPELINE_DBGDATA_4_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(19),
dataf => N_450,
datae => N_451,
datad => N_735,
datac => N_671);
\GRFPC0_OP2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(52),
dataf => \GRFPC0.N_19869\,
datae => \GRFPC0.N_19803\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19738\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_OP2_3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19738\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(52),
datad => \GRFPC0.WR.RREG.RES\(52));
\GRFPC0_OP1_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19035\,
dataf => \GRFPU0.GRFPU_X0.N_21426_I_0\,
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(52));
\GRFPC0_OP1_2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19101\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(52),
datad => \GRFPC0.MEM.RREG.RES\(52));
\GRFPC0_OP1_1_RNI0R1E3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(52),
dataf => \GRFPC0.N_19364\,
datae => \GRFPC0.N_19035\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_0\,
datab => \GRFPC0.N_19101\);
\GRFPC0_MEM_RREG_RES_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_52__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21426_I_0\,
datad => \GRFPC0.EX.RREG.RES\(52));
\GRFPC0_FP_PIPELINE_DBGDATA_4_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(20),
dataf => N_450,
datae => N_451,
datad => N_736,
datac => N_672);
\GRFPC0_OP2_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(53),
dataf => \GRFPC0.N_19870\,
datae => \GRFPC0.N_19804\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19739\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_OP2_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19739\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(53),
datad => \GRFPC0.WR.RREG.RES\(53));
\GRFPC0_FP_PIPELINE_WRDATA_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
dataf => \GRFPC0.DIV.RESULT\(53),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(53),
datab => \GRFPU0.GRFPU_X0.N_21437_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(21),
dataf => \GRFPC0.DIV.RESULT\(21),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(21),
datab => \FPO.RES\(21));
\GRFPC0_WRDATA_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(21),
dataf => N_477,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(21));
\GRFPC0_OP1_4_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19233\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_673,
datad => N_737);
\GRFPC0_OP1_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19168\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(53),
datad => \GRFPC0.WR.RREG.RES\(53));
\GRFPC0_OP1_3_RNI4J4L1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(53),
dataf => \GRFPC0.N_19299\,
datae => \GRFPC0.N_19233\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19168\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_21__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(21),
datad => \GRFPC0.EX.RREG.RES\(21));
\GRFPC0_MEM_RREG_RES_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_53__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21437_I_0\,
datad => \GRFPC0.EX.RREG.RES\(53));
\GRFPC0_FP_PIPELINE_DBGDATA_4_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(21),
dataf => N_450,
datae => N_451,
datad => N_737,
datac => N_673);
\GRFPC0_FP_PIPELINE_DBGDATA_4_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(25),
dataf => \GRFPC0.R.FSR.TEM\(2),
datae => N_450,
datad => N_451,
datac => N_741,
datab => N_677);
\GRFPC0_FP_PIPELINE_WRDATA_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
dataf => \GRFPC0.DIV.RESULT\(57),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(57),
datab => \GRFPU0.GRFPU_X0.N_21433_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(25),
dataf => \GRFPC0.DIV.RESULT\(25),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(25),
datab => \FPO.RES\(25));
\GRFPC0_WRDATA_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(25),
dataf => N_481,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(25));
\GRFPC0_OP1_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19172\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(57),
datad => \GRFPC0.WR.RREG.RES\(57));
\GRFPC0_OP1_3_RNIG36L1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(57),
dataf => \GRFPC0.N_19303\,
datae => \GRFPC0.N_19237\,
datad => \GRFPC0.OP1_SN_N_9_1\,
datac => \GRFPC0.N_19172\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_MEM_RREG_RES_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_57__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21433_I_0\,
datad => \GRFPC0.EX.RREG.RES\(57));
\GRFPC0_OP2_I_M2_5_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_23994\,
dataf => \GRFPC0.RFA2.RS2SEL\(1),
datae => \GRFPC0.EX.RREG.RES\(54),
datad => \GRFPC0.WR.RREG.RES\(54));
\GRFPC0_FP_PIPELINE_WRDATA_3_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
dataf => \GRFPC0.DIV.RESULT\(35),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(35),
datab => \GRFPU0.GRFPU_X0.N_19990_I_0\);
\GRFPC0_MEM_RREG_RES_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_35__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19990_I_0\,
datad => \GRFPC0.EX.RREG.RES\(35));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.WR2.RREG.RESV_1_0\,
datad => \GRFPC0.WR2.RREG.EXCT\(3));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNIJ2AO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fff000000f00")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_4__G0\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datad => \GRFPC0.FPR.RDY\,
datac => N_63);
\GRFPC0_FP_PIPELINE_DBGDATA_4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(4),
dataf => \GRFPC0.R.FSR.CEXC\(4),
datae => N_450,
datad => N_451,
datac => N_720,
datab => N_656);
\GRFPC0_MEM_RREG_RES_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_4__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(4),
datad => \GRFPC0.EX.RREG.RES\(4));
GRFPC0_VWR2_RREG_RESV_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FPR.RDY\,
datad => N_63);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2\(1),
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SS0\,
datad => \GRFPC0.WR2.RREG.RES\(1),
datac => \GRFPC0.WR2.RREG.RES\(11),
datab => \FPO.CC\(1),
dataa => N_467);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffccc00000ccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1\(1),
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2\(1),
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S4_1\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datab => \GRFPC0.R.FSR.FCC\(1));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2\(0),
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SS0\,
datad => \GRFPC0.WR2.RREG.RES\(0),
datac => \GRFPC0.WR2.RREG.RES\(10),
datab => \FPO.CC\(0),
dataa => N_466);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffccc00000ccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1\(0),
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2\(0),
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M2S4_1\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datab => \GRFPC0.R.FSR.FCC\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
dataf => \GRFPC0.DIV.RESULT\(43),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(43),
datab => \GRFPU0.GRFPU_X0.N_21427_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(11),
dataf => \GRFPC0.DIV.RESULT\(11),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datab => \FPO.RES\(11));
\GRFPC0_WRDATA_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(11),
dataf => N_467,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(11));
\GRFPC0_FP_PIPELINE_WRDATA_3_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
dataf => \GRFPC0.DIV.RESULT\(42),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(42),
datab => \FPO.RES\(42));
\GRFPC0_FP_PIPELINE_WRDATA_3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(10),
dataf => \GRFPC0.DIV.RESULT\(10),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datab => \FPO.RES\(10));
\GRFPC0_WRDATA_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(10),
dataf => N_466,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(10));
\GRFPC0_FP_PIPELINE_DBGDATA_4_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(10),
dataf => \GRFPC0.R.FSR.FCC\(0),
datae => N_450,
datad => N_451,
datac => N_726,
datab => N_662);
\GRFPC0_MEM_RREG_RES_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_11__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(11),
datad => \GRFPC0.EX.RREG.RES\(11));
\GRFPC0_FP_PIPELINE_WRDATA_3_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
dataf => \GRFPC0.DIV.RESULT\(47),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(47),
datab => \GRFPU0.GRFPU_X0.N_63_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(15),
dataf => \GRFPC0.DIV.RESULT\(15),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(15),
datab => \FPO.RES\(15));
\GRFPC0_WRDATA_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(15),
dataf => N_471,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(15));
\GRFPC0_MEM_RREG_RES_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_15__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(15),
datad => \GRFPC0.EX.RREG.RES\(15));
\GRFPC0_FP_PIPELINE_WRDATA_3_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
dataf => \GRFPC0.DIV.RESULT\(48),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(48),
datab => \GRFPU0.GRFPU_X0.N_21444_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(16),
dataf => \GRFPC0.DIV.RESULT\(16),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(16),
datab => \FPO.RES\(16));
\GRFPC0_WRDATA_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(16),
dataf => N_472,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(16));
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(0),
dataf => \GRFPC0.R.FSR.CEXC\(0),
datae => N_450,
datad => N_451,
datac => N_716,
datab => N_652);
\GRFPC0_FP_PIPELINE_DBGDATA_4_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(16),
dataf => \GRFPC0.R.FSR.FTT\(2),
datae => N_450,
datad => N_451,
datac => N_732,
datab => N_668);
\GRFPC0_MEM_RREG_RES_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_16__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(16),
datad => \GRFPC0.EX.RREG.RES\(16));
\GRFPC0_OP2_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19743\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(57),
datad => \GRFPC0.WR.RREG.RES\(57));
\GRFPC0_MEM_RREG_EXCT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_2__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.EXC\(2),
datad => \GRFPC0.EX.RREG.EXCT\(2));
\GRFPC0_MEM_RREG_EXCT_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_3__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => \GRFPC0.EX.RREG.EXCT\(3));
\GRFPC0_MEM_RREG_RES_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_25__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(25),
datad => \GRFPC0.EX.RREG.RES\(25));
\GRFPU0_GRFPU_X0_COMB_VEXC_5_IV_0_0_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.IOF\,
datad => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datac => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(3));
\GRFPC0_FP_PIPELINE_DBGDATA_4_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(7),
dataf => \GRFPC0.R.FSR.AEXC\(2),
datae => N_450,
datad => N_451,
datac => N_723,
datab => N_659);
\GRFPC0_MEM_RREG_RES_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_31__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(31),
datad => \GRFPC0.EX.RREG.RES\(31));
\GRFPC0_FP_PIPELINE_WRADDR_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(3),
dataf => N_455,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003333f0fff0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(1),
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datae => \GRFPC0.DIV.RD\(0),
datad => \GRFPC0.WREN_2_SQMUXA_0\,
datac => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\,
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000300")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
dataf => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(1),
datae => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.WREN_2_SQMUXA_0\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33330000f0fff0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(0),
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datae => \GRFPC0.DIV.RD\(0),
datad => \GRFPC0.WREN_2_SQMUXA_0\,
datac => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\,
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
dataf => \GRFPC0.FP_PIPELINE.WREN_17_IV_0\(0),
datae => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.WREN_2_SQMUXA_0\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.FP_PIPELINE.UN25_HOLDN_I_1\);
GRFPC0_FP_PIPELINE_UN45_WREN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN45_WREN\,
dataf => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
datae => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1));
GRFPC0_VEX_RREG_RES_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0c0c0c0f3")
port map (
combout => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
datae => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.ID_1\,
datac => \GRFPC0.RFA.ST\,
datab => N_63);
GRFPC0_FP_PIPELINE_0_IS_LDF_UN5_OP_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.IS_LDF.UN5_OP\,
dataf => \GRFPC0.N_23479\,
datae => N_134,
datad => N_133);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_21275\,
dataf => N_38025,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datad => \GRFPC0.N_21253\,
datac => \GRFPC0.N_21252\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_602_0_IV_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc0300")
port map (
combout => \GRFPC0.N_23185\,
dataf => \GRFPC0.N_21275\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\,
datab => \GRFPC0.N_21046_I\);
\GRFPC0_FP_PIPELINE_WRDATA_3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(28),
dataf => \GRFPC0.DIV.RESULT\(28),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(28),
datab => \FPO.RES\(28));
\GRFPC0_WRDATA_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(28),
dataf => N_484,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(28));
\GRFPC0_MEM_RREG_RES_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_28__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(28),
datad => \GRFPC0.EX.RREG.RES\(28));
\GRFPC0_MEM_RREG_RES_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_60__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21434_I_0\,
datad => \GRFPC0.EX.RREG.RES\(60));
\GRFPC0_OP1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(39),
dataf => \GRFPC0.N_19351\,
datae => \GRFPC0.N_19022\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19088\);
\GRFPC0_OP1_2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19088\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(39),
datad => \GRFPC0.MEM.RREG.RES\(39));
\GRFPC0_OP1_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19022\,
dataf => \FPO.RES\(39),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(39));
\GRFPC0_FP_PIPELINE_WRDATA_3_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
dataf => \GRFPC0.DIV.RESULT\(39),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(39),
datab => \FPO.RES\(39));
\GRFPC0_FP_PIPELINE_WRDATA_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(7),
dataf => \GRFPC0.DIV.RESULT\(7),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(7),
datab => \FPO.RES\(7));
\GRFPC0_MEM_RREG_RES_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_7__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(7),
datad => \GRFPC0.EX.RREG.RES\(7));
\GRFPC0_MEM_RREG_RES_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_39__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(39),
datad => \GRFPC0.EX.RREG.RES\(39));
\GRFPC0_OP1_4_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19229\,
dataf => \GRFPC0.OP1_SN_N_5\,
datae => N_669,
datad => N_733);
\GRFPC0_FP_PIPELINE_WRDATA_3_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
dataf => \GRFPC0.DIV.RESULT\(52),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(52),
datab => \GRFPU0.GRFPU_X0.N_21426_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(20),
dataf => \GRFPC0.DIV.RESULT\(20),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(20),
datab => \FPO.RES\(20));
\GRFPC0_WRDATA_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(20),
dataf => N_476,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(20));
\GRFPC0_MEM_RREG_RES_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_17__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(17),
datad => \GRFPC0.EX.RREG.RES\(17));
\GRFPC0_MEM_RREG_RES_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_20__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(20),
datad => \GRFPC0.EX.RREG.RES\(20));
GRFPC0_WREN_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.WREN_0_SQMUXA\,
dataf => N_448,
datae => N_449,
datad => N_450);
\GRFPC0_FP_PIPELINE_WRADDR_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(1),
dataf => N_453,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.WR2.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.DIV.RD\(0));
GRFPC0_FP_PIPELINE_1_DIVEN10_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c030")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
dataf => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\,
datae => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
datad => RFI2_RD2ADDRZ(3),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.DIV.RD_0\(4));
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
dataf => RFI2_RD2ADDRZ(0),
datae => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_24706\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.N_24642\);
GRFPC0_FP_PIPELINE_UN17_SHARE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000ff00f000")
port map (
combout => \GRFPC0.N_16912_I_0_I1_I_3\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.VCNT\(0),
datac => \GRFPC0.WR.CTRL.CCWR\);
\GRFPC0_FP_PIPELINE_WRDATA_3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(23),
dataf => \GRFPC0.DIV.RESULT\(23),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(23),
datab => \FPO.RES\(23));
\GRFPC0_MEM_RREG_RES_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_23__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(23),
datad => \GRFPC0.EX.RREG.RES\(23));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_28_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000ff030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_299\,
dataf => \GRFPU0.GRFPU_X0.N_9745\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_O2_I_A2_RNIKPMKF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccc00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9745\,
dataf => \GRFPU0.GRFPU_X0.N_221\,
datae => \GRFPU0.GRFPU_X0.N_380\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(0),
datab => \FPI.NONSTD\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN317_REGDEPX_1_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN317_REGDEPX_1\,
dataf => N_104,
datae => N_105);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23069\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23417_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.INST_1\(17));
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffcc00cf00")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612\(0),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_608\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.N_17842_1\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD\);
GRFPC0_RFA_RS1D_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0000000")
port map (
combout => \GRFPC0.RFA.RS1D_0_0_G1\,
dataf => \GRFPC0.UN1_RDWR_3_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
datac => \GRFPC0.INST\(31));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_A3_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_0_0\,
dataf => \GRFPC0.INST\(12),
datae => \GRFPC0.INST\(9),
datad => \GRFPC0.INST\(13));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_A3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000300000")
port map (
combout => \GRFPC0.N_20674\,
dataf => \GRFPC0.N_20683\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_0_0\,
datad => \GRFPC0.N_20668\,
datac => \GRFPC0.INST\(5),
datab => \GRFPC0.INST\(6));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_A3_1_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RDWR_I_A4_I_A3_1\,
dataf => \GRFPC0.INST\(11),
datae => \GRFPC0.INST\(10),
datad => \GRFPC0.INST\(13));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\,
dataf => \FPO.IDOUT\(4),
datae => \FPO.IDOUT\(0),
datad => \GRFPC0.EX.CTRL.ID\(0),
datac => \GRFPC0.EX.CTRL.ID\(4));
GRFPC0_FP_PIPELINE_0_REGDEP66: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303333333333333")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66\,
dataf => \GRFPU0.GRFPU_X0.N_19283_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_4\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\,
datab => \GRFPC0.EX.RREG.RESV\);
GRFPC0_FP_PIPELINE_0_EXEN2_I_S_4_RNILLS41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0ffff0ff")
port map (
combout => \GRFPC0.N_21694\,
dataf => \GRFPC0.N_21695_3\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_WRENX2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_1\,
dataf => \GRFPC0.N_23610\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_REGDEP14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000400020001000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP14\,
dataf => \GRFPC0.N_23610\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.UN1_WRENX2_2_4_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datab => \GRFPC0.DIV.RD\(2),
dataa => \GRFPC0.DIV.RD_0\(4));
GRFPC0_RFA2_RS1DEP_RNO_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33370000cccd0000")
port map (
combout => N_100350_TZ,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP14\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DIV.RD\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.RDD\,
dataa => \GRFPC0.DIV.VALID\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
dataf => \FPO.IDOUT\(1),
datae => \FPO.IDOUT\(2),
datad => \GRFPC0.WR2.CTRL.ID\(1),
datac => \GRFPC0.WR2.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_0_REGDEP18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f030f030f03")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
dataf => \GRFPU0.GRFPU_X0.N_19283_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_5\,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datac => \GRFPC0.WR2.RREG.RESV_0\,
datab => \GRFPC0.FPR.RDY\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000c")
port map (
combout => \GRFPC0.N_25161\,
dataf => \GRFPC0.N_237\,
datae => \GRFPC0.N_23865\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff33ff0f0000")
port map (
combout => \GRFPC0.N_23735\,
dataf => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2960_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_A2_1_0\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\,
datac => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_199_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_25208\,
dataf => \GRFPC0.N_24910\,
datae => N_50724,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datab => \GRFPC0.V.STDATA_14_M_5\(0));
\GRFPC0_FP_PIPELINE_15_STDEP_608_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffbf00c00080")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_608\(0),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_604\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.N_131_2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A3_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24656\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.N_24735_2\,
dataf => \GRFPC0.N_24656\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_24655_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datab => \GRFPC0.N_24719\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.N_25655\,
dataf => \GRFPC0.N_25685\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_I_A2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_8_1\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_I_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_I_A2_0\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.PC\(28),
dataa => \GRFPC0.MEM.CTRL.PC\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(28),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.FIFO.PC_1\(28),
datab => \GRFPC0.FIFO.PC_0\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28),
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(28),
dataa => \GRFPC0.EX.CTRL.PC\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(28),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.PC\(28),
dataa => \GRFPC0.DIV.INST\(28));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaafff0ccaa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(3),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(3),
dataa => \GRFPC0.WR2.CTRL.PC\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.WR.CTRL.PC\(2),
dataa => \GRFPC0.MEM.CTRL.PC\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(2),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.FIFO.PC_1\(2),
datab => \GRFPC0.FIFO.PC_0\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2),
datac => N_50724,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(2),
dataa => \GRFPC0.EX.CTRL.PC\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0aaffccf0aa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(2),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.DIV.INST\(2),
dataa => \GRFPC0.WR2.CTRL.PC\(2));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25713\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23588\,
datad => \GRFPC0.N_25565\,
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_25710\,
dataf => \GRFPC0.N_25713\,
datae => \GRFPC0.N_25724\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.N_25722_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_24965\,
dataf => \GRFPC0.N_24952\,
datae => \GRFPC0.N_24950\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_9_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff0c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\(0),
dataf => \GRFPC0.N_24881\,
datae => \GRFPC0.N_24133\,
datad => \GRFPC0.N_24135\,
datac => \GRFPC0.V.STDATA_14_M_5\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\);
\GRFPU0_GRFPU_X0_UN38_EXP_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(55),
dataf => \GRFPC0.N_19872\,
datae => \GRFPC0.N_19806\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19741\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19741\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(55),
datad => \GRFPC0.WR.RREG.RES\(55));
\GRFPC0_FP_PIPELINE_WRDATA_3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
dataf => \GRFPC0.DIV.RESULT\(55),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(55),
datab => \GRFPU0.GRFPU_X0.N_21423_I_0\);
\GRFPC0_MEM_RREG_RES_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_55__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21423_I_0\,
datad => \GRFPC0.EX.RREG.RES\(55));
\GRFPU0_GRFPU_X0_UN38_EXP_M_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(59),
dataf => \GRFPC0.N_19876\,
datae => \GRFPC0.N_19810\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19745\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19745\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(59),
datad => \GRFPC0.WR.RREG.RES\(59));
\GRFPC0_MEM_RREG_RES_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_59__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19903_I_0\,
datad => \GRFPC0.EX.RREG.RES\(59));
\GRFPC0_MEM_RREG_RES_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_33__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_21442_I_0\,
datad => \GRFPC0.EX.RREG.RES\(33));
\GRFPU0_GRFPU_X0_RES_1_6_0_1_O7_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21448\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_431\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_430\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_429\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_428\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_427\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPC0_OP2_3_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19737\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(51),
datad => \GRFPC0.WR.RREG.RES\(51));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_0_1\,
dataf => \FPI.FLOP\(6),
datae => \FPI.FLOP\(7),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000ff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_86\,
dataf => \FPI.FLOP_1\(1),
datae => \FPI.FLOP\(3),
datad => \FPI.FLOP\(2),
datac => \FPI.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000c00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_2\,
dataf => \FPI.FLOP_1\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(3),
datac => \FPI.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.N_223\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_88\,
dataf => \FPI.FLOP\(7),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0cc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_2\,
datae => \GRFPU0.GRFPU_X0.N_86\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_0_1\,
datac => \GRFPU0.GRFPU_X0.N_88\,
datab => \GRFPU0.GRFPU_X0.N_223\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_156\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_A2_1_0\,
datae => \GRFPU0.GRFPU_X0.N_83\,
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(4),
datab => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_2\,
datae => \GRFPU0.GRFPU_X0.N_156\,
datad => \GRFPU0.GRFPU_X0.N_218\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_80\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\,
datae => \GRFPU0.GRFPU_X0.N_157\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\,
datac => N_49622);
\GRFPC0_FP_PIPELINE_VFIFO_RD_3_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
dataf => N_49622_0,
datae => \GRFPC0.FIFO.RD\(0));
\GRFPC0_EX_CTRL_PC_RNO_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(22),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(22),
datad => \GRFPC0.FIFO.PC_1\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0cccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22),
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(22),
datab => \GRFPC0.EX.CTRL.PC\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(22),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(22),
datab => \GRFPC0.WR2.CTRL.PC\(22),
dataa => \GRFPC0.DIV.INST\(22));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(20),
datac => \GRFPC0.MEM.CTRL.INST\(20),
datab => \GRFPC0.WR.CTRL.PC\(20),
dataa => \GRFPC0.MEM.CTRL.PC\(20));
\GRFPC0_EX_CTRL_PC_RNO_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(20),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(20),
datad => \GRFPC0.FIFO.PC_1\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0cccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20),
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(20),
datab => \GRFPC0.EX.CTRL.PC\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(20),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(20),
datab => \GRFPC0.WR2.CTRL.PC\(20),
dataa => \GRFPC0.DIV.INST\(20));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(11),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(11),
datab => \GRFPC0.DIV.INST\(11),
dataa => \GRFPC0.WR2.CTRL.INST\(11));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_DIV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_V_FSR_AEXC_1_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fffff0f0")
port map (
combout => \GRFPC0.N_18401\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datad => \GRFPC0.DIV.EXCT\(2),
datac => \GRFPC0.R.FSR.AEXC\(2));
\GRFPC0_EX_RREG_EXCT_0_0_2__G3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc0000000f")
port map (
combout => \FPO.EXC\(2),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.IOF\,
datad => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datac => \GRFPU0.GRFPU_X0.ST4.MOF\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(2));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
dataf => \FPO.EXC\(2),
datae => \GRFPC0.WR2.RREG.RESV_1_0\,
datad => \GRFPC0.WR2.RREG.EXCT\(2));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(11),
datac => \GRFPC0.MEM.CTRL.INST\(11),
datab => \GRFPC0.WR.CTRL.PC\(11),
dataa => \GRFPC0.MEM.CTRL.PC\(11));
\GRFPC0_EX_CTRL_PC_RNO_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(11),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(11),
datad => \GRFPC0.FIFO.PC_1\(11));
\GRFPC0_FP_PIPELINE_15_STDEP_608_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffbfff40800080")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_608\(1),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_604\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.N_131_2\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffcc00fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612\(1),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_608\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.N_17842_1\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_INST_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(29),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => N_132);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25514\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_25565\,
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_10_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25518\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\(0),
datab => \GRFPC0.N_25664\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_7_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_24655_1\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A3_3_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_3_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00c0c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_3_0\(1),
datae => \GRFPC0.N_25058_1\,
datad => \GRFPC0.N_25834\,
datac => \GRFPC0.N_24655_1\,
datab => \GRFPC0.N_24719\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4785_REGDEPX2_2_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25365\,
dataf => \GRFPC0.WR2.CTRL.INST\(27),
datae => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(1),
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.N_25502\,
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(1),
datae => \GRFPC0.N_25755\,
datad => \GRFPC0.N_25365\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_5\(1),
dataf => \GRFPC0.N_25502\,
datae => \GRFPC0.N_25508\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_25757\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_A3_5_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_11_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff80ffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_11\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_8\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_9\(1),
datac => \GRFPC0.N_23708\,
datab => N_50724,
dataa => N_174890);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25538\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.V.STDATA_14\(17),
datad => N_174892,
datac => \GRFPC0.N_25549\,
datab => \GRFPC0.N_24493\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(1),
dataf => \GRFPC0.N_25538\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360_0_11\(1),
datad => \GRFPC0.N_24542_1\,
datac => \GRFPC0.N_24567\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_A2_4_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f00000000000")
port map (
combout => \GRFPC0.N_24226\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX2_305_0_A2_4_0_A3_0\(1),
datad => \GRFPC0.N_24252\,
datac => \FPI.FLOP_0\(1),
datab => \GRFPC0.N_25549\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(1),
dataf => \GRFPC0.N_24226\,
datae => \GRFPC0.N_24228\,
datad => \GRFPC0.N_25481\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_2\(1),
dataa => \GRFPC0.N_25436\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_310_0_A3_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25530\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.V.STDATA_14\(16),
datad => \GRFPC0.V.STDATA_14\(14),
datac => \GRFPC0.N_25549\,
datab => \GRFPC0.N_24079\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff40")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(1),
dataf => \GRFPC0.N_25527\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(1),
datad => \GRFPC0.N_25530\,
datac => \GRFPC0.N_24090\,
datab => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
dataa => \GRFPC0.N_24218\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_278_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_278\(1),
dataf => \GRFPC0.N_23649\,
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_3\(1),
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25304\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25361\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_2\(1),
dataf => \GRFPC0.N_25620\,
datae => \GRFPC0.N_25304\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0\(1),
datab => \GRFPC0.N_25664\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_5\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_2\(1),
datae => \GRFPC0.N_25303\,
datad => \GRFPC0.N_25674\,
datac => \GRFPC0.N_25677\,
datab => \GRFPC0.WR.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_0_0\(1),
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_1\(1),
dataf => \GRFPC0.N_25621\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_0_0\(1),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25303_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25306\,
dataf => \GRFPC0.N_25757\,
datae => \GRFPC0.N_260\,
datad => \GRFPC0.N_25350\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffa8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_8\(1),
datad => \GRFPC0.N_25618\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_O2_1\(1),
datab => \GRFPC0.N_25306\,
dataa => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3903_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3903_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3827_REGDEPX2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_0_A2_0\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_11_I_M2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPC0.N_24276\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_360\(1),
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\(1),
dataf => \GRFPC0.N_24030\,
datae => \GRFPC0.N_25458\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\,
datac => \GRFPC0.N_25457\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7047_REGDEPX2\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\(1),
datae => \GRFPC0.N_25451_2\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6990_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7019_REGDEPX2\,
datab => \GRFPC0.N_25175_1\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6180_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6180_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_A2_0\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_RNIOOQ21_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_5\,
dataf => \GRFPC0.N_25029\,
datae => \GRFPC0.N_23783\,
datad => \GRFPC0.N_25747_I\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25648_1\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_0_0\(1),
dataf => \GRFPC0.N_25755\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_0_1_RNIV3AP1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c000c000c00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_0\,
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415_0_A2_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.N_25164\,
datab => \GRFPC0.N_25674\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_0_A2_3_0_RNI19NL2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_4\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0_0\,
datae => \GRFPC0.N_185_1\,
datad => \GRFPC0.N_24554\,
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.EX.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_A2_0_RNIDQ273_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_9\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0_4\,
datae => \GRFPC0.N_25028\,
datad => \GRFPC0.N_24979_2\,
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.N_25813_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_3_RNI1HO31_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c0c0cff000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_11\,
dataf => \GRFPC0.N_25087\,
datae => \GRFPC0.N_25485\,
datad => \GRFPC0.N_25477\,
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24538\,
dataf => \GRFPC0.N_24538_2\,
datae => N_50724,
datad => N_50792,
datac => \GRFPC0.V.STDATA_14\(3),
datab => \GRFPC0.V.STDATA_14\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_1_RNI04CO9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4fffffff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0_15\,
dataf => \GRFPC0.N_24542_1\,
datae => \GRFPC0.N_24538\,
datad => \GRFPC0.D.LDLCK_0_0_27__G1_0_12\,
datac => \GRFPC0.D.LDLCK_0_0_27__G1_0_11\,
datab => \GRFPC0.N_23712\,
dataa => \GRFPC0.N_23662\);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6767_REGDEPX2_0_A2_0_0_I_O2_RNI4OSEC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_0\,
dataf => \GRFPC0.D.LDLCK_0_0_27__G1_0_15\,
datae => \GRFPC0.N_24483_I\,
datad => N_174892,
datac => \GRFPC0.N_24490\,
datab => \GRFPC0.N_24081\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0ccfc00f000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datae => \GRFPC0.N_25388\,
datad => \GRFPC0.N_25163\,
datac => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_0_0\(1),
datab => \GRFPC0.N_25090\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000030000000")
port map (
combout => \GRFPC0.N_23445\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_10\(1),
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.N_25308_2\,
datab => \GRFPC0.DIV.INST\(2));
\GRFPC0_INST_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPC0.INST\(28),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPC0.N_16961\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_0\(1),
dataf => \GRFPC0.N_24668\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datad => \GRFPC0.N_25309_1\,
datac => \GRFPC0.N_24278\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_1_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25308\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.N_25308_2\,
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_9\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_7\(1),
datae => \GRFPC0.N_25781\,
datad => \GRFPC0.N_25845\,
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.N_25854\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_11_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_11\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_9\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0_3\(1),
datad => \GRFPC0.N_25782\,
datac => \GRFPC0.N_25785\,
datab => \GRFPC0.N_25786_2\,
dataa => \GRFPC0.N_25786_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\(1),
dataf => \GRFPC0.N_25412\,
datae => \GRFPC0.N_25451_2\,
datad => \GRFPC0.N_25826_1\,
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.N_25156_2\,
dataf => \GRFPC0.N_25184\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datad => \GRFPC0.N_25163\,
datac => \GRFPC0.N_25234\,
datab => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1),
datae => \GRFPC0.N_25177\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1),
datab => \GRFPC0.N_25179\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_190_0_A2_2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_A2_0_1\(0),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2945_REGDEPX2_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2945_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(18),
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_O2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000c")
port map (
combout => \GRFPC0.N_24761\,
dataf => \GRFPC0.N_24845\,
datae => \GRFPC0.N_23865\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(1),
dataf => \GRFPC0.N_24767\,
datae => \GRFPC0.N_227\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_8\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datab => \GRFPC0.N_25433_1\,
dataa => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2945_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_0_0\(0),
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_1\(1),
dataf => \GRFPC0.N_25407\,
datae => \GRFPC0.N_23813_1\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_0_0\(0),
datac => \GRFPC0.N_25457\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2623_REGDEPX2\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_24973_2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1770_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_24938\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_12_0_A4_0\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24970\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_23741\,
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24930\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_4\(1),
dataf => \GRFPC0.N_24970\,
datae => \GRFPC0.N_24930\,
datad => \GRFPC0.N_24938\,
datac => \GRFPC0.N_25058_1\,
datab => \GRFPC0.N_24973_2\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115_0_A2_0_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1755_REGDEPX2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1755_REGDEPX2_0\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_3\(1),
dataf => \GRFPC0.N_24939\,
datae => \GRFPC0.N_24971\,
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A4_1_0\(1),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_0_11_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffeefffffffe")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_11\(1),
dataf => \GRFPC0.N_24910\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_8\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_4\(1),
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120_0_6\(1),
dataa => \GRFPC0.N_25175\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_24837\,
dataf => \GRFPC0.N_185_1\,
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A2_2_RNI40M22_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_6\,
dataf => \GRFPC0.D.LDLCK_0_0_5__G1_0_0\,
datae => \GRFPC0.N_24645\,
datad => \GRFPC0.N_25417\,
datac => \GRFPC0.N_24807\,
datab => \GRFPC0.N_24837\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_2_RNI60SS4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_11\,
dataf => \GRFPC0.D.LDLCK_0_0_5__G1_0_7\,
datae => \GRFPC0.D.LDLCK_0_0_5__G1_0_5\,
datad => \GRFPC0.D.LDLCK_0_0_5__G1_0_6\,
datac => \GRFPC0.N_25420\,
datab => \GRFPC0.N_25421\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_RNI2DPV5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2fff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0_14\,
dataf => \GRFPC0.N_24832\,
datae => \GRFPC0.N_24090\,
datad => \GRFPC0.D.LDLCK_0_0_5__G1_0_11\,
datac => \GRFPC0.N_25416\,
datab => \GRFPC0.N_23623\,
dataa => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A3_0_0\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPC0.N_16955\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
datac => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23812\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datae => \GRFPC0.N_25309_1\,
datad => \GRFPC0.N_25338\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_0\(1),
dataf => \GRFPC0.N_23812\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datad => \GRFPC0.N_23811_1\,
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_10_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_10\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_8\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_4\(1),
datad => \GRFPC0.N_23873_2\,
datac => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.N_252\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_6\(1),
dataf => \GRFPC0.N_25614\,
datae => \GRFPC0.N_23813\,
datad => \GRFPC0.N_25674\,
datac => \GRFPC0.N_25677\,
datab => \GRFPC0.WR.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_6\(1),
datae => \GRFPC0.N_23816_1\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_13_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffa8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_13\(1),
dataf => \GRFPC0.N_24517\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_10\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_9\(1),
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_1\(1),
datab => \GRFPC0.N_25617\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_35_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_35_0_A2_1\(1),
dataf => \GRFPC0.V.STDATA_14\(17),
datae => \GRFPC0.V.STDATA_14\(15),
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.V.STDATA_14\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_13\(1),
datae => \GRFPC0.N_221\,
datad => \GRFPC0.N_24483_I\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_35_0_A2_1\(1),
datab => N_174892);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_0_A4_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_1_1\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(28),
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_3_2\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20_0_A2_1_1\(0),
datab => \GRFPC0.N_25854\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN369_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_25639\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
datae => \GRFPC0.N_25759\,
datad => \GRFPC0.N_25755\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN253_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_10_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_10\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_1\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_8\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_2\(1),
datac => \GRFPC0.N_25426\,
datab => \GRFPC0.N_24979_2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_30_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffbaaaffff3000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_8_0_2\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_30_0_12\(1),
datad => \GRFPC0.N_24181\,
datac => \GRFPC0.N_24207\,
datab => \GRFPC0.V.STDATA_14\(17),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\);
\GRFPC0_D_LDLCK_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G3\,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX_268\(1),
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24030\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_24030_2\,
datad => \GRFPC0.N_25117\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_0\(1),
datae => \GRFPC0.N_25703_3\,
datad => \GRFPC0.N_24637\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A2_9_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_9_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fcf00000cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_9_0\(1),
datae => \GRFPC0.N_25164\,
datad => \GRFPC0.N_25367_I\,
datac => \GRFPC0.N_25433_1\,
datab => \GRFPC0.N_25786_1\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.N_25389\,
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_2\(1),
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_O2_0_1\(1),
datad => \GRFPC0.N_25087\,
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.N_24635\,
dataf => \GRFPC0.FP_PIPELINE.15.REGDEPX2_460_0_O2_0\(1),
datae => \GRFPC0.N_24712_2\,
datad => \GRFPC0.V.STDATA_14\(17),
datac => \FPI.FLOP\(6),
datab => \GRFPC0.N_25491\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_RNIRG2I5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030f0f0f030000")
port map (
combout => \GRFPC0.R.STATE_0_0_0__G2\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
datab => N_65);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(13),
datac => \GRFPC0.MEM.CTRL.INST\(13),
datab => \GRFPC0.WR.CTRL.PC\(13),
dataa => \GRFPC0.MEM.CTRL.PC\(13));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(14),
datac => \GRFPC0.WR.CTRL.INST\(14),
datab => \GRFPC0.WR.CTRL.PC\(14),
dataa => \GRFPC0.MEM.CTRL.PC\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(14),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.EX.CTRL.INST\(14),
datac => \GRFPC0.FIFO.PC_1\(14),
datab => \GRFPC0.FIFO.PC_0\(14));
\GRFPC0_R_STATE_0_RNIDBIE_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => N_50653_I,
dataf => \GRFPC0.R.STATE_189\(0),
datae => \GRFPC0.R.STATE_0\(1));
GRFPC0_FP_PIPELINE_UN27_PENDEXC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => N_50667_1,
dataf => \GRFPC0.R.STATE_2\(1),
datae => \GRFPC0.R.STATE_191\(0));
\GRFPC0_EX_CTRL_PC_RNO_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51943,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(8),
datad => \GRFPC0.FIFO.PC_1\(8));
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_0);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3797_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f222f00022220000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245_0_0\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_24090\,
datad => \GRFPC0.N_24087\,
datac => N_174890,
datab => \GRFPC0.N_23623\,
dataa => \GRFPC0.N_24095\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3768_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3768_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.N_25421\,
dataf => \GRFPC0.N_25451_2\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.N_24693\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_21_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21_1_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24649\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_24644\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0_5_1\(1),
datae => \GRFPC0.N_24693\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A3_2_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1));
GRFPC0_VMEM_RREG_RESV_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
dataf => \GRFPC0.N_65_0\,
datae => N_63);
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_0_RNIEPA5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => N_174807,
dataf => \GRFPC0.N_65_0\,
datae => N_63);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_24694\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_O2_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_O2_1_0\(1),
dataf => \GRFPC0.N_24694\,
datae => \GRFPC0.N_24113\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f03000000000")
port map (
combout => \GRFPC0.N_25724\,
dataf => \GRFPC0.N_25730\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.RDD_2\,
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25621\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_O2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
dataf => \GRFPC0.N_47\,
datae => \GRFPU0.GRFPU_X0.N_19283_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN302_REGDEPX2_2_0_A2_0_A2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN755_REGDEPX2_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_DIV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_DIV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
dataf => \FPO.IDOUT\(4),
datae => \FPO.IDOUT\(5),
datad => \GRFPC0.MEM.CTRL.ID\(4),
datac => \GRFPC0.MEM.CTRL.ID\(5));
GRFPC0_FP_PIPELINE_0_REGDEP50: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0333333333333333")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50\,
dataf => \GRFPU0.GRFPU_X0.N_19283_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\,
datab => \GRFPC0.MEM.RREG.RESV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_438\(0),
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_24850\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_23584\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\(0),
dataf => \GRFPC0.N_24822\,
datae => \GRFPC0.N_24850\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_3_0\(1),
datab => \GRFPC0.N_23587\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_O2_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00000000")
port map (
combout => \GRFPC0.N_25685\,
dataf => \GRFPC0.MEM.CTRL.INST\(28),
datae => \GRFPC0.MEM.CTRL.RDD\,
datad => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_O2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.N_24869\,
dataf => \GRFPC0.N_24841\,
datae => \GRFPC0.N_25695\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_424_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cff00ff0c0c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0_0\(0),
datae => \GRFPC0.N_23660\,
datad => \GRFPC0.V.STDATA_14_M_5\(0),
datac => \GRFPC0.N_23711_LI\,
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_424_0_A3_0\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_438_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_438\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\(0),
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\(0),
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_360_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3f0f000330000")
port map (
combout => \GRFPC0.N_25500\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.N_24637\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5136_REGDEPX2\,
datab => \GRFPC0.N_25694\);
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN80_REGDEPX_1_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0\(15),
datae => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_EX_CTRL_INST_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51096,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(13),
datab => N_185);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_1_RNIVTG2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_10175\,
dataf => \GRFPC0.N_21137_1\,
datae => N_61);
GRFPC0_FP_PIPELINE_VDIV_VALID2_0_RNIV1V0A: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000cc00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\,
dataf => \GRFPC0.N_21157\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datac => \GRFPC0.DIV.EXEC\,
datab => N_61);
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_O2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_I_O2_2_0\(0),
dataf => \GRFPC0.N_25452\,
datae => \GRFPC0.N_25758\,
datad => \GRFPC0.N_25223_2\,
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_1_RNI9JCR_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000000")
port map (
combout => \GRFPC0.N_21181\,
dataf => \GRFPC0.N_21137_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datad => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_2\,
dataf => \FPO.IDOUT\(5),
datae => \FPO.IDOUT\(3),
datad => \GRFPC0.DIV.ID\(3),
datac => \GRFPC0.DIV.ID\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(19),
datab => \GRFPC0.DIV.INST\(19),
dataa => \GRFPC0.WR2.CTRL.INST\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(19),
datac => \GRFPC0.MEM.CTRL.INST\(19),
datab => \GRFPC0.WR.CTRL.PC\(19),
dataa => \GRFPC0.MEM.CTRL.PC\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(19),
datac => \GRFPC0.V.STDATA_14\(19),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(19),
dataa => \GRFPC0.EX.CTRL.PC\(19));
\GRFPC0_EX_CTRL_PC_RNO_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(19),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(19),
datad => \GRFPC0.FIFO.PC_1\(19));
\GRFPC0_FP_PIPELINE_WRDATA_3_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
dataf => \GRFPC0.DIV.RESULT\(60),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(60),
datab => \GRFPU0.GRFPU_X0.N_21434_I_0\);
\GRFPC0_R_FSR_RD_0_0_0__G1_E\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.V.FSR.NONSTD_0_SQMUXA_1\,
dataf => N_448,
datae => N_449,
datad => N_450);
GRFPC0_FP_PIPELINE_UN1_CPI_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
dataf => N_274,
datae => N_273);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaf0ffccaaf000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(10),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.PC\(10),
datab => \GRFPC0.DIV.INST\(10),
dataa => \GRFPC0.WR2.CTRL.INST\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10),
datac => \FPI.FLOP\(5),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(10),
dataa => \GRFPC0.EX.CTRL.PC\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(10),
datac => \GRFPC0.MEM.CTRL.INST\(10),
datab => \GRFPC0.WR.CTRL.PC\(10),
dataa => \GRFPC0.MEM.CTRL.PC\(10));
\GRFPC0_EX_CTRL_PC_RNO_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_52015,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(10),
datad => \GRFPC0.FIFO.PC_1\(10));
GRFPC0_VEX_CTRL_PEND_0_SQMUXA_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ffffff")
port map (
combout => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0),
datad => N_64);
GRFPC0_VEX_CTRL_PEND_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c000000000000")
port map (
combout => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1\,
dataf => N_52020,
datae => \GRFPC0.VEX.CTRL.PEND_0_SQMUXA_1_0\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.EX.CTRL.CCWR\);
\GRFPC0_MEM_CTRL_VCNT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0));
\GRFPC0_MEM_CTRL_VCNT_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0));
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_3\,
dataf => \GRFPC0.WR.CTRL.INST\(22),
datae => \GRFPC0.WR.CTRL.INST\(31),
datad => \GRFPC0.WR.CTRL.INST\(24));
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_5\,
dataf => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_3\,
datae => \GRFPC0.WR.CTRL.INST\(20),
datad => \GRFPC0.WR.CTRL.INST\(23),
datac => \GRFPC0.WR.CTRL.INST\(30),
datab => \GRFPC0.WR.CTRL.INST\(21));
GRFPC0_VWR_CTRL_PEND_0_SQMUXA_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f0000000000")
port map (
combout => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_7\,
dataf => \GRFPC0.VWR.CTRL.PEND_0_SQMUXA_5\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.CCWR\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_64);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_338_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8888888")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_338\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_336_1\(0),
datae => \GRFPC0.N_24483_I\,
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_335_0_A2_1_0\(0),
datac => N_174891,
datab => \GRFPC0.EX.CTRL.RS1V\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10\(0));
GRFPC0_FP_PIPELINE_UN1_CPI_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_3\,
dataf => N_273,
datae => N_274);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225_0_A3_4_0\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(18),
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00c0c00000")
port map (
combout => \GRFPC0.N_25495_2\,
dataf => \GRFPC0.N_303\,
datae => \GRFPC0.N_24090\,
datad => \GRFPC0.N_25522_2\,
datac => \GRFPC0.N_23660\,
datab => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_A3_0_0\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24709\,
dataf => \GRFPC0.N_23588\,
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN3005_REGDEPX2_0_A2_0_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25092\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(2));
GRFPU0_GRFPU_X0_UN1_VALLOW_2_SQMUXA_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00cf")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VALLOW_2_SQMUXA_4\,
dataf => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6\,
datad => N_174933,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\);
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_3_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_66_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(20));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_1_RNIK6U01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccfc")
port map (
combout => \GRFPU0.GRFPU_X0.N_5188\,
dataf => \GRFPU0.GRFPU_X0.N_5192\,
datae => \GRFPU0.GRFPU_X0.N_5193\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\,
dataf => N_174933,
datae => \GRFPU0.GRFPU_X0.N_5188\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_66_2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_2_I_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_218\,
dataf => \FPI.FLOP\(7),
datae => \FPI.FLOP\(3),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_A2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_157\,
dataf => \GRFPU0.GRFPU_X0.N_218\,
datae => \GRFPU0.GRFPU_X0.N_76\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0));
GRFPU0_GRFPU_X0_VALLOW_4_SQMUXA_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_4_SQMUXA_6\,
dataf => N_174933,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(15));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_3_RNI24SEE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \FPO.ALLOW\(1),
dataf => \FPO.ALLOW_1\(1),
datae => N_61);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000fff0")
port map (
combout => \GRFPC0.N_21036\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_21044\,
datad => \GRFPC0.N_21043\,
datac => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_562_0_IV_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00cc00cf")
port map (
combout => \GRFPC0.N_23290_I\,
dataf => \GRFPC0.FP_PIPELINE.13.STDEP_528\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.N_21039\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_13_STDEP_528_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff0c0c000c")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_528\(0),
dataf => \GRFPC0.FP_PIPELINE.13.STDEP_524\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.N_17935\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_21076_1\);
GRFPC0_FP_PIPELINE_1_REGDEP146: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEP146_2\,
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_1_REGDEP172_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc00000f330000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP172_0\,
dataf => RFI2_RD2ADDRZ(1),
datae => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.RFA.RD\(2));
GRFPC0_UN1_REGDEP173_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc0ffff0330ffff")
port map (
combout => \GRFPC0.UN1_REGDEP173\,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP172\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.N_23661\,
datab => \GRFPC0.EX.CTRL.RDD_0_0_G1\);
GRFPC0_UN1_EX_CTRL_RDD_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP156\,
dataf => \GRFPC0.RFA.RS2D_0_0_G1\,
datae => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_1_REGDEP160: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
datad => RFI2_RD2ADDRZ(0),
datac => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_REGDEP132_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132_0\,
dataf => RFI2_RD2ADDRZ(0),
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccccf0f0ccfc")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_452_3_0_0\(1),
dataf => \GRFPC0.N_21468\,
datae => \GRFPC0.N_21459\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.N_131_1\,
datab => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O3_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.N_21474\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_M3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_20668\,
dataf => \GRFPC0.INST\(10),
datae => \GRFPC0.INST\(8),
datad => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_A4_I_X3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.N_20667_I\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(6));
GRFPC0_FP_PIPELINE_UN1_VRFA_ST: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => N_63,
datad => \GRFPC0.RFA.ST_0\);
GRFPC0_FP_PIPELINE_IS_RS1V_TMP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RS1V.TMP\,
dataf => \GRFPC0.INST\(19),
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(11));
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\,
dataf => \GRFPC0.WR2.CTRL.INST\(22),
datae => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.WR2.CTRL.INST\(24),
datac => \GRFPC0.WR2.CTRL.INST\(23));
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_3\,
dataf => \GRFPC0.WR2.CTRL.INST\(31),
datae => \GRFPC0.WR2.CTRL.INST\(30),
datad => \GRFPC0.WR2.CTRL.INST\(20));
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_4\,
datad => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1_3\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\);
GRFPC0_WR2_CTRL_PEND_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000cccc00c0")
port map (
combout => \GRFPC0.WR2.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA_1\,
datad => \GRFPC0.VWR2.CTRL.PEND_1_SQMUXA_2\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => N_52981_2);
\GRFPC0_FIFO_WR_RNIHMOD3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00ff0000ff")
port map (
combout => N_49468_I,
dataf => N_49622_0,
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.WR\(0));
GRFPC0_CCWR_0_SQMUXA_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.CCWR_0_SQMUXA_2_0\,
dataf => N_127,
datae => N_133,
datad => N_134,
datac => N_125,
datab => N_123);
GRFPC0_FP_PIPELINE_CNTX14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => \GRFPC0.FP_PIPELINE.CNTX14\,
dataf => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_0\(0));
GRFPC0_VFIFO_WR_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.VFIFO.WR_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.CNTX14\,
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
datad => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_1_UN87_PENDEXC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
dataf => \GRFPC0.FIFO.VCNT_1\(0),
datae => \GRFPC0.FIFO.VCNT_1\(2),
datad => \GRFPC0.FIFO.VCNT_1\(1));
GRFPC0_FP_PIPELINE_0_UN78_PENDEXC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
dataf => \GRFPC0.FIFO.VCNT_0\(0),
datae => \GRFPC0.FIFO.VCNT_0\(2),
datad => \GRFPC0.FIFO.VCNT_0\(1));
\GRFPC0_UN1_PENDEXC_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccc0fffffff3")
port map (
combout => N_124905,
dataf => N_52020,
datae => \GRFPC0.VFIFO.WR_1_SQMUXA\,
datad => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
datac => \GRFPC0.VFIFO.WR_0_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD10\);
\GRFPC0_EX_CTRL_INST_RNIIR895_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51232,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => N_189);
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_4\,
dataf => \GRFPC0.WR.CTRL.PEND\,
datae => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.WR2.EXC\);
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_PEND_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.PEND_3\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.CTRL.PEND\,
datad => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.MEM.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_UN4_CNTX_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.VCNT_0\(2),
datad => \GRFPC0.FIFO.VCNT_1\(2));
\GRFPC0_FP_PIPELINE_UN4_CNTX_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.VCNT_0\(1),
datad => \GRFPC0.FIFO.VCNT_1\(1));
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f3fc")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
dataf => \GRFPC0.FP_PIPELINE.UN4_CNTX\(2),
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.FIFO.WR_0\(0));
GRFPC0_FP_PIPELINE_UN42_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
dataf => \GRFPC0.WR2.CTRL.SEQERR_0\,
datae => \GRFPC0.WR2.CNT\(0),
datad => \GRFPC0.WR2.CNT\(1),
datac => \GRFPC0.WR2.CTRL.STDFQ\,
datab => N_63);
GRFPC0_VDIV_EXC_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.VDIV.EXC_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.UN42_HOLDN\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\);
GRFPC0_FP_PIPELINE_UN50_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN50_HOLDN\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.CTRL.PEND\);
GRFPC0_FIFO_INC_5_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.FIFO_INC_5_SQMUXA\,
dataf => \GRFPC0.VDIV.EXC_1_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN50_HOLDN\,
datad => \GRFPC0.WR.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.MEM.CTRL.PEND\);
GRFPC0_FP_PIPELINE_UN3_FIFO_CLR_RNINGIO6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FIFO.RD_0_0_0__G3\,
dataf => N_52020_1,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD_3\(0),
datad => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => N_52981_2);
GRFPC0_UN1_STDDEP_0_SQMUXA_100: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff300030003000")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_100\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.UN1_STDEP682\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.N_131\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_21052\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21039\,
datad => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0ff00ffc0")
port map (
combout => \GRFPC0.N_21133\,
dataf => \GRFPC0.N_175\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_O3_0\(1),
datac => \GRFPC0.N_193\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_12_3_0_A2_4_0\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O3_RNI7V111_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffff00cc00fc")
port map (
combout => N_100346_TZ,
dataf => \GRFPC0.N_21133\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datad => N_174897,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_0\);
\GRFPC0_D_STLCK_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ff0cff00")
port map (
combout => \GRFPC0.N_23257\,
dataf => \GRFPC0.FP_PIPELINE.14.STDEP_572\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_O3_1_1\(1),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\,
datab => \GRFPC0.N_21046_I\);
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000030000000")
port map (
combout => \GRFPC0.N_22603\,
dataf => \GRFPC0.N_22622\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
datac => \GRFPC0.N_22626\,
datab => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_3_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_22619_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_5_REGDEPX_102_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33333f33")
port map (
combout => \GRFPC0.N_22538\,
dataf => \GRFPC0.N_22582\,
datae => \GRFPC0.N_22603\,
datad => \GRFPC0.N_22560\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.FP_PIPELINE.FIFOV2\);
\GRFPC0_OP1_3_RNIAB5L1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(55),
dataf => \GRFPC0.N_19301\,
datae => \GRFPC0.N_19235\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19170\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19170\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(55),
datad => \GRFPC0.WR.RREG.RES\(55));
\GRFPC0_OP1_3_RNIDN5L1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP1\(56),
dataf => \GRFPC0.N_19302\,
datae => \GRFPC0.N_19236\,
datad => \GRFPC0.OP1_SN_N_9_0\,
datac => \GRFPC0.N_19171\,
datab => \GRFPC0.RFA2.RS1SEL_0\(7));
\GRFPC0_OP1_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19171\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(56),
datad => \GRFPC0.WR.RREG.RES\(56));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__N_5\,
dataf => \GRFPU0.GRFPU_X0.N_20304\,
datae => \GRFPU0.GRFPU_X0.N_20282_I_0_I3_I_1\,
datad => \FPI.OP2\(54),
datac => \GRFPU0.GRFPU_X0.N_80\,
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(6),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__N_5\,
datae => \GRFPU0.GRFPU_X0.N_221\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__G2_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_2_0_0_A2_1_4\,
datab => \GRFPU0.GRFPU_X0.N_343_3\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__G2_1\,
dataf => \FPI.OP2\(54),
datae => \GRFPU0.GRFPU_X0.N_20313_I\,
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(53),
datab => \FPI.OP2\(51));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_6__N_5\,
dataf => \GRFPU0.GRFPU_X0.N_20304\,
datae => \FPI.OP2\(54),
datad => \GRFPU0.GRFPU_X0.N_80\,
datac => \FPI.FLOP\(1));
\GRFPC0_OP2_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19575\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(21));
\GRFPC0_OP2_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19641\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(21),
datad => \GRFPC0.MEM.RREG.RES\(21));
\GRFPC0_OP2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(21),
dataf => \GRFPC0.N_19575\,
datae => \GRFPC0.N_19904\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19641\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_25\,
dataf => \FPI.OP2\(16),
datae => \FPI.OP2\(12),
datad => \FPI.OP2\(21),
datac => \FPI.OP2\(20));
\GRFPC0_OP2_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19578\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(24));
\GRFPC0_OP2_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19644\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(24),
datad => \GRFPC0.MEM.RREG.RES\(24));
\GRFPC0_OP2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(24),
dataf => \GRFPC0.N_19578\,
datae => \GRFPC0.N_19907\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19644\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_23\,
dataf => \FPI.OP2\(4),
datae => \FPI.OP2\(5),
datad => \FPI.OP2\(19),
datac => \FPI.OP2\(24));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_30\,
dataf => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_23\,
datae => \FPI.OP2\(7),
datad => \FPI.OP2\(26),
datac => \FPI.OP2\(25),
datab => \FPI.OP2\(29));
\GRFPC0_OP2_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19577\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(23));
\GRFPC0_OP2_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19643\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(23),
datad => \GRFPC0.MEM.RREG.RES\(23));
\GRFPC0_OP2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(23),
dataf => \GRFPC0.N_19577\,
datae => \GRFPC0.N_19906\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19643\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_21\,
dataf => \FPI.OP2\(3),
datae => \FPI.OP2\(10),
datad => \FPI.OP2\(17),
datac => \FPI.OP2\(23));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_29\,
dataf => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_21\,
datae => \FPI.OP2\(6),
datad => \FPI.OP2\(14),
datac => \FPI.OP2\(8),
datab => \FPI.OP2\(18));
GRFPU0_GRFPU_X0_FLTYPE_0_SQMUXA_10_I_A2_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_20\,
dataf => \FPI.OP2\(1),
datae => \FPI.OP2\(28),
datad => \FPI.OP2\(27),
datac => \FPI.OP2\(30));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_10_0_A2_RNITNF9E: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000800000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_221\,
dataf => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_32\,
datae => \GRFPU0.GRFPU_X0.N_20299\,
datad => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_28\,
datac => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_30\,
datab => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_29\,
dataa => \GRFPU0.GRFPU_X0.FLTYPE_0_SQMUXA_10_I_A2_31\);
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0_0_A2_1_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_343_3\,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_125_I\,
dataf => \FPI.OP2\(53),
datae => \FPI.OP1\(53));
GRFPU0_GRFPU_X0_UN28_EXP_ANC3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_36304,
dataf => \FPI.OP2\(54),
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(53));
GRFPU0_GRFPU_X0_UN28_EXP_SUM3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_EXP\(3),
dataf => \FPI.OP2\(54),
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(53));
GRFPU0_GRFPU_X0_UN3_EXP_ANC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19778_1\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53));
GRFPU0_GRFPU_X0_UN13_EXP_1_CO1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_388_3\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(56));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_20_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_20\(4),
dataf => \FPI.OP1\(31),
datae => \FPI.OP1\(3),
datad => \FPI.OP1\(7),
datac => \FPI.OP1\(27));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_18_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_18\(4),
dataf => \FPI.OP1\(14),
datae => \FPI.OP1\(10),
datad => \FPI.OP1\(18),
datac => \FPI.OP1\(22));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_22_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_22\(4),
dataf => \FPI.OP1\(4),
datae => \FPI.OP1\(0),
datad => \FPI.OP1\(24),
datac => \FPI.OP1\(28));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_A2_0_1_I_A2_27_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_27\(4),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_A2_0_1_I_A2_22\(4),
datae => \FPI.OP1\(16),
datad => \FPI.OP1\(12),
datac => \FPI.OP1\(8),
datab => \FPI.OP1\(20));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_335\,
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \FPI.OP1\(51));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f0f0f0f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20317\,
dataf => \FPI.OP2\(54),
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(53),
datac => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VST1_CCSEL_1_I_I_X2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_126_I\,
dataf => \FPI.OP2\(56),
datae => \FPI.OP1\(56));
\GRFPU0_GRFPU_X0_UN38_EXP_M_RNI1HO4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_8127_M_I_0_O2_0_4\,
dataf => \FPI.OP2\(56),
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(60),
datac => \FPI.OP2\(59));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20294\,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN1_EXP_17_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.UN1_EXP_17\,
dataf => \FPI.OP2\(34),
datae => \FPI.OP2\(36),
datad => \FPI.OP2\(35));
GRFPC0_VWR_RREG_RESV_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
datae => N_63);
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_0_RNIDKBF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => N_174806,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
datae => N_63);
GRFPC0_FP_PIPELINE_0_WR2SEL4_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2SEL4\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.WR2.RREG.RESV_0\,
datad => \GRFPC0.FPR.RDY\);
GRFPC0_FP_PIPELINE_1_WR2EN10_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10_1\,
dataf => RFI2_RD2ADDRZ(0),
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.WR2.CTRL.RD\(1),
datac => \GRFPC0.WR2.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_UN1_WR2_CTRL_RD_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD_2_3\,
dataf => RFI2_RD2ADDRZ(2),
datae => \GRFPC0.WR2.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_1_UN1_WR2_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2\(1),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.FCC_1_SS0\,
datad => \GRFPC0.WR.RREG.RES\(1),
datac => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.EX.RREG.RES\(1),
dataa => \GRFPC0.MEM.RREG.RES\(1));
\GRFPC0_FP_PIPELINE_FCC_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_CCZ(1),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M2\(1),
datae => N_58190,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPC0.R.FSR.FCC\(1));
\GRFPC0_FP_PIPELINE_FCC_1_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2\(0),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.FCC_1_SS0\,
datad => \GRFPC0.WR.RREG.RES\(0),
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.EX.RREG.RES\(0),
dataa => \GRFPC0.MEM.RREG.RES\(0));
\GRFPC0_FP_PIPELINE_FCC_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_CCZ(0),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M2\(0),
datae => N_58190,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPC0.R.FSR.FCC\(0));
GRFPC0_FCC_VALID_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FCC_VALID_0_SQMUXA_1\,
dataf => \GRFPC0.EX.CTRL.CCWR\,
datae => \GRFPC0.EX.RREG.RESV\);
\GRFPC0_FP_PIPELINE_WRDATA_3_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
dataf => \GRFPC0.DIV.RESULT\(33),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_2\,
datac => \GRFPC0.WR2.RREG.RES\(33),
datab => \GRFPU0.GRFPU_X0.N_21442_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(1),
dataf => \GRFPC0.DIV.RESULT\(1),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV_1\,
datac => \GRFPC0.WR2.RREG.RES\(1),
datab => \FPO.RES\(1));
\GRFPC0_WRDATA_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(1),
dataf => N_457,
datae => \GRFPC0.FP_PIPELINE.DEBUG_UNIT\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(1));
\GRFPC0_MEM_RREG_RES_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.MEM.RREG.RES_0_0_1__G2\,
dataf => \GRFPC0.VEX.RREG.RESV_0_SQMUXA\,
datae => \FPO.RES\(1),
datad => \GRFPC0.EX.RREG.RES\(1));
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_DIV: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\);
GRFPC0_FCC_VALID_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FCC_VALID_0_SQMUXA\,
dataf => \GRFPC0.WR.CTRL.CCWR\,
datae => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_M_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(2),
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.DIV.EXCT\(2));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_12_M_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(2),
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.WR2.RREG.EXCT\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
dataf => \GRFPC0.DIV.RESULT\(59),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(59),
datab => \GRFPU0.GRFPU_X0.N_19903_I_0\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_M_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(4),
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.DIV.EXCT\(4));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.DIV.EXCT\(2),
datac => \GRFPC0.DIV.EXCT\(0));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.DIV.EXCT\(1),
datac => \GRFPC0.DIV.EXCT\(3));
GRFPC0_FP_PIPELINE_V_STATE10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ea00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE10\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.DIV.EXCT\(4),
dataa => \GRFPC0.DIV.EXCT\(5));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR_0\,
datac => \GRFPC0.R.FSR.TEM\(0),
datab => \GRFPC0.DIV.EXCT\(0));
GRFPC0_V_FSR_NONSTD_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
dataf => \GRFPC0.WR2.CTRL.LD\,
datae => \GRFPC0.WR2.CTRL.AFSR\);
GRFPC0_V_FSR_CEXC_3_SQMUXA_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_V_FSR_CEXC_2_SQMUXA_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_2_SQMUXA_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datae => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_V_FSR_CEXC_4_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f000f000f")
port map (
combout => \GRFPC0.V.FSR.CEXC_4_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_UN1_V_FSR_FTT_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0cc00cc00")
port map (
combout => \GRFPC0.UN1_V.FSR.FTT_0_SQMUXA\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN11_FPEXC\,
datad => \GRFPC0.FP_PIPELINE.V.STATE10\,
datac => \GRFPC0.WR2.RREG.EXCT\(5),
datab => \GRFPC0.DIV.EXCT\(5));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_10_M_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_10_M\(3),
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.V.FSR.CEXC_1_SQMUXA_0\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPC0.DIV.EXCT\(3));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00cc00ccffcf")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\(1),
dataf => \GRFPC0.N_21178\,
datae => \GRFPC0.N_17905_1\,
datad => \GRFPC0.N_21170\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_A4_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_21205\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_21176\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.N_17905_1\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0f3")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92\(1),
dataf => \GRFPC0.N_21204\,
datae => \GRFPC0.N_21205\,
datad => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\(1),
datab => \GRFPC0.N_21176\);
\GRFPC0_FP_PIPELINE_2_STDEP_100_0_IV_I_O2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f3f00f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_O2_0\(0),
dataf => \GRFPC0.N_22899\,
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datad => \GRFPC0.N_21178\,
datac => \GRFPC0.N_21174\,
datab => \GRFPC0.N_17905_1\);
\GRFPC0_FP_PIPELINE_2_STDEP_100_0_IV_I_M4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc30fcfc3030")
port map (
combout => \GRFPC0.N_21193\,
dataf => N_38025,
datae => \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_O2_0\(0),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_100_0_IV_I_A2_1_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.N_21182\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ccc000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_A2_1\(0),
dataf => \GRFPC0.FP_PIPELINE.6.STDEP1018\,
datae => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datad => \GRFPC0.N_21704\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_20995\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_M2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc000f000c")
port map (
combout => \GRFPC0.N_23549\,
dataf => \GRFPC0.STDEP_2_SQMUXA_128\,
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.N_21704\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_23540\);
\GRFPC0_FP_PIPELINE_6_0_STDEP_265_0_IV_I_M4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfc3030fc30")
port map (
combout => \GRFPC0.N_21711\,
dataf => \GRFPC0.N_23550\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_A2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.N_21710\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000ffff0000")
port map (
combout => \GRFPC0.N_22806\,
dataf => \GRFPC0.N_22878\,
datae => \GRFPC0.N_22865\,
datad => \GRFPC0.FP_PIPELINE.VRFA.ST4\,
datac => N_134,
datab => N_133);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_110\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD\,
datad => N_198,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\,
datab => N_201);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c000c000c00")
port map (
combout => \GRFPC0.N_21789\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_21821\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22985\,
datab => \GRFPC0.STDDEP_0_SQMUXA_106_I_I_A2_0_A4_1\);
\GRFPC0_D_STLCK_RNO_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003000ffff33ff")
port map (
combout => \GRFPC0.N_22891\,
dataf => \GRFPC0.FP_PIPELINE.1.STDEP_48\(1),
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_D_STLCK_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffff00000030")
port map (
combout => \GRFPC0.N_22901\,
dataf => \GRFPC0.N_22891\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_21783\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_M4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcf00300000")
port map (
combout => \GRFPC0.N_22900\,
dataf => \GRFPC0.FP_PIPELINE.1.STDEP_48\(0),
datae => \GRFPC0.N_22899\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_1_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datab => \GRFPC0.N_20995\);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff00000f0f0")
port map (
combout => \GRFPC0.N_22902\,
dataf => \GRFPC0.N_22900\,
datae => \GRFPC0.N_21783\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_2\);
\GRFPC0_FP_PIPELINE_1_STDEP_48_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccff33030003")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_48\(0),
dataf => \GRFPC0.FP_PIPELINE.1.STDEP_44\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datad => \GRFPC0.N_17965\,
datac => \GRFPC0.N_21785\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_350_0_IV_I_A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfc00cf00cc")
port map (
combout => \GRFPC0.N_22225\,
dataf => \GRFPC0.N_132\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_20833\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
\GRFPC0_FP_PIPELINE_13_REGDEPX_248_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_248\(1),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(1),
datae => N_122,
datad => N_174895,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
datab => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN317_REGDEPX_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
dataf => N_106,
datae => N_107);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00c000ff00")
port map (
combout => \GRFPC0.N_22921\,
dataf => \GRFPC0.N_24409\,
datae => \GRFPC0.N_24360\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_21957_1\,
datab => \GRFPC0.FP_PIPELINE.1.0.REGDEPX_23_I_A2_1_0\(1));
GRFPC0_STDDEP_0_SQMUXA_19_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22896\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_267,
datad => N_268,
datac => N_270,
datab => N_269);
GRFPC0_FP_PIPELINE_1_STDEP_48_SEL1_I_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_17965\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.N_131_1\,
datac => \GRFPC0.WR.CTRL.RD\(4),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_1_STDEP_48_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff33ffcc030003")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_48\(1),
dataf => \GRFPC0.FP_PIPELINE.1.STDEP_44\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datad => \GRFPC0.N_17965\,
datac => \GRFPC0.N_21785\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0));
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A4_0_0_O3_I_A2_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.N_22782\,
dataf => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A4_0_0_O3_I_A2_I_0\,
datae => N_114,
datad => N_113,
datac => N_115,
datab => N_111);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_O3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_162_0_IV_I_O3_0\(0),
dataf => \GRFPC0.N_21016_1\,
datae => \GRFPC0.N_21012\,
datad => \GRFPC0.N_22782\,
datac => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3\(3),
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_FIFO_INST_0_RNIQ3RP_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(6),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_0\(11));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_1\(1),
datad => \GRFPC0.N_21254\,
datac => \GRFPC0.N_21252\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffffff")
port map (
combout => \GRFPC0.N_21254\,
dataf => \GRFPC0.N_17857_1\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4612_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_A2_2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_A2_2\(1),
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datad => \GRFPC0.N_21254\,
datac => \GRFPC0.N_21252\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0fff0f0f0f3f0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_572\(1),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_A2_2\(1),
datac => \GRFPC0.FP_PIPELINE.14.STDEP_572_3_0_2\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
GRFPC0_STDDEP_0_SQMUXA_7_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22807\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_268,
datad => N_267,
datac => N_270,
datab => N_269);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_I_O2_0_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_1\,
dataf => \GRFPC0.N_21181\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_0\,
datad => \GRFPC0.N_130\,
datac => \GRFPC0.N_21170\,
datab => \GRFPC0.N_21172\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_I_O2_0_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c0c0c0")
port map (
combout => \GRFPC0.N_21168_3\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_I_O2_0_3_1\,
datae => \GRFPC0.N_21137_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN676_DEP\,
datac => \GRFPC0.N_21170\,
datab => \GRFPC0.N_21172\);
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3199_REGDEPX_1_RNIQHAG1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23238\,
dataf => \GRFPC0.N_24606_2\,
datae => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datad => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_14_STDEP_576_SEL0_0_1_O2_0_O5_RNIHEBT1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPC0.N_23172\,
dataf => \GRFPC0.N_23238\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0_1\,
datad => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff000000000")
port map (
combout => \GRFPC0.N_180\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.N_22981\,
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_412_3_0_1\(0),
dataf => \GRFPC0.N_99\,
datae => \GRFPC0.N_62\,
datad => \GRFPC0.N_100\,
datac => \GRFPC0.N_59\,
datab => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O3_10_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ffffff30ff30")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_322_0_IV_I_O3_10_1\(0),
dataf => \GRFPC0.N_21612\,
datae => \GRFPC0.N_22354\,
datad => \GRFPC0.N_24408\,
datac => \GRFPC0.N_22455\,
datab => \GRFPC0.N_22324\);
\GRFPC0_FP_PIPELINE_0_STDEP_322_0_IV_I_O3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30ff3030")
port map (
combout => \GRFPC0.N_22421\,
dataf => \GRFPC0.N_22364\,
datae => \GRFPC0.N_21612\,
datad => \GRFPC0.N_22354\,
datac => \GRFPC0.N_22455\,
datab => \GRFPC0.N_22324\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"300030003000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_0\,
dataf => \GRFPC0.N_21336\,
datae => \GRFPC0.N_78_I_I_1\,
datad => \GRFPC0.RFA.LD_0\,
datac => \GRFPC0.N_21092\,
datab => N_201);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPC0.N_21443\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_6_2\,
datae => \GRFPC0.N_21553\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_3_0\,
datac => \GRFPC0.N_21420\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_O2_0_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000000")
port map (
combout => \GRFPC0.N_21414\,
dataf => \GRFPC0.N_21443\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_21416_2\,
dataf => \GRFPC0.N_21336\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_UN1_STDDEP_0_SQMUXA_103_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc0cfcfcfcfc")
port map (
combout => \GRFPC0.N_22192_I\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\,
datad => \GRFPC0.N_130\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datab => \GRFPC0.N_131\);
GRFPC0_EX_CTRL_LD_RNIA6811_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.N_23178\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_270,
datad => N_268,
datac => N_267,
datab => N_269);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030303cf000000cc")
port map (
combout => \GRFPC0.N_21629\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datad => \GRFPC0.N_21620\,
datac => \GRFPC0.N_21046_I\,
datab => \GRFPC0.N_21622\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN2972_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_21620\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f3f3f3f3f300")
port map (
combout => \GRFPC0.N_21669\,
dataf => \GRFPC0.N_21683\,
datae => \GRFPC0.N_21668\,
datad => \GRFPC0.N_21629\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_224_IV_0_O2_3_1\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN3026_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_9_STDEP_376_SEL1_I_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_17407\,
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.N_78_I_I\);
\GRFPC0_FP_PIPELINE_5_STDEP_238_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300030000000")
port map (
combout => \GRFPC0.N_22612\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_228\,
datad => \GRFPC0.N_24606_2\,
datac => \GRFPC0.N_22620\,
datab => \GRFPC0.FIFO.INST_0_0\(29));
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000f0ff")
port map (
combout => \GRFPC0.N_23474\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_20908\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003ffff0000ffff")
port map (
combout => \GRFPC0.N_23381\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datae => \GRFPC0.N_23398\,
datad => \GRFPC0.N_20908\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23420\,
dataf => \GRFPC0.N_22455\,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
datac => N_201,
datab => N_200);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132\(1),
dataf => \GRFPC0.N_21029\,
datae => N_38007,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_2\(1),
datac => \GRFPC0.N_20985\,
datab => \GRFPC0.N_20975\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_1\(1),
datad => \GRFPC0.N_20832\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332\(1),
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1\(1),
datae => \GRFPC0.N_21137\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_2\(1),
datac => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\);
GRFPC0_FP_PIPELINE_0_0_IS_RS1V_TMP_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => N_174896,
dataf => \GRFPC0.FIFO.INST_0_0\(19),
datae => \GRFPC0.FIFO.INST_0\(11),
datad => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_D_STLCK_RNO_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f00ffff0f0f")
port map (
combout => \GRFPC0.N_23268\,
dataf => \GRFPC0.FP_PIPELINE.13.STDEP_528\(1),
datae => \GRFPC0.N_21039\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_D_STLCK_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffff00000030")
port map (
combout => \GRFPC0.N_23291\,
dataf => \GRFPC0.N_23268\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_21043\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.N_78_I_I\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4063_REGDEPX_1_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24282\,
dataf => N_106,
datae => N_107);
GRFPC0_FP_PIPELINE_13_STDEP_536_SEL0_0_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_21043\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_62_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000030")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\(0),
dataf => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(0),
datae => \GRFPC0.N_22354\,
datad => \GRFPC0.N_22985\,
datac => \GRFPC0.N_22972_I\,
datab => \GRFPC0.FIFO.INST_1_0\(19));
\GRFPC0_FP_PIPELINE_3_REGDEPX_66_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX_66\(0),
dataf => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_64\(0),
datae => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(0),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22443\,
datab => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\);
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
dataf => \GRFPC0.FP_PIPELINE.4.1.REGDEPX_82\(0),
datae => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_78\(0),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22443\,
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1463_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22440\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => N_174901,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_1\(12));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3647_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => N_174900,
dataf => N_122,
datae => N_115,
datad => N_114);
\GRFPC0_D_STLCK_RNO_6_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_20965\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
datac => N_201,
datab => N_200);
\GRFPC0_FP_PIPELINE_0_STDEP_562_0_IV_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_23302\,
dataf => \GRFPC0.N_21055_I\,
datae => \GRFPC0.N_22354\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1_0\(29),
datab => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_FP_PIPELINE_13_REGDEPX_246_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffc000c0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX_246\(1),
dataf => \GRFPC0.FP_PIPELINE.13.1.REGDEPX_244\(1),
datae => \GRFPC0.N_25\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22310\,
datab => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_6_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_23310\,
dataf => \GRFPC0.N_168_1\,
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_1_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_21911_3\,
dataf => N_121,
datae => N_120);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4375_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
dataf => N_106,
datae => N_104,
datad => N_105,
datac => N_107);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_9_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(0),
dataf => N_109,
datae => N_103);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3736_REGDEPX_1_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24279\,
dataf => N_118,
datae => N_119);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2800_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2800_REGDEPX\,
dataf => N_118,
datae => N_121,
datad => N_120,
datac => N_119);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O2_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30ff00ff00ff00ff")
port map (
combout => \GRFPC0.N_21044\,
dataf => \GRFPC0.N_21055_I\,
datae => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datad => \GRFPC0.N_23282\,
datac => \GRFPC0.FIFO.INST_1_0\(29),
datab => \GRFPC0.FIFO.INST_1_0\(27));
\GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_DEP_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.N_22305\,
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4167_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.CHECK_DEP.UN1671_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4152_REGDEPX_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4152_REGDEPX_0_O2_0\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff3fff00ff")
port map (
combout => \GRFPC0.N_25\,
dataf => \GRFPC0.N_22600\,
datae => \GRFPC0.N_22565\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datab => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN300_REGDEPX_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
dataf => N_120,
datae => N_121);
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN366_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN366_DEP_1\,
dataf => \GRFPC0.WR.CTRL.RD\(2),
datae => \GRFPC0.WR.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_2_REGDEPX_48_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX_48\(1),
dataf => \GRFPC0.FP_PIPELINE.2.1.REGDEPX_46\(1),
datae => \GRFPC0.FP_PIPELINE.2.0.REGDEPX_42\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22310\,
datab => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\);
GRFPC0_FP_PIPELINE_2_1_CHECK_DEP_UN839_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_2_1_CHECK_DEP_UN824_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(16),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_UN703_REGDEPX_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPC0_FP_PIPELINE_2_0_REGDEPX_38_IV_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000c0f00000")
port map (
combout => \GRFPC0.N_24402\,
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN703_REGDEPX_0_A2_0\,
datac => \GRFPC0.N_24437\,
datab => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_UN735_REGDEPX_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_24438\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22985\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1_0\(29));
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_O3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22309\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_78_I_I_1\);
GRFPC0_STDDEP_0_SQMUXA_27_I_O5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_22719\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_268,
datad => N_267,
datac => N_270,
datab => N_269);
\GRFPC0_FP_PIPELINE_0_STDEP_162_0_IV_I_M5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f3f3f3f3f3c0")
port map (
combout => \GRFPC0.N_22709\,
dataf => \GRFPC0.N_21000\,
datae => \GRFPC0.N_22766\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_132_3_0_0_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.N_21016_1\);
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f00000003000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_164\(0),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_168_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffbf00c00080")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168\(0),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_164\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_4_STDEP_172_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffa000b000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172\(0),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_168\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_1\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1368_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(4),
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1350_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
dataf => \GRFPC0.WR.CTRL.RD\(2),
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc0000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_164\(1),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
\GRFPC0_FP_PIPELINE_4_STDEP_168_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffbfff40800080")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168\(1),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_164\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1350_DEP\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.N_131_1\);
\GRFPC0_FP_PIPELINE_4_STDEP_172_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bfffffffa000e000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172\(1),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_168\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(0),
dataa => \GRFPC0.MEM.CTRL.RDD_1\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1575_DEP_0_A4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1575_DEP_0_A4_0\,
dataf => N_267,
datae => N_270);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1561_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1561_DEP\,
dataf => N_201,
datae => N_199,
datad => N_198,
datac => N_200);
\GRFPC0_FP_PIPELINE_13_STDEP_524_0_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f00000003000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_524\(0),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1));
GRFPC0_FP_PIPELINE_13_STDEP_528_SEL1_I_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_17935\,
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4302_DEP\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.N_131_2\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4302_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4302_DEP\,
dataf => \GRFPC0.WR.CTRL.RD\(2),
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_1_STDEP_44_0_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00ccf0000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_44\(0),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\(1),
datac => \GRFPC0.FP_PIPELINE.1.STDEP178_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0));
\GRFPC0_FP_PIPELINE_1_STDEP_44_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000fc000000cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_44\(1),
dataf => \GRFPC0.N_21137\,
datae => N_174898,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_26\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datab => \GRFPC0.N_21146\);
GRFPC0_STDDEP_0_SQMUXA_24_0_A2_1_RNIJII71: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_3_0\(1),
dataf => \GRFPC0.RFA.LD\,
datae => \GRFPC0.RFA.RDD\,
datad => \GRFPC0.N_21092\,
datac => N_201,
datab => N_197);
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_2_RNIAST5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_21425\,
dataf => \GRFPC0.N_21336\,
datae => \GRFPC0.N_78_I_I_2\);
\GRFPC0_D_STLCK_RNO_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_1\(1),
dataf => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_11_0\(1),
datae => \GRFPC0.N_21423\,
datad => \GRFPC0.N_22607\,
datac => \GRFPC0.N_21425\,
datab => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_O2_3_0\(1));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_21336\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_5_STDEP_216_3_I_O2_2_RNIE9IA_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_21339\,
dataf => \GRFPC0.N_21336\,
datae => \GRFPC0.EX.CTRL.RD\(0),
datad => \GRFPC0.N_78_I_I_2\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4320_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\,
dataf => \GRFPC0.MEM.CTRL.RD\(3),
datae => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4320_DEP_1_RNI0B341: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_21361_1\,
dataf => \GRFPC0.N_20995\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1696_DEP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4284_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4284_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN243_DEP_2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN905_DEP_2\,
dataf => N_200,
datae => N_201);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN243_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
dataf => N_198,
datae => N_199);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN24_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN24_DEP\,
dataf => \GRFPC0.WR.CTRL.RD\(2),
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_STDDEP_0_SQMUXA_168_0_A2_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c0c0000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_168_0_A2_3_1\,
dataf => \GRFPC0.N_193\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.0.STDEP_8_SEL0_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff303ffff0303")
port map (
combout => \GRFPC0.N_21141\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_168_0_A2_3_1\,
datac => N_174897,
datab => \GRFPC0.MEM.CTRL.RDD_0\);
GRFPC0_STDDEP_0_SQMUXA_31_I_I_A3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_31_I_I_A3_0\,
dataf => N_268,
datae => N_267,
datad => N_270,
datac => N_269);
\GRFPC0_D_STLCK_RNO_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303ff03ff03ff03")
port map (
combout => \GRFPC0.N_22452_1\,
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.N_24606_2\,
datad => \GRFPC0.N_21775\,
datac => \GRFPC0.N_23044\,
datab => \GRFPC0.N_22448\);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1903_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1903_DEP\,
dataf => N_270,
datae => N_268,
datad => N_269,
datac => N_267);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2887_DEP_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\,
dataf => N_268,
datae => N_269);
\GRFPC0_FP_PIPELINE_0_STDEP_362_0_IV_I_A2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_20866\,
dataf => \GRFPC0.N_20852\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_267,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3215_DEP_2\,
datab => N_270);
GRFPC0_FP_PIPELINE_8_STDEP_336_SEL1_I_0_A2_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_20833\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_STDDEP_0_SQMUXA_67_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_328_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2680_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2680_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(4),
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_STDDEP_0_SQMUXA_155_1_I_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0f")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_8_STDEP_336_3_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_20884\,
dataf => N_38008,
datae => \GRFPC0.N_21137\,
datad => \GRFPC0.STDDEP_0_SQMUXA_155_1_I_O2_0\,
datac => \GRFPC0.N_20838\,
datab => \GRFPC0.N_20834\);
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3199_REGDEPX_1_RNIRT9P1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_112\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_EX_CTRL_LD_RNIA6811: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_162\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_268,
datad => N_267,
datac => N_270,
datab => N_269);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3646_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3646_DEP\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN5183_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5183_DEP\,
dataf => N_268,
datae => N_267,
datad => N_270,
datac => N_269);
GRFPC0_STDDEP_0_SQMUXA_11_0_A2_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_22448\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_270,
datad => N_268,
datac => N_267,
datab => N_269);
\GRFPC0_FP_PIPELINE_0_STDEP_522_0_IV_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_20852\,
dataf => \GRFPC0.N_78_I_I_2\,
datae => N_266);
GRFPC0_UN1_REGDEP47_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffff0ff0fffff0")
port map (
combout => \GRFPC0.UN1_REGDEP47_1\,
dataf => \GRFPC0.N_23611\,
datae => \GRFPC0.N_23610\,
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_REGDEP62: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0800020004000100")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
dataf => \GRFPC0.N_23610\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\,
datab => \GRFPC0.MEM.CTRL.RD\(4),
dataa => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_INST_RNIAQM6_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_10173_2\,
dataf => \GRFPC0.INST\(19),
datae => \GRFPC0.INST\(23),
datad => \GRFPC0.INST\(24),
datac => \GRFPC0.INST\(21));
GRFPC0_UN1_RDWR_3_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff000000")
port map (
combout => \GRFPC0.UN1_RDWR_3_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V5\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V7\,
datad => \GRFPC0.N_10173_2\);
\GRFPC0_INST_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(23),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(23),
datac => \GRFPC0.FIFO.INST_1\(23),
datab => N_126);
\GRFPC0_INST_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(24),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(24),
datac => \GRFPC0.FIFO.INST_1\(24),
datab => N_127);
\GRFPC0_INST_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(19),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_1\(19),
datab => N_122);
GRFPC0_FP_PIPELINE_RSDEC_RS1V18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V18\,
dataf => \GRFPC0.INST\(19),
datae => \GRFPC0.INST\(24),
datad => \GRFPC0.INST\(23),
datac => \GRFPC0.INST\(21));
\GRFPC0_INST_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(9),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(9),
datac => \GRFPC0.FIFO.INST_1\(9),
datab => N_112);
\GRFPC0_INST_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPC0.INST\(12),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_0\(12),
datab => N_115);
\GRFPC0_INST_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPC0.INST\(11),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_1\(11),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => N_114);
GRFPC0_FP_PIPELINE_RSDEC_RS1V13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V13_1_0\,
datae => \GRFPC0.INST\(11),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(10),
datab => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_0_EXEN2_I_S_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3ffff3ffcffffc")
port map (
combout => \GRFPC0.N_21695_3\,
dataf => \GRFPC0.N_23611\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.0.EXEN2_I_S_4_0\,
datac => \GRFPC0.EX.CTRL.RD\(4),
datab => \GRFPC0.EX.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_RS1_6_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6\(4),
dataf => \GRFPC0.N_18119\,
datae => \GRFPC0.RFA.RS1\(4),
datad => N_63);
GRFPC0_FP_PIPELINE_0_REGDEP90_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ca00350000ca0035")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP90_1\,
dataf => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datae => \GRFPC0.FP_PIPELINE.RS1_6\(4),
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datab => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
dataa => \GRFPC0.RFA.RD\(4));
GRFPC0_FP_PIPELINE_0_REGDEP90_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc0f3300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP90_2\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP90_1\,
datae => \GRFPC0.N_23610\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.RFA.RD\(2));
GRFPC0_FP_PIPELINE_UN108_HOLDN_RNIRTHA1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30fff03030f0f0")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
dataf => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datae => \GRFPC0.FP_PIPELINE.UN108_HOLDN\,
datad => \GRFPC0.RFA.WRITE_RD\,
datac => \GRFPC0.RFA.RDWR\,
datab => N_63);
GRFPC0_REGDEP_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff330000ff7b")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP74\,
datae => \GRFPC0.REGDEP_1_SQMUXA_1\,
datad => \GRFPC0.N_21695_3\,
datac => \GRFPC0.FP_PIPELINE.RS1_6\(0),
datab => \GRFPC0.EX.CTRL.RDWR\,
dataa => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_REGDEP_2_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff30ff00000000")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA_2\,
dataf => \GRFPC0.REGDEP_2_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD\,
datab => \GRFPC0.MEM.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_RS1_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6\(1),
dataf => \GRFPC0.N_18116\,
datae => \GRFPC0.RFA.RS1\(1),
datad => N_63);
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_23610\,
dataf => \GRFPC0.N_23609\,
datae => \GRFPC0.RFA.RS1\(2),
datad => N_63);
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_23611\,
dataf => \GRFPC0.N_23608\,
datae => \GRFPC0.RFA.RS1\(3),
datad => N_63);
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4240_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26));
GRFPC0_STDDEP_0_SQMUXA_88_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_88\,
dataf => \GRFPC0.N_21055_I\,
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4958_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
dataf => \GRFPC0.WR.CTRL.RD\(2),
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_UN1_STDDEP_0_SQMUXA_108: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff300030003000")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_108\,
dataf => \GRFPC0.N_21137\,
datae => \GRFPC0.UN1_STDEP2530\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4958_DEP\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.N_131\);
GRFPC0_FP_PIPELINE_0_REGDEP34: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.WR.RREG.RESV\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_26_I_S_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.N_23535_1\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(30),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(30),
datab => \GRFPC0.WR2.CTRL.PC\(30),
dataa => \GRFPC0.DIV.INST\(30));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f00ffffff00")
port map (
combout => \GRFPC0.N_21268\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.N_21252\,
datad => \GRFPC0.N_17857_1\,
datac => \GRFPC0.MEM.CTRL.RDD_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => \GRFPC0.N_21317\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
datae => \GRFPC0.N_17857_1\,
datad => \GRFPC0.N_131_0\);
\GRFPC0_FP_PIPELINE_14_STDEP_572_3_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_21252\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_14_STDEP_572_SEL1_I_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_17857_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30fff0ff3030f0f0")
port map (
combout => \GRFPC0.N_21319\,
dataf => \GRFPC0.N_21317\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datad => \GRFPC0.N_21252\,
datac => \GRFPC0.N_17857_1\,
datab => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(30),
datac => \GRFPC0.MEM.CTRL.INST\(30),
datab => \GRFPC0.WR.CTRL.PC\(30),
dataa => \GRFPC0.MEM.CTRL.PC\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(30),
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.FIFO.RD_4\(0),
datad => \GRFPC0.EX.CTRL.INST\(30),
datac => \GRFPC0.FIFO.PC_1\(30),
datab => \GRFPC0.FIFO.PC_0\(30));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0cccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30),
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(30),
datab => \GRFPC0.EX.CTRL.PC\(30));
\GRFPC0_EX_CTRL_INST_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51458,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(24),
datab => N_196);
\GRFPC0_EX_CTRL_INST_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50824,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(5),
datab => N_177);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24707\,
dataf => N_50724,
datae => N_50792,
datad => \GRFPC0.V.STDATA_14\(3),
datac => \GRFPC0.V.STDATA_14\(1),
datab => N_174890);
\GRFPC0_EX_CTRL_INST_RNIMV895_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51560,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => N_199);
\GRFPC0_EX_CTRL_INST_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51362,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(21),
datab => N_193);
\GRFPC0_EX_CTRL_INST_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51062,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(12),
datab => N_184);
\GRFPC0_EX_CTRL_INST_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50892,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(7),
datab => N_179);
\GRFPC0_EX_CTRL_INST_RNIMCN95_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50654,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(0),
datab => N_172);
GRFPC0_FP_PIPELINE_UN17_OP_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN17_OP_7\,
dataf => \GRFPC0.FP_PIPELINE.UN17_OP_7_1_0\,
datae => \FPI.FLOP_0\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(3));
GRFPC0_FP_PIPELINE_UN14_OP_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN14_OP_7\,
dataf => \GRFPC0.FP_PIPELINE.UN14_OP_7_1\,
datae => \FPI.FLOP_0\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(3));
\GRFPC0_FIFO_INST_0_RNI89R7_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(4),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(9),
datad => \GRFPC0.FIFO.INST_1\(9));
\GRFPC0_FIFO_INST_0_RNIUJRP_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(8),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(13),
datad => \GRFPC0.FIFO.INST_1\(13));
\GRFPC0_FIFO_INST_0_RNIP9UB_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(0),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(5),
datad => \GRFPC0.FIFO.INST_1\(5));
GRFPC0_FP_PIPELINE_UN15_OP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8080800000800000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN15_OP_1\,
dataf => \GRFPC0.FP_PIPELINE.UN11_OP_7_1\,
datae => \GRFPC0.FP_PIPELINE.UN8_OP_7_1_0\,
datad => \FPI.FLOP_0\(1),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(3),
dataa => \GRFPC0.FP_PIPELINE.UN8_OP_7_4\);
\GRFPC0_FIFO_INST_0_RNI0KRP_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51426,
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(23),
datad => \GRFPC0.FIFO.INST_1\(23));
\GRFPC0_FIFO_INST_0_RNIS3RP_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51364,
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(21),
datad => \GRFPC0.FIFO.INST_1\(21));
GRFPC0_DIVI_0_SQMUXA_4_M7_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc00008880")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
dataf => \GRFPC0.FP_PIPELINE.UN15_OP_1\,
datae => N_49622_0,
datad => \GRFPC0.FP_PIPELINE.UN17_OP_7\,
datac => \GRFPC0.FP_PIPELINE.UN14_OP_7\,
datab => \GRFPC0.DIVI_0_SQMUXA_4_M7_3\,
dataa => \FPI.FLOP\(5));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.WR2.RREG.EXCT\(0),
datac => \GRFPC0.WR2.RREG.EXCT\(3));
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_0_O7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\);
\GRFPC0_R_FSR_TEM_RNIGLQ52_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaa000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(2),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPU0.GRFPU_X0.ST4.IOF\,
datac => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datab => \GRFPU0.GRFPU_X0.ST4.MOF\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(2));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003330fff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_1\,
dataf => \GRFPC0.FPO_I_4_I_0\(69),
datae => \GRFPU0.GRFPU_X0.N_19274_I_0\,
datad => \GRFPU0.GRFPU_X0.N_8_I_0\,
datac => \GRFPC0.R.FSR.TEM\(1),
datab => \GRFPC0.R.FSR.TEM\(4));
GRFPC0_DIVI_0_SQMUXA_4_M2_E: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000150000003f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(2),
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_1\,
datac => \FPO.EXC\(0),
datab => \GRFPC0.R.FSR.TEM\(0),
dataa => \GRFPC0.R.FSR.TEM\(3));
GRFPC0_DIVI_0_SQMUXA_4_M7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1515150500000000")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_4\,
dataf => \GRFPC0.DIVI_0_SQMUXA_4_M7_5\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datad => \GRFPC0.N_24016\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
dataa => \GRFPC0.FP_PIPELINE.V.STATE10_0\);
\GRFPC0_FIFO_INST_0_RNIORQP_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(5),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(10),
datad => \GRFPC0.FIFO.INST_1\(10));
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffc0ffc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15_3_0\,
dataf => \FPI.FLOP_0\(1),
datae => \FPI.FLOP_0\(6),
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(3));
\GRFPC0_FIFO_INST_0_RNI69R7_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(3),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(8),
datad => \GRFPC0.FIFO.INST_0\(8));
\GRFPC0_FIFO_INST_0_RNI49R7_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(2),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(7),
datad => \GRFPC0.FIFO.INST_1\(7));
\GRFPC0_FIFO_INST_0_RNISBRP_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(7),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_0\(12));
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00cf0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\,
dataf => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15_3_0\,
datae => \FPI.FLOP_0\(1),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(3),
datab => \FPI.FLOP\(2));
\GRFPC0_FIFO_INST_0_RNIV3RP_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.V.STDATA_14\(31),
dataf => \GRFPC0.FIFO.RD_1_0\(0),
datae => \GRFPC0.FIFO.INST_0\(31),
datad => \GRFPC0.FIFO.INST_1\(31));
\GRFPC0_FIFO_INST_0_RNI2SRP_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51460,
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(24),
datad => \GRFPC0.FIFO.INST_1\(24));
\GRFPC0_EX_CTRL_INST_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50960,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(9),
datab => N_181);
\GRFPC0_EX_CTRL_INST_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50926,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(8),
datab => N_180);
\GRFPC0_EX_CTRL_INST_RNIIN895_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51492,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(25),
datab => N_197);
\GRFPC0_EX_CTRL_INST_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51300,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(19),
datab => N_191);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
dataf => \GRFPC0.EX.CTRL.RD\(4),
datae => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4841_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\,
dataf => N_199,
datae => N_200);
\GRFPC0_D_STLCK_RNO_5_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22483\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => N_198,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2217_DEP_1\,
datab => N_201);
\GRFPC0_FP_PIPELINE_0_STDEP_30_0_IV_I_O3_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_22899\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datae => \GRFPC0.MEM.CTRL.RDD_1\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033300000")
port map (
combout => \GRFPC0.N_23557\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datae => \GRFPC0.N_23544\,
datad => \GRFPC0.N_21704\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_23540\);
\GRFPC0_MEM_CTRL_RD_RNIBEDQ_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000ff")
port map (
combout => \GRFPC0.N_23544\,
dataf => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_21704\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(4),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccc30000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_A2_1\(1),
dataf => \GRFPC0.STDEP_2_SQMUXA_128\,
datae => \GRFPC0.N_23544\,
datad => \GRFPC0.N_21704\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_11_LI\(0),
datab => \GRFPC0.N_23540\);
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_26_I_I4_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.N_23571\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000c")
port map (
combout => \GRFPC0.N_22\,
dataf => \GRFPC0.N_23556\,
datae => \GRFPC0.N_23557\,
datad => \GRFPC0.N_22899\,
datac => \GRFPC0.FP_PIPELINE.6.STDEP_252_SEL0_1\,
datab => \GRFPC0.N_20995\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
dataf => \GRFPC0.RFA.RDD\,
datae => N_197);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3857_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
dataf => N_198,
datae => N_199);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_62\,
dataf => \GRFPC0.N_56\,
datae => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN44_DEP_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
dataf => \GRFPC0.MEM.CTRL.RD\(4),
datae => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FIFO_INST_1_RNIA4TP_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.V.STDATA_14\(19),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4864_REGDEPX_0_A3_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_22972_I\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL1_I_0_A2_I_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2_I_0\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.N_78_I_I\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21540\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(2),
datab => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2316_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf8f4f0f4f0f4f0")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292\(1),
dataf => N_38026,
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2316_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_1\,
datac => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_1\(1),
datab => \GRFPC0.N_21544\,
dataa => \GRFPC0.N_21549\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3682_DEP_1_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP_1\,
dataf => \GRFPC0.EX.CTRL.RD\(1),
datae => \GRFPC0.EX.CTRL.RD\(2));
\GRFPC0_D_STLCK_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffefff1eff0e")
port map (
combout => \GRFPC0.N_22418_1\,
dataf => \GRFPC0.FP_PIPELINE.7.STDEP_292\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_22373\,
datac => \GRFPC0.N_22289\,
datab => \GRFPC0.N_22288\,
dataa => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL1_I_0_A2_I_0\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_22146\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1448_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3664_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP_1\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1344_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1344_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(17));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1432_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26),
datad => \GRFPC0.FIFO.INST_1_0\(29),
datac => \GRFPC0.FIFO.INST_1_0\(27));
GRFPC0_STDDEP_0_SQMUXA_112_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_112_1\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0cfcfc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(0),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => N_50656_0,
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_INST_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPC0.INST\(27),
dataf => \GRFPC0.INST_SN_N_2\,
datae => \GRFPC0.INST_0\,
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_1\(27),
datab => N_130);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A3_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_A3_1_0\(0),
dataf => \GRFPC0.DIV.INST\(18),
datae => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4387_REGDEPX2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23822\,
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1698_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1698_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_24962\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3),
datac => \GRFPC0.V.STDATA_14\(3),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(3),
dataa => \GRFPC0.EX.CTRL.PC\(3));
\GRFPC0_EX_CTRL_PC_RNO_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_51763,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(3),
datad => \GRFPC0.FIFO.PC_1\(3));
GRFPC0_FP_PIPELINE_UN1_HOLDN: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => N_63);
GRFPC0_WR_CTRL_LD_RNI4IKR4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => N_50149,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => N_64);
GRFPC0_FP_PIPELINE_UN1_WR_CTRL_AFSR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR.CTRL.AFSR\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.WR.CTRL.AFSR\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.INST\(22),
datac => \GRFPC0.MEM.CTRL.INST\(22),
datab => \GRFPC0.WR.CTRL.PC\(22),
dataa => \GRFPC0.MEM.CTRL.PC\(22));
\GRFPC0_R_STATE_0_RNIDBIE_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => N_50358,
dataf => \GRFPC0.R.STATE_0\(1),
datae => \GRFPC0.R.STATE_189\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_3_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54545454fc74fcfc")
port map (
combout => \GRFPC0.N_21137_1\,
dataf => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
datad => N_52020_2,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datab => \GRFPC0.DIV.VALID_0\,
dataa => N_63);
GRFPC0_FP_PIPELINE_ORV_TMP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
dataf => \GRFPC0.MEM.CTRL.VCNT\(1),
datae => \GRFPC0.MEM.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_UN3511_REGDEPX_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.UN3511_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_A4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25614\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_50_0_O2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_O2_1\(1),
dataf => \GRFPC0.N_25612\,
datae => \GRFPC0.N_25614\,
datad => \GRFPC0.N_25648_2\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_12_0_A2_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25277\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5710_REGDEPX2_1_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23809\,
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7062_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25228\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_25117\,
datad => \GRFPC0.N_25264_I\,
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_15_1_CHECK_DEP_UN4895_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN207_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_3_1_CHECK_DEP_UN1151_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1151_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN190_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN190_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(16),
datae => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_0_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c000000000")
port map (
combout => \GRFPC0.N_25591\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.N_23588\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN710_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_0_A2_0\(1),
datab => \GRFPC0.N_23587\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN222_REGDEPX2_2_0_A2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_24112\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_1_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5136_REGDEPX2_1_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23741\,
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A3_0_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.N_25438_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(2),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5240_REGDEPX2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_260\,
dataf => \GRFPC0.WR2.CTRL.INST\(18),
datae => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25446\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
datae => \GRFPC0.WR.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.N_24981\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff003000")
port map (
combout => \GRFPC0.N_25436\,
dataf => \GRFPC0.N_25446\,
datae => \GRFPC0.N_25448\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
datab => \GRFPC0.N_24897\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_0_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_25694\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_DEP_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
datae => \GRFPC0.FIFO.INST_0\(4),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN285_REGDEPX2_2_0_A2_0_A2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN416_REGDEPX2_2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN859_REGDEPX2_2\,
dataf => \GRFPC0.DIV.RD_0\(3),
datae => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_5_0_A2_0_A2_0_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23817\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_19_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(0),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_13_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_25756\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(14));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1271_REGDEPX2_0_A2_1_0_A2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_268\,
dataf => \GRFPC0.WR2.CTRL.INST\(18),
datae => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_300_0_A2_8_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_300_0_A2_8_0\(0),
dataf => \GRFPC0.WR2.CTRL.INST\(2),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN816_REGDEPX2_2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN816_REGDEPX2_2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1755_REGDEPX2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25338\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3959_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2919_REGDEPX_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_24348\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_0_0\(29),
datae => \GRFPC0.FIFO.INST_0_0\(28));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN391_REGDEPX_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_24422\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21092\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_21092\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.MULO.MRES\(61));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_0\(0),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.MULO.MRES\(60));
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_31_RNIFMJ61_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff0fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
dataf => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datae => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19583\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(73),
datad => \GRFPU0.MULO.MRES_1\(73));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19587\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(72),
datad => \GRFPU0.MULO.MRES_1S\(72));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff300ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(57),
dataf => \GRFPU0.GRFPU_X0.N_17605\,
datae => \GRFPU0.GRFPU_X0.N_18\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff300ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(60),
dataf => \GRFPU0.GRFPU_X0.N_17608\,
datae => \GRFPU0.GRFPU_X0.N_18\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_53\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.N_47\,
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_47\,
dataf => \GRFPU0.GRFPU_X0.C\(6),
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(4),
datac => \GRFPU0.GRFPU_X0.C\(3),
datab => \GRFPU0.GRFPU_X0.C\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff000")
port map (
combout => \GRFPU0.GRFPU_X0.N_59\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.N_47\,
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003c0000003")
port map (
combout => \GRFPU0.GRFPU_X0.N_19221\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(9),
datad => \GRFPU0.GRFPU_X0.UN8_C\(8),
datac => \GRFPU0.GRFPU_X0.UN8_C\(7),
datab => \GRFPU0.GRFPU_X0.N_26\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0ccc0ccc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_20814\,
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => N_45083,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(55));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0ccc0ccc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_20824\,
dataf => \GRFPU0.GRFPU_X0.N_20766\,
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => N_45083,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(52));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNIR9NR5_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffccff0cffccff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20779\,
dataf => \GRFPU0.GRFPU_X0.N_20881\,
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.N_20764\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_ITER_STATE_RNINUR11_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_7942\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O3_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20487\,
dataf => \GRFPU0.GRFPU_X0.N_20881\,
datae => \GRFPU0.GRFPU_X0.N_20478\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c0f0c0f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_33_M\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNINH2V_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.LOB\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI7E1Q_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.G_672_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.LOB\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_X2_RNI3B6T3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0ccccccfc")
port map (
combout => N_174935,
dataf => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datae => \GRFPU0.GRFPU_X0.N_77_I\,
datad => \GRFPU0.GRFPU_X0.N_51_I\,
datac => \GRFPU0.GRFPU_X0.G_672_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_1_SQMUXA_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03ff03ff03ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20635\,
dataf => \GRFPU0.GRFPU_X0.N_4379\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_RNIFOTO2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19890\,
dataf => \GRFPU0.GRFPU_X0.N_4066_0\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_22914\,
dataf => \GRFPC0.N_165_1\,
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(3),
datac => \GRFPC0.FIFO.INST_1\(4),
datab => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6990_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6990_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_25754\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(25));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7019_REGDEPX2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7019_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20826\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_20816_1\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.EXP1\(0));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_185_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_24352\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3231_REGDEPX_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_24442\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2711_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3813_REGDEPX2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25730\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25813_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6165_REGDEPX2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_25477\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(18),
datad => \GRFPC0.DIV.INST\(15));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_8_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(0),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.INST\(14));
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3335_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.1.CHECK_DEP.UN3335_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
\GRFPU0_GRFPU_X0_ITER_STATE_RNISJ8T_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_2_TZ\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
GRFPU0_GRFPU_X0_VST2_RDY_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f000f03")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.N_4369\,
datac => \GRFPU0.GRFPU_X0.N_4373\,
datab => \GRFPU0.GRFPU_X0.N_4997\);
GRFPU0_GRFPU_X0_ST2_RDY_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30003000ffff3000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11219\,
dataf => \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datad => \GRFPU0.GRFPU_X0.N_4296\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffdeeeeeeec")
port map (
combout => \GRFPU0.GRFPU_X0.N_11223\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_30\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\,
datab => \GRFPU0.GRFPU_X0.COMB.SHV2_0\,
dataa => \GRFPU0.GRFPU_X0.C\(11));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0_2\,
dataf => \GRFPU0.GRFPU_X0.C\(1),
datae => \GRFPU0.GRFPU_X0.C\(4),
datad => \GRFPU0.GRFPU_X0.C\(3),
datac => \GRFPU0.GRFPU_X0.C\(2));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19557\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.N_64\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0_2\,
datac => \GRFPU0.GRFPU_X0.C\(6),
datab => \GRFPU0.GRFPU_X0.C\(5));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.C\(6),
datae => \GRFPU0.GRFPU_X0.C\(3),
datad => \GRFPU0.GRFPU_X0.C\(2));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.DIFFV2_0_A2_0\,
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(4),
datab => \GRFPU0.GRFPU_X0.C\(0));
GRFPU0_GRFPU_X0_COMB_VST2_DIFFV2_0_A2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19554_5\,
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.C\(9),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(7));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.MULO.MRES\(72),
datad => \GRFPU0.MULO.MRES_1\(72));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G5\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.MULO.MRES\(73),
datad => \GRFPU0.MULO.MRES_1S\(73));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc30fc30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.MULO.MRES\(98),
datad => N_31020,
datac => N_31019,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ccccc000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20957\,
dataf => \GRFPU0.GRFPU_X0.N_19831\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIJMQ91_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15316_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datad => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(5));
GRFPU0_GRFPU_X0_ITER_NORM_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfccc")
port map (
combout => N_29619,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.N_6100\,
datac => \GRFPU0.GRFPU_X0.ITER.V_3\,
datab => \GRFPU0.GRFPU_X0.ITER.NORM\);
\GRFPC0_EX_CTRL_INST_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50722,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => N_174);
\GRFPC0_EX_CTRL_INST_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50994,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(10),
datab => N_182);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G4\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_37_0_A2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19340\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fcfcff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G4\,
datac => \GRFPU0.GRFPU_X0.N_19340\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G4\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_37_0_A2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19342\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fcfcff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19398\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G4\,
datac => \GRFPU0.GRFPU_X0.N_19342\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcccccc0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ffccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G2_0\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G4\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19352\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19352\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19376\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19376\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19385\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19385\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_48__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_47__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_46__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_45__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_44__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_43__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_42__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_41__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f333c300f030c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_40__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f333c300f030c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_39__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_38__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_37__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f333c300f030c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_36__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f333c300f030c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_34__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f333c300f030c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datac => \GRFPU0.GRFPU_X0.N_17_I\,
datab => \GRFPU0.GRFPU_X0.N_10710_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18060\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(21));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18043\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18041\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(2));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_UN8_C_CARRY_7_RNID747: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_O2_0_0\(1),
dataf => \GRFPU0.GRFPU_X0.UN8_C\(8),
datae => \GRFPU0.GRFPU_X0.UN8_C\(7));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_12\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(37),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(36),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(27),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(29));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_12\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(33),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(34),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(31),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(28));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_35: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_10\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(38),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(32),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(35),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(30));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_30\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_0\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_17\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(49),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(47),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(50),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(51));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_29\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(42),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(40),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(41),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(39));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3ccc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_26: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => N_100066_TZ,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffcfff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19_TZ\,
datae => N_100066_TZ,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(44),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(23),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_5\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => N_100069_TZ,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\,
dataf => N_100069_TZ,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(26),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_9\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_6\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_4\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_25_TZ_5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_31\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(43),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(48),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(45),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(46));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(37),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(36),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(27),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(29));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(33),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(34),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(31),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(28));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_40: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccffccffc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_TZ_0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(25),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M7_4_03_0_G2\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_10\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(38),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(35),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(32),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(30));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_30\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_17\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_16_0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(49),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(51),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(47),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(50));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(42),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(40),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(41),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(39));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_31: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0ff0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => N_100071_TZ,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccffccffc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_14\,
dataf => N_100071_TZ,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_0\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(23),
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_19_TZ_1\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_14\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(44),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(45),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(46));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_5\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_32: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => N_100074_TZ,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9\,
dataf => N_100074_TZ,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(26),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_9\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_6\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_4\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_25_TZ_5\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_30\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_15\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(48),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(43));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19586_I\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(69),
datad => \GRFPU0.MULO.MRES_1S\(69));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2211_REGDEPX2_0_A2_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_257\,
dataf => \GRFPC0.DIV.INST\(4),
datae => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_148\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145\(1),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2211_REGDEPX2\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2196_REGDEPX2_0_A2_0_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25378\,
dataf => \GRFPC0.DIV.INST\(18),
datae => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN383_REGDEPX2_1_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_I_A2_4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25222_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(18),
datae => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN400_REGDEPX2_1_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN400_REGDEPX2_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(2),
datae => \GRFPC0.WR2.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_6_CHECK_DEP_DEP_2_0_A2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25223_2\,
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_6_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_6_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_O2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_O2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_6_2\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_8_1\(1),
datab => \GRFPC0.N_25854\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25819\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_24701_1\,
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN351_REGDEPX2_1_0_A2_0_A4_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(2),
datae => \GRFPC0.WR.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN320_REGDEPX2_1_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_5_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_145_0_A2_5_0\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6032_REGDEPX2_0_A4_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25859\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_12_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_24299_1\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2182_REGDEPX2_0_A2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_23819\,
dataf => \GRFPC0.DIV.RD_0\(3),
datae => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_185_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24427\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_184_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00c0c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.0.REGDEPX_184\(1),
dataf => \GRFPC0.N_21956_1\,
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.UN3199_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.FP_PIPELINE.10.0.CHECK_DEP.DEP_1_0\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2033_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_UN2592_REGDEPX_2_0_A3_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2904_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_146_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_146_IV\(1),
dataf => \GRFPC0.N_228\,
datae => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0_0\(27),
datab => \GRFPC0.FIFO.INST_0_0\(28));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_148_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_148\(1),
dataf => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_146_IV\(1),
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2904_REGDEPX_2\,
datab => \GRFPC0.N_24372_1\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5606_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5606_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5591_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5561_REGDEPX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5561_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_23783_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(28),
datae => \GRFPC0.MEM.CTRL.INST\(29));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M35_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(35),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M37_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(37),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M34_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(34),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M32_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(32),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M30_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(30),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M28_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(28),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M26_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(26),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M24_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(24),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M25_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(25),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M33_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(33),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M38_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(38),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M36_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(36),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M23_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(23),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M27_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(27),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M29_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(29),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M31_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(31),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M35_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(35),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M37_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(37),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M34_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(34),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M32_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(32),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M30_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(30),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M28_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(28),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M26_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(26),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M24_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(24),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M33_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(33),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M38_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(38),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M36_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(36),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M23_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(23),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M27_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(27),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M29_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(29),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M31_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(31),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(21),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datab => \FPI.OP1_RETO\(21));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(21),
dataf => \GRFPU0.GRFPU_X0.N_17184\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(49),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(49),
dataf => \GRFPU0.GRFPU_X0.N_17212\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(38),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_16252\,
datad => \GRFPU0.GRFPU_X0.N_16304\,
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(23),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datab => \FPI.OP1_RETO\(23));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(23),
dataf => \GRFPU0.GRFPU_X0.N_17186\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPU0_GRFPU_X0_VST3_REG_37_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24));
\GRFPU0_GRFPU_X0_VST3_REG_37_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34));
\GRFPU0_GRFPU_X0_VST3_REG_47_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccfff0f0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(34),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(34),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17368\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(88),
datad => \GRFPU0.MULO.MRES_1S\(88));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17369\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(89),
datad => \GRFPU0.MULO.MRES_1S\(89));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17371\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(91),
datad => \GRFPU0.MULO.MRES_1S\(91));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17372\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(92),
datad => \GRFPU0.MULO.MRES_1S\(92));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17373\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(93),
datad => \GRFPU0.MULO.MRES_1S\(93));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX6_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3000cf0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6\,
datad => \GRFPU0.GRFPU_X0.N_7645\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17299\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(70),
datad => \GRFPU0.MULO.MRES_1\(70));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17348\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31062,
datad => N_31061,
datac => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17350\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(70),
datad => \GRFPU0.MULO.MRES_1S\(70));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17300\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(71),
datad => \GRFPU0.MULO.MRES_1\(71));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17303\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(74),
datad => \GRFPU0.MULO.MRES_1\(74));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17304\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(75),
datad => \GRFPU0.MULO.MRES_1\(75));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17305\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(76),
datad => \GRFPU0.MULO.MRES_1\(76));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17306\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(77),
datad => \GRFPU0.MULO.MRES_1\(77));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17307\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(78),
datad => \GRFPU0.MULO.MRES_1\(78));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17308\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(79),
datad => \GRFPU0.MULO.MRES_1\(79));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17309\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(80),
datad => \GRFPU0.MULO.MRES_1\(80));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17310\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(81),
datad => \GRFPU0.MULO.MRES_1\(81));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17311\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(82),
datad => \GRFPU0.MULO.MRES_1\(82));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17312\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES_1\(83));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17313\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(84),
datad => \GRFPU0.MULO.MRES_1\(84));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17314\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES_1\(85));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17315\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(86),
datad => \GRFPU0.MULO.MRES_1\(86));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17316\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(87),
datad => \GRFPU0.MULO.MRES_1\(87));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17317\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(88),
datad => \GRFPU0.MULO.MRES_1\(88));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17318\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(89),
datad => \GRFPU0.MULO.MRES_1\(89));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17320\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(91),
datad => \GRFPU0.MULO.MRES_1\(91));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17321\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(92),
datad => \GRFPU0.MULO.MRES_1\(92));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17322\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(93),
datad => \GRFPU0.MULO.MRES_1\(93));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17325\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => N_31016,
datad => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.FPMUL0.SX\(96));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17334\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31034,
datad => N_31033,
datac => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17335\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31036,
datad => N_31035,
datac => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17336\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31038,
datad => N_31037,
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17337\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31040,
datad => N_31039,
datac => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17339\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31044,
datad => N_31043,
datac => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17340\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31046,
datad => N_31045,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17342\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31050,
datad => N_31049,
datac => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17351\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(71),
datad => \GRFPU0.MULO.MRES_1S\(71));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17354\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(74),
datad => \GRFPU0.MULO.MRES_1S\(74));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17355\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(75),
datad => \GRFPU0.MULO.MRES_1S\(75));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17356\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(76),
datad => \GRFPU0.MULO.MRES_1S\(76));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17357\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(77),
datad => \GRFPU0.MULO.MRES_1S\(77));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17358\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(78),
datad => \GRFPU0.MULO.MRES_1S\(78));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17359\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(79),
datad => \GRFPU0.MULO.MRES_1S\(79));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17360\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(80),
datad => \GRFPU0.MULO.MRES_1S\(80));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17361\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(81),
datad => \GRFPU0.MULO.MRES_1S\(81));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17362\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(82),
datad => \GRFPU0.MULO.MRES_1S\(82));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17363\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES_1S\(83));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17364\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(84),
datad => \GRFPU0.MULO.MRES_1S\(84));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17365\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES_1S\(85));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17366\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(86),
datad => \GRFPU0.MULO.MRES_1S\(86));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17367\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(87),
datad => \GRFPU0.MULO.MRES_1S\(87));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000ff00ff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19669\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.FPMUL0.CS_DP_R\,
datac => \GRFPU0.MULO.MRES_1S\(68));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19670\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(69),
datad => \GRFPU0.MULO.MRES_1\(69));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19672\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31052,
datad => N_31051,
datac => \GRFPU0.MULO.MRES\(114),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19673\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31054,
datad => N_31053,
datac => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19674\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31056,
datad => N_31055,
datac => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c033f000f033")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(40),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(40),
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff0fc330f300c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(54),
datae => \GRFPU0.GRFPU_X0.N_16770\,
datad => \GRFPU0.GRFPU_X0.N_13127_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c00fcc00cc0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(34),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.N_19890\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fcf000030c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18161\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(6),
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => N_35934,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c00fcc00cc0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(33),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.N_19890\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(33));
\GRFPU0_GRFPU_X0_EXP_11_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cffccff3c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_11\(8),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(9),
datae => N_35944,
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c033f000f033")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(37),
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_16749_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(37),
datab => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18056\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(17));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18049\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(10));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18048\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18053\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(14));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18062\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(23));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18084\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(45),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18149\,
datab => \GRFPU0.GRFPU_X0.N_18084\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18047\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18063\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(24));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18064\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18058\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(50),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(50));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(50),
dataf => \GRFPU0.GRFPU_X0.N_17213\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datad => \FPI.OP1_RETO\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(27),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datab => \FPI.OP1_RETO\(27));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(27),
dataf => \GRFPU0.GRFPU_X0.N_17190\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M3_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20509\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20645\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(33),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(33));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(33),
dataf => \GRFPU0.GRFPU_X0.N_17196\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33));
\GRFPU0_GRFPU_X0_DIFFIN1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(43),
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(42),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(42),
dataf => \GRFPU0.GRFPU_X0.N_17205\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
\GRFPU0_GRFPU_X0_DIFFIN1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(35),
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(34),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(34));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(34),
dataf => \GRFPU0.GRFPU_X0.N_17197\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
dataf => \GRFPU0.GRFPU_X0.N_17173\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPU0_GRFPU_X0_ST1_RAW1_RNIH4TA1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20773\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(41));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20786\,
dataf => \GRFPU0.DIVROM0.RADDR\(1),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(3),
dataf => \GRFPU0.GRFPU_X0.N_17166\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(20),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datad => \FPI.OP1_RETO\(20));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(20),
dataf => \GRFPU0.GRFPU_X0.N_17183\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15567\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(8),
dataf => \GRFPU0.GRFPU_X0.N_17171\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(11),
dataf => \GRFPU0.GRFPU_X0.N_17174\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
dataf => \GRFPU0.GRFPU_X0.N_17180\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(26),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datab => \FPI.OP1_RETO\(26));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(26),
dataf => \GRFPU0.GRFPU_X0.N_17189\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
dataf => \GRFPU0.GRFPU_X0.N_17165\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_DIFFIN1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(48),
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(47),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17210\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(47),
datae => \GRFPU0.GRFPU_X0.N_20764\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(47),
dataf => \GRFPU0.GRFPU_X0.N_17210\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(15),
dataf => \GRFPU0.GRFPU_X0.N_17178\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
\GRFPU0_GRFPU_X0_DIFFIN1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN1\(29),
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(28),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datab => \FPI.OP1_RETO\(28));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(28),
dataf => \GRFPU0.GRFPU_X0.N_17191\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(40),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(40));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(40),
dataf => \GRFPU0.GRFPU_X0.N_17203\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
dataf => \GRFPU0.GRFPU_X0.N_17170\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(56),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(56));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(12),
dataf => \GRFPU0.GRFPU_X0.N_17175\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(22),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \FPI.OP1_RETO\(22));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(22),
dataf => \GRFPU0.GRFPU_X0.N_17185\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_1\(2),
dataf => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datae => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN242_BCO_MSB\(15));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0),
dataf => \GRFPU0.GRFPU_X0.L1_3_1_5\(0),
datae => \GRFPU0.GRFPU_X0.UN258_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_4_5\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_0_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ff300030")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03f303f303f30000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPU0_GRFPU_X0_L1_2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_7\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_3_7\(0),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(15),
datad => \GRFPU0.GRFPU_X0.N_20647\,
datac => \GRFPU0.GRFPU_X0.N_20790\,
datab => \GRFPU0.GRFPU_X0.N_20789\);
\GRFPU0_GRFPU_X0_L1_1_1_6_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000cff0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_6_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_L1_1_1_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_20792\,
datae => \GRFPU0.GRFPU_X0.L1_1_1_6_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(66),
datac => \GRFPU0.MULO.MRES\(65));
GRFPU0_GRFPU_X0_VITER_DBUF_13_SUM1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000ff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(1),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.N_10889\,
datad => N_124864,
datac => N_124865);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(63),
datac => \GRFPU0.MULO.MRES\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff33ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(7),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_19404_I\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20648\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18044\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(31),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(91),
datac => \GRFPU0.MULO.DRES_1\(91),
datab => \GRFPU0.MULO.DRES_1S\(90),
dataa => \GRFPU0.MULO.DRES_S\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(89),
datac => \GRFPU0.MULO.DRES_1\(89),
datab => \GRFPU0.MULO.DRES_1S\(88),
dataa => \GRFPU0.MULO.DRES_S\(88));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(36),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_16250\,
datad => \GRFPU0.GRFPU_X0.N_16302\,
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(40),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_16254\,
datad => \GRFPU0.GRFPU_X0.N_16306\,
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18055\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18138\,
datab => \GRFPU0.GRFPU_X0.N_18073\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18073\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18054\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(15));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18046\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(7));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0c0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(48),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_21000_1\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(48));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18057\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(18));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18051\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(64),
datac => \GRFPU0.MULO.MRES\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff0fff33ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_19404_I\,
datac => \GRFPU0.MULO.MRES\(65),
datab => \GRFPU0.MULO.MRES\(64));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(62),
datac => \GRFPU0.MULO.MRES\(61));
\GRFPU0_GRFPU_X0_S3ADDI_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15701\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(28));
\GRFPU0_GRFPU_X0_UN1_INCSP_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fc00f300f000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INCSP\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.S_SP_2\,
datae => \GRFPU0.GRFPU_X0.N_11478\,
datad => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datac => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55));
\GRFPC0_OP2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19554\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(0));
\GRFPC0_OP2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19620\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(0),
datad => \GRFPC0.DIV.RESULT\(0));
\GRFPC0_OP2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(0),
dataf => \GRFPC0.N_19554\,
datae => \GRFPC0.N_19883\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19620\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_299_0\,
datae => \FPI.OP2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(8),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(52),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(52));
\GRFPC0_OP2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19556\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(2));
\GRFPC0_OP2_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19622\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(2),
datad => \GRFPC0.MEM.RREG.RES\(2));
\GRFPC0_OP2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(2),
dataf => \GRFPC0.N_19556\,
datae => \GRFPC0.N_19885\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19622\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(2));
\GRFPC0_OP2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19558\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(4));
\GRFPC0_OP2_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19624\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(4),
datad => \GRFPC0.MEM.RREG.RES\(4));
\GRFPC0_OP2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(4),
dataf => \GRFPC0.N_19558\,
datae => \GRFPC0.N_19887\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19624\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_4_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3f0f3300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(12),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.MULO.MRES\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(12),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.MULO.DRES_1\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.MULO.DRES_1\(72),
datab => \GRFPU0.MULO.DRES_1S\(71),
dataa => \GRFPU0.MULO.DRES_S\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(12),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(12),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPC0_OP2_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19559\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(5));
\GRFPC0_OP2_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19625\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(5),
datad => \GRFPC0.MEM.RREG.RES\(5));
\GRFPC0_OP2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(5),
dataf => \GRFPC0.N_19559\,
datae => \GRFPC0.N_19888\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19625\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_5_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(5));
\GRFPC0_OP2_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19561\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(7));
\GRFPC0_OP2_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19627\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(7),
datad => \GRFPC0.MEM.RREG.RES\(7));
\GRFPC0_OP2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(7),
dataf => \GRFPC0.N_19561\,
datae => \GRFPC0.N_19890\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19627\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_7_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff33ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(15),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_19404_I\,
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(15),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(15),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.DRES_1\(75));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(15),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(15),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
\GRFPC0_OP2_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19562\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(8));
\GRFPC0_OP2_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19628\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(8),
datad => \GRFPC0.MEM.RREG.RES\(8));
\GRFPC0_OP2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(8),
dataf => \GRFPC0.N_19562\,
datae => \GRFPC0.N_19891\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19628\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_8_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc0c0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20981\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => N_174935_0,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44),
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000003f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(16),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_264\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(16),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_3_0_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(16),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(76),
datac => \GRFPU0.MULO.DRES_1\(76),
datab => \GRFPU0.MULO.DRES_1S\(75),
dataa => \GRFPU0.MULO.DRES_S\(75));
\GRFPC0_OP2_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19564\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(10));
\GRFPC0_OP2_2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19630\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(10),
datad => \GRFPC0.MEM.RREG.RES\(10));
\GRFPC0_OP2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(10),
dataf => \GRFPC0.N_19564\,
datae => \GRFPC0.N_19893\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19630\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_10_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(18),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.MULO.DRES_1\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.MULO.DRES_1\(78),
datab => \GRFPU0.MULO.DRES_1S\(77),
dataa => \GRFPU0.MULO.DRES_S\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(18),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPC0_OP2_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19566\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(12));
\GRFPC0_OP2_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19632\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(12),
datad => \GRFPC0.MEM.RREG.RES\(12));
\GRFPC0_OP2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(12),
dataf => \GRFPC0.N_19566\,
datae => \GRFPC0.N_19895\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19632\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_12_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(20),
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(80));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(20),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(80),
datad => \GRFPU0.MULO.DRES_1\(80));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(80),
datac => \GRFPU0.MULO.DRES_1\(80),
datab => \GRFPU0.MULO.DRES_1S\(79),
dataa => \GRFPU0.MULO.DRES_S\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(20),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(20),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(20),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40));
\GRFPC0_OP2_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19567\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(13));
\GRFPC0_OP2_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19633\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(13),
datad => \GRFPC0.MEM.RREG.RES\(13));
\GRFPC0_OP2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(13),
dataf => \GRFPC0.N_19567\,
datae => \GRFPC0.N_19896\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19633\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_13_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(21),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(81),
datad => \GRFPU0.MULO.DRES_1\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.MULO.DRES_1\(81),
datab => \GRFPU0.MULO.DRES_1S\(80),
dataa => \GRFPU0.MULO.DRES_S\(80));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(21),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(21),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(21),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39));
\GRFPC0_OP2_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19569\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(15));
\GRFPC0_OP2_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19635\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(15),
datad => \GRFPC0.MEM.RREG.RES\(15));
\GRFPC0_OP2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(15),
dataf => \GRFPC0.N_19569\,
datae => \GRFPC0.N_19898\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19635\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_15_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcf0fcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.MULO.DRES_1\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.MULO.DRES_1\(83),
datab => \GRFPU0.MULO.DRES_1S\(82),
dataa => \GRFPU0.MULO.DRES_S\(82));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(23),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPC0_OP2_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19571\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(17));
\GRFPC0_OP2_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19637\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(17),
datad => \GRFPC0.MEM.RREG.RES\(17));
\GRFPC0_OP2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(17),
dataf => \GRFPC0.N_19571\,
datae => \GRFPC0.N_19900\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19637\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_17_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(25),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(85),
datac => \GRFPU0.MULO.DRES_1\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(25),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPC0_OP2_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19572\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(18));
\GRFPC0_OP2_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19638\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(18),
datad => \GRFPC0.MEM.RREG.RES\(18));
\GRFPC0_OP2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(18),
dataf => \GRFPC0.N_19572\,
datae => \GRFPC0.N_19901\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19638\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_18_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_2_0_TZ_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_0\(26),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.DRES_1\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_2_0_TZ_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccfc0030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ_1\(26),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c0000cc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_0\(26),
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_0\(26),
datae => \GRFPU0.GRFPU_X0.N_20925\,
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_0_0_M2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20910_I\,
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.MULO.MRES\(86),
datac => \GRFPU0.MULO.DRES_1\(86),
datab => \GRFPU0.MULO.DRES_1S\(85),
dataa => \GRFPU0.MULO.DRES_S\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_1\(26),
datae => \GRFPU0.GRFPU_X0.N_21025\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_1_2_0_TZ\(26),
datac => \GRFPU0.GRFPU_X0.N_20910_I\,
datab => \GRFPU0.GRFPU_X0.N_296\);
\GRFPC0_OP2_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19574\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(20));
\GRFPC0_OP2_2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19640\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(20),
datad => \GRFPC0.MEM.RREG.RES\(20));
\GRFPC0_OP2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(20),
dataf => \GRFPC0.N_19574\,
datae => \GRFPC0.N_19903\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19640\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_20_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3f330f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(28),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.MULO.DRES_1\(88),
datab => \GRFPU0.MULO.DRES_1S\(87),
dataa => \GRFPU0.MULO.DRES_S\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(28),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPC0_OP2_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19579\,
dataf => \FPO.RES\(25),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(25));
\GRFPC0_OP2_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19645\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(25),
datad => \GRFPC0.MEM.RREG.RES\(25));
\GRFPC0_OP2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(25),
dataf => \GRFPC0.N_19579\,
datae => \GRFPC0.N_19908\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19645\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_25_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_A2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_135\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(93),
datac => \GRFPU0.MULO.DRES_1\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_3_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_3\(33),
dataf => \GRFPU0.GRFPU_X0.N_135\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0_0\(33),
datad => \GRFPU0.GRFPU_X0.N_19279_I\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf3f0ff0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(33),
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_174935_0);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(33),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0c00000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20288_I\,
dataf => \GRFPU0.GRFPU_X0.N_19712\,
datae => \GRFPU0.GRFPU_X0.N_389\,
datad => \FPI.OP1\(54),
datac => \GRFPU0.GRFPU_X0.N_80_0\,
datab => \FPI.OP1\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(59),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(59),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(53),
datac => \FPI.OP1\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(58),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(58),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(58));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(52),
datac => \FPI.OP1\(49));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_0_13_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_13\(4),
dataf => \FPI.OP1\(43),
datae => \FPI.OP1\(42),
datad => \FPI.OP1\(37),
datac => \FPI.OP1\(39));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_0_9_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_0_O2_I_A2_0_9\(4),
dataf => \FPI.OP1\(32),
datae => \FPI.OP1\(50),
datad => \FPI.OP1\(47));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_0_O2_I_A2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_331\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53));
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_19767_6\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(56),
datad => \FPI.OP1\(57),
datac => \FPI.OP1\(62));
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_19767_5\,
dataf => \FPI.OP1\(59),
datae => \FPI.OP1\(58),
datad => \FPI.OP1\(60),
datac => \FPI.OP1\(61));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20286_I\,
dataf => \GRFPU0.GRFPU_X0.N_19712\,
datae => \GRFPU0.GRFPU_X0.N_389\,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.OP1\(51),
datab => \FPI.OP1\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(56),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(56),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(56));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(43),
datac => \FPI.OP1\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(42),
datac => \FPI.OP1\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(50),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(50),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(50));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(40),
datac => \FPI.OP1\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(48),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(48),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(41),
datac => \FPI.OP1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(46),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(46),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(40),
datac => \FPI.OP1\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(45),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(45),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(36),
datac => \FPI.OP1\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(41),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(35),
datac => \FPI.OP1\(32));
\GRFPC0_OP1_I_M4_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_23916\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(30));
\GRFPC0_OP1_I_M4_2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_23917\,
dataf => \GRFPC0.RFA2.RS1SEL\(2),
datae => \GRFPC0.DIV.RESULT\(30),
datad => \GRFPC0.MEM.RREG.RES\(30));
\GRFPC0_OP1_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(30),
dataf => \GRFPC0.N_23954\,
datae => \GRFPC0.N_23916\,
datad => \GRFPC0.OP1_SN_N_6\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_23917\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \FPI.OP1\(33),
datac => \FPI.OP1\(30));
\GRFPC0_OP1_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19012\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(29));
\GRFPC0_OP1_2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19078\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(29),
datad => \GRFPC0.MEM.RREG.RES\(29));
\GRFPC0_OP1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(29),
dataf => \GRFPC0.N_19341\,
datae => \GRFPC0.N_19012\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19078\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_20287_0\,
datae => \GRFPU0.GRFPU_X0.N_19712_0\,
datad => \FPI.OP1\(32),
datac => \FPI.OP1\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(37),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37));
\GRFPC0_OP1_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19011\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(28));
\GRFPC0_OP1_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19077\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(28),
datad => \GRFPC0.MEM.RREG.RES\(28));
\GRFPC0_OP1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(28),
dataf => \GRFPC0.N_19340\,
datae => \GRFPC0.N_19011\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19077\);
\GRFPC0_OP1_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19010\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(27));
\GRFPC0_OP1_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19076\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(27),
datad => \GRFPC0.MEM.RREG.RES\(27));
\GRFPC0_OP1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(27),
dataf => \GRFPC0.N_19339\,
datae => \GRFPC0.N_19010\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19076\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(35),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPC0_OP1_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19009\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(26));
\GRFPC0_OP1_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19075\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(26),
datad => \GRFPC0.MEM.RREG.RES\(26));
\GRFPC0_OP1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(26),
dataf => \GRFPC0.N_19338\,
datae => \GRFPC0.N_19009\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19075\);
\GRFPC0_OP1_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19008\,
dataf => \FPO.RES\(25),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(25));
\GRFPC0_OP1_2_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19074\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(25),
datad => \GRFPC0.MEM.RREG.RES\(25));
\GRFPC0_OP1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(25),
dataf => \GRFPC0.N_19337\,
datae => \GRFPC0.N_19008\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19074\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(33),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(33));
\GRFPC0_OP1_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19007\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(24));
\GRFPC0_OP1_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19073\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(24),
datad => \GRFPC0.MEM.RREG.RES\(24));
\GRFPC0_OP1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(24),
dataf => \GRFPC0.N_19336\,
datae => \GRFPC0.N_19007\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19073\);
\GRFPC0_OP1_I_M2_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_23984\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(22));
\GRFPC0_OP1_2_I_M2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_24003\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(22),
datad => \GRFPC0.MEM.RREG.RES\(22));
\GRFPC0_OP1_I_M2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(22),
dataf => \GRFPC0.N_24011\,
datae => \GRFPC0.N_23984\,
datad => \GRFPC0.OP1_SN_N_6\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_24003\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(30),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPC0_OP1_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19002\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(19));
\GRFPC0_OP1_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19068\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(19),
datad => \GRFPC0.MEM.RREG.RES\(19));
\GRFPC0_OP1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(19),
dataf => \GRFPC0.N_19331\,
datae => \GRFPC0.N_19002\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19068\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(27),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
\GRFPC0_OP1_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19000\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(17));
\GRFPC0_OP1_2_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19066\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(17),
datad => \GRFPC0.MEM.RREG.RES\(17));
\GRFPC0_OP1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(17),
dataf => \GRFPC0.N_19329\,
datae => \GRFPC0.N_19000\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19066\);
\GRFPC0_OP1_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18999\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(16));
\GRFPC0_OP1_2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19065\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(16),
datad => \GRFPC0.MEM.RREG.RES\(16));
\GRFPC0_OP1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(16),
dataf => \GRFPC0.N_19328\,
datae => \GRFPC0.N_18999\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19065\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_2_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc00f000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_2\(24),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.N_19292_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(24),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_2\(24),
datae => \GRFPU0.GRFPU_X0.N_20635_0\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPC0_OP1_1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18998\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(15));
\GRFPC0_OP1_2_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19064\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(15),
datad => \GRFPC0.MEM.RREG.RES\(15));
\GRFPC0_OP1_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(15),
dataf => \GRFPC0.N_19327\,
datae => \GRFPC0.N_18998\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19064\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(23),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(23),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPC0_OP1_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18997\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(14));
\GRFPC0_OP1_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19063\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(14),
datad => \GRFPC0.MEM.RREG.RES\(14));
\GRFPC0_OP1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(14),
dataf => \GRFPC0.N_19326\,
datae => \GRFPC0.N_18997\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19063\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(22),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(22));
\GRFPC0_OP1_1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18996\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(13));
\GRFPC0_OP1_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19062\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(13),
datad => \GRFPC0.MEM.RREG.RES\(13));
\GRFPC0_OP1_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(13),
dataf => \GRFPC0.N_19325\,
datae => \GRFPC0.N_18996\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19062\);
\GRFPC0_OP1_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18994\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(11));
\GRFPC0_OP1_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19060\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(11),
datad => \GRFPC0.MEM.RREG.RES\(11));
\GRFPC0_OP1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(11),
dataf => \GRFPC0.N_19323\,
datae => \GRFPC0.N_18994\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19060\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(19),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(19));
\GRFPC0_OP1_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18993\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(10));
\GRFPC0_OP1_2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19059\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(10),
datad => \GRFPC0.MEM.RREG.RES\(10));
\GRFPC0_OP1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(10),
dataf => \GRFPC0.N_19322\,
datae => \GRFPC0.N_18993\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19059\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(18),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPC0_OP1_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18992\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(9));
\GRFPC0_OP1_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19058\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(9),
datad => \GRFPC0.MEM.RREG.RES\(9));
\GRFPC0_OP1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(9),
dataf => \GRFPC0.N_19321\,
datae => \GRFPC0.N_18992\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19058\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(17),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPC0_OP1_1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18991\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(8));
\GRFPC0_OP1_2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19057\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(8),
datad => \GRFPC0.MEM.RREG.RES\(8));
\GRFPC0_OP1_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(8),
dataf => \GRFPC0.N_19320\,
datae => \GRFPC0.N_18991\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19057\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(16),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
\GRFPC0_OP1_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18989\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(6));
\GRFPC0_OP1_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19055\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(6),
datad => \GRFPC0.MEM.RREG.RES\(6));
\GRFPC0_OP1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(6),
dataf => \GRFPC0.N_19318\,
datae => \GRFPC0.N_18989\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19055\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(14),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPC0_OP1_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18988\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(5));
\GRFPC0_OP1_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19054\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(5),
datad => \GRFPC0.MEM.RREG.RES\(5));
\GRFPC0_OP1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(5),
dataf => \GRFPC0.N_19317\,
datae => \GRFPC0.N_18988\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19054\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_2_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc00f000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_2\(13),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.N_19292_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0\(13),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_2\(13),
datae => \GRFPU0.GRFPU_X0.N_20635_0\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPC0_OP1_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18987\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(4));
\GRFPC0_OP1_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19053\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(4),
datad => \GRFPC0.MEM.RREG.RES\(4));
\GRFPC0_OP1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(4),
dataf => \GRFPC0.N_19316\,
datae => \GRFPC0.N_18987\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19053\);
\GRFPC0_OP1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18986\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(3));
\GRFPC0_OP1_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19052\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(3),
datad => \GRFPC0.MEM.RREG.RES\(3));
\GRFPC0_OP1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(3),
dataf => \GRFPC0.N_19315\,
datae => \GRFPC0.N_18986\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19052\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc00f000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\(11),
dataf => \GRFPU0.GRFPU_X0.N_19513_I\,
datae => \GRFPU0.GRFPU_X0.N_19292_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_0\(11),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_2\(11),
datae => \GRFPU0.GRFPU_X0.N_20635\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPC0_OP1_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18985\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(2));
\GRFPC0_OP1_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19051\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(2),
datad => \GRFPC0.MEM.RREG.RES\(2));
\GRFPC0_OP1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(2),
dataf => \GRFPC0.N_19314\,
datae => \GRFPC0.N_18985\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19051\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(10),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPC0_OP1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18984\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(1));
\GRFPC0_OP1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19050\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(1),
datad => \GRFPC0.DIV.RESULT\(1));
\GRFPC0_OP1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(1),
dataf => \GRFPC0.N_19313\,
datae => \GRFPC0.N_18984\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19050\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(9),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPC0_OP1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18983\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(0));
\GRFPC0_OP1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19049\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(0),
datad => \GRFPC0.DIV.RESULT\(0));
\GRFPC0_OP1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(0),
dataf => \GRFPC0.N_19312\,
datae => \GRFPC0.N_18983\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19049\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.DIVROMI\(7),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(54),
datac => \FPI.OP2\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(59),
dataf => \GRFPU0.MULO.MRES_1\(120),
datae => \GRFPU0.MULO.MRES\(119),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(59),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.MULO.DRES_1\(119));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cfffa0f0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_17677\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(59),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_138095,
dataa => N_138094);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.DIVROMI\(6),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(53),
datac => \FPI.OP2\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f330000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(58),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.DRES_1\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00f03030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(58),
datae => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datad => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"503050300000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(21),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(117),
dataa => \GRFPU0.MULO.MRES\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000ccfd0031")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(58),
datae => \GRFPU0.GRFPU_X0.N_17676\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_DIVROM0_DATA_1_6_0__M159\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0333033303030333")
port map (
combout => \GRFPU0.DIVAPPR\(6),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffc0cf303f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(58),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
datad => \GRFPU0.DIVAPPR\(6),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20284_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_1\(57),
dataf => \GRFPU0.MULO.MRES\(117),
datae => \GRFPU0.MULO.MRES\(118),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ff000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(57),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_94\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_0_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.DRES_1\(117));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(57),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_1\(57),
datac => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(57),
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(117));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16270\,
dataf => N_30893,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(116));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16322\,
dataf => \GRFPU0.GRFPU_X0.N_5221_1\,
datae => \GRFPU0.MULO.DRES_1\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31115,
datab => N_31114);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
dataf => \GRFPU0.GRFPU_X0.N_16270\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16322\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ffcf00c000cf")
port map (
combout => N_138081,
dataf => \GRFPU0.DIVAPPR\(5),
datae => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_94\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_57_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd20dd00ff22df02")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(57),
datae => \GRFPU0.GRFPU_X0.N_17675\,
datad => N_138081,
datac => \GRFPU0.GRFPU_X0.N_19496_0\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.DIVROMI\(4),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(56),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(116),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30944,
datab => N_30943);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_47_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(116),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30944,
datab => N_30943);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47\(56),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(56),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0a0c0a0f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(19),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(116),
dataa => \GRFPU0.MULO.MRES\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf3c03f0c3300")
port map (
combout => N_138076,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(56),
datac => N_174935_0,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_DIVROM0_DATA_1_6_0__M150\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333303c3030303c")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_151\,
dataf => N_124803,
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fcf0ff030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(56),
dataf => \GRFPU0.GRFPU_X0.N_16650\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_147\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_151\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPC0_OP2_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19604\,
dataf => \GRFPU0.GRFPU_X0.N_21436_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(50));
\GRFPC0_OP2_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19670\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(50),
datad => \GRFPC0.MEM.RREG.RES\(50));
\GRFPC0_OP2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(50),
dataf => \GRFPC0.N_19604\,
datae => \GRFPC0.N_19933\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19670\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.DIVROMI\(3),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(47),
datac => \FPI.OP2\(50));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20281_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(49),
datac => \FPI.OP2\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(54),
datae => \GRFPU0.MULO.MRES\(114),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(54),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.MULO.DRES_1\(114));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(54),
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(114));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_0_M2_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19504\,
dataf => N_30887,
datae => \GRFPU0.GRFPU_X0.N_5221\,
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(113));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_0_M2_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19503\,
dataf => \GRFPU0.GRFPU_X0.N_5221\,
datae => \GRFPU0.MULO.DRES_1\(114),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31109,
datab => N_31108);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffa0ffffff88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(54),
datad => \GRFPU0.GRFPU_X0.N_19524\,
datac => \GRFPU0.GRFPU_X0.N_17119\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_SQRTROM0_DATA_1_6_0__M69\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000ccccfffff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_70\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_SQRTROM0_DATA_1_6_0__M62\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033ffffccc00033")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_63\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_SQRTROM0_DATA_1_6_0__M59\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc333300ccfff33")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_60_I\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_SQRTROM0_DATA_1_6_0__M71\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a820b931ec64fd75")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_72\,
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_63\,
datae => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_60_I\,
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_70\,
datac => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_65\,
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_DIVROM0_DATA_1_6_0__M118\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000137ffffccc0")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_119\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M112\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"337ccccc333324cc")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_113\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M119\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_120\,
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_113\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_119\,
datad => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_DIVROM0_DATA_1_6_0__M103\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00003fffc0003ff")
port map (
combout => N_124860,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M100\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03fff0003fff000f")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_101\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M93\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003ff00ffc03fc00")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_94\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M105\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"20a831b964ec75fd")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_106\,
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_96\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_94\,
datad => N_124860,
datac => \GRFPU0.DIVROM0.DATA_1_6_0_.N_101\,
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fcf0ff030c000")
port map (
combout => N_138072,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(54),
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_106\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_120\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff22df02fd20dd00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(54),
datae => \GRFPU0.GRFPU_X0.N_17672\,
datad => N_138072,
datac => \GRFPU0.GRFPU_X0.N_19496_0\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPC0_OP2_3_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19734\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(48),
datad => \GRFPC0.WR.RREG.RES\(48));
\GRFPC0_OP2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(48),
dataf => \GRFPC0.N_19865\,
datae => \GRFPC0.N_19799\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19734\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_45_I_0\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(45),
datac => \FPI.OP2\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_1\(53),
dataf => \GRFPU0.MULO.MRES\(114),
datae => \GRFPU0.MULO.MRES\(113),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000f00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(53),
dataf => \GRFPU0.SQRTAPPR\(1),
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(53),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.DRES_1\(113));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(53),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_1\(53),
datac => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(53),
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(113));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16266\,
dataf => N_30885,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(112));
\GRFPU0_SQRTROM0_DATA_1_6_0__M54\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c333330ccccf3333")
port map (
combout => N_124878,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_SQRTROM0_DATA_1_6_0__M44\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fd80376c9966719")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_45\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_6_0__M56\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f000cf3ffc0cc")
port map (
combout => \GRFPU0.SQRTAPPR\(1),
dataf => N_124878,
datae => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_45\,
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_49\,
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_DIVROM0_DATA_1_6_0__M88\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0017fec8033fccc1")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_89\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M63\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4d25f07c16d2da1f")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_64\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M90\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9180b3a2d5c4f7e6")
port map (
combout => \GRFPU0.DIVAPPR\(1),
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_71\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_82\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_64\,
datac => \GRFPU0.DIVROM0.DATA_1_6_0_.N_89\,
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => N_138080,
dataf => \GRFPU0.DIVAPPR\(1),
datae => \GRFPU0.SQRTAPPR\(1),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(53));
\GRFPC0_OP2_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19601\,
dataf => \GRFPU0.GRFPU_X0.N_63_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(47));
\GRFPC0_OP2_2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19667\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(47),
datad => \GRFPC0.MEM.RREG.RES\(47));
\GRFPC0_OP2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(47),
dataf => \GRFPC0.N_19601\,
datae => \GRFPC0.N_19930\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_19667\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.DIVROMI\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(47),
datac => \FPI.OP2\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
datae => \GRFPU0.MULO.MRES\(112),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(52),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.MULO.DRES_1\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(52),
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff88ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(52),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(15),
datab => \GRFPU0.GRFPU_X0.N_17117\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_SQRTROM0_DATA_1_6_0__M21_E\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_117\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc000fccccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_31\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_18\,
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_DIVROM0_DATA_1_6_0__M50\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03fc03fc03f00ff0")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_51\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M48\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fc0fc03f03f00fc")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_49\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M41\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fc0fc3f03f03c0f")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_42\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M36\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c0f03c0f03c3f0f")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_37\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M52\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec64fd75a820b931")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_53\,
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_42\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_37\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_51\,
datac => \GRFPU0.DIVROM0.DATA_1_6_0_.N_49\,
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_DIVROM0_DATA_1_6_0__M103_E\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_183\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_6_0__M25\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3cf0f3c3cf3c30")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_26\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M17\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c30c30c33cf30cf3")
port map (
combout => N_124879,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M8\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3330cccccccf")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_9\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M30\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a291b3c4e6d5f7")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_31\,
dataf => N_124879,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_9\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_26\,
datac => \GRFPU0.DIVROM0.DATA_1_6_0_.N_29\,
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_D_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0f3fc0f00030")
port map (
combout => N_138073,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_53\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_31\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff22df02fd20dd00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(52),
datae => \GRFPU0.GRFPU_X0.N_17670\,
datad => N_138073,
datac => \GRFPU0.GRFPU_X0.N_19496_0\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPC0_OP2_3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19732\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(46),
datad => \GRFPC0.WR.RREG.RES\(46));
\GRFPC0_OP2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(46),
dataf => \GRFPC0.N_19863\,
datae => \GRFPC0.N_19797\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19732\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20283_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(46),
datac => \FPI.OP2\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(51),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(111),
datac => \GRFPU0.MULO.DRES_1\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16316\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(111),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31103,
datab => N_31102);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
dataf => \GRFPU0.MULO.DRES_S\(110),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16316\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(51),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(51),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ee22ff33fc30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(51),
datad => \GRFPU0.GRFPU_X0.N_17669\,
datac => N_138118,
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => N_138119);
\GRFPC0_OP2_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19597\,
dataf => \GRFPU0.GRFPU_X0.N_21427_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(43));
\GRFPC0_OP2_2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19663\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(43),
datad => \GRFPC0.MEM.RREG.RES\(43));
\GRFPC0_OP2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(43),
dataf => \GRFPC0.N_19597\,
datae => \GRFPC0.N_19926\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19663\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_41_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(40),
datac => \FPI.OP2\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(48),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30928,
datab => N_30927);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_47_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30928,
datab => N_30927);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47\(48),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(48),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff88ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(48),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datab => \GRFPU0.GRFPU_X0.N_17113\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3232103232101010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(48),
datae => \GRFPU0.GRFPU_X0.N_17666\,
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_39_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(39),
datac => \FPI.OP2\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f3f0ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(47),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(107),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(47),
datae => \GRFPU0.MULO.MRES\(107),
datad => \GRFPU0.MULO.MRES\(108),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f330000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(47),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.MULO.DRES_1\(107));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(47),
datad => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(107));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16260\,
dataf => N_30873,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(106));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16312\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31095,
datab => N_31094);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"305030500000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(107),
dataa => \GRFPU0.MULO.MRES\(106));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff0000f00000")
port map (
combout => N_138141,
dataf => \GRFPU0.GRFPU_X0.N_17665\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_2\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0505000005150010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(47),
datae => N_138141,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(47),
datac => \GRFPU0.GRFPU_X0.N_21025\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(47),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\);
\GRFPC0_OP2_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19594\,
dataf => \GRFPU0.GRFPU_X0.N_21441_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(40));
\GRFPC0_OP2_2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19660\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(40),
datad => \GRFPC0.MEM.RREG.RES\(40));
\GRFPC0_OP2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(40),
dataf => \GRFPC0.N_19594\,
datae => \GRFPC0.N_19923\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19660\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19185_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(40),
datac => \FPI.OP2\(37));
\GRFPC0_OP2_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19593\,
dataf => \FPO.RES\(39),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(39));
\GRFPC0_OP2_2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19659\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(39),
datad => \GRFPC0.MEM.RREG.RES\(39));
\GRFPC0_OP2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(39),
dataf => \GRFPC0.N_19593\,
datae => \GRFPC0.N_19922\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19659\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_33_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(39),
datac => \FPI.OP2\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(44),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.MULO.DRES_1\(104));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(44),
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(104));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff22ffffff0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(44),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datab => \GRFPU0.GRFPU_X0.N_17109\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3210101032321032")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(44),
datae => \GRFPU0.GRFPU_X0.N_17662\,
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(44),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPC0_OP2_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19591\,
dataf => \GRFPU0.GRFPU_X0.N_21440_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(37));
\GRFPC0_OP2_2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19657\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(37),
datad => \GRFPC0.MEM.RREG.RES\(37));
\GRFPC0_OP2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(37),
dataf => \GRFPC0.N_19591\,
datae => \GRFPC0.N_19920\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19657\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_29_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(34),
datac => \FPI.OP2\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(42),
dataf => \GRFPU0.MULO.MRES\(103),
datae => \GRFPU0.MULO.MRES\(102),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f3f0ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(42),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(102),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(42),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(42),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(42),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPC0_OP2_3_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19720\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(34),
datad => \GRFPC0.WR.RREG.RES\(34));
\GRFPC0_OP2_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(34),
dataf => \GRFPC0.N_19851\,
datae => \GRFPC0.N_19785\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19720\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_OP2_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19585\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(31));
\GRFPC0_OP2_2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19651\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(31),
datad => \GRFPC0.MEM.RREG.RES\(31));
\GRFPC0_OP2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(31),
dataf => \GRFPC0.N_19585\,
datae => \GRFPC0.N_19914\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19651\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_23_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(34),
datac => \FPI.OP2\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fcf00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(39),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(100),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(39),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.MULO.DRES_1\(99));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(39),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(39),
datad => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(39),
datad => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(99));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16252\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.MRES\(99),
datad => N_30857,
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(98));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16304\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31079,
datab => N_31078);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31079,
datab => N_31078);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0c0a0c0f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(98),
dataa => \GRFPU0.MULO.MRES\(99));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff0000f00000")
port map (
combout => N_138140,
dataf => \GRFPU0.GRFPU_X0.N_20927\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_2\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555505055455040")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(39),
datae => N_138140,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(39),
datac => \GRFPU0.GRFPU_X0.N_21025\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\);
\GRFPC0_OP2_I_M4_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_23924\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(30));
\GRFPC0_OP2_I_M4_2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_23925\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(30),
datad => \GRFPC0.MEM.RREG.RES\(30));
\GRFPC0_OP2_I_M2_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(30),
dataf => \GRFPC0.N_23924\,
datae => \GRFPC0.N_23950\,
datad => \GRFPC0.OP2_SN_N_9\,
datac => \GRFPC0.N_23925\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_21_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(30),
datac => \FPI.OP2\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fff0f55335533")
port map (
combout => \GRFPU0.GRFPU_X0.N_20608\,
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(97),
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.MULO.DRES_1\(98),
dataa => \GRFPU0.MULO.DRES_1S\(97));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffce")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(38),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(38),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(38),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(38),
dataa => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f303f000f505")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(38),
datad => \GRFPU0.GRFPU_X0.N_17656\,
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_138131,
dataa => N_138130);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(38),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPC0_OP2_1_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19583\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(29));
\GRFPC0_OP2_2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19649\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(29),
datad => \GRFPC0.MEM.RREG.RES\(29));
\GRFPC0_OP2_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(29),
dataf => \GRFPC0.N_19583\,
datae => \GRFPC0.N_19912\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19649\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(29),
datac => \FPI.OP2\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.MULO.DRES_1\(97));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(37),
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.GRFPU_X0.N_5193\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff3030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(37),
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(97));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16250\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.MRES\(97),
datad => N_30853,
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00ccfff0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16302\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.N_267\,
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => \GRFPU0.MULO.DRES_1\(97),
datab => N_31075);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00cc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(37),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16250\,
datac => \GRFPU0.GRFPU_X0.N_16302\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3210101032321032")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(37),
datae => \GRFPU0.GRFPU_X0.N_17655\,
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
dataa => \GRFPU0.GRFPU_X0.ITER.V_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15720\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(48));
\GRFPU0_GRFPU_X0_S3ADDI_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15719\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(47));
\GRFPU0_GRFPU_X0_S3ADDI_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15718\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(46));
\GRFPU0_GRFPU_X0_S3ADDI_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15717\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(45));
\GRFPU0_GRFPU_X0_S3ADDI_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15716\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(44));
\GRFPU0_GRFPU_X0_S3ADDI_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15715\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(43));
\GRFPU0_GRFPU_X0_S3ADDI_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15714\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(42));
\GRFPU0_GRFPU_X0_S3ADDI_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15713\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(41));
\GRFPU0_GRFPU_X0_S3ADDI_0_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15712\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(40));
\GRFPU0_GRFPU_X0_S3ADDI_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15711\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(39));
\GRFPU0_GRFPU_X0_S3ADDI_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15710\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(38));
\GRFPU0_GRFPU_X0_S3ADDI_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15709\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(37));
\GRFPU0_GRFPU_X0_S3ADDI_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15708\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(36));
\GRFPU0_GRFPU_X0_S3ADDI_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15707\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(35));
\GRFPU0_GRFPU_X0_S3ADDI_0_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15706\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(34));
\GRFPU0_GRFPU_X0_S3ADDI_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15705\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(33));
\GRFPU0_GRFPU_X0_S3ADDI_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15704\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(32));
\GRFPU0_GRFPU_X0_S3ADDI_0_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15703\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIF5EJ5_110_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(110),
dataf => N_30881,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(110));
GRFPU0_FPMUL0_R2_RET_206_RNINSHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(99),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30910,
datad => N_30909);
GRFPU0_FPMUL0_R2_RET_159_RNIS2DI_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(120),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009);
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNID34EV1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(28),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31127,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(1));
\GRFPU0_GRFPU_X0_DIFFIN1_RNITP6432_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(29),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31129,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(2));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
dataf => N_31293,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(29));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(30),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31131,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(3));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNI9J34A2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(31),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31133,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(4));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
dataf => N_31297,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(31));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(32),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31135,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(5));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(33),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31137,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(6));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(34),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(7),
datad => N_31139);
\GRFPU0_GRFPU_X0_DIFFIN1_RNIE6AQN2_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(35),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31141,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(8));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
dataf => N_31305,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(35));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(37),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31145,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(10));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(39),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31149,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(12));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(40),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31151,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(13));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNI271GC3_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(41),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31153,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(14));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
dataf => N_31317,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(41));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(42),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(15),
datad => N_31155);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(43),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31157,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(16));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(44),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31159,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(17));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(45),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31161,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(18));
\GRFPU0_GRFPU_X0_DIFFIN1_I_M2_RNIOGRVS3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(46),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31163,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(19));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
dataf => N_31327,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(46));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIHED704_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(47),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31165,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(20));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
dataf => N_31329,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(47));
\GRFPU0_GRFPU_X0_DIFFIN1_RNILI7J34_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(48),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31167,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(21));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
dataf => N_31331,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31360,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_RNO_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31388,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31412,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_RNO_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31440,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18072\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(33));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(33),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18137\,
datab => \GRFPU0.GRFPU_X0.N_18072\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18059\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(20));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18066\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(27));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_0_A2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ccccc000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_246\,
dataf => \GRFPU0.GRFPU_X0.N_19831\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
GRFPU0_GRFPU_X0_COMB_VST4_REG36_RNIUHJD5_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19840\,
dataf => \GRFPU0.GRFPU_X0.N_4066_0\,
datae => \GRFPU0.GRFPU_X0.N_4063\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.N_6485\,
datab => \GRFPU0.GRFPU_X0.N_6484\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
datad => N_36192,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_36192,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_1_61_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003ccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19804\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datad => N_36192,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3c3ccccff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19549\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
datad => \GRFPU0.GRFPU_X0.C\(6),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
GRFPU0_GRFPU_X0_COMB_SIGN2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN2_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datad => \GRFPU0.GRFPU_X0.ST1.OP2NX\);
GRFPU0_GRFPU_X0_COMB_SIGN1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.OP1NX\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(1),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datad => \FPI.OP1_RETO\(1));
\GRFPU0_GRFPU_X0_INF_ABS0_3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(2),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(34));
GRFPU0_GRFPU_X0_UN242_BCO_MSB_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f0f0f000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3256\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(32));
\GRFPU0_GRFPU_X0_BCO_MSB_4_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_3253\,
dataf => \GRFPU0.GRFPU_X0.N_3256\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(2),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_21048\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(38));
\GRFPU0_GRFPU_X0_INF_ABS0_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(4),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(36));
\GRFPU0_GRFPU_X0_L1_3_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_3263\,
dataf => \GRFPU0.GRFPU_X0.N_21048\,
datae => \GRFPU0.GRFPU_X0.N_3266\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_L1_2_5_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_3226\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_10_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_20474\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20792\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(55));
\GRFPU0_GRFPU_X0_L1_1_1_6_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_3283\,
dataf => \GRFPU0.GRFPU_X0.N_20792\,
datae => \GRFPU0.GRFPU_X0.N_3286\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
dataf => \GRFPU0.GRFPU_X0.N_17176\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
\GRFPU0_GRFPU_X0_INF_ABS0_3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(36),
dataf => \GRFPU0.GRFPU_X0.N_17199\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(36),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(51),
dataf => \GRFPU0.GRFPU_X0.N_17214\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(51),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_6_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_21042\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(38));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc3ccc3ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19551\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.C\(8),
datad => N_36129,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(8));
GRFPU0_GRFPU_X0_UN8_C_CARRY_0_RNIQLK63: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19259_1\,
dataf => \GRFPU0.GRFPU_X0.N_19213\,
datae => \GRFPU0.GRFPU_X0.N_19264\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C\(1),
datab => \GRFPU0.GRFPU_X0.UN8_C\(0));
GRFPU0_GRFPU_X0_UN8_C_CARRY_0_RNIV647: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19270\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(1),
datae => \GRFPU0.GRFPU_X0.UN8_C\(0));
GRFPU0_GRFPU_X0_UN8_C_CARRY_7_RNI4TGS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19213\,
dataf => \GRFPU0.GRFPU_X0.N_19212\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(9),
datad => \GRFPU0.GRFPU_X0.UN8_C\(8),
datac => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17338\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31042,
datad => N_31041,
datac => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNO_0_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc30fc30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I\,
datae => \GRFPU0.MULO.MRES\(99),
datad => N_31022,
datac => N_31021,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
GRFPU0_GRFPU_X0_COMB_EXP37: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP37\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNIBKTV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff00f0ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_77_I\,
dataf => \GRFPU0.MULO.MRES\(68),
datae => \GRFPU0.MULO.MRES\(69),
datad => \GRFPU0.GRFPU_X0.ITER.NORM\,
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0));
GRFPU0_GRFPU_X0_EXPOP_1_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_RNDOP_32_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
dataf => \GRFPU0.GRFPU_X0.N_19314\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.MULO.MRES\(96));
GRFPU0_FPMUL0_R2_RET_185_RNI3HIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(121),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30954,
datad => N_30953);
GRFPU0_GRFPU_X0_UN1_EXPOP_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00ccc00000c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPOP_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA_0\,
datab => \GRFPU0.MULO.DRES_1\(121));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS1\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.INST\(25),
datac => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.PC\(25),
dataa => \GRFPC0.MEM.CTRL.PC\(25));
\GRFPC0_EX_CTRL_PC_RNO_1_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(25),
datad => \GRFPC0.FIFO.PC_1\(25));
\GRFPC0_FIFO_RD_5_RNIP1EQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
dataf => \GRFPC0.FIFO.INST_0\(25),
datae => \GRFPC0.FIFO.RD_1_0\(0),
datad => \GRFPC0.FIFO.INST_1_0\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25),
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G3\,
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(25),
dataa => \GRFPC0.EX.CTRL.PC\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_25_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0ccffaaf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(25),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.WR2.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.PC\(25),
dataa => \GRFPC0.DIV.INST\(25));
\GRFPC0_EX_CTRL_PC_RNO_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(16),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.PC_0\(16),
datad => \GRFPC0.FIFO.PC_1\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS4\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16),
datac => \GRFPC0.V.STDATA_14\(16),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M0\(16),
dataa => \GRFPC0.EX.CTRL.PC\(16));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccaafff0ccaa00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(16),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SS7\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM7\,
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(16),
dataa => \GRFPC0.WR2.CTRL.PC\(16));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2637_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_251\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_DEP_2_IV_0_I2_0_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.CHECK_DEP.UN4759_REGDEPX_2_LI\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_0_0\(26));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1329_REGDEPX2_0_A2_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25465\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3));
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNI3KBP_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_53__N_6_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(52),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31175,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(25));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(51),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31173,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(24));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNINMB2A4_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(23),
datad => N_31171);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
dataf => N_31335,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIQGPQ64_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(49),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31169,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(22));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
dataf => N_31333,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(49));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_RNIHDEQ13_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(38),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31147,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(11));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
dataf => N_31311,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(38));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_RNI9SNMQ2_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(36),
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31143,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(9));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
dataf => N_31307,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(36));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc0f0ff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G4\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31177,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26),
datac => N_31125,
datab => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(0));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ffff03fc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(27),
dataf => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G4\,
datad => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G2\,
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_27__G2\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31125,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(0));
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNIENGRH4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G5\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
datae => N_31177,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1_1\(26));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18067\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(28));
\GRFPU0_GRFPU_X0_UN1_INCDP_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f0f0f0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INCDP\(0),
dataf => \GRFPU0.GRFPU_X0.N_15674\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datac => \GRFPU0.GRFPU_X0.COMB.G_DP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3c003cffcc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => N_36187,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00cf003000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18163\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(8),
datae => N_35944,
datad => \GRFPU0.GRFPU_X0.N_6328\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
GRFPU0_GRFPU_X0_UN1_VST3_REG_2_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000fcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG_2_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_19484\,
datae => \GRFPU0.GRFPU_X0.N_6654\,
datad => \GRFPU0.GRFPU_X0.N_6611\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.DIFFN\);
GRFPU0_GRFPU_X0_COMB_VST3_RDY41: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6611\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
\GRFPU0_GRFPU_X0_REST_2_IV_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffc0000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_REST_2_IV_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff00000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_IV_1\(2),
dataf => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
GRFPU0_GRFPU_X0_UN1_VST2_REG108: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG108\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.REST_2_IV_1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNID5S61_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_REST_1_2_IV_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffc0000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_REST_1_2_IV_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff00000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_IV_1\(2),
dataf => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
GRFPU0_GRFPU_X0_UN1_VITER_EXP28: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\,
dataf => \GRFPU0.GRFPU_X0.N_4227\,
datae => \GRFPU0.GRFPU_X0.REST_1_2_IV_1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1_M\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcfcfcfc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_5__G2_0\,
dataf => \GRFPU0.GRFPU_X0.N_4352\,
datae => \GRFPU0.GRFPU_X0.N_4227\,
datad => \GRFPU0.GRFPU_X0.N_4997\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
GRFPU0_GRFPU_X0_COMB_CCV18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV18\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
GRFPU0_GRFPU_X0_VST2_EXC_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datae => \GRFPU0.GRFPU_X0.COMB.CCV18\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"dfcedfcedfce5342")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(55),
dataf => \GRFPU0.GRFPU_X0.N_19817\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(55),
datad => \GRFPU0.GRFPU_X0.N_16772\,
datac => \GRFPU0.GRFPU_X0.N_13127_I\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
dataa => \GRFPU0.GRFPU_X0.N_19890\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_16772\,
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_0_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_0\(55),
dataf => \GRFPU0.GRFPU_X0.N_19821_1\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(4),
datad => \GRFPU0.GRFPU_X0.N_19832\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3cf00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_0\(55),
datae => \GRFPU0.GRFPU_X0.N_19818_1\,
datad => N_36102,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff003cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_2\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_1\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => N_36167,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
\GRFPC0_OP2_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19598\,
dataf => \GRFPU0.GRFPU_X0.N_21431_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(44));
\GRFPC0_OP2_2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19664\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(44),
datad => \GRFPC0.MEM.RREG.RES\(44));
\GRFPC0_OP2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(44),
dataf => \GRFPC0.N_19598\,
datae => \GRFPC0.N_19927\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19664\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(41),
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(41),
datac => \FPI.OP2\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(49),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00f0ccfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(49),
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.MULO.MRES\(110),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16262\,
dataf => N_30877,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(108));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16314\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31099,
datab => N_31098);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
dataf => \GRFPU0.GRFPU_X0.N_16262\,
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16314\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ee22ff33fc30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
datad => \GRFPU0.GRFPU_X0.N_17667\,
datac => N_138114,
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => N_138115);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(49),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03fc03ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19545\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.C\(2),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00ff00fffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19546\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.C\(3),
datad => N_36109,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc3ccc3ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19547\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.C\(4),
datad => N_36109,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00f0fff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19552\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => N_36139,
datad => \GRFPU0.GRFPU_X0.C\(9),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33333c3cff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19553\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => N_36139,
datad => \GRFPU0.GRFPU_X0.C\(10),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000fffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21876\,
dataf => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(3),
datae => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(2),
datad => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(1),
datac => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(0));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_A2_0_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000003f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_3\,
dataf => \GRFPU0.GRFPU_X0.N_21876\,
datae => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(9),
datad => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(8),
datac => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(5),
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(4));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_A2_0_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_4\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_3\,
datae => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(10),
datad => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(7),
datac => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(6));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_A2_0_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff00000fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.N_19536\,
datae => \GRFPU0.GRFPU_X0.C\(6),
datad => \GRFPU0.GRFPU_X0.C\(5),
datac => \GRFPU0.GRFPU_X0.C\(4),
datab => \GRFPU0.GRFPU_X0.C\(3));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_O4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19536\,
dataf => \GRFPU0.GRFPU_X0.C\(1),
datae => \GRFPU0.GRFPU_X0.C\(0),
datad => \GRFPU0.GRFPU_X0.C\(2));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIJRJG8_118_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(118),
dataf => N_30897,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0aacc00f0aacc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
dataf => \GRFPU0.MULO.DRES_S\(118),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.MULO.DRES_1\(119),
dataa => \GRFPU0.MULO.DRES_1S\(118));
\GRFPU0_GRFPU_X0_COMB_VST4_MEXP_1_0_2__G0_0_M2\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(121),
datad => N_31011);
GRFPU0_GRFPU_X0_COMB_EXPINC_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fffcf3f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => N_31066,
datad => N_31065,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_S3ADDI_0_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15722\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(50));
\GRFPU0_GRFPU_X0_S3ADDI_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15725\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(53));
\GRFPU0_GRFPU_X0_S3ADDI_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15724\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(52));
\GRFPU0_GRFPU_X0_S3ADDI_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15723\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(51));
\GRFPU0_GRFPU_X0_S3ADDI_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15721\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(49));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15674\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNINOIB_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19432\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIK9US_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_15\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI92LP_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000ff0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G1_E_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datae => \GRFPU0.GRFPU_X0.ITER.V_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_42_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(25),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(26),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(24),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(27));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M7_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M5_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M8_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M6_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M16_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfccc3c00f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M15_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M13_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M12_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M11_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M10_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M9_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_18_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(44),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(10),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(9),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(11));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_38_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(34),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(15),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(13),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(12));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M2_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M1_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_16_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(51),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(50),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_44_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_44\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_3\(18),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_0\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(18),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(35));
GRFPU0_GRFPU_X0_UN1_VST3_REG_4_SQMUXA_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6639\,
dataf => \GRFPU0.GRFPU_X0.N_7053\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_31_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(62),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(1),
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_62_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ffffff0300ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(62),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(62),
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\,
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
GRFPU0_GRFPU_X0_VST3_ZERO_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0c0c0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.ZERO_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.N_6661\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0c0cfc0c0cfcf")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(4),
datae => \GRFPU0.GRFPU_X0.N_10889\,
datad => \GRFPU0.GRFPU_X0.L4_1\(4),
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.MULO.DRES_1\(92),
datab => \GRFPU0.MULO.DRES_1S\(91),
dataa => \GRFPU0.MULO.DRES_S\(91));
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf3f00f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G4\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.N_10710_0\,
datab => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G4\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datae => \GRFPU0.GRFPU_X0.N_19472\,
datad => \GRFPU0.GRFPU_X0.N_10715\,
datac => \GRFPU0.GRFPU_X0.N_10717\,
datab => \GRFPU0.GRFPU_X0.L4_4_I_A2_2\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
datad => \GRFPU0.GRFPU_X0.N_10710\,
datac => \GRFPU0.GRFPU_X0.N_10716\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datab => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.N_17_I\,
datac => \GRFPU0.GRFPU_X0.N_10710\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_4_03_0_G1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datad => \GRFPU0.GRFPU_X0.N_10710_0\,
datac => \GRFPU0.GRFPU_X0.N_10716\);
\GRFPU0_GRFPU_X0_L4_4_I_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17_I\,
dataf => \GRFPU0.GRFPU_X0.N_10716\,
datae => \GRFPU0.GRFPU_X0.N_19472\,
datad => \GRFPU0.GRFPU_X0.N_10715\,
datac => \GRFPU0.GRFPU_X0.N_10717\,
datab => \GRFPU0.GRFPU_X0.L4_4_I_A2_2\(4));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2_3\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN6_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_1_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6_1_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffcf3000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\,
dataf => \GRFPU0.GRFPU_X0.N_7645\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN6\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN2\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16265\,
dataf => N_30883,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16317\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31105,
datab => N_31104);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0c0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(51),
dataf => \GRFPU0.GRFPU_X0.N_16265\,
datae => \GRFPU0.GRFPU_X0.N_19499_0\,
datad => \GRFPU0.GRFPU_X0.N_16317\,
datac => \GRFPU0.GRFPU_X0.N_19502_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_31_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(35),
datac => \FPI.OP2\(38));
\GRFPC0_OP2_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19595\,
dataf => \GRFPU0.GRFPU_X0.N_21430_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(41));
\GRFPC0_OP2_2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19661\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(41),
datad => \GRFPC0.MEM.RREG.RES\(41));
\GRFPC0_OP2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(41),
dataf => \GRFPC0.N_19595\,
datae => \GRFPC0.N_19924\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19661\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPC0_OP2_1_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19592\,
dataf => \GRFPU0.GRFPU_X0.N_21435_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(38));
\GRFPC0_OP2_2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19658\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(38),
datad => \GRFPC0.MEM.RREG.RES\(38));
\GRFPC0_OP2_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(38),
dataf => \GRFPC0.N_19592\,
datae => \GRFPC0.N_19921\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19658\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19186_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(41),
datac => \FPI.OP2\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(46),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00f0ccfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_0\(46),
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.MULO.MRES\(107),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_3_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_2\(46),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.MULO.DRES_1\(106));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_4_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_3\(46),
datad => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(106));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16259\,
dataf => N_30871,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(105));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16311\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31093,
datab => N_31092);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0a0c0a0f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.MULO.MRES\(106),
dataa => \GRFPU0.MULO.MRES\(105));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff0000f00000")
port map (
combout => N_138142,
dataf => \GRFPU0.GRFPU_X0.N_17664\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V_2\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555505055455040")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_M\(46),
datae => N_138142,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_4\(46),
datac => \GRFPU0.GRFPU_X0.N_21025\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\);
\GRFPC0_OP2_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19565\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(11));
\GRFPC0_OP2_2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19631\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(11),
datad => \GRFPC0.MEM.RREG.RES\(11));
\GRFPC0_OP2_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(11),
dataf => \GRFPC0.N_19565\,
datae => \GRFPC0.N_19894\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19631\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_11_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(19),
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(19),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(79),
datac => \GRFPU0.MULO.DRES_1\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(79),
datac => \GRFPU0.MULO.DRES_1\(79),
datab => \GRFPU0.MULO.DRES_1S\(78),
dataa => \GRFPU0.MULO.DRES_S\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(19),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41));
\GRFPC0_OP2_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19563\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(9));
\GRFPC0_OP2_2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19629\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(9),
datad => \GRFPC0.MEM.RREG.RES\(9));
\GRFPC0_OP2_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(9),
dataf => \GRFPC0.N_19563\,
datae => \GRFPC0.N_19892\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19629\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_9_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(17),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.DRES_1\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(17),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(17),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPC0_OP2_1_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19582\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(28));
\GRFPC0_OP2_2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19648\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(28),
datad => \GRFPC0.MEM.RREG.RES\(28));
\GRFPC0_OP2_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(28),
dataf => \GRFPC0.N_19582\,
datae => \GRFPC0.N_19911\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19648\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_28_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31400,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31348,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0cfc03f300f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(36),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_174935_0);
\GRFPC0_OP1_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18995\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(12));
\GRFPC0_OP1_2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19061\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(12),
datad => \GRFPC0.MEM.RREG.RES\(12));
\GRFPC0_OP1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(12),
dataf => \GRFPC0.N_19324\,
datae => \GRFPC0.N_18995\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19061\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(20),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(47),
datac => \FPI.OP1\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(52),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(52),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_2_RNO_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000f00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_I_M\(55),
dataf => \GRFPU0.SQRTAPPR\(3),
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(55));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI90127_114_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(114),
dataf => N_30889,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(114));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0aacc00f0aacc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
dataf => \GRFPU0.MULO.DRES_S\(114),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.MULO.DRES_1\(115),
dataa => \GRFPU0.MULO.DRES_1S\(114));
\GRFPU0_SQRTROM0_DATA_1_6_0__M77\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"22266667555ddd99")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_78\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(5),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_6_0__M82\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fddfa88a75572002")
port map (
combout => \GRFPU0.SQRTAPPR\(3),
dataf => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_81\,
datae => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_78\,
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_79\,
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf00c0f0c00")
port map (
combout => N_138075,
dataf => \GRFPU0.GRFPU_X0.N_17673\,
datae => \GRFPU0.SQRTAPPR\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8d8d88888ddd88d8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_I_M\(55),
datae => N_138075,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
datac => \GRFPU0.GRFPU_X0.N_21025\,
datab => \GRFPU0.DIVAPPR\(3),
dataa => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\);
\GRFPU0_DIVROM0_DATA_1_6_0__M139\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a2b3e6f78091c4d5")
port map (
combout => \GRFPU0.DIVAPPR\(3),
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_135\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_131\,
datad => \GRFPU0.DIVROM0.DATA_1_6_0_.N_127\,
datac => \GRFPU0.DIVROM0.DATA_1_6_0_.N_138\,
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_SQRTROM0_DATA_1_6_0__M49\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000000000")
port map (
combout => N_124803,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_SQRTROM0_DATA_1_6_0__M1\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_2\,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_SQRTROM0_DATA_1_6_0__M46\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ffffff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_47\,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2),
datad => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_SQRTROM0_DATA_1_6_0__M3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_4\,
dataf => \GRFPU0.DIVROM0.RADDR\(3),
datae => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_6_0__M123\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003ffff00003ffff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_124\,
dataf => \GRFPU0.DIVROM0.RADDR\(4),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_6_0__M126\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc3fff00c033f3")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_6_0_.N_127\,
dataf => \GRFPU0.DIVROM0.DATA_1_6_0_.N_110\,
datae => \GRFPU0.DIVROM0.DATA_1_6_0_.N_124\,
datad => \GRFPU0.SQRTROM0.DATA_1_6_0_.N_4\,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20925\,
dataf => N_174935,
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34),
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(36),
datac => \FPI.OP1\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(44),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(44),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(42),
datac => \FPI.OP1\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(47),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(47),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPC0_OP2_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19589\,
dataf => \GRFPU0.GRFPU_X0.N_19990_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(35));
\GRFPC0_OP2_2_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19655\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(35),
datad => \GRFPC0.MEM.RREG.RES\(35));
\GRFPC0_OP2_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(35),
dataf => \GRFPC0.N_19589\,
datae => \GRFPC0.N_19918\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19655\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPC0_OP2_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19586\,
dataf => \FPO.RES\(32),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(32));
\GRFPC0_OP2_2_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19652\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(32),
datad => \GRFPC0.MEM.RREG.RES\(32));
\GRFPC0_OP2_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(32),
dataf => \GRFPC0.N_19586\,
datae => \GRFPC0.N_19915\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19652\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_25_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(32),
datac => \FPI.OP2\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31408,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31356,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c00c000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20993\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
datad => \GRFPU0.GRFPU_X0.N_19496_0\,
datac => N_174935_0,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_20993\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.MULO.MRES\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccff0c0fccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(40),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(40),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.DRES_1\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03fff300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_21025\,
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_271\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datad => \GRFPU0.MULO.MRES\(100),
datac => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datab => \GRFPU0.MULO.DRES_1\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_5_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_5\(40),
dataf => \GRFPU0.GRFPU_X0.N_271\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
datab => \GRFPU0.GRFPU_X0.N_296\);
\GRFPC0_OP1_1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19001\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(18));
\GRFPC0_OP1_2_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19067\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(18),
datad => \GRFPC0.MEM.RREG.RES\(18));
\GRFPC0_OP1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(18),
dataf => \GRFPC0.N_19330\,
datae => \GRFPC0.N_19001\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19067\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(26),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_0_1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(41),
datac => \FPI.OP1\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(49),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(49),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(49));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(49),
datac => \FPI.OP1\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(50),
datac => \FPI.OP1\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(55),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(55),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(55));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(45),
datac => \FPI.OP1\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(53),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(53),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
\GRFPC0_OP1_1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19003\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(20));
\GRFPC0_OP1_2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19069\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(20),
datad => \GRFPC0.MEM.RREG.RES\(20));
\GRFPC0_OP1_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(20),
dataf => \GRFPC0.N_19332\,
datae => \GRFPC0.N_19003\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19069\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(28),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPC0_OP2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19555\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(1));
\GRFPC0_OP2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19621\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(1),
datad => \GRFPC0.DIV.RESULT\(1));
\GRFPC0_OP2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(1),
dataf => \GRFPC0.N_19555\,
datae => \GRFPC0.N_19884\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19621\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_1_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc0c0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20989\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => N_174935_0,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51),
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_0_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccff0c0fccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(9),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(9),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datab => \GRFPU0.MULO.DRES_1\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_1\(9),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.MULO.DRES_1\(69),
datab => \GRFPU0.MULO.DRES_1S\(68),
dataa => \GRFPU0.MULO.DRES_S\(68));
GRFPU0_FPMUL0_R2_RET_166_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(113),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(113),
datad => N_30995);
\GRFPC0_OP1_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_18990\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(7));
\GRFPC0_OP1_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19056\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(7),
datad => \GRFPC0.MEM.RREG.RES\(7));
\GRFPC0_OP1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(7),
dataf => \GRFPC0.N_19319\,
datae => \GRFPC0.N_18990\,
datad => \GRFPC0.OP1_SN_N_6_0\,
datac => \GRFPC0.OP1_SN_N_9_1\,
datab => \GRFPC0.N_19056\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(15),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
\GRFPC0_OP1_1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19004\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.RFA2.RS1SEL_0\(4),
datad => \GRFPC0.WR2.RREG.RES\(21));
\GRFPC0_OP1_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19070\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(21),
datad => \GRFPC0.MEM.RREG.RES\(21));
\GRFPC0_OP1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(21),
dataf => \GRFPC0.N_19333\,
datae => \GRFPC0.N_19004\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19070\);
\GRFPC0_OP1_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19014\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(31));
\GRFPC0_OP1_2_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19080\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(31),
datad => \GRFPC0.MEM.RREG.RES\(31));
\GRFPC0_OP1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(31),
dataf => \GRFPC0.N_19343\,
datae => \GRFPC0.N_19014\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19080\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(34),
datac => \FPI.OP1\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(39),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(34),
datac => \FPI.OP1\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(42),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0ffff00c000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_283\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3842_REGDEPX2_2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4283_REGDEPX2_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(3),
datae => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_4_0_0\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
dataf => \GRFPC0.MEM.CTRL.RDD_0\,
datae => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_A2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25565\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_0_A2_4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_234_1\,
dataf => \GRFPC0.EX.CTRL.INST\(26),
datae => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FIFO_INST_0_RNI0SRP_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.V.STDATA_14\(14),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(14),
datad => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_280\(0),
dataf => \GRFPC0.N_23648\,
datae => \GRFPC0.N_207\,
datad => \GRFPC0.N_23870\,
datac => \GRFPC0.N_305\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_14_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_14\(0),
dataf => \GRFPC0.N_23788\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.RDD_2\,
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_OP1_1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19006\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.RFA2.RS1SEL_1\(4),
datad => \GRFPC0.WR2.RREG.RES\(23));
\GRFPC0_OP1_2_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19072\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(23),
datad => \GRFPC0.MEM.RREG.RES\(23));
\GRFPC0_OP1_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf0fcff0c000c0")
port map (
combout => \FPI.OP1\(23),
dataf => \GRFPC0.N_19335\,
datae => \GRFPC0.N_19006\,
datad => \GRFPC0.OP1_SN_N_6_1\,
datac => \GRFPC0.OP1_SN_N_9\,
datab => \GRFPC0.N_19072\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(31),
dataf => \GRFPU0.GRFPU_X0.N_20635_0\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19379\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19379\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19367\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19367\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_01\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_8_RNIUOF92: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc000000f0")
port map (
combout => N_91841,
dataf => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19191\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(8),
datad => \GRFPU0.GRFPU_X0.C\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003c0000003")
port map (
combout => \GRFPU0.GRFPU_X0.N_52\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.C\(9),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00ff00fffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19550\,
dataf => \GRFPU0.GRFPU_X0.VITER.EXP_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => N_36129,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff3fff0fffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\,
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.FLUSH0_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33333333f3333333")
port map (
combout => \GRFPU0.GRFPU_X0.N_51\,
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.C\(9),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4378\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
GRFPU0_GRFPU_X0_ITER_V_3_RNIH2FH: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datae => \GRFPU0.GRFPU_X0.ITER.V_3\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIF5GG4_107_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(107),
dataf => N_30875,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(107));
GRFPU0_FPMUL0_R2_RET_171_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(108),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(108),
datad => N_30985);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16313\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1S\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30928,
datab => N_30927);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
dataf => \GRFPU0.MULO.DRES_S\(107),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16313\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(108));
GRFPU0_FPMUL0_R2_RET_172_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(107),
datad => N_30983);
\GRFPU0_GRFPU_X0_BCO_MSB_2_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3813\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_BCO_MSB_1_2_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3733\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_L1_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff03ffffff00")
port map (
combout => N_124836,
dataf => \GRFPU0.GRFPU_X0.N_3733\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_L3_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000330f330f")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(1),
dataf => \GRFPU0.GRFPU_X0.L2_0\(4),
datae => \GRFPU0.GRFPU_X0.L1_2_6\(1),
datad => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datac => N_124836,
datab => N_124837);
\GRFPU0_GRFPU_X0_BCO_MSB_2_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_L1_1_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f30000f3f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_BCO_MSB_1_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_L1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff330000ff30")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_2\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_L3_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0\(4),
datae => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datad => \GRFPU0.GRFPU_X0.L1_0\(0),
datac => \GRFPU0.GRFPU_X0.L1_1_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_6\(0));
GRFPU0_GRFPU_X0_VITER_DBUF_7_1_ANC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO1\,
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1));
GRFPU0_GRFPU_X0_UN73_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_L2_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0\(2),
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => \GRFPU0.GRFPU_X0.N_3846\,
datad => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIELKA2_101_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(101),
dataf => N_30863,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16307\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(102),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31085,
datab => N_31084);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc0c0cff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(101),
datad => \GRFPU0.GRFPU_X0.N_16307\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(102));
GRFPU0_GRFPU_X0_COMB_VST4_REG16_3_RNII41H1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccfffcfffcfff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_4\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_3\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI7RF21_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIJU9B2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6485\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI4RF21_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIJU9B2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6484\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_77_2\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_VST4_RDY4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7297\,
dataf => \GRFPU0.GRFPU_X0.N_6485\,
datae => \GRFPU0.GRFPU_X0.N_6484\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_COMB_VST4_REG16_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_VST4_REG16_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_VST4_EXC_1_SQMUXA_9_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_4\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG16_3\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6606_REGDEPX2_2_0_A2_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_25271\,
dataf => \GRFPC0.DIV.INST\(18),
datae => \GRFPC0.DIV.INST\(15));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6606_REGDEPX2_1_I_O3_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24278\,
dataf => \GRFPC0.DIV.INST\(16),
datae => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_8_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_10_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_3\(1),
dataf => \GRFPC0.N_25192\,
datae => \GRFPC0.N_23217\,
datad => \GRFPC0.N_25164\,
datac => \GRFPC0.N_25367_I\,
datab => \GRFPC0.N_25236\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6549_REGDEPX2_0_A2_1_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6549_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_14_0\(1),
dataf => \GRFPC0.DIV.RD_0\(3),
datae => \GRFPC0.DIV.RD_0\(4));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_19_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.RD\(0));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1300_REGDEPX2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_23821\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6621_REGDEPX2_2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
dataf => \GRFPC0.DIV.INST\(4),
datae => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
dataf => \GRFPC0.DIV.RDD_0\,
datae => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_A2_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25225\,
dataf => \GRFPC0.N_25759\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2976_REGDEPX2_0_A2_0_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25236\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5681_REGDEPX2_2_0_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25117\,
dataf => \GRFPC0.WR2.CTRL.INST\(18),
datae => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25234\,
dataf => \GRFPC0.WR.CTRL.INST\(2),
datae => \GRFPC0.WR.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1271_REGDEPX2_0_A2_0_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24327\,
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_10_7_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_7\(1),
dataf => \GRFPC0.N_25186\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_4\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_10_3\(1),
datac => \GRFPC0.N_25451_2\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6549_REGDEPX2\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_24794\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_A2_0_A2_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_25695\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6414_REGDEPX2_1_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23865\,
dataf => \GRFPC0.EX.CTRL.INST\(28),
datae => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_O2_0_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_O2_0_0\(1),
dataf => \GRFPC0.N_24791\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datad => \GRFPC0.N_25695\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6473_REGDEPX2_2_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3827_REGDEPX2_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(18),
datae => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_1_I_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22305\,
dataf => \GRFPC0.FIFO.INST_1_0\(6),
datae => \GRFPC0.FIFO.INST_1\(14));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_I_O3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22310\,
dataf => \GRFPC0.FIFO.INST_1_0\(6),
datae => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
dataf => \GRFPC0.FIFO.INST_0_0\(6),
datae => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_256_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.FIFO.INST_0_I_M_2\(25),
dataf => \GRFPC0.FP_PIPELINE.11.0.IS_RDD.TMP_1\,
datae => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.INST_0_0\(27),
datab => \GRFPC0.FIFO.INST_0_0\(28));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_256_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000cf0f0f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_256\(1),
dataf => \GRFPC0.FIFO.INST_0_I_M_2\(25),
datae => N_174896,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.UN1_FIFO.INST_0_9\,
datab => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4464_REGDEPX\);
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(1),
dataf => \GRFPC0.FIFO.INST_0\(0),
datae => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_14_REGDEPX_264_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX_264\(1),
dataf => \GRFPC0.FP_PIPELINE.14.1.REGDEPX_262\(1),
datae => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_258\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22310\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(1),
dataf => N_109,
datae => N_117);
GRFPU0_GRFPU_X0_COMB_UN26_FLUSH_RNILR1F1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f030f0f0f030")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.V_1_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_1_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_19405\,
datad => \GRFPU0.GRFPU_X0.N_18972\,
datac => \GRFPU0.GRFPU_X0.N_19307\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
GRFPU0_GRFPU_X0_COMB_UN26_FLUSH: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f03c0fc33c0fc3f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18972\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(3),
datae => \FPI.FLUSHID\(5),
datad => \FPI.FLUSHID\(4),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(5),
datab => \GRFPU0.GRFPU_X0.ST1.ID\(4));
GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1_0\);
GRFPU0_GRFPU_X0_ST4_MOF_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.EMAX\);
GRFPC0_VEX_CTRL_ID_2_1_CO1_RNIE9EK: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \FPI.OPID\(5),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO1\,
datae => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.EX.CTRL.ID\(3),
datac => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.EX.CTRL.ID\(5));
\GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_ALTB_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f0fcff00c0f0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(2),
datae => \FPI.OPID\(4),
datad => \FPI.OPID\(3),
datac => \FPI.FLUSHID\(4),
datab => \FPI.FLUSHID\(3));
GRFPC0_FP_PIPELINE_UN26_FPUSTART_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_FPUSTART_0\,
dataf => N_204,
datae => N_205);
GRFPC0_RFA_ST_0_RNI3FBQ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => N_50504_4,
dataf => \GRFPC0.RFA.LD_0\,
datae => \GRFPC0.RFA.ST_0\);
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F0_I_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcffff0fffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_19306\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1));
GRFPU0_GRFPU_X0_ITER_LOB_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003330ffccfffc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1_0\,
dataf => \GRFPU0.GRFPU_X0.N_19306\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datad => \GRFPU0.GRFPU_X0.ITER.LOB\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(2));
GRFPU0_GRFPU_X0_COMB_VITER_LOB_5_F0_I_A2_2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_A2_2_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(7));
\GRFPU0_GRFPU_X0_BCO_MSB_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPU0_GRFPU_X0_L1_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0f0c0f0c0f0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_BCO_MSB_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_L1_2_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff003300ff0030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_3\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_2_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_L1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_2\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_BCO_MSB_1_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_L1_0_1_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_L2_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_7370\,
datae => \GRFPU0.GRFPU_X0.L1_1\(0),
datad => \GRFPU0.GRFPU_X0.N_7376\,
datac => \GRFPU0.GRFPU_X0.L1_0_1_2\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_1\(0));
\GRFPU0_GRFPU_X0_L3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_7365\,
datae => \GRFPU0.GRFPU_X0.L2_0_2\(0),
datad => \GRFPU0.GRFPU_X0.L1_2\(3),
datac => \GRFPU0.GRFPU_X0.L1_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_2\(0));
\GRFPU0_GRFPU_X0_L1_6_1_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303330333033300")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_6_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L1_4_1_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cceecece00880808")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(1),
dataf => \GRFPU0.GRFPU_X0.L4_3_I\(1),
datae => N_174934,
datad => \GRFPU0.GRFPU_X0.L3_0\(0),
datac => \GRFPU0.GRFPU_X0.L4_2_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcfcf00cc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(1),
datae => N_174934,
datad => \GRFPU0.GRFPU_X0.L3_0\(2),
datac => \GRFPU0.GRFPU_X0.L4_2_1\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(2),
datae => \GRFPU0.GRFPU_X0.L4_3\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffc0f0f0fc00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4LT6\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(3),
datae => N_174934,
datad => \GRFPU0.GRFPU_X0.L4_3\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
GRFPU0_GRFPU_X0_ITER_LOB_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222ee2222222e22")
port map (
combout => N_91844,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4LT6\,
datae => \GRFPU0.GRFPU_X0.N_19310\,
datad => \GRFPU0.GRFPU_X0.ITER.LOB_0_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.LOB_5_F0_I_A2_2_1\,
datab => \GRFPU0.GRFPU_X0.ITER.V_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\);
GRFPU0_GRFPU_X0_UN1_VITER_STATE_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc0f3")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.STATE_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6809\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18039\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18065\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(10),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(70),
datac => \GRFPU0.MULO.DRES_1\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(70),
datac => \GRFPU0.MULO.DRES_1\(70),
datab => \GRFPU0.MULO.DRES_1S\(69),
dataa => \GRFPU0.MULO.DRES_S\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(10),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
GRFPU0_GRFPU_X0_COMB_INCX16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03ff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_8376\,
dataf => \GRFPU0.GRFPU_X0.N_7229_3\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_2\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_FLUSH0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6328\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datae => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\);
\GRFPU0_GRFPU_X0_L2_0_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(2),
dataf => \GRFPU0.GRFPU_X0.N_7370\,
datae => \GRFPU0.GRFPU_X0.N_7376\,
datad => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPU0_GRFPU_X0_L3_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcc0fccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(2),
dataf => \GRFPU0.GRFPU_X0.N_7365\,
datae => \GRFPU0.GRFPU_X0.L2_0_2\(2),
datad => \GRFPU0.GRFPU_X0.L1_2\(3),
datac => \GRFPU0.GRFPU_X0.N_19295\,
datab => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4\(3),
datae => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3905_1\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
GRFPU0_GRFPU_X0_ITER_NX_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\,
dataf => \GRFPU0.GRFPU_X0.COMB.STICKY_1\,
datae => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12));
GRFPU0_GRFPU_X0_UN133_BCO_LSB_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_0_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(19),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.DRES_1S\(118));
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_S_1_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4020082004200420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB_S_1\(5),
dataf => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datad => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_L4_D_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcffff0000")
port map (
combout => N_138078,
dataf => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(19),
datab => \GRFPU0.GRFPU_X0.N_3576\);
GRFPU0_FPMUL0_R2_RET_194_RNI3PIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(111),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30934,
datad => N_30933);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(14),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(111),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31103,
datab => N_31102);
GRFPU0_FPMUL0_R2_RET_196_RNIUSIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(109),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30930,
datad => N_30929);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31099,
datab => N_31098);
GRFPU0_FPMUL0_CS_DP_R_RET_38_RNICV1M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31097,
datad => N_31096);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1S\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30928,
datab => N_30927);
\GRFPU0_GRFPU_X0_L1_5_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222222200ff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_5_1_3_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(15),
dataa => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\(0));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31089,
datab => N_31088);
GRFPU0_FPMUL0_R2_RET_199_RNI4TIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(106),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30924,
datad => N_30923);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_9_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31093,
datab => N_31092);
GRFPU0_FPMUL0_R2_RET_198_RNI2TIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30926,
datad => N_30925);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31095,
datab => N_31094);
GRFPU0_FPMUL0_R2_RET_203_RNIQOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(102),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30916,
datad => N_30915);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(102),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31085,
datab => N_31084);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(100),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31081,
datab => N_31080);
\GRFPU0_GRFPU_X0_L1_4_1_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cacaffca")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(101),
dataa => \GRFPU0.MULO.DRES_1S\(100));
\GRFPU0_GRFPU_X0_L1_4_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f200f2ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1_3\(0),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10));
GRFPU0_FPMUL0_R2_RET_186_RNISKIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(119),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30950,
datad => N_30949);
GRFPU0_FPMUL0_R2_RET_79_RNIODVO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31119,
datad => N_31118);
GRFPU0_FPMUL0_R2_RET_188_RNI0LIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30946,
datad => N_30945);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(20),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31115,
datab => N_31114);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(19),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1S\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30944,
datab => N_30943);
\GRFPU0_FPMUL0_VS2_96_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.N_267\,
dataf => \GRFPU0.FPMUL0.SX\(96),
datae => \GRFPU0.FPMUL0.CS_DP_R\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0cc00ccff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.N_267\,
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => \GRFPU0.MULO.DRES_1\(97),
datab => N_31075);
\GRFPU0_GRFPU_X0_L4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aea2aea2eeee2222")
port map (
combout => \GRFPU0.GRFPU_X0.L4\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_4\(0),
datad => \GRFPU0.GRFPU_X0.L1_5_4\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datab => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
dataa => N_138079);
GRFPU0_FPMUL0_R2_RET_192_RNIVOIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(113),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30938,
datad => N_30937);
GRFPU0_FPMUL0_CS_DP_R_RET_33_RNIBV1M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31107,
datad => N_31106);
GRFPU0_FPMUL0_R2_RET_193_RNI1PIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30936,
datad => N_30935);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(15),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31105,
datab => N_31104);
GRFPU0_FPMUL0_R2_RET_190_RNIROIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30942,
datad => N_30941);
GRFPU0_FPMUL0_CS_DP_R_RET_31_RNI7V1M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(114),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31111,
datad => N_31110);
GRFPU0_FPMUL0_R2_RET_191_RNITOIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(114),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30940,
datad => N_30939);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(17),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(114),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31109,
datab => N_31108);
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffa60059ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2LT6\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(1),
datae => N_138220,
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB_S_1\(5),
datac => \GRFPU0.GRFPU_X0.L4_2_2\(2),
datab => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
GRFPU0_GRFPU_X0_ITER_NX_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2LT6\,
datae => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6));
GRFPU0_GRFPU_X0_ITER_NX_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0c0c0cfc0")
port map (
combout => N_91842,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M\,
datae => \GRFPU0.GRFPU_X0.COMB.STICKY_1_I_M\,
datad => \GRFPU0.GRFPU_X0.ITER.NX_1_0_G1_0\,
datac => \GRFPU0.GRFPU_X0.ITER.NX_1_0_N_13\,
datab => \GRFPU0.GRFPU_X0.ITER.NX\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_20287\,
datae => \GRFPU0.GRFPU_X0.N_19712\,
datad => \FPI.OP1\(35),
datac => \FPI.OP1\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_IV_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(43),
dataf => \GRFPU0.GRFPU_X0.N_20635\,
datae => \GRFPU0.GRFPU_X0.N_19513_I_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_1\(43),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(43));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2NLD7_115_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(115),
dataf => N_30891,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(115));
GRFPU0_FPMUL0_R2_RET_163_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(116),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(116),
datad => N_31001);
GRFPU0_FPMUL0_CS_DP_R_RET_30_RNI5V1M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31113,
datad => N_31112);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16321\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1S\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => N_30944,
datab => N_30943);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
dataf => \GRFPU0.MULO.DRES_S\(115),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16321\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(116));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIGTS31_97_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(97),
dataf => N_30855,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(97));
GRFPU0_FPMUL0_R2_RET_100_RNILSHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(97),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31077,
datad => N_31076);
GRFPU0_FPMUL0_R2_RET_207_RNIPSHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(98),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30908,
datad => N_30907);
GRFPU0_FPMUL0_R2_RET_164_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(115),
datad => N_30999);
GRFPU0_FPMUL0_R2_RET_160_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(119),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(119),
datad => N_31007);
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fccccc00cccccc")
port map (
combout => N_29688,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => N_174882_0,
datad => \GRFPU0.GRFPU_X0.N_10\,
datac => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(59));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNO_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fccccc00cccccc")
port map (
combout => N_29689,
dataf => \GRFPU0.GRFPU_X0.N_20_I\,
datae => N_174882_0,
datad => \GRFPU0.GRFPU_X0.N_10\,
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(60));
GRFPU0_GRFPU_X0_VITER_DBUF_3_SQMUXA_I: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19403\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.DRES_1\(77),
datab => \GRFPU0.MULO.DRES_1S\(76),
dataa => \GRFPU0.MULO.DRES_S\(76));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54));
GRFPU0_GRFPU_X0_UN1_ST3_FARRES_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f000f000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
dataf => \GRFPU0.GRFPU_X0.N_8154\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0f0ff0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17600\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1_0\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff0f0ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => N_36200,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff0f0ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => N_36182,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
datad => N_36172,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datad => N_36167,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(55));
GRFPU0_GRFPU_X0_COMB_ADDI3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
dataf => \GRFPU0.GRFPU_X0.N_7781_6\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_6_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_0_2\,
datac => \GRFPU0.GRFPU_X0.COMB.FLOP4_1\(0),
datab => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7781\,
dataf => \GRFPU0.GRFPU_X0.N_7781_6\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_1_5_0\,
datac => \GRFPU0.GRFPU_X0.N_7942\,
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_UN1_ADDI3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f000cccccc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.N_7781\,
datad => \GRFPU0.GRFPU_X0.COMB.ADDI3_0\,
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.EMINM1\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_8154\,
dataf => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_31286,
datac => \GRFPU0.GRFPU_X0.N_9851\,
datab => \GRFPU0.GRFPU_X0.N_9852\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA_RNIPP5P: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f000f000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
dataf => \GRFPU0.GRFPU_X0.N_8154\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_5\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2));
GRFPU0_GRFPU_X0_COMB_CCUF_1_I_M3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003f0f33f03fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_15359\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3_3\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_ADDOF: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
datae => \GRFPU0.GRFPU_X0.N_15359\,
datad => \GRFPU0.GRFPU_X0.N_4094\,
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datab => \GRFPU0.GRFPU_X0.ST3.EMIN\);
GRFPU0_GRFPU_X0_COMB_VST4_SEL3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7767\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.SEL3_1\,
datae => \GRFPU0.GRFPU_X0.N_7767_6\,
datad => \GRFPU0.GRFPU_X0.N_7942\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_VST4_SEL2_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7767_6\,
dataf => \GRFPU0.GRFPU_X0.N_7942\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
\GRFPU0_GRFPU_X0_ST3_FARRES_0_RNILL1A_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4094\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55));
GRFPU0_GRFPU_X0_VITER_NX_0_SQMUXA_1_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19502\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ITER.DP\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\);
\GRFPU0_GRFPU_X0_EXPOP_1_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6498\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datad => N_31123,
datac => N_31122);
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff000ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.L4_6\(3),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfc000cfcfc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
datae => \GRFPU0.GRFPU_X0.N_10514\,
datad => \GRFPU0.GRFPU_X0.L4_6\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_L4_6_RNITGJ12_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00ff00ff03c3c0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.L4_6\(3),
datac => \GRFPU0.GRFPU_X0.L4_6\(4),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_1_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0fff0fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(60),
dataf => \GRFPU0.GRFPU_X0.N_5299_I_M\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
datad => \GRFPU0.MULO.MRES_1\(120),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_60_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(60),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(60));
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNIJBC71_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f3cffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19434\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_VITER_FLUSH0_0_SQMUXA_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6100\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5091_REGDEPX2_1_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24113\,
dataf => \GRFPC0.EX.CTRL.INST\(26),
datae => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_A2_6_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25786_1\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5622_REGDEPX2_2_0_0_A2_0_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25164\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4583_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.INST_1\(1),
datac => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_1_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22443\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(0));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4672_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
dataf => N_120,
datae => N_119,
datad => N_118,
datac => N_121);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_4\(0),
dataf => N_109,
datae => N_117);
\GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_DEP_1_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24372_1\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_23613_I_0\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2_1\(0),
dataf => \GRFPC0.FIFO.INST_0_0\(6),
datae => \GRFPC0.FIFO.INST_0\(14));
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4479_REGDEPX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.CHECK_DEP.UN4479_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_2\(0),
dataf => \GRFPC0.FIFO.INST_0\(0),
datae => \GRFPC0.FIFO.INST_0_0\(6));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_I_A2_9_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.N_24697_1\,
dataf => \GRFPC0.EX.CTRL.INST\(4),
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5165_REGDEPX2_0_O2_0_0_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24637\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(2));
GRFPU0_GRFPU_X0_VITER_ODDEXP_1_SQMUXA_1_RNIL9GJ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ff00ff00")
port map (
combout => N_91845,
dataf => \GRFPU0.GRFPU_X0.VITER.ODDEXP_2_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(37),
dataf => \GRFPU0.GRFPU_X0.N_17200\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(37),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(37));
GRFPU0_GRFPU_X0_ST1_SIGN2_RNIICT33: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff30ff00")
port map (
combout => N_29618,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datae => \GRFPU0.GRFPU_X0.N_4373\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
GRFPU0_GRFPU_X0_VITER_ODDEXP_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.ODDEXP_2_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_L4_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3_I\(1),
dataf => N_174934,
datae => N_124873,
datad => N_124872);
\GRFPU0_GRFPU_X0_L3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124873,
dataf => \GRFPU0.GRFPU_X0.N_7365\,
datae => N_124852,
datad => \GRFPU0.GRFPU_X0.L1_2\(3),
datac => N_124807,
datab => N_124828);
\GRFPU0_GRFPU_X0_L1_6_1_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3873\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3753\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_L1_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffcfffccffcc")
port map (
combout => N_124829,
dataf => \GRFPU0.GRFPU_X0.N_3753\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_BCO_MSB_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3783\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_L1_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfffcfcfcfc")
port map (
combout => N_124828,
dataf => \GRFPU0.GRFPU_X0.N_3783\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_L1_2_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccfffff0f0")
port map (
combout => N_124807,
dataf => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
GRFPU0_GRFPU_X0_UN138_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_7376\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_BCO_MSB_1_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3763\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_L1_0_1_2_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_4013\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_L2_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => N_124852,
dataf => \GRFPU0.GRFPU_X0.N_7370\,
datae => N_124826,
datad => \GRFPU0.GRFPU_X0.N_7376\,
datac => \GRFPU0.GRFPU_X0.N_4013\,
datab => \GRFPU0.GRFPU_X0.N_3763\);
GRFPU0_GRFPU_X0_UN143_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN143_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_BCO_MSB_2_2_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3743\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_L1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff03ffffff00")
port map (
combout => N_124826,
dataf => \GRFPU0.GRFPU_X0.N_3743\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
GRFPU0_GRFPU_X0_UN158_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_L1_4_2_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3836\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_L1_4_1_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3913\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_L1_4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcffff0000")
port map (
combout => N_124825,
dataf => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3913\,
datad => \GRFPU0.GRFPU_X0.N_3836\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
GRFPU0_GRFPU_X0_UN153_BCO_LSB_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19295\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
GRFPU0_GRFPU_X0_UN148_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17631\,
dataf => N_174935,
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47),
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(13),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(73),
datac => \GRFPU0.MULO.DRES_1\(73));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(73),
datac => \GRFPU0.MULO.DRES_1\(73),
datab => \GRFPU0.MULO.DRES_1S\(72),
dataa => \GRFPU0.MULO.DRES_S\(72));
\GRFPU0_GRFPU_X0_L1_6_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000fc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccfc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
\GRFPU0_GRFPU_X0_L1_5_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0f0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(49));
\GRFPU0_GRFPU_X0_L1_4_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f300f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPU0_GRFPU_X0_L1_4_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(0),
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1_4\(0),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_5_3\(0));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(0),
datad => \GRFPU0.GRFPU_X0.N_10489\,
datac => \GRFPU0.GRFPU_X0.L1_5_1_5\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_6_3\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030333000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_L1_3_1_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00fcfcffff")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.TZI\(22),
datae => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
\GRFPU0_GRFPU_X0_L1_2_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333300000f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(0),
dataf => \GRFPU0.GRFPU_X0.N_10526\,
datae => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\(0),
datad => \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\(0),
datac => \GRFPU0.GRFPU_X0.TZI\(16),
datab => \GRFPU0.GRFPU_X0.TZI\(20));
\GRFPU0_GRFPU_X0_L2_1_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.N_10519\,
datae => \GRFPU0.GRFPU_X0.L1_2_5\(0),
datad => \GRFPU0.GRFPU_X0.N_10521\,
datac => \GRFPU0.GRFPU_X0.BCO_MSB_4_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_1_3\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.TZI\(12),
datad => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_L1_1_1_4_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPU0_GRFPU_X0_L1_1_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.TZI\(8),
datae => \GRFPU0.GRFPU_X0.L1_1_1_4_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_BCO_MSB_1_5_0_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPU0_GRFPU_X0_L1_0_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00fcffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_10583\,
datae => \GRFPU0.GRFPU_X0.L1_0_1_5\(0),
datad => \GRFPU0.GRFPU_X0.TZI\(4),
datac => \GRFPU0.GRFPU_X0.TZI\(5),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L2_0_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(0),
dataf => \GRFPU0.GRFPU_X0.N_10569\,
datae => \GRFPU0.GRFPU_X0.L1_0_6\(0),
datad => \GRFPU0.GRFPU_X0.N_10570\,
datac => \GRFPU0.GRFPU_X0.L1_1_1_4\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_6\(0));
\GRFPU0_GRFPU_X0_L3_0_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_10558\,
datae => \GRFPU0.GRFPU_X0.L2_1_3\(0),
datad => \GRFPU0.GRFPU_X0.L2_0_4\(0));
\GRFPU0_GRFPU_X0_L4_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_10514\,
datae => \GRFPU0.GRFPU_X0.L3_0_6\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_5\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16257\,
dataf => N_30867,
datae => \GRFPU0.GRFPU_X0.N_5221_0\,
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datab => \GRFPU0.FPMUL0.SX\(103));
GRFPU0_FPMUL0_R2_RET_201_RNIMOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(104),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30920,
datad => N_30919);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16309\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31089,
datab => N_31088);
\GRFPU0_GRFPU_X0_L1_6_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3413\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffcfffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3313\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
\GRFPU0_GRFPU_X0_L1_5_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3433\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_L1_4_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3463\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124869,
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => N_124850,
datad => \GRFPU0.GRFPU_X0.N_10489\,
datac => \GRFPU0.GRFPU_X0.N_3433\,
datab => \GRFPU0.GRFPU_X0.N_3313\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3393\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_L1_3_1_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3483\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_TZI_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(20),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_TZI_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(22),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPU0_GRFPU_X0_L1_2_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3503\,
dataf => \GRFPU0.GRFPU_X0.TZI\(16),
datae => \GRFPU0.GRFPU_X0.N_3506\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_L2_1_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => N_124885,
dataf => \GRFPU0.GRFPU_X0.N_10519\,
datae => N_124870,
datad => \GRFPU0.GRFPU_X0.N_10521\,
datac => \GRFPU0.GRFPU_X0.N_3393\,
datab => \GRFPU0.GRFPU_X0.N_3483\);
\GRFPU0_GRFPU_X0_TZI_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(12),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3366\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3363\,
dataf => \GRFPU0.GRFPU_X0.N_3366\,
datae => \GRFPU0.GRFPU_X0.TZI\(12),
datad => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_L1_1_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3523\,
dataf => \GRFPU0.GRFPU_X0.TZI\(8),
datae => \GRFPU0.GRFPU_X0.N_3526\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_TZI_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_TZI_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNIFH0L1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3336\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
\GRFPU0_GRFPU_X0_L2_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124871,
dataf => \GRFPU0.GRFPU_X0.N_10569\,
datae => N_124847,
datad => \GRFPU0.GRFPU_X0.N_10570\,
datac => \GRFPU0.GRFPU_X0.N_3523\,
datab => \GRFPU0.GRFPU_X0.N_3363\);
\GRFPU0_GRFPU_X0_L3_0_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_124890,
dataf => \GRFPU0.GRFPU_X0.N_10558\,
datae => N_124885,
datad => N_124871);
\GRFPU0_GRFPU_X0_L4_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124896,
dataf => \GRFPU0.GRFPU_X0.N_10514\,
datae => N_124890,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => N_124869,
datab => \GRFPU0.GRFPU_X0.N_3413\);
\GRFPU0_GRFPU_X0_L4_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(3),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
datac => \GRFPU0.GRFPU_X0.N_10715\,
datab => \GRFPU0.GRFPU_X0.N_10765\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_I_O4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19472\,
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.N_19483_1\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.N_19483_1\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
\GRFPU0_GRFPU_X0_L4_4_I_A2_2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_I_A2_2\(4),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
\GRFPU0_GRFPU_X0_L4_4_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(2),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
datab => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_19491\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(12));
\GRFPU0_GRFPU_X0_L4_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcc0fccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(1),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => N_124846,
datab => \GRFPU0.GRFPU_X0.L1_6\(1));
\GRFPU0_GRFPU_X0_L3_0_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcc0fcc0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(1),
dataf => \GRFPU0.GRFPU_X0.N_10716\,
datae => N_124845,
datad => \GRFPU0.GRFPU_X0.N_10715\,
datac => N_124806,
datab => \GRFPU0.GRFPU_X0.L1_2_3\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_6_2_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3633\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(9));
\GRFPU0_GRFPU_X0_BCO_MSB_5_2_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3653\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16));
\GRFPU0_GRFPU_X0_L1_4_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff03ffffff00")
port map (
combout => N_124823,
dataf => \GRFPU0.GRFPU_X0.N_3653\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
\GRFPU0_GRFPU_X0_L1_3_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => N_124806,
dataf => \GRFPU0.GRFPU_X0.N_10717\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(24));
\GRFPU0_GRFPU_X0_L1_2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(1),
dataf => \GRFPU0.GRFPU_X0.N_10722\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(32));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3643\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40));
\GRFPU0_GRFPU_X0_BCO_MSB_1_3_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3623\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48));
\GRFPU0_GRFPU_X0_L1_0_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfffcfcfcfc")
port map (
combout => N_124821,
dataf => \GRFPU0.GRFPU_X0.N_3623\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_A4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19481\,
dataf => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
GRFPU0_GRFPU_X0_UN228_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_A4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19480\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19473\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccffffcccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.N_19481\,
datad => \GRFPU0.GRFPU_X0.N_19483_1\,
datac => \GRFPU0.GRFPU_X0.N_19473\,
datab => \GRFPU0.GRFPU_X0.N_19480\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_A4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19482\,
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_UN223_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10717\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_4_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
\GRFPU0_GRFPU_X0_L1_3_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_UN218_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10722\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
\GRFPU0_GRFPU_X0_BCO_MSB_3_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
\GRFPU0_GRFPU_X0_L1_2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_3_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_UN213_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10728\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_3\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38));
\GRFPU0_GRFPU_X0_L1_1_1_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_UN208_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10741\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_BCO_MSB_1_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPU0_GRFPU_X0_L1_0_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3033303330333030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_3\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_L2_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(0),
dataf => \GRFPU0.GRFPU_X0.N_10765\,
datae => \GRFPU0.GRFPU_X0.L1_0_4\(0),
datad => \GRFPU0.GRFPU_X0.N_10728\,
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_1_1_3\(0));
\GRFPU0_GRFPU_X0_L3_0_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_10716\,
datae => \GRFPU0.GRFPU_X0.L2_0_3\(0),
datad => \GRFPU0.GRFPU_X0.N_10715\,
datac => \GRFPU0.GRFPU_X0.L1_3_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_3\(0));
\GRFPU0_GRFPU_X0_L4_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcaafcaaffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(0),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(0),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2_0_1\(0),
datab => \GRFPU0.GRFPU_X0.N_19482\,
dataa => \GRFPU0.GRFPU_X0.L1_6\(0));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_18: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_18\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(7),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(6));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(13),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(17),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(12));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_22\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_16\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(8),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(3));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_14: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(16),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(15),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(14),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(10));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_21\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_14\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(9),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(24));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_I_A2_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_21\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(11));
\GRFPU0_GRFPU_X0_COMB_VST4_EXC_12_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_12\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_24\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_I_A2_25\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(28));
GRFPU0_GRFPU_X0_COMB_IEXC25_NE_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_0\,
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
datad => \GRFPU0.GRFPU_X0.ITER.TZR\(6));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIDM9E_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6453\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_L3_0_5_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(3),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_10409\,
datac => \GRFPU0.GRFPU_X0.L1_2_1\(3));
\GRFPU0_GRFPU_X0_L4_7_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(3),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L3_0_5\(3),
datad => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datac => \GRFPU0.GRFPU_X0.N_20965\,
datab => \GRFPU0.GRFPU_X0.ITER.DP_5\);
GRFPU0_GRFPU_X0_UN68_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN68_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datae => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3905_1\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_L3_0_5_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(2),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.L2_0_5\(2),
datac => \GRFPU0.GRFPU_X0.L1_2_1\(3),
datab => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L4_7_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(2),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L3_0_5\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(2),
datab => \GRFPU0.GRFPU_X0.UN68_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L1_6_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f3ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3423\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_BCO_MSB_6_4_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3293\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_L1_5_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffcfffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3443\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L1_5_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcff03000000")
port map (
combout => N_124868,
dataf => \GRFPU0.GRFPU_X0.N_3443\,
datae => \GRFPU0.GRFPU_X0.N_3293\,
datad => \GRFPU0.GRFPU_X0.N_3905_1\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_L3_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0f0ff00")
port map (
combout => N_124889,
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datad => N_124841,
datac => N_124868,
datab => \GRFPU0.GRFPU_X0.N_3423\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3373\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_L1_3_1_4_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3473\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_L2_0_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00ff00")
port map (
combout => N_124867,
dataf => \GRFPU0.GRFPU_X0.N_10409\,
datae => \GRFPU0.GRFPU_X0.N_10410\,
datad => N_124842,
datac => \GRFPU0.GRFPU_X0.N_3383\,
datab => \GRFPU0.GRFPU_X0.N_3513\);
\GRFPU0_GRFPU_X0_L1_6_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff003000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(58));
\GRFPU0_GRFPU_X0_BCO_MSB_6_4_0_I_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf0ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20892\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_5_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303330000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L1_5_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_5_1_4\(0),
datae => \GRFPU0.GRFPU_X0.N_20892\,
datad => \GRFPU0.GRFPU_X0.N_3905_1\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_BCO_MSB_5_4_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_L1_4_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000fc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_L1_4_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6\(0),
dataf => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1_5\(0),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(44));
\GRFPU0_GRFPU_X0_L3_1_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datad => \GRFPU0.GRFPU_X0.L1_4_6\(0),
datac => \GRFPU0.GRFPU_X0.L1_5_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_4\(0));
\GRFPU0_GRFPU_X0_ITER_R_I_RNI47JF1_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_7_0\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
GRFPU0_GRFPU_X0_UN53_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(39));
\GRFPU0_GRFPU_X0_L1_3_1_4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0f0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_L1_3_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_3_1_4\(0),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_BCO_MSB_3_4_0_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_L1_2_1_5_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_L1_2_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.TZI2\(16),
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_L1_2_4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c0f0cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_2_1_5\(0),
datad => \GRFPU0.GRFPU_X0.TZI2\(21),
datac => \GRFPU0.GRFPU_X0.TZI2\(20),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_L1_0_5_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030003000003030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5_1\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datac => \GRFPU0.GRFPU_X0.N_3406\,
datab => \GRFPU0.GRFPU_X0.TZI2\(4));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_A4_0_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030300000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.TZI2\(12),
datad => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_L1_1_1_5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_1_1_5_TZ\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_L1_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0fffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_1_4\(0),
datae => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_TZ\(0),
datac => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_1\,
datab => \GRFPU0.GRFPU_X0.TZI2\(4));
\GRFPU0_GRFPU_X0_L2_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffffccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_5\(0),
datae => \GRFPU0.GRFPU_X0.N_10409\,
datad => \GRFPU0.GRFPU_X0.N_10410\,
datac => \GRFPU0.GRFPU_X0.L1_1_1_5\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_5\(0));
\GRFPU0_GRFPU_X0_L3_0_5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bf80ffffbf800000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(0),
datae => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datad => \GRFPU0.GRFPU_X0.L1_2_4\(0),
datac => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.L1_2_1\(3),
dataa => \GRFPU0.GRFPU_X0.L1_3_4\(0));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(0),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L3_0_5\(0),
datad => \GRFPU0.GRFPU_X0.L3_1_1\(0),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(0));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0c000fffcfcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(2),
dataf => \GRFPU0.GRFPU_X0.L4_7\(2),
datae => N_124895,
datad => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(0),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(1));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(2),
datae => \GRFPU0.GRFPU_X0.L4_7\(3),
datad => \GRFPU0.GRFPU_X0.ITER.TZR\(3));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fcf0ff00f0c0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\,
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(3),
datae => \GRFPU0.GRFPU_X0.L4_7\(4),
datad => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(4));
\GRFPU0_GRFPU_X0_COMB_IEXC_6_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC_6\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
datac => \GRFPU0.GRFPU_X0.ITER.NX\);
\GRFPU0_GRFPU_X0_COMB_VST4_EXC_11_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff5500ffffd5c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC_6\(0),
datae => \GRFPU0.GRFPU_X0.IEXC_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_7910\,
datac => \GRFPU0.GRFPU_X0.N_6325\,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\,
dataa => \GRFPU0.GRFPU_X0.ST3.EXC\(0));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datae => \GRFPU0.GRFPU_X0.N_20965\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRAPI_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3905_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIMHI51_52_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_0_A2_1\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_COMB_RNDM_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDM_1\(0),
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNI1KSH_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_16\(0),
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(19));
GRFPU0_FPMUL0_R2_RET_181_RNIBCIA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(98),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(98),
datad => N_30965);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_4\,
dataf => \GRFPU0.MULO.MRES\(87),
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0\);
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_6\,
datae => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_4\,
datad => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.MULO.MRES\(79));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21896\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_8\,
datae => \GRFPU0.MULO.MRES\(95),
datad => \GRFPU0.GRFPU_X0.NXX_3\,
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.MULO.MRES\(89));
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_O6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19606\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17319\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(90),
datad => \GRFPU0.MULO.MRES_1\(90));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17370\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
datae => \GRFPU0.MULO.MRES\(90),
datad => \GRFPU0.MULO.MRES_1S\(90));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_7_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_7\(0),
dataf => \GRFPU0.MULO.MRES\(65),
datae => \GRFPU0.MULO.MRES\(35),
datad => \GRFPU0.MULO.MRES\(32));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_20_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_20\(0),
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19\,
datae => \GRFPU0.GRFPU_X0.NXX_1_I_A2_10\,
datad => \GRFPU0.GRFPU_X0.NXX_1_36\,
datac => \GRFPU0.GRFPU_X0.NXX_1_39\,
datab => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_7\(0));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_12_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_12\(0),
dataf => \GRFPU0.MULO.MRES\(64),
datae => \GRFPU0.MULO.MRES\(61),
datad => \GRFPU0.MULO.MRES\(60),
datac => \GRFPU0.MULO.MRES\(59));
\GRFPU0_GRFPU_X0_UN1_INC_DP_I_A2_16_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_I_A2_16\(0),
dataf => \GRFPU0.GRFPU_X0.N_19652_9\,
datae => \GRFPU0.MULO.MRES\(63),
datad => \GRFPU0.MULO.MRES\(62),
datac => \GRFPU0.MULO.MRES\(57),
datab => \GRFPU0.MULO.MRES\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00ff0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
dataf => N_174945,
datae => \GRFPU0.GRFPU_X0.N_19279_I\,
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.MULO.MRES\(66));
GRFPU0_GRFPU_X0_UN43_BCO_LSB_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
GRFPU0_GRFPU_X0_UN43_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
GRFPU0_GRFPU_X0_UN43_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10410\,
dataf => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_1\,
datae => \GRFPU0.GRFPU_X0.UN43_BCO_LSB_0\);
\GRFPU0_GRFPU_X0_TZI2_12_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(12),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3383\,
dataf => \GRFPU0.GRFPU_X0.N_3386\,
datae => \GRFPU0.GRFPU_X0.TZI2\(12),
datad => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_L1_1_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_3513\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3386\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNITG9S_95_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(95),
dataf => N_30851,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(95));
GRFPU0_FPMUL0_R2_RET_102_RNIPVUC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1S\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(95),
datad => N_31073);
GRFPU0_FPMUL0_R2_RET_209_RNI2OUC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1\(96),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => \GRFPU0.FPMUL0.SX\(96),
datad => N_30904);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffaa00aaf0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(95),
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.DRES_1S\(95),
datab => \GRFPU0.MULO.DRES_1\(96),
dataa => \GRFPU0.MULO.MRES\(96));
GRFPU0_GRFPU_X0_UN38_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_L1_0_5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfff0fff0")
port map (
combout => N_124842,
dataf => \GRFPU0.GRFPU_X0.UN38_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_I_0\(1),
datad => \GRFPU0.GRFPU_X0.TZI2\(0),
datac => \GRFPU0.GRFPU_X0.TZI2\(1),
datab => \GRFPU0.GRFPU_X0.N_3406\);
\GRFPU0_GRFPU_X0_TZI2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_TZI2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_VST3_REG_47_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0ffccccf000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(51),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(51),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33fc30cf03cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX6_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19382\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19373\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19382\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19373\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_24: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI8DAA1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI9HR11_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI8DAA1_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_5_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIHU5C2_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7645\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_5_2\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI2TBO4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_15\,
dataf => \GRFPU0.GRFPU_X0.N_7645\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_2\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_13_1\);
GRFPU0_GRFPU_X0_ST2_V_RNINTU08: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000fccc3000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15336_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_15\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_8\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datab => \GRFPU0.GRFPU_X0.ST2.V\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_31_59_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(59),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(4),
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59));
GRFPU0_GRFPU_X0_UN1_VST3_EXC52: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccfcfcffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_6577\,
dataf => \GRFPU0.GRFPU_X0.N_7053\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_7\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_6_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_6_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(21));
GRFPU0_GRFPU_X0_UN233_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19491\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(11));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_8\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_I_A4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19484\,
dataf => \GRFPU0.GRFPU_X0.N_10710_0\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_12\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_10\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_6_0\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_I_A4_7\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0_TZ: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_6659_TZ\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6659\,
dataf => \GRFPU0.GRFPU_X0.N_6659_TZ\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_VST3_REG21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6654\,
dataf => \GRFPU0.GRFPU_X0.N_6659\,
datae => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.DRES_1\(75),
datab => \GRFPU0.MULO.DRES_1S\(74),
dataa => \GRFPU0.MULO.DRES_S\(74));
\GRFPU0_GRFPU_X0_VST3_REG_37_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29));
GRFPU0_GRFPU_X0_ST3_RDY_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G5\,
dataf => \GRFPU0.GRFPU_X0.N_7053\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc30fc30")
port map (
combout => \GRFPU0.GRFPU_X0.N_17331\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => \GRFPU0.MULO.MRES\(102),
datad => N_31028,
datac => N_31027,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc3030")
port map (
combout => \GRFPU0.GRFPU_X0.N_17332\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31030,
datad => \GRFPU0.MULO.MRES\(103),
datac => N_31029,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_2_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_VST3_INF_0_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.INF_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_7053\,
datae => \GRFPU0.GRFPU_X0.N_7445\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_RNIF5R81: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_7143\,
dataf => \GRFPU0.GRFPU_X0.N_7019\,
datae => \GRFPU0.GRFPU_X0.N_7028\,
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(0));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7019\,
dataf => \GRFPU0.GRFPU_X0.N_6660\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_2_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
GRFPU0_GRFPU_X0_COMB_OP_GT_VST3_EXC40LT9_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LT9_2_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(60));
GRFPU0_GRFPU_X0_VST3_INF_0_SQMUXA_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7445\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12\,
dataf => \GRFPU0.MULO.MRES\(85),
datae => \GRFPU0.MULO.MRES\(89),
datad => \GRFPU0.MULO.MRES\(78),
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\,
dataf => \GRFPU0.MULO.MRES\(87),
datae => \GRFPU0.MULO.MRES\(81),
datad => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_19\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_12\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\,
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.MULO.MRES\(90));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\,
dataf => \GRFPU0.MULO.MRES\(88),
datae => \GRFPU0.MULO.MRES\(87),
datad => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.MULO.MRES\(79));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\,
dataf => \GRFPU0.MULO.MRES\(74),
datae => \GRFPU0.MULO.MRES\(73),
datad => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_13\,
dataf => \GRFPU0.MULO.MRES\(85),
datae => \GRFPU0.MULO.MRES\(78),
datad => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_16: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_16\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_13\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_9\,
datad => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.MULO.MRES\(90));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_2_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_19\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_16\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_17\,
datad => \GRFPU0.MULO.MRES\(93),
datac => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c03fc030c03f0000")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.STICKY_1\,
datae => \GRFPU0.GRFPU_X0.COMB.GUARD_3\,
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_COMB_UN1_SGNFOF_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_SGNFOF_0\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datad => N_31123,
datac => N_31122);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNIBMDL_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_6661\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
GRFPU0_GRFPU_X0_UN48_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000330f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_3496\,
datae => \GRFPU0.GRFPU_X0.TZI2\(16),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_TZI2_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(21),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_TZI2_20_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(20),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIEGQS_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3356\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_TZI2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(16),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
GRFPU0_GRFPU_X0_UN48_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3496\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_L1_2_1_5_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3493\,
dataf => \GRFPU0.GRFPU_X0.N_3496\,
datae => \GRFPU0.GRFPU_X0.TZI2\(16),
datad => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_L1_2_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcffff0000")
port map (
combout => N_124866,
dataf => \GRFPU0.GRFPU_X0.UN48_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3493\,
datad => \GRFPU0.GRFPU_X0.TZI2\(21),
datac => \GRFPU0.GRFPU_X0.TZI2\(20),
datab => \GRFPU0.GRFPU_X0.N_3356\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19675\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31058,
datad => N_31057,
datac => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17333\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31032,
datad => N_31031,
datac => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNI3T6A3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_7023\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT10\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300f3f0ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(43),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(43),
datae => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.MULO.MRES\(104),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(43),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.MULO.DRES_1\(103));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0fffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(43),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(43),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(43),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(6),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(103),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31087,
datab => N_31086);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00dd11cc00cf03")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(43),
datad => \GRFPU0.GRFPU_X0.N_17661\,
datac => N_138138,
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => N_138139);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(43),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIVGR11_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffff0fffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0_O4_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIUKCP_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19465\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_ST2_RDY_RNIMH3K2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_G0_0_O4_3\,
datae => \GRFPU0.GRFPU_X0.N_19465\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNII8B31_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00000fff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5437\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
\GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_ALTB_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f0f033f0f0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\(2),
datae => \FPI.FLUSHID\(4),
datad => \FPI.FLUSHID\(3),
datac => \GRFPU0.GRFPU_X0.ST2.ID\(4),
datab => \GRFPU0.GRFPU_X0.ST2.ID\(3));
GRFPU0_GRFPU_X0_COMB_UN48_FLUSH: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000ff00ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18975\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\,
datae => \FPI.FLUSHID\(5),
datad => \GRFPU0.GRFPU_X0.ST2.ID\(5));
\GRFPC0_OP2_1_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19580\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(26));
\GRFPC0_OP2_2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19646\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(26),
datad => \GRFPC0.MEM.RREG.RES\(26));
\GRFPC0_OP2_26_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(26),
dataf => \GRFPC0.N_19580\,
datae => \GRFPC0.N_19909\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19646\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_26_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc33f033ccccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_17652\,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => N_174935,
datac => N_31396,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfcccfccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(34),
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datad => \GRFPU0.MULO.MRES\(94),
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.N_19404_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_4_RNO_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc3c3c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datab => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIEKMK_93_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(93),
dataf => N_30847,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_I_M2_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333cccc0ff00ff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_20650\,
dataf => \GRFPU0.GRFPU_X0.N_5221_1\,
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datac => \GRFPU0.FPMUL0.SX\(94),
datab => \GRFPU0.FPMUL0.SX\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f330f330000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20609\,
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_20650\,
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.DRES_S\(93),
datab => \GRFPU0.MULO.MRES\(94));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_34_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0fc0f0f000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34),
dataf => \GRFPU0.GRFPU_X0.N_17652\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_4\(34),
datad => \GRFPU0.GRFPU_X0.N_20609\,
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPC0_OP2_1_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19573\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(19));
\GRFPC0_OP2_2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19639\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(19),
datad => \GRFPC0.MEM.RREG.RES\(19));
\GRFPC0_OP2_19_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(19),
dataf => \GRFPC0.N_19573\,
datae => \GRFPC0.N_19902\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19639\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_19_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17645\,
dataf => N_174935,
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33),
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fcccf000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(27),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.MULO.DRES_1\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(27),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
dataf => \GRFPC0.FPR.ID\(4),
datae => \GRFPC0.FPR.ID\(5),
datad => \GRFPC0.WR.CTRL.ID\(4),
datac => \GRFPC0.WR.CTRL.ID\(5));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.WR.CTRL.ID\(0),
datac => \GRFPC0.WR.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
dataf => \GRFPC0.FPR.ID\(2),
datae => \GRFPC0.FPR.ID\(3),
datad => \GRFPC0.WR.CTRL.ID\(2),
datac => \GRFPC0.WR.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_1_WRENX10_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
dataf => RFI2_RD2ADDRZ(3),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.WR.CTRL.RD\(3),
datac => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_1_UN1_WR_CTRL_RD_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_2\,
dataf => RFI2_RD2ADDRZ(1),
datae => \GRFPC0.WR.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_UN1_WR_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_RS2_1_RNI2JM61_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_1__G0_3_0_0\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.EX.CTRL.RD\(0),
datac => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_REGDEP160_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000ff0000")
port map (
combout => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
dataf => RFI2_RD2ADDRZ(3),
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_RS2_1_RNIA3N61_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_1_2\(1),
dataf => RFI2_RD2ADDRZ(2),
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_2\,
dataf => \GRFPC0.EX.CTRL.ID\(3),
datae => \GRFPC0.EX.CTRL.ID\(4),
datad => \GRFPC0.FPR.ID\(3),
datac => \GRFPC0.FPR.ID\(4));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES10_0_O2_5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fcff3fc")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_5\,
dataf => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES10_0_O2_2\,
datae => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.EX.CTRL.ID\(0),
datac => \GRFPC0.FPR.ID\(2),
datab => \GRFPC0.FPR.ID\(0));
GRFPC0_FP_PIPELINE_UN1_EX_CTRL_ID_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_EX.CTRL.ID_1\,
dataf => \GRFPC0.EX.CTRL.ID\(1),
datae => \GRFPC0.FPR.ID\(1));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_3\,
dataf => \GRFPC0.FPR.ID\(4),
datae => \GRFPC0.FPR.ID\(5),
datad => \GRFPC0.MEM.CTRL.ID\(4),
datac => \GRFPC0.MEM.CTRL.ID\(5));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffff0ff0fffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.MEM.CTRL.ID\(0),
datac => \GRFPC0.MEM.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\,
dataf => \GRFPC0.FPR.ID\(2),
datae => \GRFPC0.FPR.ID\(3),
datad => \GRFPC0.MEM.CTRL.ID\(2),
datac => \GRFPC0.MEM.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_65\,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.MEM.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_0_MEMSEL4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.MEMSEL4\,
dataf => \GRFPC0.N_65_0\,
datae => \GRFPC0.MEM.RREG.RESV\);
\GRFPC0_FP_PIPELINE_RS2_1_RNI0DK31_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
dataf => RFI2_RD2ADDRZ(0),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.MEM.CTRL.RD\(3),
datac => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_2\,
dataf => RFI2_RD2ADDRZ(1),
datae => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FPUSEL_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c33000000")
port map (
combout => \GRFPC0.FPUSEL_1\(2),
dataf => \GRFPC0.FP_PIPELINE.1.EXEN7\,
datae => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
datad => \GRFPC0.FP_PIPELINE.0.MEMSEL4\,
datac => \GRFPC0.N_121_1\,
datab => N_63);
\GRFPC0_OP2_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19576\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(22));
\GRFPC0_OP2_2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19642\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(22),
datad => \GRFPC0.MEM.RREG.RES\(22));
\GRFPC0_OP2_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(22),
dataf => \GRFPC0.N_19576\,
datae => \GRFPC0.N_19905\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19642\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_22_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_1_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000cc0cc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20969\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30),
datac => N_174935_0,
datab => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_2_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000003f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(30),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_268\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_0\(30),
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_3_0_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303ffcf00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_3\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_I_A2_2\(30),
datae => \GRFPU0.GRFPU_X0.N_21034\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_I_A2_3_29_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_21025\,
dataf => \GRFPU0.GRFPU_X0.N_19496_0\,
datae => \GRFPU0.GRFPU_X0.ITER.V_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(30),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(90),
datac => \GRFPU0.MULO.DRES_1\(90),
datab => \GRFPU0.MULO.DRES_1S\(89),
dataa => \GRFPU0.MULO.DRES_S\(89));
\GRFPC0_OP2_1_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19570\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(16));
\GRFPC0_OP2_2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19636\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(16),
datad => \GRFPC0.MEM.RREG.RES\(16));
\GRFPC0_OP2_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(16),
dataf => \GRFPC0.N_19570\,
datae => \GRFPC0.N_19899\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19636\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_16_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff333f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(24),
datae => N_174945,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(24),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.MULO.DRES_1\(84));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.MULO.DRES_1\(84),
datab => \GRFPU0.MULO.DRES_1S\(83),
dataa => \GRFPU0.MULO.DRES_S\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(24),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_24_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(24),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPC0_OP2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19557\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(3));
\GRFPC0_OP2_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19623\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(3),
datad => \GRFPC0.MEM.RREG.RES\(3));
\GRFPC0_OP2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(3),
dataf => \GRFPC0.N_19557\,
datae => \GRFPC0.N_19886\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19623\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_3_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
datad => \GRFPU0.MULO.MRES\(71),
datac => \GRFPU0.MULO.DRES_1\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
dataf => \GRFPU0.GRFPU_X0.N_19499_0\,
datae => \GRFPU0.GRFPU_X0.N_5221_1\,
datad => \GRFPU0.MULO.MRES\(71),
datac => \GRFPU0.MULO.DRES_1\(71),
datab => \GRFPU0.MULO.DRES_1S\(70),
dataa => \GRFPU0.MULO.DRES_S\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(11),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPC0_WREN_0_SQMUXA_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.WREN_0_SQMUXA_2\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE10\,
datae => \GRFPC0.WR2.CTRL.LD\);
GRFPC0_WREN_0_SQMUXA_5_I_A2_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.WREN_2_SQMUXA_0\,
dataf => \GRFPC0.WR2.CTRL.CCWR\,
datae => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datad => \GRFPC0.PENDEXC_0_SQMUXA\,
datac => \GRFPC0.WREN_0_SQMUXA_2\,
datab => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
dataf => \GRFPC0.FPR.ID\(0),
datae => \GRFPC0.WR2.CTRL.ID\(0),
datad => \GRFPC0.WR2.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7fbfdfeff7fbfdfe")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
dataf => \GRFPC0.FPR.ID\(5),
datae => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.FPR.ID\(2),
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.WR2.CTRL.ID\(4),
dataa => \GRFPC0.WR2.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff7dbe")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datad => \GRFPC0.FPR.ID\(1),
datac => \GRFPC0.FPR.ID\(3),
datab => \GRFPC0.WR2.CTRL.ID\(3),
dataa => \GRFPC0.WR2.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_0_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(3),
dataf => N_131,
datae => N_132);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(1),
dataf => N_129,
datae => N_130);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_0\(1),
dataf => \GRFPC0.N_23430\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I\,
datad => \GRFPC0.N_20908\,
datac => \GRFPC0.MEM.CTRL.RD\(0),
datab => \GRFPC0.MEM.CTRL.RDD_2\);
GRFPC0_STDDEP_0_SQMUXA_39_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(4),
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_5_0_1_I_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_20995\,
dataf => \GRFPC0.MEM.CTRL.RD\(0),
datae => \GRFPC0.MEM.CTRL.RDD_0\);
GRFPC0_FP_PIPELINE_12_STDEP_492_SEL1_I_0_A2_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_20908\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(3),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_X2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000ff")
port map (
combout => \GRFPC0.N_69_I\,
dataf => \GRFPC0.N_20908\,
datae => \GRFPC0.MEM.CTRL.RD\(0),
datad => \GRFPC0.MEM.CTRL.RDD_2\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_I_A4_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff030000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492_3_I_A4_1\(1),
dataf => \GRFPC0.STDEP_2_SQMUXA_135\,
datae => \GRFPC0.N_69_I\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datac => \GRFPC0.WR.CTRL.RD\(0),
datab => \GRFPC0.N_131_2\);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN3956_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_1\,
dataf => \GRFPC0.EX.CTRL.RD\(1),
datae => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4199_DEP: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4199_DEP\,
dataf => N_268,
datae => N_267,
datad => N_270,
datac => N_269);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_15_0_I_O3_0_I_O2_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_23044\,
dataf => \GRFPC0.N_78_I_I_0\,
datae => N_266);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_3_0\,
dataf => \GRFPC0.N_290\,
datae => N_124,
datad => \GRFPC0.N_23533\,
datac => N_122);
GRFPC0_FP_PIPELINE_VRFA_ST7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_50421_2,
dataf => N_123,
datae => N_124);
GRFPC0_LDLOCK_15_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_23498\,
dataf => \GRFPC0.N_23489\,
datae => \GRFPC0.N_23486\,
datad => \GRFPC0.N_23496\,
datac => \GRFPC0.N_23493\,
datab => N_130,
dataa => N_129);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_4_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_2\,
dataf => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_1\,
datae => N_133,
datad => N_134,
datac => N_126,
datab => N_124);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefaeeaafcf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\,
dataf => \GRFPC0.N_23498\,
datae => \GRFPC0.N_201_2\,
datad => \GRFPC0.D.FLDLCK\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_4_2\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_3_0\,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_2_2\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_1_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_1_1\,
dataf => \GRFPC0.N_23533\,
datae => \GRFPC0.N_290\,
datad => N_124);
GRFPC0_LDLOCK_1_27_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23518\,
dataf => \GRFPC0.D.STLCK\(15),
datae => \GRFPC0.D.STLCK\(31),
datad => N_132);
GRFPC0_LDLOCK_1_26_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_184\,
dataf => \GRFPC0.D.STLCK\(14),
datae => \GRFPC0.D.STLCK\(30),
datad => N_132);
GRFPC0_LDLOCK_1_24_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23516\,
dataf => \GRFPC0.D.STLCK\(13),
datae => \GRFPC0.D.STLCK\(29),
datad => N_132);
GRFPC0_LDLOCK_1_23_I_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23515\,
dataf => \GRFPC0.D.STLCK\(12),
datae => \GRFPC0.D.STLCK\(28),
datad => N_132);
GRFPC0_LDLOCK_1_29: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_19515\,
dataf => \GRFPC0.N_23516\,
datae => \GRFPC0.N_23515\,
datad => \GRFPC0.N_23518\,
datac => \GRFPC0.N_184\,
datab => N_129,
dataa => N_128);
GRFPC0_LDLOCK_1_30: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf3f00f0c0300")
port map (
combout => \GRFPC0.N_19516\,
dataf => \GRFPC0.N_19515\,
datae => \GRFPC0.N_23514\,
datad => \GRFPC0.N_23511\,
datac => N_130,
datab => N_129);
GRFPC0_LDLOCK_1_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_19501\,
dataf => \GRFPC0.N_23503\,
datae => \GRFPC0.N_23500\,
datad => \GRFPC0.N_23508\,
datac => \GRFPC0.N_23506\,
datab => N_130,
dataa => N_129);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030e020d010c000")
port map (
combout => \GRFPC0.N_198\,
dataf => \GRFPC0.N_19516\,
datae => \GRFPC0.N_19501\,
datad => \GRFPC0.D.FSTLCK\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_1_1\,
datab => N_122,
dataa => N_131);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0ff000")
port map (
combout => \GRFPC0.N_23482\,
dataf => \GRFPC0.N_23607\,
datae => \GRFPC0.N_22020\,
datad => \GRFPC0.N_22027\,
datac => N_130);
GRFPC0_FP_PIPELINE_UN1_CPI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI\,
dataf => N_135,
datae => N_136);
GRFPC0_FP_PIPELINE_VRFA_ST4_I_O4_I_A2_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\,
dataf => N_126,
datae => N_125,
datad => N_123,
datac => N_122);
GRFPC0_FP_PIPELINE_VRFA_ST4_I_O4_I_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST4\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST4_1\,
datae => N_124,
datad => N_127);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_290\,
dataf => N_126,
datae => N_127,
datad => N_125,
datac => N_123);
\GRFPC0_R_STATE_1_RNIFBIE_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => N_52826,
dataf => \GRFPC0.R.STATE_190\(0),
datae => \GRFPC0.R.STATE_1\(1));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_I_M3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_23607\,
dataf => \GRFPC0.N_23598\,
datae => \GRFPC0.N_23595\,
datad => \GRFPC0.N_23605\,
datac => \GRFPC0.N_23602\,
datab => N_130,
dataa => N_129);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_9_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22022\,
dataf => \GRFPC0.D.LDLCK\(20),
datae => \GRFPC0.D.LDLCK\(28),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_8_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22021\,
dataf => \GRFPC0.D.LDLCK\(4),
datae => \GRFPC0.D.LDLCK\(12),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_14_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf3f00f0c0300")
port map (
combout => \GRFPC0.N_22027\,
dataf => \GRFPC0.N_22026\,
datae => \GRFPC0.N_22022\,
datad => \GRFPC0.N_22021\,
datac => N_129,
datab => N_132);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_5_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22018\,
dataf => \GRFPC0.D.LDLCK\(18),
datae => \GRFPC0.D.LDLCK\(26),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_4_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22017\,
dataf => \GRFPC0.D.LDLCK\(2),
datae => \GRFPC0.D.LDLCK\(10),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_2_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22015\,
dataf => \GRFPC0.D.LDLCK\(16),
datae => \GRFPC0.D.LDLCK\(24),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22014\,
dataf => \GRFPC0.D.LDLCK\(0),
datae => \GRFPC0.D.LDLCK\(8),
datad => N_131);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_7_I_M3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_22020\,
dataf => \GRFPC0.N_22015\,
datae => \GRFPC0.N_22014\,
datad => \GRFPC0.N_22018\,
datac => \GRFPC0.N_22017\,
datab => N_129,
dataa => N_132);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff2f0")
port map (
combout => CPO_LDLOCKZ,
dataf => \GRFPC0.N_198\,
datae => \GRFPC0.N_196\,
datad => \GRFPC0.N_23482\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_1\,
datab => N_52826,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0_0\);
GRFPC0_FP_PIPELINE_VRFA_STDFQ_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDD_1_1\,
dataf => N_52020,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN_1_0\,
datad => N_134,
datac => N_133,
datab => N_138);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_12_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_2\(15),
dataf => N_131,
datae => N_132);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_0_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_LDLOCK3_1\(4),
dataf => N_129,
datae => N_130);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_9_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_9\(1),
dataf => N_103,
datae => N_109);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3751_REGDEPX_1_I_O3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24280\,
dataf => N_104,
datae => N_105);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc000000000000")
port map (
combout => \GRFPC0.N_116\,
dataf => \GRFPC0.N_21137_0\,
datae => \GRFPC0.N_23572\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_22\(1),
datab => \GRFPC0.N_59\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_A2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0300000f0f0")
port map (
combout => \GRFPC0.N_127\,
dataf => \GRFPC0.STDEP_2_SQMUXA_138\,
datae => \GRFPC0.N_116\,
datad => \GRFPC0.N_21181\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_246_IV_0_A2_4_2\,
datab => \GRFPC0.N_59\);
GRFPC0_FP_PIPELINE_10_1_CHECK_DEP_UN3304_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2680_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1_0\(29));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \GRFPC0.N_76\,
dataf => \GRFPC0.N_127\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
datad => \GRFPC0.N_55_LI\,
datac => \GRFPC0.N_56\,
datab => \GRFPC0.MEM.CTRL.RDD_1\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_1_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_21997\,
dataf => N_129,
datae => N_130);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_2_I_O4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_21996\,
dataf => N_131,
datae => N_132);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_M2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0fff000f000f0")
port map (
combout => \GRFPC0.N_84\,
dataf => \GRFPC0.N_76\,
datae => \GRFPC0.N_83\,
datad => \GRFPC0.N_77\,
datac => \GRFPC0.N_78_I_I_1\,
datab => \GRFPC0.N_21998\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0f0000000f")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcccccc0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ffccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G2_0\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G4\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35));
\GRFPU0_GRFPU_X0_VST3_REG_37_31_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_5\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19388\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccfff0f0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(48),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(48),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(19),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47\(48),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19370\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19364\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\,
dataf => \GRFPU0.GRFPU_X0.N_19339\,
datae => \GRFPU0.GRFPU_X0.N_19361\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_38_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__N_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccfff0f0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(37),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(37),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000ffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(8),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47\(37),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_37_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32));
\GRFPU0_GRFPU_X0_VST3_REG_47_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccfff0f0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(32),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(32),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_2\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_37_30_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30));
\GRFPU0_GRFPU_X0_VST3_REG_37_21_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.N_7458\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(21));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19388\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19370\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_01\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f300000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19364\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_01\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19361\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_0_RNIG7SQ5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13127_I\,
dataf => \GRFPU0.GRFPU_X0.N_19840_0\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datad => \GRFPU0.GRFPU_X0.N_4066_0\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_0_RNIKM2M_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__I4_I_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datae => \GRFPU0.GRFPU_X0.N_4066_0\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18052\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(13));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18061\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(22));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18050\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(11));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ccccc000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20985\,
dataf => \GRFPU0.GRFPU_X0.N_19831\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPU0_GRFPU_X0_COMB_VST4_REG36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000c000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4063\,
dataf => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0),
datab => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
dataf => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(1),
datad => \GRFPU0.GRFPU_X0.ST3.EMAX\);
GRFPU0_GRFPU_X0_VITER_FLUSH0_1_SQMUXA_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
GRFPU0_GRFPU_X0_ST3_ZERO_RNIQMTJ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f0c0c0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(1),
dataf => \GRFPU0.GRFPU_X0.VITER.FLUSH0_1_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datad => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.ZERO\);
GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ST3.RDY\,
datae => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
GRFPU0_GRFPU_X0_TMP3_0_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6875\,
datae => \GRFPU0.GRFPU_X0.N_9851\,
datad => \GRFPU0.GRFPU_X0.N_9852\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_ST3_INF_RNI8C8L1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
dataf => \GRFPU0.GRFPU_X0.N_11367\,
datae => \GRFPU0.GRFPU_X0.ST3.RDY\,
datad => \GRFPU0.GRFPU_X0.ST3.INF\);
GRFPU0_GRFPU_X0_COMB_VST4_REG38: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000030000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_4066_0\,
dataf => \GRFPU0.GRFPU_X0.TMP3_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_M\(1),
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0),
datab => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_0_56_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19791\,
dataf => \GRFPU0.GRFPU_X0.N_19836\,
datae => N_36102,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => N_36109,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_SUM5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fff0000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.EXP\(6),
dataf => N_36109,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_0_A2_1_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000ff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19798\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datad => N_36182,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_36167,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(54));
GRFPU0_GRFPU_X0_UN23_EXP_ANC6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_35944,
dataf => N_35934,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_EX_CTRL_INST_RNO_0_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_51424,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(23),
datab => N_195);
\GRFPC0_EX_CTRL_INST_RNO_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50756,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(3),
datab => N_175);
\GRFPC0_EX_CTRL_INST_RNO_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f003f33")
port map (
combout => N_50790,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
datae => N_50653_I,
datad => N_50667_1,
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => N_176);
GRFPC0_FP_PIPELINE_10_0_CHECK_DEP_UN3199_REGDEPX_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2575_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22455\,
dataf => \GRFPC0.RFA.RDD\,
datae => N_197);
GRFPC0_FP_PIPELINE_0_STDEP_16_SEL0_0_A2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_21046_I\,
dataf => \GRFPC0.EX.CTRL.RD\(0),
datae => \GRFPC0.N_78_I_I_1\);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_A2_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_100\,
dataf => \GRFPC0.N_56\,
datae => \GRFPC0.MEM.CTRL.RDD_2\);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_ITER_IDCST_RET_RNIAU4D1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f3f0f0f030300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
dataf => \FPI.FLUSHID\(4),
datae => \FPI.FLUSHID\(3),
datad => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\(2),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(3));
GRFPU0_GRFPU_X0_VRDY_0_SQMUXA_1_1_I_O2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fffff0ff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19307\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \FPI.FLUSHID\(5),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(5));
\GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_ALTB_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f0f033f0f0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(2),
datae => \FPI.FLUSHID\(4),
datad => \FPI.FLUSHID\(3),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(4),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(3));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_2\,
dataf => \FPO.IDOUT\(4),
datae => \FPO.IDOUT\(5),
datad => \GRFPC0.WR.CTRL.ID\(4),
datac => \GRFPC0.WR.CTRL.ID\(5));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\,
dataf => \FPO.IDOUT\(1),
datae => \FPO.IDOUT\(2),
datad => \GRFPC0.WR.CTRL.ID\(1),
datac => \GRFPC0.WR.CTRL.ID\(2));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_A2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_103\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.N_58\,
datac => \GRFPC0.N_59\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0cff00")
port map (
combout => \GRFPC0.FP_PIPELINE.10.STDEP_412_3_0_1\(1),
dataf => \GRFPC0.N_103\,
datae => \GRFPC0.N_58\,
datad => \GRFPC0.N_100\,
datac => \GRFPC0.N_59\,
datab => \GRFPC0.N_131_1\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3318_DEP_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN694_DEP_1\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_58\,
dataf => \GRFPC0.N_56\,
datae => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_26_I_I2_I_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_23572\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
GRFPC0_FP_PIPELINE_10_STDEP_416_SEL0_0_I_O2_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_21703_2\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_10_STDEP_416_SEL1_I_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_17452\,
dataf => \GRFPC0.N_21703_2\,
datae => \GRFPC0.EX.CTRL.RD\(4),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.N_78_I_I\);
\GRFPU0_GRFPU_X0_REST_2_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0f000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18411\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI07711_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(8));
GRFPU0_GRFPU_X0_UN1_VST2_REG82_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\,
dataf => \GRFPU0.GRFPU_X0.N_4369\,
datae => \GRFPU0.GRFPU_X0.N_4997\,
datad => \GRFPU0.GRFPU_X0.REST_1_1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3));
GRFPU0_GRFPU_X0_COMB_VST2_REG_19_SEL1_0_A3_0_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0000ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_SEL1_0_A3_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_4284\,
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4284\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_1_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccccccf0f0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18279\,
dataf => \GRFPU0.GRFPU_X0.N_20764_0\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.N_4284\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_3_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0cccf3330000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
dataf => \GRFPU0.GRFPU_X0.N_18279\,
datae => \GRFPU0.GRFPU_X0.N_18280\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19_SEL1_0_A3_0_0\,
datab => \GRFPU0.GRFPU_X0.N_4997\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4285\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_40_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffc0ffc0c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_40\(63),
dataf => \GRFPU0.GRFPU_X0.N_4285\,
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datac => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(63),
dataf => \GRFPU0.GRFPU_X0.N_17918\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datad => \GRFPU0.GRFPU_X0.N_21039\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3cf0ff3c3cf000")
port map (
combout => \GRFPU0.GRFPU_X0.N_17161\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(63),
datae => \GRFPU0.GRFPU_X0.N_4352_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63),
dataf => \GRFPU0.GRFPU_X0.N_17161\,
datae => \GRFPU0.GRFPU_X0.N_20764_0\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_33_I_63_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_33\(63),
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPU0_GRFPU_X0_REST_1_1_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18396\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
GRFPU0_GRFPU_X0_COMB_UN1_ST1_SIGN1_0_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000ff00ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4325\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_REST_1_2_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_0\(6),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(39),
dataf => \GRFPU0.GRFPU_X0.N_17202\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_39_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(39),
datae => \GRFPU0.GRFPU_X0.N_20766\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(39));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(4),
dataf => \GRFPU0.GRFPU_X0.N_17167\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(6),
dataf => \GRFPU0.GRFPU_X0.N_17169\,
datae => \GRFPU0.GRFPU_X0.N_242\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA_RNIKE3A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20881\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50_SN_N_5\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.N_4961\);
GRFPU0_GRFPU_X0_COMB_VST2_REG107_0_RNIJ0PR_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20764\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\);
\GRFPU0_GRFPU_X0_ST1_RAW2_RNIPSUA1_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G5\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \FPI.OP1_RETO\(18),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(18));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_0_M2_0_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffcf00c0ffc000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20803\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G5\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18));
\GRFPU0_GRFPU_X0_REST_2_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000fcccc")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2\(5),
dataf => \GRFPU0.GRFPU_X0.N_4205\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5));
GRFPU0_GRFPU_X0_COMB_VST2_EXC56: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4313\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_REST_1_1_U_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f0fff0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_1\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIKP8N_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4373\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNIHF7A2_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfccc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4));
GRFPU0_GRFPU_X0_COMB_CCV12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV12\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIFLIT_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4458_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIEJJG_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_26\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_ST1_FLTYPE2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4205\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4));
\GRFPU0_GRFPU_X0_REST_1_2_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0f000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18426\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNINRTP_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4369\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4227\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_32_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fc30fc30")
port map (
combout => \GRFPU0.GRFPU_X0.N_17329\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
datae => \GRFPU0.MULO.MRES\(100),
datad => N_31024,
datac => N_31023,
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPC0_OP2_1_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19590\,
dataf => \GRFPU0.GRFPU_X0.N_21443_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(36));
\GRFPC0_OP2_2_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19656\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(36),
datad => \GRFPC0.MEM.RREG.RES\(36));
\GRFPC0_OP2_36_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(36),
dataf => \GRFPC0.N_19590\,
datae => \GRFPC0.N_19919\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19656\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPC0_OP2_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19587\,
dataf => \GRFPU0.GRFPU_X0.N_21442_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(33));
\GRFPC0_OP2_2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19653\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(33),
datad => \GRFPC0.MEM.RREG.RES\(33));
\GRFPC0_OP2_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(33),
dataf => \GRFPC0.N_19587\,
datae => \GRFPC0.N_19916\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19653\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_27_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(36),
datac => \FPI.OP2\(33));
\GRFPC0_OP2_3_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19731\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(45),
datad => \GRFPC0.WR.RREG.RES\(45));
\GRFPC0_OP2_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(45),
dataf => \GRFPC0.N_19862\,
datae => \GRFPC0.N_19796\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19731\,
datab => \GRFPC0.RFA2.RS2SEL_0\(7));
\GRFPC0_OP2_1_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19596\,
dataf => \FPO.RES\(42),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(42));
\GRFPC0_OP2_2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19662\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(42),
datad => \GRFPC0.MEM.RREG.RES\(42));
\GRFPC0_OP2_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(42),
dataf => \GRFPC0.N_19596\,
datae => \GRFPC0.N_19925\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19662\,
datab => \GRFPC0.OP2_SN_N_6\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_42_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_43_I\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST1.ID3\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(45),
datac => \FPI.OP2\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31428,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_SUB_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31376,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
GRFPU0_FPMUL0_R2_RET_170_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(109),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(109),
datad => N_30987);
GRFPU0_FPMUL0_R2_RET_168_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(111),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(111),
datad => N_30991);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(50),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.MULO.DRES_1\(110));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI2BP75_109_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(109),
dataf => N_30879,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(109));
GRFPU0_FPMUL0_R2_RET_169_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(110),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(110),
datad => N_30989);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16315\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31101,
datab => N_31100);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcff000c0cff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
dataf => \GRFPU0.MULO.DRES_S\(109),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16315\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(50),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
GRFPU0_FPMUL0_R2_RET_195_RNI5PIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(110),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30932,
datad => N_30931);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_13_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31101,
datab => N_31100);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18076\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_37_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(37),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18141\,
datab => \GRFPU0.GRFPU_X0.N_18076\);
GRFPU0_GRFPU_X0_UN58_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
GRFPU0_FPMUL0_R2_RET_167_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(112),
datad => N_30993);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_44_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17341\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31048,
datad => N_31047,
datac => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_33_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17330\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31026,
datad => N_31025,
datac => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_17347\,
dataf => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
datae => N_31060,
datad => N_31059,
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3300ffff3300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(41),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(41),
datae => \GRFPU0.MULO.MRES\(102),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(41),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.DRES_1\(101),
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3300ffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(41),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
datac => \GRFPU0.MULO.DRES_1\(101),
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00cc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(41),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_16254\,
datac => \GRFPU0.GRFPU_X0.N_16306\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f303f000f505")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(41),
datad => \GRFPU0.GRFPU_X0.N_17659\,
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_138123,
dataa => N_138122);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(41),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
GRFPU0_FPMUL0_R2_RET_175_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(104),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(104),
datad => N_30977);
GRFPU0_FPMUL0_R2_RET_173_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(106),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(106),
datad => N_30981);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(45),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datae => \GRFPU0.MULO.MRES\(105),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26\,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ccf0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(45),
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.MULO.MRES\(105),
datac => N_174945,
datab => \GRFPU0.GRFPU_X0.N_19279_I\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIADID3_104_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(104),
dataf => N_30869,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(104));
GRFPU0_FPMUL0_R2_RET_174_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(105),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(105),
datad => N_30979);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16310\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(105),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31091,
datab => N_31090);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc0c0cff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(104),
datad => \GRFPU0.GRFPU_X0.N_16310\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(105));
GRFPU0_FPMUL0_R2_RET_200_RNIKOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(105),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30922,
datad => N_30921);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
dataf => \GRFPU0.MULO.MRES_0\(120),
datae => \GRFPU0.MULO.DRES_1\(105),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31091,
datab => N_31090);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ee22ff33fc30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
datad => \GRFPU0.GRFPU_X0.N_17663\,
datac => N_138110,
datab => \GRFPU0.GRFPU_X0.N_19496\,
dataa => N_138111);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_45_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(45),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
GRFPU0_GRFPU_X0_VITER_R_I_3_SQMUXA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_3_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_1_41_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc00ccf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16254\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => N_30861,
datad => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datac => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.FPMUL0.SX\(100));
GRFPU0_FPMUL0_CS_DP_R_RET_45_RNIH32M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(100),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31083,
datad => N_31082);
GRFPU0_FPMUL0_R2_RET_204_RNISOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(101),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30914,
datad => N_30913);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI189M2_102_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(102),
dataf => N_30865,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(102));
GRFPU0_FPMUL0_R2_RET_176_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(103),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(103),
datad => N_30975);
GRFPU0_FPMUL0_R2_RET_202_RNIOOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(103),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30918,
datad => N_30917);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16308\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(103),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31087,
datab => N_31086);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_43_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc0c0cff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(102),
datad => \GRFPU0.GRFPU_X0.N_16308\,
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(103));
GRFPU0_FPMUL0_R2_RET_177_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(102),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(102),
datad => N_30973);
\GRFPU0_GRFPU_X0_L1_4_5_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3306\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIN4V48_117_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(117),
dataf => N_30895,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(117));
GRFPU0_FPMUL0_R2_RET_161_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(118),
datad => N_31005);
GRFPU0_FPMUL0_CS_DP_R_RET_28_RNIAR1M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => N_31117,
datad => N_31116);
GRFPU0_FPMUL0_R2_RET_187_RNIUKIG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30948,
datad => N_30947);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_58_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0aacc00f0aacc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
dataf => \GRFPU0.MULO.DRES_S\(117),
datae => \GRFPU0.GRFPU_X0.N_19499\,
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.DRES_1\(118),
dataa => \GRFPU0.MULO.DRES_1S\(117));
\GRFPU0_GRFPU_X0_TZI_23_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(23),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
GRFPU0_FPMUL0_R2_RET_162_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(117),
datad => N_31003);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3806\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(3),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_3806\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_L4_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_10889\,
datae => \GRFPU0.GRFPU_X0.N_10895\,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(3),
datac => \GRFPU0.GRFPU_X0.N_10894\,
datab => \GRFPU0.GRFPU_X0.L1_0\(3));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNITV5L_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3806\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(47));
\GRFPU0_GRFPU_X0_L1_4_1_0_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3846\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_L1_4_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3923\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_L1_4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcff00ff00")
port map (
combout => N_124815,
dataf => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_3846\,
datad => \GRFPU0.GRFPU_X0.N_3923\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_L4_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0f0ff00")
port map (
combout => N_124864,
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datad => N_124815,
datac => N_124820,
datab => \GRFPU0.GRFPU_X0.N_3883\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3773\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_L1_3_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f3fffff0f0")
port map (
combout => N_124819,
dataf => \GRFPU0.GRFPU_X0.N_3773\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNI775L_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3826\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_BCO_MSB_1_I_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_3853\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_L1_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfffcfcfcfc")
port map (
combout => N_124816,
dataf => \GRFPU0.GRFPU_X0.N_3853\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_L2_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_124838,
dataf => \GRFPU0.GRFPU_X0.L1_0\(3),
datae => N_124817,
datad => N_124816);
\GRFPU0_GRFPU_X0_L3_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_124865,
dataf => \GRFPU0.GRFPU_X0.N_10895\,
datae => N_124838,
datad => \GRFPU0.GRFPU_X0.N_10894\,
datac => N_124818,
datab => N_124819);
\GRFPU0_GRFPU_X0_L1_6_1_0_TZ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15295\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_L1_5_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_6\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.L1_4\(0),
datad => \GRFPU0.GRFPU_X0.L1_5_2\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_4_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_L1_3_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0fc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_L1_2_1_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
\GRFPU0_GRFPU_X0_BCO_MSB_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_L1_1_1_2_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_BCO_MSB_1_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_L1_0_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030333330303330")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_L2_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0\(3),
datae => \GRFPU0.GRFPU_X0.L1_0_3\(0),
datad => \GRFPU0.GRFPU_X0.N_10907\,
datac => \GRFPU0.GRFPU_X0.L1_1_1_2\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2\(0));
\GRFPU0_GRFPU_X0_L3_0_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_10895\,
datae => \GRFPU0.GRFPU_X0.L2_0_1\(0),
datad => \GRFPU0.GRFPU_X0.N_10894\,
datac => \GRFPU0.GRFPU_X0.L1_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_2\(0));
\GRFPU0_GRFPU_X0_L4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44f044f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_10889\,
datae => \GRFPU0.GRFPU_X0.L3_0_1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
datab => \GRFPU0.GRFPU_X0.N_15295\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
GRFPU0_GRFPU_X0_VITER_DBUF_13_SUM2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f330000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_13\(2),
dataf => \GRFPU0.GRFPU_X0.L4_1\(2),
datae => \GRFPU0.GRFPU_X0.L4_1\(0),
datad => \GRFPU0.GRFPU_X0.N_10889\,
datac => N_124864,
datab => N_124865);
\GRFPU0_GRFPU_X0_L1_6_1_I_A4_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3886\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
GRFPU0_GRFPU_X0_UN113_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
GRFPU0_GRFPU_X0_UN108_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
GRFPU0_GRFPU_X0_UN103_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10896\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPU0_GRFPU_X0_L2_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_10894\,
datae => \GRFPU0.GRFPU_X0.N_10901\,
datad => \GRFPU0.GRFPU_X0.N_10896\);
GRFPU0_GRFPU_X0_UN93_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10907\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNIE9R61_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_10920\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_L2_0_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(2),
dataf => \GRFPU0.GRFPU_X0.L1_0\(3),
datae => \GRFPU0.GRFPU_X0.N_10907\,
datad => \GRFPU0.GRFPU_X0.N_10920\);
\GRFPU0_GRFPU_X0_L4_1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_10889\,
datae => \GRFPU0.GRFPU_X0.L4_2\(2),
datad => \GRFPU0.GRFPU_X0.N_10895\,
datac => \GRFPU0.GRFPU_X0.L2_1\(2),
datab => \GRFPU0.GRFPU_X0.L2_0_1\(2));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_25758\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_I_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.N_25110\,
dataf => \GRFPC0.N_25758\,
datae => \GRFPC0.WR2.CTRL.INST\(4),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2609_REGDEPX2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25745_I\,
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25759\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2594_REGDEPX2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2594_REGDEPX2_2\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_13_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25757\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_0_A2_2_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24701_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(28),
datae => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_10_0_A2_0_A2_0_A2_0_A2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23788\,
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_6_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
dataf => \GRFPC0.MEM.CTRL.RDD_0\,
datae => \GRFPC0.MEM.CTRL.INST\(25));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2504_REGDEPX2_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(18),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
dataf => \GRFPC0.MEM.CTRL.RDD_0\,
datae => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_7_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(1),
dataf => \GRFPC0.N_131_0\,
datae => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
dataf => \GRFPC0.MEM.CTRL.RDD_0\,
datae => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25703\,
dataf => \GRFPC0.N_25703_3\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_1_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25179_1\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_12_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(1),
dataf => \GRFPC0.N_131_0\,
datae => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_4_0_A2_0_A2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25657\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2474_REGDEPX2_0_A2_0_0_A2_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24554\,
dataf => \GRFPC0.EX.CTRL.INST\(1),
datae => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_170_0_1_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_1\(1),
dataf => \GRFPC0.N_25706\,
datae => \GRFPC0.N_25703\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_25674\,
datab => \GRFPC0.N_25179_1\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_3_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
datae => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0ff000000")
port map (
combout => \GRFPC0.N_25693_2\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165_0_A2_3_0\(1),
datae => \GRFPC0.N_25708_2\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11_1\(0),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_2_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(1),
dataf => \GRFPC0.N_131_0\,
datae => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_170_0_3_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_3\(1),
dataf => \GRFPC0.N_25693_2\,
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_1\(1),
datad => \GRFPC0.N_25450_1\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FIFO_INST_1_RNI8SSP_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.V.STDATA_14\(18),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FIFO_INST_0_RNI4CSP_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.V.STDATA_14\(16),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(16),
datad => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FIFO_INST_0_RNI6KSP_17_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.V.STDATA_14\(17),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FIFO_INST_1_RNI24SP_15_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.V.STDATA_14\(15),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_0\(15),
datad => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FIFO_RD_5_RNI32FQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
dataf => \GRFPC0.FIFO.INST_0_0\(29),
datae => \GRFPC0.FIFO.INST_1_0\(29),
datad => \GRFPC0.FIFO.RD_1_0\(0));
\GRFPC0_FIFO_RD_5_RNIS9EQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_0_0\(26),
datad => \GRFPC0.FIFO.RD_1_0\(0));
\GRFPC0_FIFO_RD_5_RNI0QEQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_0_0\(28),
datad => \GRFPC0.FIFO.RD_1_0\(0));
\GRFPC0_FIFO_RD_5_RNIVHEQ_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
dataf => \GRFPC0.FIFO.INST_0_0\(27),
datae => \GRFPC0.FIFO.INST_1_0\(27),
datad => \GRFPC0.FIFO.RD_1_0\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_153_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(1),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2\,
datae => \GRFPC0.N_23726\,
datad => \GRFPC0.N_24712_2\,
datac => \GRFPC0.N_23712\,
datab => \FPI.FLOP_0\(6));
\GRFPC0_FIFO_INST_1_RNIF9UB_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_50656,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FIFO_INST_1_RNIN9UB_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => N_50792,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(4));
\GRFPC0_FIFO_INST_1_RNIJ9UB_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_50724,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_1\(2));
\GRFPC0_FIFO_INST_1_RNIL9UB_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.V.STDATA_14\(3),
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(3));
\GRFPC0_FIFO_INST_1_RNIH9UB_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.V.STDATA_14\(1),
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_170_0_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_154\(1),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170_0_3\(1),
datac => \GRFPC0.N_25702\,
datab => \GRFPC0.N_25045\);
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25826_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(28),
datae => \GRFPC0.WR2.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_I_O2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25755\,
dataf => \GRFPC0.WR2.CTRL.RDD_0\,
datae => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_L1_4_4_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3346\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPU0_GRFPU_X0_BCO_MSB_5_3_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0fc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPC0_OP2_1_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19581\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(27));
\GRFPC0_OP2_2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19647\,
dataf => \GRFPC0.RFA2.RS2SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(27),
datad => \GRFPC0.MEM.RREG.RES\(27));
\GRFPC0_OP2_27_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(27),
dataf => \GRFPC0.N_19581\,
datae => \GRFPC0.N_19910\,
datad => \GRFPC0.OP2_SN_N_9_1\,
datac => \GRFPC0.N_19647\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_27_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datae => N_31398,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datae => N_31346,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fcf00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(35),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
datae => \GRFPU0.MULO.MRES\(95),
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
datac => \GRFPU0.GRFPU_X0.N_19279_I\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3f03300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(35),
datae => \GRFPU0.MULO.MRES\(95),
datad => N_174945,
datac => \GRFPU0.GRFPU_X0.N_5193\,
datab => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(35),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.MULO.DRES_1\(95));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNIL0GO_94_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(94),
dataf => N_30849,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(94));
GRFPU0_FPMUL0_R2_RET_101_RNINRUC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1S\(94),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(94),
datad => N_31071);
GRFPU0_FPMUL0_R2_RET_208_RNI0KUC: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => \GRFPU0.FPMUL0.SX\(95),
datad => N_30902);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000f0ccaaccaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.MULO.DRES_S\(94),
datad => \GRFPU0.GRFPU_X0.N_5221\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.MULO.DRES_1S\(94),
dataa => \GRFPU0.MULO.DRES_1\(95));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0cfc03f300f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35),
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(35),
datac => \GRFPU0.GRFPU_X0.N_19496\,
datab => N_174935_0);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_35_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPC0_OP2_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19568\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(14));
\GRFPC0_OP2_2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19634\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(14),
datad => \GRFPC0.MEM.RREG.RES\(14));
\GRFPC0_OP2_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(14),
dataf => \GRFPC0.N_19568\,
datae => \GRFPC0.N_19897\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19634\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_14_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(22),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.MULO.DRES_1\(82));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(22),
datae => \GRFPU0.GRFPU_X0.N_19496\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_22_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(22),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_1\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPC0_OP2_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19560\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(6));
\GRFPC0_OP2_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19626\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(6),
datad => \GRFPC0.MEM.RREG.RES\(6));
\GRFPC0_OP2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(6),
dataf => \GRFPC0.N_19560\,
datae => \GRFPC0.N_19889\,
datad => \GRFPC0.OP2_SN_N_9_0\,
datac => \GRFPC0.N_19626\,
datab => \GRFPC0.OP2_SN_N_6\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_6_0_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_299\,
datae => \FPI.OP2\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.MULO.DRES_1\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(14),
datae => \GRFPU0.GRFPU_X0.N_19496_0\,
datad => N_174935_0,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_14_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14),
datae => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
GRFPU0_GRFPU_X0_UN18_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_10521\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_TZI_16_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(16),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
GRFPU0_GRFPU_X0_UN13_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3506\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
GRFPU0_GRFPU_X0_UN13_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10526\,
dataf => \GRFPU0.GRFPU_X0.TZI\(16),
datae => \GRFPU0.GRFPU_X0.N_3506\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_TZI_8_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(8),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
GRFPU0_GRFPU_X0_UN8_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3526\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
GRFPU0_GRFPU_X0_UN8_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10570\,
dataf => \GRFPU0.GRFPU_X0.TZI\(8),
datae => \GRFPU0.GRFPU_X0.N_3526\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_TZI_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPU0_GRFPU_X0_TZI_I_M2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19299\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
\GRFPU0_GRFPU_X0_L4_6_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(2),
dataf => \GRFPU0.GRFPU_X0.N_10514\,
datae => \GRFPU0.GRFPU_X0.L3_0_6\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
datab => \GRFPU0.GRFPU_X0.UN33_BCO_LSB\(15));
GRFPU0_GRFPU_X0_UN33_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN33_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
GRFPU0_GRFPU_X0_UN23_BCO_LSB_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.N_10489\,
datad => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.N_10484\);
GRFPU0_GRFPU_X0_UN28_BCO_LSB: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_10489\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
GRFPU0_FPMUL0_R2_RET_165_RNIQ2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(114),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(114),
datad => N_30997);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI7QGB1_99_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_S\(99),
dataf => N_30859,
datae => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(99));
GRFPU0_FPMUL0_R2_RET_179_RNIO2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(100),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(100),
datad => N_30969);
GRFPU0_FPMUL0_R2_RET_205_RNIUOHG: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(100),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datae => N_30912,
datad => N_30911);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16305\,
dataf => \GRFPU0.GRFPU_X0.N_5221_0\,
datae => \GRFPU0.MULO.DRES_1\(100),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datac => N_31081,
datab => N_31080);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
dataf => \GRFPU0.GRFPU_X0.N_19499\,
datae => \GRFPU0.GRFPU_X0.N_16305\,
datad => \GRFPU0.MULO.DRES_S\(99),
datac => \GRFPU0.GRFPU_X0.N_5221\,
datab => \GRFPU0.MULO.MRES\(100));
GRFPU0_FPMUL0_R2_RET_180_RNIBGIA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(99),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(99),
datad => N_30967);
GRFPU0_GRFPU_X0_COMB_UN1_ST3_EMAX: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7680\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datae => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_S3ADDI_0_28_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15702\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(30));
GRFPU0_GRFPU_X0_COMB_S_SP_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_SP_2\,
dataf => \GRFPU0.GRFPU_X0.S_SP_25\,
datae => \GRFPU0.GRFPU_X0.S_SP_22\,
datad => \GRFPU0.GRFPU_X0.S_SP_21\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
GRFPU0_GRFPU_X0_S_SP_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_19\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
GRFPU0_GRFPU_X0_S_SP_20: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_20\,
dataf => \GRFPU0.GRFPU_X0.S_SP_14\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datac => \GRFPU0.GRFPU_X0.ST3.STICKY\);
GRFPU0_GRFPU_X0_S_SP_25: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_25\,
dataf => \GRFPU0.GRFPU_X0.S_SP_19\,
datae => \GRFPU0.GRFPU_X0.S_SP_20\,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(13));
GRFPU0_GRFPU_X0_S_SP_17: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_17\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(16));
GRFPU0_GRFPU_X0_S_SP_22: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_22\,
dataf => \GRFPU0.GRFPU_X0.S_SP_17\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(27));
GRFPU0_GRFPU_X0_S_SP_15: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_15\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(7));
GRFPU0_GRFPU_X0_S_SP_21: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_21\,
dataf => \GRFPU0.GRFPU_X0.S_SP_15\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(5));
GRFPU0_GRFPU_X0_COMB_S_SP_1_1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_11478\,
dataf => \GRFPU0.GRFPU_X0.S_SP_25\,
datae => \GRFPU0.GRFPU_X0.S_SP_22\,
datad => \GRFPU0.GRFPU_X0.S_SP_21\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
GRFPU0_GRFPU_X0_COMB_TMP316_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_TMP316_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9851\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP316_3_0\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6860\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_2\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_FPMUL0_R2_RET_182_RNIB8IA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(97),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(97),
datad => N_30963);
GRFPU0_GRFPU_X0_NXX_1_I_A2_19_13: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_13\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10\,
datae => \GRFPU0.MULO.MRES\(49),
datad => \GRFPU0.MULO.MRES\(48),
datac => \GRFPU0.MULO.MRES\(51),
datab => \GRFPU0.MULO.MRES\(50));
GRFPU0_GRFPU_X0_NXX_1_I_A2_19_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_8\,
dataf => \GRFPU0.MULO.MRES\(27),
datae => \GRFPU0.MULO.MRES\(26),
datad => \GRFPU0.MULO.MRES\(25),
datac => \GRFPU0.MULO.MRES\(24));
GRFPU0_GRFPU_X0_NXX_1_I_A2_19: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_13\,
datae => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_8\,
datad => \GRFPU0.MULO.MRES\(21),
datac => \GRFPU0.MULO.MRES\(20),
datab => \GRFPU0.MULO.MRES\(23),
dataa => \GRFPU0.MULO.MRES\(22));
GRFPU0_GRFPU_X0_NXX_1_I_A2_10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_10\,
dataf => \GRFPU0.MULO.MRES\(47),
datae => \GRFPU0.MULO.MRES\(46),
datad => \GRFPU0.MULO.MRES\(45),
datac => \GRFPU0.MULO.MRES\(43));
GRFPU0_GRFPU_X0_NXX_1_39: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_39\,
dataf => \GRFPU0.MULO.MRES\(31),
datae => \GRFPU0.MULO.MRES\(30),
datad => \GRFPU0.MULO.MRES\(29),
datac => \GRFPU0.MULO.MRES\(28));
GRFPU0_GRFPU_X0_NXX_1_I_A2_7: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_7\,
dataf => \GRFPU0.MULO.MRES\(65),
datae => \GRFPU0.MULO.MRES\(59),
datad => \GRFPU0.MULO.MRES\(34));
GRFPU0_GRFPU_X0_NXX_1_36: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_36\,
dataf => \GRFPU0.MULO.MRES\(19),
datae => \GRFPU0.MULO.MRES\(18),
datad => \GRFPU0.MULO.MRES\(17),
datac => \GRFPU0.MULO.MRES\(16));
GRFPU0_GRFPU_X0_NXX_1_I_A2_9: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_9\,
dataf => \GRFPU0.MULO.MRES\(41),
datae => \GRFPU0.MULO.MRES\(39),
datad => \GRFPU0.MULO.MRES\(44),
datac => \GRFPU0.MULO.MRES\(42));
GRFPU0_GRFPU_X0_NXX_1_I_A2_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_8\,
dataf => \GRFPU0.MULO.MRES\(35),
datae => \GRFPU0.MULO.MRES\(33),
datad => \GRFPU0.MULO.MRES\(40),
datac => \GRFPU0.MULO.MRES\(32));
GRFPU0_GRFPU_X0_NXX_1_I_A2_12: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_12\,
dataf => \GRFPU0.MULO.MRES\(64),
datae => \GRFPU0.MULO.MRES\(63),
datad => \GRFPU0.MULO.MRES\(60),
datac => \GRFPU0.MULO.MRES\(58));
GRFPU0_GRFPU_X0_NXX_1_I_A2_9_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19652_9\,
dataf => \GRFPU0.MULO.MRES\(37),
datae => \GRFPU0.MULO.MRES\(38),
datad => \GRFPU0.MULO.MRES\(36));
GRFPU0_GRFPU_X0_NXX_1_I_A2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19652\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_I_A2_21\,
datae => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.MULO.MRES\(66));
GRFPU0_FPMUL0_R2_RET_184_RNIB0IA: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(95),
datad => N_30959);
GRFPU0_GRFPU_X0_NXX_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_4_0\,
dataf => \GRFPU0.MULO.MRES\(84),
datae => \GRFPU0.MULO.MRES\(83),
datad => \GRFPU0.MULO.MRES\(82),
datac => \GRFPU0.GRFPU_X0.NXX_1\);
GRFPU0_GRFPU_X0_NXX_6: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_6_0\,
dataf => \GRFPU0.GRFPU_X0.NXX_4_0\,
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES\(80),
datac => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1\);
GRFPU0_GRFPU_X0_NXX_8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_8\,
dataf => \GRFPU0.GRFPU_X0.NXX_6_0\,
datae => \GRFPU0.MULO.MRES\(88),
datad => \GRFPU0.MULO.MRES\(87),
datac => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.MULO.MRES\(91));
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI88U5_94_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(94),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(94));
GRFPU0_GRFPU_X0_COMB_NXX_1_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"22ff2230ffffff30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.NXX_1\,
dataf => \GRFPU0.GRFPU_X0.N_19652\,
datae => \GRFPU0.GRFPU_X0.NXX\,
datad => \GRFPU0.GRFPU_X0.N_8376\,
datac => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
dataa => \GRFPU0.MULO.MRES\(68));
GRFPU0_GRFPU_X0_COMB_NXX_1_3_RNI9Q732: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0f0c0c0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_7910\,
dataf => \GRFPU0.GRFPU_X0.COMB.NXX_1\,
datae => \GRFPU0.GRFPU_X0.N_7913_TZ\,
datad => \GRFPU0.GRFPU_X0.N_6875\,
datac => \GRFPU0.GRFPU_X0.N_7942\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_1_0_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccccccf0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_1_0\(53),
dataf => \GRFPU0.GRFPU_X0.N_19821_1\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(2),
datad => \GRFPU0.GRFPU_X0.N_19832\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
GRFPU0_GRFPU_X0_UN23_EXP_SUM1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff0fc330f300c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(53),
datae => \GRFPU0.GRFPU_X0.N_16770\,
datad => \GRFPU0.GRFPU_X0.N_13127_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
datab => \GRFPU0.GRFPU_X0.N_19890\);
GRFPU0_GRFPU_X0_ITER_V_4_RNIGAD51: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_11367\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIDRF21_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNII4601_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_7229_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_DPRES4_2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES4_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_DPRES4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7226\,
dataf => \GRFPU0.GRFPU_X0.COMB.DPRES4_2\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_17757_M_1\,
dataf => \GRFPU0.GRFPU_X0.N_7226\,
datae => \GRFPU0.GRFPU_X0.N_7229_3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_2\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_90_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_53_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_16770\,
dataf => \GRFPU0.GRFPU_X0.N_13127_I\,
datae => \GRFPU0.GRFPU_X0.N_7654\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.ST3.REG_1\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18086\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_47_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(47),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18151\,
datab => \GRFPU0.GRFPU_X0.N_18086\);
\GRFPU0_GRFPU_X0_COMB_RMND_13_1_0__M3\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff033cc0ff0c33c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
dataf => \GRFPU0.MULO.MRES\(68),
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18088\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(49));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_49_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(49),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18153\,
datab => \GRFPU0.GRFPU_X0.N_18088\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18090\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_51_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(51),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18155\,
datab => \GRFPU0.GRFPU_X0.N_18090\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003cff00003c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18158\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(3),
datae => \GRFPU0.GRFPU_X0.N_6328\,
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datac => N_36102,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
GRFPU0_GRFPU_X0_COMB_EXP57: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP57\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_ANC1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_36102,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f0ccf0ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18093\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datae => N_36102,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17602\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_0\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_54_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(54),
dataf => \GRFPU0.GRFPU_X0.N_17602\,
datae => \GRFPU0.GRFPU_X0.N_18158\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datab => \GRFPU0.GRFPU_X0.N_18093\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18079\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(40),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18144\,
datab => \GRFPU0.GRFPU_X0.N_18079\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18089\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_50_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(50),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_18154\,
datab => \GRFPU0.GRFPU_X0.N_18089\);
GRFPU0_GRFPU_X0_ITER_SIGN_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00000cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_N_4_0_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_6_RNO_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0c0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(46),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_228_1\,
datac => \GRFPU0.GRFPU_X0.N_6466\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(46));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_X2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_51_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_COMB_SIGN_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datad => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPU0_GRFPU_X0_COMB_RNDM_2_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDM_2\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
\GRFPU0_GRFPU_X0_COMB_RNDM_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDM_2\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX2_6_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX2_6_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_2_01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M2_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_2_01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M1_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_2_01: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00fffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_2_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datad => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_0_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_0_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI0HR11_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6661_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_VST3_REG71: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6661\,
dataf => \GRFPU0.GRFPU_X0.COMB.BIAS15_1\,
datae => \GRFPU0.GRFPU_X0.N_6661_6\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_BIAS15_4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15_4\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_BIAS15_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.BIAS15_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00fff00f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(44),
datac => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_4_03_0_G0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00fff00f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(45),
datac => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
\GRFPC0_EX_RREG_EXCT_RNO_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fff000000ff00")
port map (
combout => N_91837,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datad => \GRFPC0.EX.RREG.EXCT\(3),
datac => N_63);
\GRFPC0_EX_RREG_EXCT_RNO_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fff000000ff00")
port map (
combout => N_91838,
dataf => \FPO.EXC\(2),
datae => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datad => \GRFPC0.EX.RREG.EXCT\(2),
datac => N_63);
\GRFPC0_EX_RREG_EXCT_RNO_5_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33000000f0f0f0f0")
port map (
combout => N_91835,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datac => \GRFPC0.EX.RREG.EXCT\(5),
datab => N_63);
\GRFPC0_EX_RREG_EXCT_RNO_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33000000f0f0f0f0")
port map (
combout => N_91839,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.EX.RREG.EXCT\(1),
datab => N_63);
\GRFPC0_EX_RREG_EXCT_RNO_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33000000f0f0f0f0")
port map (
combout => N_91836,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_5__G0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.EX.RREG.EXCT\(4),
datab => N_63);
GRFPC0_WR_CTRL_RS1V_RNI8F401: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPC0.WR.CTRL.RS1VI\,
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.WR.CTRL.RS1V\,
datad => N_61,
datac => N_63);
GRFPC0_MEM_CTRL_RS1V_RNI8K0J: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff0000f0f0000")
port map (
combout => \GRFPC0.MEM.CTRL.RS1VI\,
dataf => \GRFPC0.EX.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.RS1V\,
datad => N_61,
datac => N_63);
GRFPU0_GRFPU_X0_VITER_STATE_18_SQMUXA_RNIPFVJ3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_11284_0\,
dataf => \GRFPU0.GRFPU_X0.VITER.STATE_18_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_6__G0_I_0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
N_189350 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(2);
N_189351 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(3);
N_189352 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(4);
N_189353 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(5);
N_189354 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(6);
N_189355 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(7);
N_189356 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(8);
N_189357 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(9);
N_189358 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(10);
N_189359 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(11);
N_189360 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(12);
N_189361 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(13);
N_189362 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(14);
N_189363 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(15);
N_189364 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(16);
N_189365 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(17);
N_189366 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(18);
N_189367 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(19);
N_189368 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(20);
N_189369 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(21);
N_189370 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(22);
N_189371 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(23);
N_189372 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(24);
N_189373 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(25);
N_189374 <= not \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\;
N_189375 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(26);
GRFPC0_WR_CTRL_INST_RET_14: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24633\,
datain => \GRFPC0.N_24633_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(28),
datain => N_185356,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(27),
datain => N_185355,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(18),
datain => N_53016,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(16),
datain => N_53014,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(17),
datain => N_53015,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(15),
datain => N_53013,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA2_RS1SEL_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL\(7),
datain => \GRFPC0.FPUSEL_6\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.N_78_I_I\,
datain => N_52982,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(0),
datain => N_52998,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(14),
datain => N_53012,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.TZI2\(4),
datain => \GRFPU0.GRFPU_X0.TZI2_RETI\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_DP: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_RNDMODE_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_5193\,
datain => \GRFPU0.GRFPU_X0.N_5193_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_28: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(67),
datain => \GRFPU0.MULO.MRES_RETI\(67),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datain => \GRFPU0.GRFPU_X0.N_11287\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datain => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(0),
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datain => \GRFPU0.GRFPU_X0.ITER.RNDMODEI\(1),
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_R2_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10\,
datain => \GRFPU0.GRFPU_X0.NXX_1_I_A2_19_10_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_13: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24719\,
datain => \GRFPC0.N_24719_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(2),
datain => N_185330,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(3),
datain => N_185331,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_MEM_CTRL_INST_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24642\,
datain => \GRFPC0.N_24642_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_MEM_CTRL_RS1V: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RS1V\,
datain => \GRFPC0.MEM.CTRL.RS1VI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RDD\,
datain => \GRFPC0.MEM.CTRL.RDDI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_INST_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(14),
datain => N_185280,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_19713_RETO\,
datain => \GRFPU0.GRFPU_X0.N_19713\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_12: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1\(0),
datain => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19_1_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(16),
datain => N_185344,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(17),
datain => N_185345,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(15),
datain => N_185343,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(18),
datain => N_185346,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_11: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0\(0),
datain => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_1_0_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RDD_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0\(1),
datain => \GRFPC0.FP_PIPELINE.9.REGDEPX2_290_0_A4_3_0_RETI\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RS1V: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RS1V\,
datain => \GRFPC0.WR.CTRL.RS1VI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_INST_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(14),
datain => N_185342,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.N_131\,
datain => \GRFPC0.N_131I\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_RDD_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0\(1),
datain => \GRFPC0.FP_PIPELINE.1.REGDEPX2_50_0_A4_3_0_RETI\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_10: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2\(0),
datain => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A2_2_2_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_9: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25664\,
datain => \GRFPC0.N_25664_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RDD_RET_1: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25854\,
datain => \GRFPC0.N_25854_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_25: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1_RETI\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_3: stratixii_lcell_ff port map (
regout => N_174945,
datain => N_174945_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_19279_I\,
datain => \GRFPU0.GRFPU_X0.N_19279_I_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_24: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(71),
datain => \GRFPU0.MULO.MRES_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_19404_I\,
datain => \GRFPU0.GRFPU_X0.N_19404_I_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_25: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(70),
datain => \GRFPU0.MULO.MRES_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_8: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25090\,
datain => \GRFPC0.N_25090_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_7: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25586\,
datain => \GRFPC0.N_25586_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_6: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25585\,
datain => \GRFPC0.N_25585_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_5: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1\(0),
datain => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_A2_1_1_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_4: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1_RETI\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SQRT: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datain => N_29618,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datain => \GRFPU0.GRFPU_X0.N_11278\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datain => \GRFPU0.GRFPU_X0.N_11272\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
datain => \GRFPU0.GRFPU_X0.N_11284_0\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datain => \GRFPU0.GRFPU_X0.N_11269_0\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datain => \GRFPU0.GRFPU_X0.N_11275\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_23: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(72),
datain => \GRFPU0.MULO.MRES_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datain => \GRFPU0.GRFPU_X0.N_11277\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_ODDEXP: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datain => N_91845,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_R_I_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_3406\,
datain => \GRFPU0.GRFPU_X0.N_3406_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_19: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_4_16_1_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_14: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(81),
datain => \GRFPU0.MULO.MRES_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_18: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(77),
datain => \GRFPU0.MULO.MRES_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_19: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(76),
datain => \GRFPU0.MULO.MRES_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.NXX_1\,
datain => \GRFPU0.GRFPU_X0.NXX_1_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_16: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(79),
datain => \GRFPU0.MULO.MRES_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_17: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(78),
datain => \GRFPU0.MULO.MRES_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_20: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(75),
datain => \GRFPU0.MULO.MRES_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_21: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(74),
datain => \GRFPU0.MULO.MRES_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\,
datain => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_STICKY: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.STICKY\,
datain => \GRFPU0.GRFPU_X0.N_11253\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_21: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0\,
datain => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.G_DP_1\,
datain => \GRFPU0.GRFPU_X0.COMB.G_DP_1_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_4: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0\(0),
datain => \GRFPC0.FP_PIPELINE.6.REGDEPX2_199_0_0_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_3: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25091\,
datain => \GRFPC0.N_25091_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_2: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25384\,
datain => \GRFPC0.N_25384_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2\(0),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_2_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(4),
datain => N_185332,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(1),
datain => N_185329,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_INST_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7\(0),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_7_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RS1V_RET_2: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24957\,
datain => \GRFPC0.N_24957_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RS1V_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24981\,
datain => \GRFPC0.N_24981_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_MEM_CTRL_INST_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(0),
datain => N_185266,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_STATE_RET_1: stratixii_lcell_ff port map (
regout => N_184434,
datain => N_184434_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datain => \GRFPU0.GRFPU_X0.N_11279\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_16: stratixii_lcell_ff port map (
regout => \GRFPC0.N_23587\,
datain => \GRFPC0.N_23587_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(25),
datain => N_53023,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_15: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\,
datain => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(28),
datain => N_53026,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(26),
datain => N_53024,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(29),
datain => N_53027,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(27),
datain => N_53025,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_14: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25532\,
datain => \GRFPC0.N_25532_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_13: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25553\,
datain => \GRFPC0.N_25553_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RS1V: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RS1V\,
datain => \GRFPC0.EX.CTRL.RS1V_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_12: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0\(1),
datain => \GRFPC0.FP_PIPELINE.10.REGDEPX2_310_0_A3_1_0_0_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_11: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24727\,
datain => \GRFPC0.N_24727_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_10: stratixii_lcell_ff port map (
regout => \GRFPC0.N_252\,
datain => \GRFPC0.N_252_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_9: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24487\,
datain => \GRFPC0.N_24487_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_FPMUL0_R2_RET_213: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(97),
datain => \GRFPU0.MULO.DRES_1_RETI\(97),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_104: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\,
datain => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.CS_DP_R\,
datain => \GRFPU0.GRFPU_X0.N_15336_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_97_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(97),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_8: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25566\,
datain => \GRFPC0.N_25566_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_STATE_RET_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
datain => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_7: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2\,
datain => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3782_REGDEPX2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_6: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0\(1),
datain => \GRFPC0.FP_PIPELINE.6.REGDEPX2_190_0_A2_0_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_5: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2\,
datain => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5987_REGDEPX2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_4: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2\,
datain => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4223_REGDEPX2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET_3: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0\(0),
datain => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_A2_0_RETI\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_INST_RET_1: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12\(0),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_12_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(25),
datain => N_185353,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_FARRES_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.S_SP_14\,
datain => \GRFPU0.GRFPU_X0.S_SP_14_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_ITER_IDCST_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\(2),
datain => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB_RETI\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FID_0_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(0),
datain => \GRFPC0.FID_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_IDCST_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(0),
datain => \GRFPU0.GRFPU_X0.ITER.IDI\(0),
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA2_FID_2_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(2),
datain => \GRFPC0.FID_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FID_1_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(1),
datain => \GRFPC0.FID_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_IDCST_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(2),
datain => \GRFPU0.GRFPU_X0.ITER.IDI\(2),
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(1),
datain => \GRFPU0.GRFPU_X0.ITER.IDI\(1),
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_24: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_7_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_15: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(80),
datain => \GRFPU0.MULO.MRES_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(0),
datain => N_185328,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_21036\,
datain => \GRFPU0.GRFPU_X0.N_21036_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_STATE_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2\,
datain => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_REG_RET_3: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_4296_RETO\,
datain => \GRFPU0.GRFPU_X0.N_4296\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_REG_RET_2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SIGN2_RETO\,
datain => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_REG_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I_RETO\(63),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_REG_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2_RETO\(63),
datain => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_2_5_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_27: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(68),
datain => \GRFPU0.MULO.MRES_RETI\(68),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_26: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(69),
datain => \GRFPU0.MULO.MRES_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_13: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_13_I_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_9: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(86),
datain => \GRFPU0.MULO.MRES_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_13: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(82),
datain => \GRFPU0.MULO.MRES_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS2SEL_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.OP2_SN_N_6\,
datain => \GRFPC0.OP2_SN_N_6_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL\(2),
datain => \GRFPC0.FPUSEL_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RS1V_RET_1: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0\(0),
datain => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80_0_A2_1_0_RETI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_27: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_5_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_CS_ITER_R_0_0_RET_26: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6\,
datain => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_6_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_22: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(73),
datain => \GRFPU0.MULO.MRES_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_2: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1\(1),
datain => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_A2_2_1_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_RET_3: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24711\,
datain => \GRFPC0.N_24711_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2\,
datain => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3341_REGDEPX2_2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.N_24119\,
datain => \GRFPC0.N_24119_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_RET_2: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10\(0),
datain => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_10_RETI\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA2_RS1SEL_RET_11: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
datain => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_9: stratixii_lcell_ff port map (
regout => \GRFPC0.UN1_WRENX2_2_4_1_RETO\,
datain => \GRFPC0.UN1_WRENX2_2_4_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_7: stratixii_lcell_ff port map (
regout => \GRFPC0.UN1_WRENX2_2_5_RETO\,
datain => \GRFPC0.UN1_WRENX2_2_5\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_0: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.VALID_RETO\,
datain => \GRFPC0.DIV.VALID\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_CTRL_INST_RET_1: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_RET_1: stratixii_lcell_ff port map (
regout => \GRFPC0.N_25715_2\,
datain => \GRFPC0.N_25715_2_RETI\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_INST_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datain => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA2_RS1SEL_RET_6: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RESV_RETO\,
datain => \GRFPC0.WR.RREG.RESV\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_5: stratixii_lcell_ff port map (
regout => \GRFPC0.FPUSEL_6_1_RETO\(7),
datain => \GRFPC0.FPUSEL_6_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_3: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.WR2SEL4_RETO\,
datain => \GRFPC0.FP_PIPELINE.0.WR2SEL4\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_2: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_RETO\,
datain => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET_1: stratixii_lcell_ff port map (
regout => HOLDN_RETO,
datain => N_63,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1SEL_RET: stratixii_lcell_ff port map (
regout => \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\,
datain => \GRFPC0.FP_PIPELINE.0.WRENX2\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_212: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(96),
datain => \GRFPU0.MULO.MRES_RETI\(96),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datain => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_183: stratixii_lcell_ff port map (
regout => N_30961,
datain => N_30961_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_96_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(96),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_211: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(101),
datain => \GRFPU0.MULO.MRES_RETI\(101),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_178: stratixii_lcell_ff port map (
regout => N_30971,
datain => N_30971_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_101_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(101),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_71: stratixii_lcell_ff port map (
regout => N_30907,
datain => N_30907_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_70: stratixii_lcell_ff port map (
regout => N_30909,
datain => N_30909_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_69: stratixii_lcell_ff port map (
regout => N_30911,
datain => N_30911_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_68: stratixii_lcell_ff port map (
regout => N_30913,
datain => N_30913_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_67: stratixii_lcell_ff port map (
regout => N_30915,
datain => N_30915_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_66: stratixii_lcell_ff port map (
regout => N_30917,
datain => N_30917_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_65: stratixii_lcell_ff port map (
regout => N_30919,
datain => N_30919_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_64: stratixii_lcell_ff port map (
regout => N_30921,
datain => N_30921_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_63: stratixii_lcell_ff port map (
regout => N_30923,
datain => N_30923_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_62: stratixii_lcell_ff port map (
regout => N_30925,
datain => N_30925_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_61: stratixii_lcell_ff port map (
regout => N_30927,
datain => N_30927_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_60: stratixii_lcell_ff port map (
regout => N_30929,
datain => N_30929_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_59: stratixii_lcell_ff port map (
regout => N_30931,
datain => N_30931_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_58: stratixii_lcell_ff port map (
regout => N_30933,
datain => N_30933_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_57: stratixii_lcell_ff port map (
regout => N_30935,
datain => N_30935_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_56: stratixii_lcell_ff port map (
regout => N_30937,
datain => N_30937_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_55: stratixii_lcell_ff port map (
regout => N_30939,
datain => N_30939_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_54: stratixii_lcell_ff port map (
regout => N_30941,
datain => N_30941_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_53: stratixii_lcell_ff port map (
regout => N_30943,
datain => N_30943_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_52: stratixii_lcell_ff port map (
regout => N_30945,
datain => N_30945_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_51: stratixii_lcell_ff port map (
regout => N_30947,
datain => N_30947_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_50: stratixii_lcell_ff port map (
regout => N_30949,
datain => N_30949_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_49: stratixii_lcell_ff port map (
regout => N_30953,
datain => N_30953_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_98_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(98),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_99_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(99),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_100_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(100),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_102_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(102),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_103_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(103),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_104_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(104),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_105_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(105),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_106_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(106),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_107_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(107),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_108_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(108),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_109_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(109),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_110_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(110),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_111_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(111),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_112_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(112),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_113_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(113),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_114_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(114),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_115_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(115),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_116_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(116),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_117_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(117),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_118_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(118),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_119_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(119),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_120_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(120),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_121_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(121),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_209: stratixii_lcell_ff port map (
regout => N_30904,
datain => N_30904_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_208: stratixii_lcell_ff port map (
regout => N_30902,
datain => N_30902_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_207: stratixii_lcell_ff port map (
regout => N_30908,
datain => N_30908_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_206: stratixii_lcell_ff port map (
regout => N_30910,
datain => N_30910_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_205: stratixii_lcell_ff port map (
regout => N_30912,
datain => N_30912_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_204: stratixii_lcell_ff port map (
regout => N_30914,
datain => N_30914_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_203: stratixii_lcell_ff port map (
regout => N_30916,
datain => N_30916_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_202: stratixii_lcell_ff port map (
regout => N_30918,
datain => N_30918_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_201: stratixii_lcell_ff port map (
regout => N_30920,
datain => N_30920_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_200: stratixii_lcell_ff port map (
regout => N_30922,
datain => N_30922_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_199: stratixii_lcell_ff port map (
regout => N_30924,
datain => N_30924_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_198: stratixii_lcell_ff port map (
regout => N_30926,
datain => N_30926_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_197: stratixii_lcell_ff port map (
regout => N_30928,
datain => N_30928_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_196: stratixii_lcell_ff port map (
regout => N_30930,
datain => N_30930_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_195: stratixii_lcell_ff port map (
regout => N_30932,
datain => N_30932_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_194: stratixii_lcell_ff port map (
regout => N_30934,
datain => N_30934_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_193: stratixii_lcell_ff port map (
regout => N_30936,
datain => N_30936_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_192: stratixii_lcell_ff port map (
regout => N_30938,
datain => N_30938_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_191: stratixii_lcell_ff port map (
regout => N_30940,
datain => N_30940_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_190: stratixii_lcell_ff port map (
regout => N_30942,
datain => N_30942_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_189: stratixii_lcell_ff port map (
regout => N_30944,
datain => N_30944_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_188: stratixii_lcell_ff port map (
regout => N_30946,
datain => N_30946_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_187: stratixii_lcell_ff port map (
regout => N_30948,
datain => N_30948_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_186: stratixii_lcell_ff port map (
regout => N_30950,
datain => N_30950_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_185: stratixii_lcell_ff port map (
regout => N_30954,
datain => N_30954_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_95_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(95),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_94_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(94),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_184: stratixii_lcell_ff port map (
regout => N_30959,
datain => N_30959_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_182: stratixii_lcell_ff port map (
regout => N_30963,
datain => N_30963_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_181: stratixii_lcell_ff port map (
regout => N_30965,
datain => N_30965_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_180: stratixii_lcell_ff port map (
regout => N_30967,
datain => N_30967_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_179: stratixii_lcell_ff port map (
regout => N_30969,
datain => N_30969_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_177: stratixii_lcell_ff port map (
regout => N_30973,
datain => N_30973_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_176: stratixii_lcell_ff port map (
regout => N_30975,
datain => N_30975_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_175: stratixii_lcell_ff port map (
regout => N_30977,
datain => N_30977_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_174: stratixii_lcell_ff port map (
regout => N_30979,
datain => N_30979_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_173: stratixii_lcell_ff port map (
regout => N_30981,
datain => N_30981_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_172: stratixii_lcell_ff port map (
regout => N_30983,
datain => N_30983_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_171: stratixii_lcell_ff port map (
regout => N_30985,
datain => N_30985_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_170: stratixii_lcell_ff port map (
regout => N_30987,
datain => N_30987_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_169: stratixii_lcell_ff port map (
regout => N_30989,
datain => N_30989_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_168: stratixii_lcell_ff port map (
regout => N_30991,
datain => N_30991_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_167: stratixii_lcell_ff port map (
regout => N_30993,
datain => N_30993_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_166: stratixii_lcell_ff port map (
regout => N_30995,
datain => N_30995_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_165: stratixii_lcell_ff port map (
regout => N_30997,
datain => N_30997_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_164: stratixii_lcell_ff port map (
regout => N_30999,
datain => N_30999_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_163: stratixii_lcell_ff port map (
regout => N_31001,
datain => N_31001_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_162: stratixii_lcell_ff port map (
regout => N_31003,
datain => N_31003_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_161: stratixii_lcell_ff port map (
regout => N_31005,
datain => N_31005_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_160: stratixii_lcell_ff port map (
regout => N_31007,
datain => N_31007_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_159: stratixii_lcell_ff port map (
regout => N_31009,
datain => N_31009_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_158: stratixii_lcell_ff port map (
regout => N_31011,
datain => N_31011_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_157: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(67),
datain => \GRFPU0.MULO.DRES_1S_RETI\(67),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_156: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(68),
datain => \GRFPU0.MULO.DRES_1S_RETI\(68),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_155: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(69),
datain => \GRFPU0.MULO.DRES_1S_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_154: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(70),
datain => \GRFPU0.MULO.DRES_1S_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_153: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(71),
datain => \GRFPU0.MULO.DRES_1S_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_152: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(72),
datain => \GRFPU0.MULO.DRES_1S_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_151: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(73),
datain => \GRFPU0.MULO.DRES_1S_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_150: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(74),
datain => \GRFPU0.MULO.DRES_1S_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_149: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(75),
datain => \GRFPU0.MULO.DRES_1S_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_148: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(76),
datain => \GRFPU0.MULO.DRES_1S_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_147: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(77),
datain => \GRFPU0.MULO.DRES_1S_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_146: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(78),
datain => \GRFPU0.MULO.DRES_1S_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_145: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(79),
datain => \GRFPU0.MULO.DRES_1S_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_144: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(80),
datain => \GRFPU0.MULO.DRES_1S_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_143: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(81),
datain => \GRFPU0.MULO.DRES_1S_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_142: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(82),
datain => \GRFPU0.MULO.DRES_1S_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_141: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(83),
datain => \GRFPU0.MULO.DRES_1S_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_140: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(84),
datain => \GRFPU0.MULO.DRES_1S_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_139: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(85),
datain => \GRFPU0.MULO.DRES_1S_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_138: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(86),
datain => \GRFPU0.MULO.DRES_1S_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_137: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(87),
datain => \GRFPU0.MULO.DRES_1S_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_136: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(88),
datain => \GRFPU0.MULO.DRES_1S_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_135: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(89),
datain => \GRFPU0.MULO.DRES_1S_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_134: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(90),
datain => \GRFPU0.MULO.DRES_1S_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_133: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(91),
datain => \GRFPU0.MULO.DRES_1S_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_132: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1S\(92),
datain => \GRFPU0.MULO.DRES_1S_RETI\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_131: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\,
datain => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_65_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(65),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_68_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(68),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_92_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(92),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_130: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(68),
datain => \GRFPU0.MULO.DRES_1_RETI\(68),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_129: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(69),
datain => \GRFPU0.MULO.DRES_1_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_128: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(70),
datain => \GRFPU0.MULO.DRES_1_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_127: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(71),
datain => \GRFPU0.MULO.DRES_1_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_126: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(72),
datain => \GRFPU0.MULO.DRES_1_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_125: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(73),
datain => \GRFPU0.MULO.DRES_1_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_124: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(74),
datain => \GRFPU0.MULO.DRES_1_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_123: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(75),
datain => \GRFPU0.MULO.DRES_1_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_122: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(76),
datain => \GRFPU0.MULO.DRES_1_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_121: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(77),
datain => \GRFPU0.MULO.DRES_1_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_120: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(78),
datain => \GRFPU0.MULO.DRES_1_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_119: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(79),
datain => \GRFPU0.MULO.DRES_1_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_118: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(80),
datain => \GRFPU0.MULO.DRES_1_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_117: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(81),
datain => \GRFPU0.MULO.DRES_1_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_116: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(82),
datain => \GRFPU0.MULO.DRES_1_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_115: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(83),
datain => \GRFPU0.MULO.DRES_1_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_114: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(84),
datain => \GRFPU0.MULO.DRES_1_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_113: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(85),
datain => \GRFPU0.MULO.DRES_1_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_112: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(86),
datain => \GRFPU0.MULO.DRES_1_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_111: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(87),
datain => \GRFPU0.MULO.DRES_1_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_110: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(88),
datain => \GRFPU0.MULO.DRES_1_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_109: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(89),
datain => \GRFPU0.MULO.DRES_1_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_108: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(90),
datain => \GRFPU0.MULO.DRES_1_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_107: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(91),
datain => \GRFPU0.MULO.DRES_1_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_106: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(92),
datain => \GRFPU0.MULO.DRES_1_RETI\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_105: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_1\(93),
datain => \GRFPU0.MULO.DRES_1_RETI\(93),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_93_\: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.SX\(93),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_29: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(66),
datain => \GRFPU0.MULO.MRES_RETI\(66),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_12: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(83),
datain => \GRFPU0.MULO.MRES_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_11: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(84),
datain => \GRFPU0.MULO.MRES_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_10: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(85),
datain => \GRFPU0.MULO.MRES_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_8: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(87),
datain => \GRFPU0.MULO.MRES_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_7: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(88),
datain => \GRFPU0.MULO.MRES_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_6: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(89),
datain => \GRFPU0.MULO.MRES_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_5: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(90),
datain => \GRFPU0.MULO.MRES_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_4: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(91),
datain => \GRFPU0.MULO.MRES_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_3: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(92),
datain => \GRFPU0.MULO.MRES_RETI\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_ITER_R_0_0_RET_2: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(93),
datain => \GRFPU0.MULO.MRES_RETI\(93),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_103: stratixii_lcell_ff port map (
regout => N_31075,
datain => N_31075_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_102: stratixii_lcell_ff port map (
regout => N_31073,
datain => N_31073_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_101: stratixii_lcell_ff port map (
regout => N_31071,
datain => N_31071_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_100: stratixii_lcell_ff port map (
regout => N_31077,
datain => N_31077_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_99: stratixii_lcell_ff port map (
regout => N_31079,
datain => N_31079_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_98: stratixii_lcell_ff port map (
regout => N_31081,
datain => N_31081_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_97: stratixii_lcell_ff port map (
regout => N_31083,
datain => N_31083_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_96: stratixii_lcell_ff port map (
regout => N_31085,
datain => N_31085_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_95: stratixii_lcell_ff port map (
regout => N_31087,
datain => N_31087_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_94: stratixii_lcell_ff port map (
regout => N_31089,
datain => N_31089_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_93: stratixii_lcell_ff port map (
regout => N_31091,
datain => N_31091_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_92: stratixii_lcell_ff port map (
regout => N_31093,
datain => N_31093_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_91: stratixii_lcell_ff port map (
regout => N_31095,
datain => N_31095_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_90: stratixii_lcell_ff port map (
regout => N_31097,
datain => N_31097_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_89: stratixii_lcell_ff port map (
regout => N_31099,
datain => N_31099_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_88: stratixii_lcell_ff port map (
regout => N_31101,
datain => N_31101_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_87: stratixii_lcell_ff port map (
regout => N_31103,
datain => N_31103_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_86: stratixii_lcell_ff port map (
regout => N_31105,
datain => N_31105_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_85: stratixii_lcell_ff port map (
regout => N_31107,
datain => N_31107_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_84: stratixii_lcell_ff port map (
regout => N_31109,
datain => N_31109_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_83: stratixii_lcell_ff port map (
regout => N_31111,
datain => N_31111_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_82: stratixii_lcell_ff port map (
regout => N_31113,
datain => N_31113_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_81: stratixii_lcell_ff port map (
regout => N_31115,
datain => N_31115_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_80: stratixii_lcell_ff port map (
regout => N_31117,
datain => N_31117_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_79: stratixii_lcell_ff port map (
regout => N_31119,
datain => N_31119_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_78: stratixii_lcell_ff port map (
regout => N_31123,
datain => N_31123_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_48: stratixii_lcell_ff port map (
regout => N_31076,
datain => N_31076_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_47: stratixii_lcell_ff port map (
regout => N_31078,
datain => N_31078_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_46: stratixii_lcell_ff port map (
regout => N_31080,
datain => N_31080_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_45: stratixii_lcell_ff port map (
regout => N_31082,
datain => N_31082_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_44: stratixii_lcell_ff port map (
regout => N_31084,
datain => N_31084_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_43: stratixii_lcell_ff port map (
regout => N_31086,
datain => N_31086_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_42: stratixii_lcell_ff port map (
regout => N_31088,
datain => N_31088_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_41: stratixii_lcell_ff port map (
regout => N_31090,
datain => N_31090_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_40: stratixii_lcell_ff port map (
regout => N_31092,
datain => N_31092_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_39: stratixii_lcell_ff port map (
regout => N_31094,
datain => N_31094_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_38: stratixii_lcell_ff port map (
regout => N_31096,
datain => N_31096_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_37: stratixii_lcell_ff port map (
regout => N_31098,
datain => N_31098_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_36: stratixii_lcell_ff port map (
regout => N_31100,
datain => N_31100_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_35: stratixii_lcell_ff port map (
regout => N_31102,
datain => N_31102_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_34: stratixii_lcell_ff port map (
regout => N_31104,
datain => N_31104_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_33: stratixii_lcell_ff port map (
regout => N_31106,
datain => N_31106_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_32: stratixii_lcell_ff port map (
regout => N_31108,
datain => N_31108_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_31: stratixii_lcell_ff port map (
regout => N_31110,
datain => N_31110_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_30: stratixii_lcell_ff port map (
regout => N_31112,
datain => N_31112_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_29: stratixii_lcell_ff port map (
regout => N_31114,
datain => N_31114_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_28: stratixii_lcell_ff port map (
regout => N_31116,
datain => N_31116_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_0: stratixii_lcell_ff port map (
regout => N_31118,
datain => N_31118_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET: stratixii_lcell_ff port map (
regout => N_31122,
datain => N_31122_RETI,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_77: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(69),
datain => \GRFPU0.MULO.MRES_1S_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_76: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(70),
datain => \GRFPU0.MULO.MRES_1S_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_75: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(71),
datain => \GRFPU0.MULO.MRES_1S_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_74: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(72),
datain => \GRFPU0.MULO.MRES_1S_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_73: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(73),
datain => \GRFPU0.MULO.MRES_1S_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_72: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(74),
datain => \GRFPU0.MULO.MRES_1S_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_71: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(75),
datain => \GRFPU0.MULO.MRES_1S_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_70: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(76),
datain => \GRFPU0.MULO.MRES_1S_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_69: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(77),
datain => \GRFPU0.MULO.MRES_1S_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_68: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(78),
datain => \GRFPU0.MULO.MRES_1S_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_67: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(79),
datain => \GRFPU0.MULO.MRES_1S_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_66: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(80),
datain => \GRFPU0.MULO.MRES_1S_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_65: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(81),
datain => \GRFPU0.MULO.MRES_1S_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_64: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(82),
datain => \GRFPU0.MULO.MRES_1S_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_63: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(83),
datain => \GRFPU0.MULO.MRES_1S_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_62: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(84),
datain => \GRFPU0.MULO.MRES_1S_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_61: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(85),
datain => \GRFPU0.MULO.MRES_1S_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_60: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(86),
datain => \GRFPU0.MULO.MRES_1S_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_59: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(87),
datain => \GRFPU0.MULO.MRES_1S_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_58: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(88),
datain => \GRFPU0.MULO.MRES_1S_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_57: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(89),
datain => \GRFPU0.MULO.MRES_1S_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_56: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(90),
datain => \GRFPU0.MULO.MRES_1S_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_55: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(91),
datain => \GRFPU0.MULO.MRES_1S_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_54: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(92),
datain => \GRFPU0.MULO.MRES_1S_RETI\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_53: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(93),
datain => \GRFPU0.MULO.MRES_1S_RETI\(93),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_52: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(94),
datain => \GRFPU0.MULO.MRES_1S_RETI\(94),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_51: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(95),
datain => \GRFPU0.MULO.MRES_1S_RETI\(95),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_50: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(96),
datain => \GRFPU0.MULO.MRES_1S_RETI\(96),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_49: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(97),
datain => \GRFPU0.MULO.MRES_1S_RETI\(97),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_48: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(98),
datain => \GRFPU0.MULO.MRES_1S_RETI\(98),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_47: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(99),
datain => \GRFPU0.MULO.MRES_1S_RETI\(99),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_46: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(100),
datain => \GRFPU0.MULO.MRES_1S_RETI\(100),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_45: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(101),
datain => \GRFPU0.MULO.MRES_1S_RETI\(101),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_44: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(102),
datain => \GRFPU0.MULO.MRES_1S_RETI\(102),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_43: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(103),
datain => \GRFPU0.MULO.MRES_1S_RETI\(103),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_42: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(104),
datain => \GRFPU0.MULO.MRES_1S_RETI\(104),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_41: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(105),
datain => \GRFPU0.MULO.MRES_1S_RETI\(105),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_40: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(106),
datain => \GRFPU0.MULO.MRES_1S_RETI\(106),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_39: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(107),
datain => \GRFPU0.MULO.MRES_1S_RETI\(107),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_38: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(108),
datain => \GRFPU0.MULO.MRES_1S_RETI\(108),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_37: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(109),
datain => \GRFPU0.MULO.MRES_1S_RETI\(109),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_36: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(110),
datain => \GRFPU0.MULO.MRES_1S_RETI\(110),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_35: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(111),
datain => \GRFPU0.MULO.MRES_1S_RETI\(111),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_34: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(112),
datain => \GRFPU0.MULO.MRES_1S_RETI\(112),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_33: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(113),
datain => \GRFPU0.MULO.MRES_1S_RETI\(113),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_32: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(114),
datain => \GRFPU0.MULO.MRES_1S_RETI\(114),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_31: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(115),
datain => \GRFPU0.MULO.MRES_1S_RETI\(115),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_30: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(116),
datain => \GRFPU0.MULO.MRES_1S_RETI\(116),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_29: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(117),
datain => \GRFPU0.MULO.MRES_1S_RETI\(117),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_28: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(118),
datain => \GRFPU0.MULO.MRES_1S_RETI\(118),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_27: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(119),
datain => \GRFPU0.MULO.MRES_1S_RETI\(119),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_0: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1S\(120),
datain => \GRFPU0.MULO.MRES_1S_RETI\(120),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_27: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(69),
datain => \GRFPU0.MULO.MRES_1_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_26: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(70),
datain => \GRFPU0.MULO.MRES_1_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_25: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(71),
datain => \GRFPU0.MULO.MRES_1_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_24: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(72),
datain => \GRFPU0.MULO.MRES_1_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_23: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(73),
datain => \GRFPU0.MULO.MRES_1_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_22: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(74),
datain => \GRFPU0.MULO.MRES_1_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_21: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(75),
datain => \GRFPU0.MULO.MRES_1_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_20: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(76),
datain => \GRFPU0.MULO.MRES_1_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_19: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(77),
datain => \GRFPU0.MULO.MRES_1_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_18: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(78),
datain => \GRFPU0.MULO.MRES_1_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_17: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(79),
datain => \GRFPU0.MULO.MRES_1_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_16: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(80),
datain => \GRFPU0.MULO.MRES_1_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_15: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(81),
datain => \GRFPU0.MULO.MRES_1_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_14: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(82),
datain => \GRFPU0.MULO.MRES_1_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_13: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(83),
datain => \GRFPU0.MULO.MRES_1_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_12: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(84),
datain => \GRFPU0.MULO.MRES_1_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_11: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(85),
datain => \GRFPU0.MULO.MRES_1_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_10: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(86),
datain => \GRFPU0.MULO.MRES_1_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_9: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(87),
datain => \GRFPU0.MULO.MRES_1_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_8: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(88),
datain => \GRFPU0.MULO.MRES_1_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_7: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(89),
datain => \GRFPU0.MULO.MRES_1_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_6: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(90),
datain => \GRFPU0.MULO.MRES_1_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_5: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(91),
datain => \GRFPU0.MULO.MRES_1_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_4: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(92),
datain => \GRFPU0.MULO.MRES_1_RETI\(92),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_3: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(93),
datain => \GRFPU0.MULO.MRES_1_RETI\(93),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_2: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES_1\(94),
datain => \GRFPU0.MULO.MRES_1_RETI\(94),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_CS_DP_R_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datain => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_26: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(68),
datain => \GRFPU0.MULO.DRES_S_RETI\(68),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_25: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(67),
datain => \GRFPU0.MULO.DRES_S_RETI\(67),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_24: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(66),
datain => \GRFPU0.MULO.DRES_S_RETI\(66),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_23: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(69),
datain => \GRFPU0.MULO.DRES_S_RETI\(69),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_22: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(70),
datain => \GRFPU0.MULO.DRES_S_RETI\(70),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_21: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(71),
datain => \GRFPU0.MULO.DRES_S_RETI\(71),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_20: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(72),
datain => \GRFPU0.MULO.DRES_S_RETI\(72),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_19: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(73),
datain => \GRFPU0.MULO.DRES_S_RETI\(73),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_18: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(74),
datain => \GRFPU0.MULO.DRES_S_RETI\(74),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_17: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(75),
datain => \GRFPU0.MULO.DRES_S_RETI\(75),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_16: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(76),
datain => \GRFPU0.MULO.DRES_S_RETI\(76),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_15: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(77),
datain => \GRFPU0.MULO.DRES_S_RETI\(77),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_14: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(78),
datain => \GRFPU0.MULO.DRES_S_RETI\(78),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_13: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(79),
datain => \GRFPU0.MULO.DRES_S_RETI\(79),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_12: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(80),
datain => \GRFPU0.MULO.DRES_S_RETI\(80),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_11: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(81),
datain => \GRFPU0.MULO.DRES_S_RETI\(81),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_10: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(82),
datain => \GRFPU0.MULO.DRES_S_RETI\(82),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_9: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(83),
datain => \GRFPU0.MULO.DRES_S_RETI\(83),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_8: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(84),
datain => \GRFPU0.MULO.DRES_S_RETI\(84),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_7: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(85),
datain => \GRFPU0.MULO.DRES_S_RETI\(85),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_6: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(86),
datain => \GRFPU0.MULO.DRES_S_RETI\(86),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_5: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(87),
datain => \GRFPU0.MULO.DRES_S_RETI\(87),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_4: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(88),
datain => \GRFPU0.MULO.DRES_S_RETI\(88),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_3: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(89),
datain => \GRFPU0.MULO.DRES_S_RETI\(89),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_2: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(90),
datain => \GRFPU0.MULO.DRES_S_RETI\(90),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET_1: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.DRES_S\(91),
datain => \GRFPU0.MULO.DRES_S_RETI\(91),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_FPMUL0_R2_RET: stratixii_lcell_ff port map (
regout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datain => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26_RETI\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(31),
datain => N_185513,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(30),
datain => N_185512,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(29),
datain => N_185511,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(28),
datain => N_185510,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(27),
datain => N_185509,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(26),
datain => N_185508,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(25),
datain => N_185507,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(24),
datain => N_185506,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(23),
datain => N_185505,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(22),
datain => N_185504,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(21),
datain => N_185503,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(20),
datain => N_185502,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(19),
datain => N_185501,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(18),
datain => N_185500,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(17),
datain => N_185499,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(16),
datain => N_185498,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(15),
datain => N_185497,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(14),
datain => N_185496,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(13),
datain => N_185495,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(12),
datain => N_185494,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(11),
datain => N_185493,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(10),
datain => N_185492,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(9),
datain => N_185491,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(8),
datain => N_185490,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(7),
datain => N_185489,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(6),
datain => N_185488,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(5),
datain => N_185487,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(4),
datain => N_185486,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(3),
datain => N_185485,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_PC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PC\(2),
datain => N_185484,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(31),
datain => N_185483,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(30),
datain => N_185482,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(29),
datain => N_185481,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(28),
datain => N_185480,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(27),
datain => N_185479,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(26),
datain => N_185478,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(25),
datain => N_185477,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(24),
datain => N_185476,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(23),
datain => N_185475,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(22),
datain => N_185474,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(21),
datain => N_185473,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(20),
datain => N_185472,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(19),
datain => N_185471,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(18),
datain => N_185470,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(17),
datain => N_185469,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(16),
datain => N_185468,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(15),
datain => N_185467,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(14),
datain => N_185466,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(13),
datain => N_185465,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(12),
datain => N_185464,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(11),
datain => N_185463,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(10),
datain => N_185462,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(9),
datain => N_185461,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(8),
datain => N_185460,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(7),
datain => N_185459,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(6),
datain => N_185458,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(5),
datain => N_185457,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(4),
datain => N_185456,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(3),
datain => N_185455,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(2),
datain => N_185454,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(1),
datain => N_185453,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_INST_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.INST\(0),
datain => N_185452,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(31),
datain => N_185451,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(30),
datain => N_185450,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(29),
datain => N_185449,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(28),
datain => N_185448,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(27),
datain => N_185447,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(26),
datain => N_185446,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(25),
datain => N_185445,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(24),
datain => N_185444,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(23),
datain => N_185443,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(22),
datain => N_185442,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(21),
datain => N_185441,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(20),
datain => N_185440,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(19),
datain => N_185439,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(18),
datain => N_185438,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(17),
datain => N_185437,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(16),
datain => N_185436,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(15),
datain => N_185435,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(14),
datain => N_185434,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(13),
datain => N_185433,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(12),
datain => N_185432,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(11),
datain => N_185431,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(10),
datain => N_185430,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(9),
datain => N_185429,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(8),
datain => N_185428,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(7),
datain => N_185427,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(6),
datain => N_185426,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(5),
datain => N_185425,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(4),
datain => N_185424,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(3),
datain => N_185423,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_PC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PC\(2),
datain => N_185422,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(31),
datain => N_185421,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(30),
datain => N_185420,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(29),
datain => N_185419,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(28),
datain => N_185418,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(27),
datain => N_185417,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(26),
datain => N_185416,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(25),
datain => N_185415,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(24),
datain => N_185414,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(23),
datain => N_185413,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(22),
datain => N_185412,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(21),
datain => N_185411,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(20),
datain => N_185410,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(19),
datain => N_185409,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(18),
datain => N_185408,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(17),
datain => N_185407,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(16),
datain => N_185406,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(15),
datain => N_185405,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(14),
datain => N_185404,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(13),
datain => N_185403,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(12),
datain => N_185402,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(11),
datain => N_185401,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(10),
datain => N_185400,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(9),
datain => N_185399,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(8),
datain => N_185398,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(7),
datain => N_185397,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(6),
datain => N_185396,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(5),
datain => N_185395,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(4),
datain => N_185394,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(3),
datain => N_185393,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(2),
datain => N_185392,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(1),
datain => N_185391,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR2_CTRL_INST_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.INST\(0),
datain => N_185390,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(31),
datain => N_185389,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(30),
datain => N_185388,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(29),
datain => N_185387,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(28),
datain => N_185386,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(27),
datain => N_185385,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(26),
datain => N_185384,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(25),
datain => N_185383,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(24),
datain => N_185382,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(23),
datain => N_185381,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(22),
datain => N_185380,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(21),
datain => N_185379,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(20),
datain => N_185378,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(19),
datain => N_185377,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(18),
datain => N_185376,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(17),
datain => N_185375,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(16),
datain => N_185374,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(15),
datain => N_185373,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(14),
datain => N_185372,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(13),
datain => N_185371,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(12),
datain => N_185370,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(11),
datain => N_185369,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(10),
datain => N_185368,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(9),
datain => N_185367,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(8),
datain => N_185366,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(7),
datain => N_185365,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(6),
datain => N_185364,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(5),
datain => N_185363,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(4),
datain => N_185362,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(3),
datain => N_185361,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_PC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PC\(2),
datain => N_185360,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(31),
datain => N_185359,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(30),
datain => N_185358,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(29),
datain => N_185357,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(26),
datain => N_185354,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(24),
datain => N_185352,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(23),
datain => N_185351,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(22),
datain => N_185350,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(21),
datain => N_185349,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(20),
datain => N_185348,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(19),
datain => N_185347,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(13),
datain => N_185341,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(12),
datain => N_185340,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(11),
datain => N_185339,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(10),
datain => N_185338,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(9),
datain => N_185337,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(8),
datain => N_185336,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(7),
datain => N_185335,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(6),
datain => N_185334,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_CTRL_INST_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.INST\(5),
datain => N_185333,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(31),
datain => N_185327,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(30),
datain => N_185326,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(29),
datain => N_185325,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(28),
datain => N_185324,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(27),
datain => N_185323,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(26),
datain => N_185322,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(25),
datain => N_185321,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(24),
datain => N_185320,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(23),
datain => N_185319,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(22),
datain => N_185318,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(21),
datain => N_185317,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(20),
datain => N_185316,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(19),
datain => N_185315,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(18),
datain => N_185314,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(17),
datain => N_185313,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(16),
datain => N_185312,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(15),
datain => N_185311,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(14),
datain => N_185310,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(13),
datain => N_185309,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(12),
datain => N_185308,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(11),
datain => N_185307,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(10),
datain => N_185306,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(9),
datain => N_185305,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(8),
datain => N_185304,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(7),
datain => N_185303,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(6),
datain => N_185302,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(5),
datain => N_185301,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(4),
datain => N_185300,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(3),
datain => N_185299,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_PC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PC\(2),
datain => N_185298,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(31),
datain => N_185297,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(30),
datain => N_185296,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(29),
datain => N_185295,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(28),
datain => N_185294,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(27),
datain => N_185293,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(26),
datain => N_185292,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(25),
datain => N_185291,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(24),
datain => N_185290,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(23),
datain => N_185289,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(22),
datain => N_185288,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(21),
datain => N_185287,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(20),
datain => N_185286,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(19),
datain => N_185285,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(18),
datain => N_185284,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(17),
datain => N_185283,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(16),
datain => N_185282,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(15),
datain => N_185281,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(13),
datain => N_185279,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(12),
datain => N_185278,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(11),
datain => N_185277,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(10),
datain => N_185276,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(9),
datain => N_185275,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(8),
datain => N_185274,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(7),
datain => N_185273,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(6),
datain => N_185272,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(5),
datain => N_185271,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(4),
datain => N_185270,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(3),
datain => N_185269,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(2),
datain => N_185268,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_MEM_CTRL_INST_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.INST\(1),
datain => N_185267,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_DIV_EXC: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXC\,
datain => N_185265,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
datain => \GRFPU0.GRFPU_X0.N_11285\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
datain => \GRFPU0.GRFPU_X0.N_11271\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(3),
datain => \GRFPU0.GRFPU_X0.N_11288\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datain => \GRFPU0.GRFPU_X0.N_11280\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datain => \GRFPU0.GRFPU_X0.N_11283\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datain => \GRFPU0.GRFPU_X0.N_11286\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
datain => \GRFPU0.GRFPU_X0.N_11289\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_5__G0_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_DIV_PEND: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.PEND\,
datain => N_91848,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXPOP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datain => N_91847,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXPOP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datain => N_91846,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_LOB: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.LOB\,
datain => N_91844,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_EMAXP1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datain => N_91843,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_NX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.NX\,
datain => N_91842,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_FLUSH0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datain => N_91841,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(0),
datain => N_91840,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(1),
datain => N_91839,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(2),
datain => N_91838,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(3),
datain => N_91837,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(4),
datain => N_91836,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_EX_RREG_EXCT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.EXCT\(5),
datain => N_91835,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_WR_RREG_RES_63_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(63),
datain => \GRFPC0.WR.RREG.RES_0_0_63__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(63),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_62_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(62),
datain => \GRFPC0.WR.RREG.RES_0_0_62__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(62),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_61_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(61),
datain => \GRFPC0.WR.RREG.RES_0_0_61__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21425_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_60_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(60),
datain => \GRFPC0.WR.RREG.RES_0_0_60__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21434_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_59_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(59),
datain => \GRFPC0.WR.RREG.RES_0_0_59__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19903_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_58_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(58),
datain => \GRFPC0.WR.RREG.RES_0_0_58__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21424_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_57_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(57),
datain => \GRFPC0.WR.RREG.RES_0_0_57__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21433_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_56_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(56),
datain => \GRFPC0.WR.RREG.RES_0_0_56__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21438_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_55_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(55),
datain => \GRFPC0.WR.RREG.RES_0_0_55__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21423_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_54_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(54),
datain => \GRFPC0.WR.RREG.RES_0_0_54__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_67_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_53_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(53),
datain => \GRFPC0.WR.RREG.RES_0_0_53__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21437_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_52_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(52),
datain => \GRFPC0.WR.RREG.RES_0_0_52__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21426_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_51_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(51),
datain => \GRFPC0.WR.RREG.RES_0_0_51__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21432_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_50_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(50),
datain => \GRFPC0.WR.RREG.RES_0_0_50__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21436_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_49_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(49),
datain => \GRFPC0.WR.RREG.RES_0_0_49__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21429_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_48_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(48),
datain => \GRFPC0.WR.RREG.RES_0_0_48__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21444_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_47_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(47),
datain => \GRFPC0.WR.RREG.RES_0_0_47__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_63_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_46_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(46),
datain => \GRFPC0.WR.RREG.RES_0_0_46__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21428_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_45_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(45),
datain => \GRFPC0.WR.RREG.RES_0_0_45__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_20333_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_44_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(44),
datain => \GRFPC0.WR.RREG.RES_0_0_44__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21431_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_43_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(43),
datain => \GRFPC0.WR.RREG.RES_0_0_43__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21427_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_42_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(42),
datain => \GRFPC0.WR.RREG.RES_0_0_42__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(42),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_41_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(41),
datain => \GRFPC0.WR.RREG.RES_0_0_41__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21430_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_40_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(40),
datain => \GRFPC0.WR.RREG.RES_0_0_40__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21441_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_39_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(39),
datain => \GRFPC0.WR.RREG.RES_0_0_39__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(39),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_38_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(38),
datain => \GRFPC0.WR.RREG.RES_0_0_38__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21435_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_37_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(37),
datain => \GRFPC0.WR.RREG.RES_0_0_37__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21440_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_36_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(36),
datain => \GRFPC0.WR.RREG.RES_0_0_36__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21443_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_35_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(35),
datain => \GRFPC0.WR.RREG.RES_0_0_35__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19990_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_34_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(34),
datain => \GRFPC0.WR.RREG.RES_0_0_34__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21439_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_33_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(33),
datain => \GRFPC0.WR.RREG.RES_0_0_33__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21442_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_32_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(32),
datain => \GRFPC0.WR.RREG.RES_0_0_32__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(32),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(31),
datain => \GRFPC0.WR.RREG.RES_0_0_31__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(31),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(30),
datain => \GRFPC0.WR.RREG.RES_0_0_30__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(30),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(29),
datain => \GRFPC0.WR.RREG.RES_0_0_29__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(29),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(28),
datain => \GRFPC0.WR.RREG.RES_0_0_28__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(28),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(27),
datain => \GRFPC0.WR.RREG.RES_0_0_27__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(27),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(26),
datain => \GRFPC0.WR.RREG.RES_0_0_26__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(26),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(25),
datain => \GRFPC0.WR.RREG.RES_0_0_25__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(25),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(24),
datain => \GRFPC0.WR.RREG.RES_0_0_24__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(24),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(23),
datain => \GRFPC0.WR.RREG.RES_0_0_23__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(23),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(22),
datain => \GRFPC0.WR.RREG.RES_0_0_22__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(22),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(21),
datain => \GRFPC0.WR.RREG.RES_0_0_21__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(21),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(20),
datain => \GRFPC0.WR.RREG.RES_0_0_20__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(20),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(19),
datain => \GRFPC0.WR.RREG.RES_0_0_19__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(19),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(18),
datain => \GRFPC0.WR.RREG.RES_0_0_18__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(18),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(17),
datain => \GRFPC0.WR.RREG.RES_0_0_17__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(17),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(16),
datain => \GRFPC0.WR.RREG.RES_0_0_16__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(16),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(15),
datain => \GRFPC0.WR.RREG.RES_0_0_15__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(15),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(14),
datain => \GRFPC0.WR.RREG.RES_0_0_14__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(14),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(13),
datain => \GRFPC0.WR.RREG.RES_0_0_13__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(13),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(12),
datain => \GRFPC0.WR.RREG.RES_0_0_12__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(12),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(11),
datain => \GRFPC0.WR.RREG.RES_0_0_11__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(11),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(10),
datain => \GRFPC0.WR.RREG.RES_0_0_10__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(10),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(9),
datain => \GRFPC0.WR.RREG.RES_0_0_9__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(9),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(8),
datain => \GRFPC0.WR.RREG.RES_0_0_8__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(8),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(7),
datain => \GRFPC0.WR.RREG.RES_0_0_7__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(7),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(6),
datain => \GRFPC0.WR.RREG.RES_0_0_6__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(6),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(5),
datain => \GRFPC0.WR.RREG.RES_0_0_5__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(5),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(4),
datain => \GRFPC0.WR.RREG.RES_0_0_4__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(4),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(3),
datain => \GRFPC0.WR.RREG.RES_0_0_3__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(3),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(2),
datain => \GRFPC0.WR.RREG.RES_0_0_2__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(2),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(1),
datain => \GRFPC0.WR.RREG.RES_0_0_1__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(1),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_RES_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RES\(0),
datain => \GRFPC0.WR.RREG.RES_0_0_0__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(0),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_63_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(63),
datain => \GRFPC0.MEM.RREG.RES_0_0_63__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(63),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_62_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(62),
datain => \GRFPC0.MEM.RREG.RES_0_0_62__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(62),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_61_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(61),
datain => \GRFPC0.MEM.RREG.RES_0_0_61__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21425_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_60_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(60),
datain => \GRFPC0.MEM.RREG.RES_0_0_60__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21434_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_59_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(59),
datain => \GRFPC0.MEM.RREG.RES_0_0_59__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19903_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_58_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(58),
datain => \GRFPC0.MEM.RREG.RES_0_0_58__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21424_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_57_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(57),
datain => \GRFPC0.MEM.RREG.RES_0_0_57__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21433_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_56_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(56),
datain => \GRFPC0.MEM.RREG.RES_0_0_56__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21438_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_55_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(55),
datain => \GRFPC0.MEM.RREG.RES_0_0_55__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21423_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_54_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(54),
datain => \GRFPC0.MEM.RREG.RES_0_0_54__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_67_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_53_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(53),
datain => \GRFPC0.MEM.RREG.RES_0_0_53__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21437_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_52_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(52),
datain => \GRFPC0.MEM.RREG.RES_0_0_52__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21426_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_51_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(51),
datain => \GRFPC0.MEM.RREG.RES_0_0_51__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21432_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_50_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(50),
datain => \GRFPC0.MEM.RREG.RES_0_0_50__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21436_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_49_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(49),
datain => \GRFPC0.MEM.RREG.RES_0_0_49__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21429_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_48_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(48),
datain => \GRFPC0.MEM.RREG.RES_0_0_48__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21444_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_47_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(47),
datain => \GRFPC0.MEM.RREG.RES_0_0_47__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_63_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_46_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(46),
datain => \GRFPC0.MEM.RREG.RES_0_0_46__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21428_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_45_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(45),
datain => \GRFPC0.MEM.RREG.RES_0_0_45__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_20333_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_44_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(44),
datain => \GRFPC0.MEM.RREG.RES_0_0_44__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21431_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_43_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(43),
datain => \GRFPC0.MEM.RREG.RES_0_0_43__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21427_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_42_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(42),
datain => \GRFPC0.MEM.RREG.RES_0_0_42__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(42),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_41_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(41),
datain => \GRFPC0.MEM.RREG.RES_0_0_41__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21430_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_40_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(40),
datain => \GRFPC0.MEM.RREG.RES_0_0_40__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21441_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_39_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(39),
datain => \GRFPC0.MEM.RREG.RES_0_0_39__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(39),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_38_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(38),
datain => \GRFPC0.MEM.RREG.RES_0_0_38__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21435_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_37_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(37),
datain => \GRFPC0.MEM.RREG.RES_0_0_37__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21440_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_36_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(36),
datain => \GRFPC0.MEM.RREG.RES_0_0_36__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21443_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_35_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(35),
datain => \GRFPC0.MEM.RREG.RES_0_0_35__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19990_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_34_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(34),
datain => \GRFPC0.MEM.RREG.RES_0_0_34__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21439_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_33_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(33),
datain => \GRFPC0.MEM.RREG.RES_0_0_33__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_21442_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_32_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(32),
datain => \GRFPC0.MEM.RREG.RES_0_0_32__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(32),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(31),
datain => \GRFPC0.MEM.RREG.RES_0_0_31__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(31),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(30),
datain => \GRFPC0.MEM.RREG.RES_0_0_30__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(30),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(29),
datain => \GRFPC0.MEM.RREG.RES_0_0_29__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(29),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(28),
datain => \GRFPC0.MEM.RREG.RES_0_0_28__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(28),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(27),
datain => \GRFPC0.MEM.RREG.RES_0_0_27__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(27),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(26),
datain => \GRFPC0.MEM.RREG.RES_0_0_26__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(26),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(25),
datain => \GRFPC0.MEM.RREG.RES_0_0_25__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(25),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(24),
datain => \GRFPC0.MEM.RREG.RES_0_0_24__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(24),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(23),
datain => \GRFPC0.MEM.RREG.RES_0_0_23__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(23),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(22),
datain => \GRFPC0.MEM.RREG.RES_0_0_22__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(22),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(21),
datain => \GRFPC0.MEM.RREG.RES_0_0_21__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(21),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(20),
datain => \GRFPC0.MEM.RREG.RES_0_0_20__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(20),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(19),
datain => \GRFPC0.MEM.RREG.RES_0_0_19__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(19),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(18),
datain => \GRFPC0.MEM.RREG.RES_0_0_18__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(18),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(17),
datain => \GRFPC0.MEM.RREG.RES_0_0_17__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(17),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(16),
datain => \GRFPC0.MEM.RREG.RES_0_0_16__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(16),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(15),
datain => \GRFPC0.MEM.RREG.RES_0_0_15__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(15),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(14),
datain => \GRFPC0.MEM.RREG.RES_0_0_14__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(14),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(13),
datain => \GRFPC0.MEM.RREG.RES_0_0_13__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(13),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(12),
datain => \GRFPC0.MEM.RREG.RES_0_0_12__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(12),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(11),
datain => \GRFPC0.MEM.RREG.RES_0_0_11__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(11),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(10),
datain => \GRFPC0.MEM.RREG.RES_0_0_10__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(10),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(9),
datain => \GRFPC0.MEM.RREG.RES_0_0_9__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(9),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(8),
datain => \GRFPC0.MEM.RREG.RES_0_0_8__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(8),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(7),
datain => \GRFPC0.MEM.RREG.RES_0_0_7__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(7),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(6),
datain => \GRFPC0.MEM.RREG.RES_0_0_6__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(6),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(5),
datain => \GRFPC0.MEM.RREG.RES_0_0_5__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(5),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(4),
datain => \GRFPC0.MEM.RREG.RES_0_0_4__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(4),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(3),
datain => \GRFPC0.MEM.RREG.RES_0_0_3__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(3),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(2),
datain => \GRFPC0.MEM.RREG.RES_0_0_2__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(2),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(1),
datain => \GRFPC0.MEM.RREG.RES_0_0_1__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(1),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RES\(0),
datain => \GRFPC0.MEM.RREG.RES_0_0_0__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.RES\(0),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_EXCT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(5),
datain => N_29916,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_EXCT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(4),
datain => N_29915,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_EXCT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(3),
datain => N_29914,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_EXCT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(2),
datain => N_29913,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_EXCT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(1),
datain => N_29912,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_EXCT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.EXCT\(0),
datain => N_29911,
clk => N_62,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_RREG_EXCT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(5),
datain => \GRFPC0.WR.RREG.EXCT_0_0_5__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPC0.FPO_I_4_I_0\(69),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_EXCT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(4),
datain => \GRFPC0.WR.RREG.EXCT_0_0_4__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19274_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_EXCT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(3),
datain => \GRFPC0.WR.RREG.EXCT_0_0_3__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_EXCT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(2),
datain => \GRFPC0.WR.RREG.EXCT_0_0_2__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.EXC\(2),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_EXCT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(1),
datain => \GRFPC0.WR.RREG.EXCT_0_0_1__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_8_I_0\,
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR_RREG_EXCT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.EXCT\(0),
datain => \GRFPC0.WR.RREG.EXCT_0_0_0__G2\,
clk => N_62,
sload => \GRFPC0.VWR.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.EXC\(0),
ena => N_174806,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(5),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_5__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPC0.FPO_I_4_I_0\(69),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(4),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_4__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_19274_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(3),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_3__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(2),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_2__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.EXC\(2),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(1),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_1__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \GRFPU0.GRFPU_X0.N_8_I_0\,
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_EXCT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.EXCT\(0),
datain => \GRFPC0.MEM.RREG.EXCT_0_0_0__G2\,
clk => N_62,
sload => \GRFPC0.VMEM.RREG.RESV_1_SQMUXA\,
adatasdata => \FPO.EXC\(0),
ena => N_174807,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
RST_I <= not N_61;
\GRFPC0_R_STATE_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE\(1),
datain => \GRFPC0.R.STATE_0_0_1__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE\(0),
datain => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_FPR_RDY: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.RDY\,
datain => \GRFPU0.GRFPU_X0.N_19283_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_DIV_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RDD\,
datain => \GRFPC0.WR2.CTRL.RDD_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA2_FLUSH: stratixii_lcell_ff port map (
regout => \FPI.FLUSH\,
datain => \GRFPC0.N_16912_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_DIVLCK: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.DIVLCK\,
datain => \GRFPC0.FP_PIPELINE.DEPMUX.RES\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS2DEP: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2DEP\,
datain => \GRFPC0.N_10165\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_RFA2_RS1DEP: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1DEP\,
datain => \GRFPC0.N_10167\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_DIV_VALID: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.VALID\,
datain => \GRFPC0.N_10175\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR2_RREG_RESV: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RESV\,
datain => \GRFPC0.N_10177\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_RREG_RESV: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.RREG.RESV\,
datain => \GRFPC0.N_10179\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_MEM_RREG_RESV: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.RREG.RESV\,
datain => \GRFPC0.N_10181\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_DIV_EXEC: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXEC\,
datain => \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_EX_RREG_RESV: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RESV\,
datain => \GRFPC0.N_10185\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FOP_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.FOP\(0),
datain => \GRFPC0.N_10172\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FOP_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.FOP\(1),
datain => \GRFPC0.N_10173\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL\(7),
datain => \GRFPC0.N_10169\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL\(3),
datain => \GRFPC0.FPUSEL_6\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL\(2),
datain => \GRFPC0.FPUSEL_6\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL\(1),
datain => \GRFPC0.FPUSEL_6\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL\(4),
datain => \GRFPC0.FPUSEL_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL\(3),
datain => \GRFPC0.FPUSEL_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL\(1),
datain => \GRFPC0.FPUSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ALLOW_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ALLOW\(0),
datain => \GRFPC0.FPRIN.ALLOW\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ALLOW_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ALLOW\(1),
datain => \FPO.ALLOW\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ALLOW_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ALLOW\(2),
datain => \GRFPU0.GRFPU_X0.N_5184\,
clk => N_62,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA_RS1_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1\(0),
datain => \GRFPC0.N_18115\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1\(1),
datain => \GRFPC0.N_18116\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1\(2),
datain => \GRFPC0.N_23609\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS1_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1\(3),
datain => \GRFPC0.N_23608\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS1_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1\(4),
datain => \GRFPC0.N_18119\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA2_FID_3_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(3),
datain => \GRFPC0.FID_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FID_4_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(4),
datain => \GRFPC0.FID_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_FID_5_\: stratixii_lcell_ff port map (
regout => \FPI.FLUSHID\(5),
datain => \GRFPC0.FID_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA_RS2_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2\(0),
datain => N_52884,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS2_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2\(1),
datain => N_52885,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS2_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2\(2),
datain => N_52886,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS2_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2\(3),
datain => N_52887,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RS2_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2\(4),
datain => N_52888,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD\(0),
datain => \GRFPC0.WR2.CTRL.RD\(0),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD\(1),
datain => \GRFPC0.WR2.CTRL.RD\(1),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD\(2),
datain => \GRFPC0.WR2.CTRL.RD\(2),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD\(3),
datain => \GRFPC0.WR2.CTRL.RD\(3),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD\(4),
datain => \GRFPC0.WR2.CTRL.RD\(4),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FPR_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(0),
datain => \FPO.IDOUT\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(1),
datain => \FPO.IDOUT\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(2),
datain => \FPO.IDOUT\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(3),
datain => \FPO.IDOUT\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(4),
datain => \FPO.IDOUT\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FPR_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FPR.ID\(5),
datain => \FPO.IDOUT\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_ADD: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ADD\,
datain => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST4_ADDOF: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datain => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST4_MOF: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MOF\,
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_INF: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.INF\,
datain => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_EMIN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EMIN\,
datain => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_EMAX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datain => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_EMINM1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EMINM1\,
datain => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_DIFFV: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datain => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_DEFERNX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_3207\,
datain => \GRFPU0.GRFPU_X0.N_3206\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_DEFERNX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.N_3206\,
datain => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST4_DEFERNX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datain => \GRFPU0.GRFPU_X0.N_3207\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_QSNAN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
datain => \GRFPU0.GRFPU_X0.N_21692\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_INF: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.INF\,
datain => \GRFPU0.GRFPU_X0.N_11211\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_RDY: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.RDY\,
datain => \GRFPU0.GRFPU_X0.N_11213\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_ZERO: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ZERO\,
datain => \GRFPU0.GRFPU_X0.N_11215\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_ZERO: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ZERO\,
datain => \GRFPU0.GRFPU_X0.N_11217\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_RDY: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.RDY\,
datain => \GRFPU0.GRFPU_X0.N_11219\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_QSNAN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.QSNAN\,
datain => \GRFPU0.GRFPU_X0.N_11221\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_STICKY: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.STICKY\,
datain => \GRFPU0.GRFPU_X0.N_11223\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST4_RDY: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.RDY\,
datain => \GRFPU0.GRFPU_X0.N_11225\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_V: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.V\,
datain => \GRFPU0.GRFPU_X0.N_11230\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_EMINM1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
datain => \GRFPU0.GRFPU_X0.N_11261\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_DIFFV: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
datain => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST2_DIFFN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFFN\,
datain => \GRFPU0.GRFPU_X0.N_11265\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_DEFERNX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
datain => \GRFPU0.GRFPU_X0.N_68_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_OP2NX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datain => \GRFPU0.GRFPU_X0.N_11295\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_OP1NX: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
datain => \GRFPU0.GRFPU_X0.N_11297\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_V: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.V\,
datain => \GRFPU0.GRFPU_X0.N_11356\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0.GRFPU_X0.N_80_I\ <= not \GRFPU0.GRFPU_X0.N_80_0\;
GRFPU0_GRFPU_X0_ST1_SIGN2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datain => \FPI.OP2\(63),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_SIGN1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datain => \FPI.OP1\(63),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST3_V: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.V\,
datain => \GRFPU0.GRFPU_X0.N_19427_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST4_IOF: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.IOF\,
datain => \GRFPU0.GRFPU_X0.N_11367\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
datain => \FPI.RNDMODE\(0),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
datain => \FPI.RNDMODE\(1),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_GUARDS_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(52),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(52),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0.GRFPU_X0.C_I\(11) <= not \GRFPU0.GRFPU_X0.C\(11);
\GRFPU0_GRFPU_X0_ST2_GUARDS_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(53),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(53),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(54),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(54),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(55),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(55),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(56),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(56),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(57),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(57),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
datain => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(58),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(58),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_SGNF2_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
datain => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
adatasdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datain => \GRFPU0.GRFPU_X0.N_11267\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datain => \GRFPU0.GRFPU_X0.N_11268\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
datain => \GRFPU0.GRFPU_X0.N_11270\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datain => \GRFPU0.GRFPU_X0.N_11273\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datain => \GRFPU0.GRFPU_X0.N_11274\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datain => \GRFPU0.GRFPU_X0.N_11276\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
datain => \GRFPU0.GRFPU_X0.N_11281\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
datain => \GRFPU0.GRFPU_X0.N_11282\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datain => \GRFPU0.GRFPU_X0.N_11290\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datain => \GRFPU0.GRFPU_X0.N_11291\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXPT_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datain => \GRFPU0.GRFPU_X0.N_11257\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXPT_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datain => \GRFPU0.GRFPU_X0.N_11258\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXPT_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXPT\(2),
datain => \GRFPU0.GRFPU_X0.N_11259\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datain => \GRFPU0.GRFPU_X0.N_11246\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datain => \GRFPU0.GRFPU_X0.N_11247\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datain => \GRFPU0.GRFPU_X0.N_11248\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datain => \GRFPU0.GRFPU_X0.N_11249\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datain => \GRFPU0.GRFPU_X0.N_11250\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_EXC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datain => \GRFPU0.GRFPU_X0.N_11251\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datain => \GRFPU0.GRFPU_X0.N_11242\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datain => \GRFPU0.GRFPU_X0.N_11243\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datain => \GRFPU0.GRFPU_X0.N_11244\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(0),
datain => \FPI.OPID\(0),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(1),
datain => \FPI.OPID\(1),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(2),
datain => \FPI.OPID\(2),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(3),
datain => \FPI.OPID\(3),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(4),
datain => \FPI.OPID\(4),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_IDCST_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.ID\(5),
datain => \FPI.OPID\(5),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXC_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXC\(4),
datain => \GRFPU0.GRFPU_X0.N_11232\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXC_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXC\(5),
datain => \GRFPU0.GRFPU_X0.N_11233\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
datain => \GRFPU0.GRFPU_X0.N_11227\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
datain => \GRFPU0.GRFPU_X0.N_11228\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(0),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(1),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(2),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(3),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(4),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_IDCST_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.ID\(5),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXC_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXC\(0),
datain => \GRFPU0.GRFPU_X0.VST2.EXC_8\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_EXC_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.EXC\(1),
datain => \GRFPU0.GRFPU_X0.N_4226\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
datain => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_FLOP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
datain => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_0_IV_I\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ND_I_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
datain => \GRFPU0.GRFPU_X0.N_19510_I_0\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(0),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(1),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(3),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(4),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_IDCST_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datain => \GRFPU0.GRFPU_X0.ST2.ID\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0),
datain => \GRFPU0.GRFPU_X0.N_19586_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19669\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1),
datain => \GRFPU0.GRFPU_X0.N_17350\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19670\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
datain => \GRFPU0.GRFPU_X0.N_17351\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17299\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
datain => \GRFPU0.GRFPU_X0.N_19587\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17300\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G5\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_4__G2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5),
datain => \GRFPU0.GRFPU_X0.N_17354\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19583\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6),
datain => \GRFPU0.GRFPU_X0.N_17355\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17303\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7),
datain => \GRFPU0.GRFPU_X0.N_17356\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17304\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8),
datain => \GRFPU0.GRFPU_X0.N_17357\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17305\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9),
datain => \GRFPU0.GRFPU_X0.N_17358\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17306\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10),
datain => \GRFPU0.GRFPU_X0.N_17359\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17307\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11),
datain => \GRFPU0.GRFPU_X0.N_17360\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17308\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12),
datain => \GRFPU0.GRFPU_X0.N_17361\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17309\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13),
datain => \GRFPU0.GRFPU_X0.N_17362\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17310\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14),
datain => \GRFPU0.GRFPU_X0.N_17363\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17311\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15),
datain => \GRFPU0.GRFPU_X0.N_17364\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17312\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16),
datain => \GRFPU0.GRFPU_X0.N_17365\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17313\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17),
datain => \GRFPU0.GRFPU_X0.N_17366\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17314\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18),
datain => \GRFPU0.GRFPU_X0.N_17367\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17315\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19),
datain => \GRFPU0.GRFPU_X0.N_17368\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17316\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20),
datain => \GRFPU0.GRFPU_X0.N_17369\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17317\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21),
datain => \GRFPU0.GRFPU_X0.N_17370\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17318\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22),
datain => \GRFPU0.GRFPU_X0.N_17371\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17319\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23),
datain => \GRFPU0.GRFPU_X0.N_17372\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17320\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24),
datain => \GRFPU0.GRFPU_X0.N_17373\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17321\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25),
datain => \GRFPU0.GRFPU_X0.N_17374\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17322\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26),
datain => \GRFPU0.GRFPU_X0.N_17375\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17323\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27),
datain => \GRFPU0.GRFPU_X0.N_17376\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17324\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
datain => \GRFPU0.GRFPU_X0.N_19676\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17325\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
datain => \GRFPU0.GRFPU_X0.N_19589\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19671\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G5\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_30__G2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G5\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST4.MSGNF_1_3_0_31__G2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
datain => \GRFPU0.GRFPU_X0.N_19592_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17329\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
datain => \GRFPU0.GRFPU_X0.N_19593_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17330\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34),
datain => \GRFPU0.GRFPU_X0.N_19594_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17331\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
datain => \GRFPU0.GRFPU_X0.N_19595_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17332\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36),
datain => \GRFPU0.GRFPU_X0.N_19596_I\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17333\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
datain => \GRFPU0.GRFPU_X0.N_19681\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17334\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38),
datain => \GRFPU0.GRFPU_X0.N_19682\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17335\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
datain => \GRFPU0.GRFPU_X0.N_19683\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17336\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
datain => \GRFPU0.GRFPU_X0.N_19684\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17337\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41),
datain => \GRFPU0.GRFPU_X0.N_19685\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17338\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42),
datain => \GRFPU0.GRFPU_X0.N_19686\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17339\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
datain => \GRFPU0.GRFPU_X0.N_19687\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17340\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44),
datain => \GRFPU0.GRFPU_X0.N_19688\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17341\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
datain => \GRFPU0.GRFPU_X0.N_19677\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17342\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46),
datain => \GRFPU0.GRFPU_X0.N_19678\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19672\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47),
datain => \GRFPU0.GRFPU_X0.N_19679\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19673\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
datain => \GRFPU0.GRFPU_X0.N_19680\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19674\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
datain => \GRFPU0.GRFPU_X0.N_19689\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_19675\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
datain => \GRFPU0.GRFPU_X0.N_17399\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17347\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MSGNF_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
datain => \GRFPU0.GRFPU_X0.N_17400\,
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
adatasdata => \GRFPU0.GRFPU_X0.N_17348\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_MEXP_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.MEXP\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(0),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(1),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(2),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(3),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(4),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(5),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(6),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(7),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(8),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(9),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(10),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(11),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(12),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(13),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(14),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(15),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(16),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(17),
datain => \GRFPU0.GRFPU_X0.VST3.REG_37\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(19),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(21),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(24),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(25),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(26),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(27),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_MUX2\(28),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datain => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_AEXP_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_0_\: stratixii_lcell_ff port map (
regout => \FPO.CC\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_0__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_1_\: stratixii_lcell_ff port map (
regout => \FPO.CC\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_1__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_2__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_3__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_4__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_6__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_7__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_8__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_9__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_10__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_11__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_12__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(13),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_13__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(14),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_14__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(15),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_15__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(16),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_16__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(17),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_17__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_18__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_19__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_20__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_21__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_22__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_23__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_24__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_25__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_26__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_27__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_28__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_29__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_30__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_31__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0_5__G0_I_0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(32),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(33),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(34),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(35),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(36),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(37),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(38),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(39),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(40),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(42),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(43),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(44),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(45),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(46),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(47),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(48),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(49),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(50),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(51),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(52),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(53),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(56),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(57),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(58),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(59),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(60),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(61),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.REG\(62),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_REG_63_\: stratixii_lcell_ff port map (
regout => \FPO.RES\(63),
datain => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(60),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(0),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(1),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(2),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(3),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(4),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(5),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(6),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(7),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(8),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(9),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(10),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(11),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(12),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(13),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(14),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(15),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(16),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(17),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(18),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(19),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(20),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(21),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(22),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(23),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(24),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(26),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(27),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(28),
datain => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SGNF_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
datain => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(0),
datain => \GRFPU0.GRFPU_X0.VST3.EXC_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
datain => \GRFPU0.GRFPU_X0.VST3.EXC_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
datain => \GRFPU0.GRFPU_X0.N_6759\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
datain => \GRFPU0.GRFPU_X0.N_7143\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datain => \GRFPU0.GRFPU_X0.VST3.EXC_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_EXC_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
datain => \GRFPU0.GRFPU_X0.VST3.EXC_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datain => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189350,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189351,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189352,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189353,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189354,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189355,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189356,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189357,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189358,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189359,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189360,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189361,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189362,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189363,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189364,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189365,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189366,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189367,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189368,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189369,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189370,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189371,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189372,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189373,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
datain => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.COMB.VST2.DIFF2\,
adatasdata => N_189375,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datain => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datain => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(29),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(30),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(31),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(32),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(33),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(34),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(35),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(36),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(37),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(38),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(39),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(40),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(41),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(42),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(43),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(44),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(45),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(46),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(47),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(48),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(49),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(51),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datain => \GRFPU0.GRFPU_X0.UN2_DIFF1\(52),
clk => N_62,
sload => N_189374,
adatasdata => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
datain => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ALLOW_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0),
datain => \GRFPC0.FPRIN.ALLOW_0_0__G5\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ALLOW_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
datain => \FPO.ALLOW_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_ALLOW_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2),
datain => \GRFPU0.GRFPU_X0.N_5184\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datain => \GRFPU0.GRFPU_X0.N_19711_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datain => \GRFPU0.GRFPU_X0.N_20280\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datain => \GRFPU0.GRFPU_X0.N_20282_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datain => \GRFPU0.GRFPU_X0.N_20285_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(51),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(50),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(49),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(48),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(47),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(46),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(43),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(42),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(41),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(40),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(39),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(38),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(37),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(36),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(35),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(34),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(33),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(32),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(31),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(30),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(29),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(28),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(27),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(26),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(25),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(24),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(23),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(22),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_34__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(21),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_35__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(20),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_36__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(19),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_37__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(18),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_38__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(17),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_39__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(16),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_40__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(15),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_41__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(14),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_42__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(13),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_43__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(12),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_44__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(11),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_45__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(10),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_46__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(9),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_47__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(8),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_48__G1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(7),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(49),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(6),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(50),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(5),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(51),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(4),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(52),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datain => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(3),
clk => N_62,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
adatasdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(53),
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datain => \GRFPU0.GRFPU_X0.N_25_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datain => \GRFPU0.GRFPU_X0.N_27_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datain => \GRFPU0.GRFPU_X0.N_29_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datain => \GRFPU0.GRFPU_X0.N_31_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datain => \GRFPU0.GRFPU_X0.N_33_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datain => \GRFPU0.GRFPU_X0.N_19185_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datain => \GRFPU0.GRFPU_X0.N_19186_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datain => \GRFPU0.GRFPU_X0.N_39_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datain => \GRFPU0.GRFPU_X0.N_41_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datain => \GRFPU0.GRFPU_X0.N_43_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datain => \GRFPU0.GRFPU_X0.N_20283_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datain => \GRFPU0.GRFPU_X0.N_20286_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF1_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datain => \GRFPU0.GRFPU_X0.N_20288_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datain => \FPI.FLOP\(0),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datain => \GRFPU0.GRFPU_X0.N_20313_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datain => \FPI.FLOP\(2),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datain => \FPI.FLOP\(3),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datain => \FPI.FLOP\(4),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datain => \FPI.FLOP\(5),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datain => \FPI.FLOP\(6),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datain => \FPI.FLOP\(7),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
datain => \FPI.FLOP\(8),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
datain => \GRFPU0.GRFPU_X0.L4_4\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
datain => \GRFPU0.GRFPU_X0.L4_4\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
datain => \GRFPU0.GRFPU_X0.L4_4\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
datain => \GRFPU0.GRFPU_X0.L4_4\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
datain => \GRFPU0.GRFPU_X0.N_17_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_LZCNT_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
datain => \GRFPU0.GRFPU_X0.N_10710\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datain => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datain => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datain => \FPI.OP2\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datain => \FPI.OP2\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datain => \FPI.OP2\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datain => \FPI.OP2\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datain => \FPI.OP2\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datain => \FPI.OP2\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datain => \FPI.OP2\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datain => \FPI.OP2\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datain => \FPI.OP2\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datain => \FPI.OP2\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datain => \FPI.OP2\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datain => \FPI.OP2\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datain => \FPI.OP2\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datain => \FPI.OP2\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datain => \FPI.OP2\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datain => \FPI.OP2\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datain => \FPI.OP2\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datain => \FPI.OP2\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datain => \FPI.OP2\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datain => \FPI.OP2\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datain => \FPI.OP2\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datain => \FPI.OP2\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datain => \FPI.OP2\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datain => \FPI.OP2\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datain => \FPI.OP2\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datain => \FPI.OP2\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datain => \FPI.OP2\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datain => \FPI.OP2\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datain => \FPI.OP2\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datain => \FPI.OP2\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datain => \FPI.OP2\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datain => \FPI.OP2\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datain => \FPI.OP2\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datain => \FPI.OP2\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datain => \FPI.OP2\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datain => \FPI.OP2\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datain => \FPI.OP2\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datain => \FPI.OP2\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datain => \FPI.OP2\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datain => \FPI.OP2\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datain => \FPI.OP2\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datain => \FPI.OP2\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datain => \FPI.OP2\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datain => \FPI.OP2\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datain => \FPI.OP2\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datain => \FPI.OP2\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datain => \FPI.OP2\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datain => \FPI.OP2\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datain => \FPI.OP2\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datain => \FPI.OP2\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datain => \FPI.OP2\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datain => \FPI.OP2\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datain => \FPI.OP2\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datain => \FPI.OP2\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datain => \FPI.OP2\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datain => \FPI.OP2\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datain => \FPI.OP2\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datain => \FPI.OP2\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datain => \FPI.OP2\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datain => \FPI.OP2\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datain => \FPI.OP2\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datain => \FPI.OP2\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datain => \FPI.OP2\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW2_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datain => \FPI.OP2\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_0_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(0),
datain => \FPI.OP1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_1_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(1),
datain => \FPI.OP1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_2_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(2),
datain => \FPI.OP1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_3_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(3),
datain => \FPI.OP1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_4_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(4),
datain => \FPI.OP1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_5_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(5),
datain => \FPI.OP1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_6_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(6),
datain => \FPI.OP1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_7_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(7),
datain => \FPI.OP1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_8_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(8),
datain => \FPI.OP1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_9_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(9),
datain => \FPI.OP1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_10_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(10),
datain => \FPI.OP1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_11_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(11),
datain => \FPI.OP1\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_12_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(12),
datain => \FPI.OP1\(12),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_13_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(13),
datain => \FPI.OP1\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_14_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(14),
datain => \FPI.OP1\(14),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_15_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(15),
datain => \FPI.OP1\(15),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_16_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(16),
datain => \FPI.OP1\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_17_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(17),
datain => \FPI.OP1\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_18_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(18),
datain => \FPI.OP1\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_19_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(19),
datain => \FPI.OP1\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_20_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(20),
datain => \FPI.OP1\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_21_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(21),
datain => \FPI.OP1\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_22_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(22),
datain => \FPI.OP1\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_23_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(23),
datain => \FPI.OP1\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_24_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(24),
datain => \FPI.OP1\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_25_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(25),
datain => \FPI.OP1\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_26_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(26),
datain => \FPI.OP1\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_27_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(27),
datain => \FPI.OP1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_28_\: stratixii_lcell_ff port map (
regout => \FPI.OP1_RETO\(28),
datain => \FPI.OP1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datain => \FPI.OP1\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datain => \FPI.OP1\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
datain => \FPI.OP1\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
datain => \FPI.OP1\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
datain => \FPI.OP1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
datain => \FPI.OP1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
datain => \FPI.OP1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datain => \FPI.OP1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
datain => \FPI.OP1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
datain => \FPI.OP1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
datain => \FPI.OP1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
datain => \FPI.OP1\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
datain => \FPI.OP1\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
datain => \FPI.OP1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
datain => \FPI.OP1\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
datain => \FPI.OP1\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
datain => \FPI.OP1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
datain => \FPI.OP1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
datain => \FPI.OP1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
datain => \FPI.OP1\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
datain => \FPI.OP1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
datain => \FPI.OP1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
datain => \FPI.OP1\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
datain => \FPI.OP1\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
datain => \FPI.OP1\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
datain => \FPI.OP1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
datain => \FPI.OP1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datain => \FPI.OP1\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datain => \FPI.OP1\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datain => \FPI.OP1\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
datain => \FPI.OP1\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datain => \FPI.OP1\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datain => \FPI.OP1\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datain => \FPI.OP1\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_RAW1_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
datain => \FPI.OP1\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FLOP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(0),
datain => \GRFPU0.DIVROMI\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(1),
datain => \GRFPU0.GRFPU_X0.N_45_I_0\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(2),
datain => \GRFPU0.GRFPU_X0.N_20281_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(3),
datain => \GRFPU0.DIVROMI\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(4),
datain => \GRFPU0.DIVROMI\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(5),
datain => \GRFPU0.GRFPU_X0.N_20284_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(6),
datain => \GRFPU0.DIVROMI\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_DIVROM0_RADDR_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.DIVROM0.RADDR\(7),
datain => \GRFPU0.DIVROMI\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datain => \GRFPU0.GRFPU_X0.N_23_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datain => \GRFPU0.GRFPU_X0.N_21_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datain => \GRFPU0.GRFPU_X0.N_19_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_SGNF2_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SGNFEQ: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datain => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_NORM: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.NORM\,
datain => N_29619,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_EMIN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EMIN\,
datain => N_29620,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SIGN: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datain => \GRFPU0.GRFPU_X0.ITER.SIGN_0_0_N_4_0_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_BMLSB_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datain => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_BMLSB_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
datain => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_1__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_2__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_3__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_4__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_5__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_6__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
datain => N_52963,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_8__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_9__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_10__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datain => N_52964,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_12__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_13__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_14_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datain => N_52965,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_15_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
datain => N_52966,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datain => N_52967,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datain => N_52968,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datain => N_52969,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_19__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_20__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_21__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datain => N_52970,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_23__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_24__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datain => N_52971,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_26__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datain => N_52972,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_28__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_29__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_30__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datain => N_52973,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_32__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datain => N_52974,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_34__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_35__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_36__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_37__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_38__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datain => N_52975,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_40__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_41__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datain => N_52976,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datain => N_52977,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datain => N_52978,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_45__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datain => N_52979,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datain => N_52980,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_48__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_49__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_50__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_51__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(52),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_52__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(53),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_53__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(54),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_54__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(55),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_55__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(56),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_56__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(57),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_57__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(58),
datain => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_58__G3\,
clk => N_62,
ena => N_174882,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
datain => N_29688,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_DBUF_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
datain => N_29689,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXPT_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(0),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(1),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(2),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(3),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(3),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(4),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(4),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datain => \GRFPU0.GRFPU_X0.ST1.ID\(5),
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_N_5\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_RS2D: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS2D\,
datain => \GRFPC0.RFA.RS2D_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_WRITE_RD: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.WRITE_RD\,
datain => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_READ_RS1: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.READ_RS1\,
datain => \GRFPC0.RFA.READ_RS1_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_RS1D: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RS1D\,
datain => \GRFPC0.RFA.RS1D_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_FIFO_FULL: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.FULL\,
datain => \GRFPC0.FIFO.FULL_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_D_FSTLCK: stratixii_lcell_ff port map (
regout => \GRFPC0.D.FSTLCK\,
datain => \GRFPC0.D.FSTLCK_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_D_FLDLCK: stratixii_lcell_ff port map (
regout => \GRFPC0.D.FLDLCK\,
datain => \GRFPC0.D.FLDLCK_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDWR: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RDWR\,
datain => N_52983,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_SEQERR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.SEQERR\,
datain => N_50070,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_AFSR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.AFSR\,
datain => N_50084,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_PEND: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.PEND\,
datain => \GRFPC0.MEM.CTRL.PEND_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_PEND: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PEND\,
datain => \GRFPC0.EX.CTRL.PEND_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_PEND: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.PEND\,
datain => \GRFPC0.WR.CTRL.PEND_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_INST_1_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(31),
datain => N_134,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(31),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(31),
datain => N_134,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(31),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(21),
datain => N_124,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(21),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(21),
datain => N_124,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(21),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_WR_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.WR\(0),
datain => \GRFPC0.FIFO.WR_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_STDFQ: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.STDFQ\,
datain => N_50098,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_RDWR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RDWR\,
datain => N_52984,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_LD: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.LD\,
datain => N_50123,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_DIV: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.DIV\,
datain => N_52985,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_CCWR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.CCWR\,
datain => N_52986,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_SEQERR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.SEQERR\,
datain => N_52987,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_RDWR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RDWR\,
datain => N_52988,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_LD: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.LD\,
datain => N_50192,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_DIV: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.DIV\,
datain => N_52989,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_CCWR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.CCWR\,
datain => N_52990,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_AFSR: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.AFSR\,
datain => N_52991,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_SEQERR: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.SEQERR\,
datain => N_52992,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_RDWR: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RDWR\,
datain => N_52993,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_LD: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.LD\,
datain => N_50271,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_DIV: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.DIV\,
datain => N_52994,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_CCWR: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.CCWR\,
datain => N_52995,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_AFSR: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.AFSR\,
datain => N_52996,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_ST: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.ST\,
datain => N_50328,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_DIV: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.DIV\,
datain => \GRFPC0.EX.CTRL.DIV_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_SEQERR: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.SEQERR\,
datain => N_50340,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_CCWR: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.CCWR\,
datain => N_50359,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_SEQERR: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.SEQERR\,
datain => N_50374,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_LD: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.LD\,
datain => N_50387,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_AFSR: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.AFSR\,
datain => N_50395,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_EXC: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.EXC\,
datain => N_29747,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR2_CTRL_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RDD\,
datain => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_STDFQ: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.STDFQ\,
datain => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_STDFQ: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.STDFQ\,
datain => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_STDFQ: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.STDFQ\,
datain => N_50405,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_PEND: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.PEND\,
datain => \GRFPC0.WR2.CTRL.PEND_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_STDFQ: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.STDFQ\,
datain => N_50421,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_RDWR: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RDWR\,
datain => N_50438,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_RDD: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RDD\,
datain => N_50456,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_LD: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.LD\,
datain => N_50471,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_AFSR: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.AFSR\,
datain => N_50487,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(7),
datain => \GRFPC0.EX.CTRL.RD_0_0_0__G0_I_M4_0_2569_I_O4_1\,
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(7),
datain => \GRFPC0.WR2.CTRL.ID\(7),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_DIV_RS1V: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RS1V\,
datain => \GRFPC0.WR2.CTRL.RS1V\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_R_FSR_NONSTD: stratixii_lcell_ff port map (
regout => \FPI.NONSTD\,
datain => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_RS1V: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RS1V\,
datain => \GRFPC0.WR.CTRL.RS1V\,
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(7),
datain => \GRFPC0.MEM.CTRL.ID\(7),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(7),
datain => \GRFPC0.WR.CTRL.ID\(7),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(7),
datain => \GRFPC0.EX.CTRL.ID\(7),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_VCNT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.VCNT\(0),
datain => \GRFPC0.MEM.CTRL.VCNT\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CNT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CNT\(0),
datain => N_411,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CNT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CNT\(1),
datain => N_412,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RD\(0),
datain => \GRFPC0.EX.CTRL.RD\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RD\(1),
datain => \GRFPC0.EX.CTRL.RD\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RD\(2),
datain => \GRFPC0.EX.CTRL.RD\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RD\(3),
datain => \GRFPC0.EX.CTRL.RD\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RD\(4),
datain => \GRFPC0.EX.CTRL.RD\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RD\(0),
datain => N_128,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RD\(1),
datain => N_129,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RD\(2),
datain => N_130,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RD\(3),
datain => N_131,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.RD\(4),
datain => N_132,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RD\(0),
datain => \GRFPC0.WR.CTRL.RD\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RD\(1),
datain => \GRFPC0.WR.CTRL.RD\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RD\(2),
datain => \GRFPC0.WR.CTRL.RD\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RD\(3),
datain => \GRFPC0.WR.CTRL.RD\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RD\(4),
datain => \GRFPC0.WR.CTRL.RD\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(0),
datain => \GRFPC0.EX.CTRL.ID\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(1),
datain => \GRFPC0.EX.CTRL.ID\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(2),
datain => \GRFPC0.EX.CTRL.ID\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(3),
datain => \GRFPC0.EX.CTRL.ID\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(4),
datain => \GRFPC0.EX.CTRL.ID\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.ID\(5),
datain => \GRFPC0.EX.CTRL.ID\(5),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(0),
datain => \GRFPC0.WR.CTRL.ID\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(1),
datain => \GRFPC0.WR.CTRL.ID\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(2),
datain => \GRFPC0.WR.CTRL.ID\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(3),
datain => \GRFPC0.WR.CTRL.ID\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(4),
datain => \GRFPC0.WR.CTRL.ID\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_CTRL_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.ID\(5),
datain => \GRFPC0.WR.CTRL.ID\(5),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RD\(0),
datain => \GRFPC0.MEM.CTRL.RD\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RD\(1),
datain => \GRFPC0.MEM.CTRL.RD\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RD\(2),
datain => \GRFPC0.MEM.CTRL.RD\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RD\(3),
datain => \GRFPC0.MEM.CTRL.RD\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.RD\(4),
datain => \GRFPC0.MEM.CTRL.RD\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(0),
datain => \GRFPC0.MEM.CTRL.ID\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(1),
datain => \GRFPC0.MEM.CTRL.ID\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(2),
datain => \GRFPC0.MEM.CTRL.ID\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(3),
datain => \GRFPC0.MEM.CTRL.ID\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(4),
datain => \GRFPC0.MEM.CTRL.ID\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR_CTRL_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR.CTRL.ID\(5),
datain => \GRFPC0.MEM.CTRL.ID\(5),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_VCNT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.VCNT\(0),
datain => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_MEM_CTRL_VCNT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.VCNT\(1),
datain => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_EXCT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(0),
datain => \FPO.EXC\(0),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_EXCT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(1),
datain => \GRFPU0.GRFPU_X0.N_8_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_EXCT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(2),
datain => N_29816,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_EXCT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_EXCT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(4),
datain => \GRFPU0.GRFPU_X0.N_19274_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_EXCT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.EXCT\(5),
datain => \GRFPC0.FPO_I_4_I_0\(69),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(0),
datain => \FPO.RES\(0),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(1),
datain => \FPO.RES\(1),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(2),
datain => \FPO.RES\(2),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(3),
datain => \FPO.RES\(3),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(4),
datain => \FPO.RES\(4),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(5),
datain => \FPO.RES\(5),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(6),
datain => \FPO.RES\(6),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(7),
datain => \FPO.RES\(7),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(8),
datain => \FPO.RES\(8),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(9),
datain => \FPO.RES\(9),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(10),
datain => \FPO.RES\(10),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(11),
datain => \FPO.RES\(11),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(12),
datain => \FPO.RES\(12),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(13),
datain => \FPO.RES\(13),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(14),
datain => \FPO.RES\(14),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(15),
datain => \FPO.RES\(15),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(16),
datain => \FPO.RES\(16),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(17),
datain => \FPO.RES\(17),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(18),
datain => \FPO.RES\(18),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(19),
datain => \FPO.RES\(19),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(20),
datain => \FPO.RES\(20),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(21),
datain => \FPO.RES\(21),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(22),
datain => \FPO.RES\(22),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(23),
datain => \FPO.RES\(23),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(24),
datain => \FPO.RES\(24),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(25),
datain => \FPO.RES\(25),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(26),
datain => \FPO.RES\(26),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(27),
datain => \FPO.RES\(27),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(28),
datain => \FPO.RES\(28),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(29),
datain => \FPO.RES\(29),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(30),
datain => \FPO.RES\(30),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(31),
datain => \FPO.RES\(31),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_32_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(32),
datain => \FPO.RES\(32),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_33_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(33),
datain => \GRFPU0.GRFPU_X0.N_21442_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_34_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(34),
datain => \GRFPU0.GRFPU_X0.N_21439_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_35_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(35),
datain => \GRFPU0.GRFPU_X0.N_19990_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_36_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(36),
datain => \GRFPU0.GRFPU_X0.N_21443_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_37_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(37),
datain => \GRFPU0.GRFPU_X0.N_21440_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_38_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(38),
datain => \GRFPU0.GRFPU_X0.N_21435_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_39_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(39),
datain => \FPO.RES\(39),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_40_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(40),
datain => \GRFPU0.GRFPU_X0.N_21441_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_41_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(41),
datain => \GRFPU0.GRFPU_X0.N_21430_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_42_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(42),
datain => \FPO.RES\(42),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_43_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(43),
datain => \GRFPU0.GRFPU_X0.N_21427_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_44_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(44),
datain => \GRFPU0.GRFPU_X0.N_21431_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_45_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(45),
datain => \GRFPU0.GRFPU_X0.N_20333_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_46_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(46),
datain => \GRFPU0.GRFPU_X0.N_21428_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_47_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(47),
datain => \GRFPU0.GRFPU_X0.N_63_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_48_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(48),
datain => \GRFPU0.GRFPU_X0.N_21444_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_49_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(49),
datain => \GRFPU0.GRFPU_X0.N_21429_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_50_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(50),
datain => \GRFPU0.GRFPU_X0.N_21436_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_51_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(51),
datain => \GRFPU0.GRFPU_X0.N_21432_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_52_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(52),
datain => \GRFPU0.GRFPU_X0.N_21426_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_53_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(53),
datain => \GRFPU0.GRFPU_X0.N_21437_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_54_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(54),
datain => \GRFPU0.GRFPU_X0.N_67_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_55_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(55),
datain => \GRFPU0.GRFPU_X0.N_21423_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_56_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(56),
datain => \GRFPU0.GRFPU_X0.N_21438_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_57_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(57),
datain => \GRFPU0.GRFPU_X0.N_21433_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_58_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(58),
datain => \GRFPU0.GRFPU_X0.N_21424_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_59_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(59),
datain => \GRFPU0.GRFPU_X0.N_19903_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_60_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(60),
datain => \GRFPU0.GRFPU_X0.N_21434_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_61_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(61),
datain => \GRFPU0.GRFPU_X0.N_21425_I_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_62_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(62),
datain => \FPO.RES\(62),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RESULT_63_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RESULT\(63),
datain => \FPO.RES\(63),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_VCNT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.VCNT\(0),
datain => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_VCNT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.VCNT\(1),
datain => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_RD_0_\: stratixii_lcell_ff port map (
regout => \FPI.RNDMODE\(0),
datain => \GRFPC0.R.FSR.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_RD_1_\: stratixii_lcell_ff port map (
regout => \FPI.RNDMODE\(1),
datain => \GRFPC0.R.FSR.RD_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_TEM_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.TEM\(0),
datain => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_TEM_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.TEM\(1),
datain => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_TEM_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.TEM\(2),
datain => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_TEM_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.TEM\(3),
datain => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_TEM_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.TEM\(4),
datain => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_RREG_RES_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(0),
datain => \FPI.OP1\(0),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(0),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
HOLDN_I <= not N_63;
\GRFPC0_EX_RREG_RES_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(1),
datain => \FPI.OP1\(1),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(1),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(2),
datain => \FPI.OP1\(2),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(2),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(3),
datain => \FPI.OP1\(3),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(3),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(4),
datain => \FPI.OP1\(4),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(4),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(5),
datain => \FPI.OP1\(5),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(5),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(6),
datain => \FPI.OP1\(6),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(6),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(7),
datain => \FPI.OP1\(7),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(7),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(8),
datain => \FPI.OP1\(8),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(8),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(9),
datain => \FPI.OP1\(9),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(9),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(10),
datain => \FPI.OP1\(10),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(10),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(11),
datain => \FPI.OP1\(11),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(11),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(12),
datain => \FPI.OP1\(12),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(12),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(13),
datain => \FPI.OP1\(13),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(13),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(14),
datain => \FPI.OP1\(14),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(14),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(15),
datain => \FPI.OP1\(15),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(15),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(16),
datain => \FPI.OP1\(16),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(16),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(17),
datain => \FPI.OP1\(17),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(17),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(18),
datain => \FPI.OP1\(18),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(18),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(19),
datain => \FPI.OP1\(19),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(19),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(20),
datain => \FPI.OP1\(20),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(20),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(21),
datain => \FPI.OP1\(21),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(21),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(22),
datain => \FPI.OP1\(22),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(22),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(23),
datain => \FPI.OP1\(23),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(23),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(24),
datain => \FPI.OP1\(24),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(24),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(25),
datain => \FPI.OP1\(25),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(25),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(26),
datain => \FPI.OP1\(26),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(26),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(27),
datain => \FPI.OP1\(27),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(27),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(28),
datain => \FPI.OP1\(28),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(28),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(29),
datain => \FPI.OP1\(29),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(29),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(30),
datain => \FPI.OP1\(30),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(30),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(31),
datain => \FPI.OP1\(31),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(31),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_32_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(32),
datain => \FPI.OP1\(32),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(32),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_33_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(33),
datain => \FPI.OP1\(33),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21442_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_34_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(34),
datain => \FPI.OP1\(34),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21439_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_35_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(35),
datain => \FPI.OP1\(35),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_19990_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_36_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(36),
datain => \FPI.OP1\(36),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21443_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_37_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(37),
datain => \FPI.OP1\(37),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21440_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_38_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(38),
datain => \FPI.OP1\(38),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21435_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_39_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(39),
datain => \FPI.OP1\(39),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(39),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_40_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(40),
datain => \FPI.OP1\(40),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21441_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_41_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(41),
datain => \FPI.OP1\(41),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21430_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_42_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(42),
datain => \FPI.OP1\(42),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(42),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_43_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(43),
datain => \FPI.OP1\(43),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21427_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_44_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(44),
datain => \FPI.OP1\(44),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21431_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_45_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(45),
datain => \FPI.OP1\(45),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_20333_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_46_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(46),
datain => \FPI.OP1\(46),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21428_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_47_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(47),
datain => \FPI.OP1\(47),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_63_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_48_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(48),
datain => \FPI.OP1\(48),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21444_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_49_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(49),
datain => \FPI.OP1\(49),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21429_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_50_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(50),
datain => \FPI.OP1\(50),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21436_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_51_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(51),
datain => \FPI.OP1\(51),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21432_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_52_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(52),
datain => \FPI.OP1\(52),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21426_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_53_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(53),
datain => \FPI.OP1\(53),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21437_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_54_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(54),
datain => \FPI.OP1\(54),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_67_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_55_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(55),
datain => \FPI.OP1\(55),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21423_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_56_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(56),
datain => \FPI.OP1\(56),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21438_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_57_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(57),
datain => \FPI.OP1\(57),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21433_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_58_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(58),
datain => \FPI.OP1\(58),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21424_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_59_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(59),
datain => \FPI.OP1\(59),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_19903_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_60_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(60),
datain => \FPI.OP1\(60),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21434_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_61_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(61),
datain => \FPI.OP1\(61),
clk => N_62,
sload => HOLDN_I,
adatasdata => \GRFPU0.GRFPU_X0.N_21425_I_0\,
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_62_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(62),
datain => \FPI.OP1\(62),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(62),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_63_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.RREG.RES\(63),
datain => \FPI.OP1\(63),
clk => N_62,
sload => HOLDN_I,
adatasdata => \FPO.RES\(63),
ena => \GRFPC0.VEX.RREG.RES_0_SQMUXA\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(0),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STDATA_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(1),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STDATA_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(2),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(2),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(2),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(3),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(3),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(3),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(4),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(4),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(4),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(5),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(5),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(5),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(6),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(6),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(7),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(7),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(7),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(8),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(8),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(8),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(9),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(9),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(9),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(10),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(10),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(11),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(11),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(11),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(12),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(12),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(12),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(13),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(13),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(13),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(14),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(14),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(14),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(15),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(15),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(15),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(16),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(16),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(16),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(17),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(17),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(17),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(18),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(18),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(18),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(19),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(19),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(20),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(20),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(20),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(21),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(21),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(21),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(22),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(22),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(22),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(23),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(23),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(23),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(24),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(24),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(25),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(25),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(26),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(26),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(27),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(27),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(28),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(28),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(29),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(29),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(30),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(30),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(30),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_STDATA_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STDATA\(31),
datain => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
clk => N_62,
sload => \GRFPC0.V.STDATA_0_SQMUXA_1\,
adatasdata => \GRFPC0.DIV.PC\(31),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_DIV_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(0),
datain => \GRFPC0.WR2.CTRL.ID\(0),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(1),
datain => \GRFPC0.WR2.CTRL.ID\(1),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(2),
datain => \GRFPC0.WR2.CTRL.ID\(2),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(3),
datain => \GRFPC0.WR2.CTRL.ID\(3),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(4),
datain => \GRFPC0.WR2.CTRL.ID\(4),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.ID\(5),
datain => \GRFPC0.WR2.CTRL.ID\(5),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_WR2_RREG_RES_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(0),
datain => \GRFPC0.N_18817\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18752\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(1),
datain => \GRFPC0.N_18818\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18753\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(2),
datain => \GRFPC0.N_18819\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18754\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(3),
datain => \GRFPC0.N_18820\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18755\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(4),
datain => \GRFPC0.N_18821\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18756\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(5),
datain => \GRFPC0.N_18822\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18757\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(6),
datain => \GRFPC0.N_18823\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18758\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(7),
datain => \GRFPC0.N_18824\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18759\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(8),
datain => \GRFPC0.N_18825\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18760\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(9),
datain => \GRFPC0.N_18826\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18761\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(10),
datain => \GRFPC0.N_18827\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18762\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(11),
datain => \GRFPC0.N_18828\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18763\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(12),
datain => \GRFPC0.N_18829\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18764\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(13),
datain => \GRFPC0.N_18830\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18765\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(14),
datain => \GRFPC0.N_18831\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18766\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(15),
datain => \GRFPC0.N_18832\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18767\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(16),
datain => \GRFPC0.N_18833\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18768\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(17),
datain => \GRFPC0.N_18834\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18769\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(18),
datain => \GRFPC0.N_18835\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18770\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(19),
datain => \GRFPC0.N_18836\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18771\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(20),
datain => \GRFPC0.N_18837\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18772\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(21),
datain => \GRFPC0.N_18838\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18773\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(22),
datain => \GRFPC0.N_18839\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_23999\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(23),
datain => \GRFPC0.N_18840\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18775\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(24),
datain => \GRFPC0.N_18841\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18776\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(25),
datain => \GRFPC0.N_18842\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18777\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(26),
datain => \GRFPC0.N_18843\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18778\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(27),
datain => \GRFPC0.N_18844\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18779\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(28),
datain => \GRFPC0.N_18845\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18780\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(29),
datain => \GRFPC0.N_18846\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18781\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(30),
datain => \GRFPC0.N_23937\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_23956\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(31),
datain => \GRFPC0.N_18848\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18783\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_32_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(32),
datain => \GRFPC0.N_18849\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18784\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_33_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(33),
datain => \GRFPC0.N_18850\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18785\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_34_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(34),
datain => \GRFPC0.N_18851\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18786\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_35_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(35),
datain => \GRFPC0.N_18852\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18787\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_36_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(36),
datain => \GRFPC0.N_18853\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18788\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_37_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(37),
datain => \GRFPC0.N_18854\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18789\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_38_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(38),
datain => \GRFPC0.N_18855\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18790\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_39_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(39),
datain => \GRFPC0.N_18856\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18791\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_40_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(40),
datain => \GRFPC0.N_18857\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18792\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_41_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(41),
datain => \GRFPC0.N_18858\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18793\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_42_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(42),
datain => \GRFPC0.N_18859\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18794\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_43_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(43),
datain => \GRFPC0.N_18860\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18795\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_44_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(44),
datain => \GRFPC0.N_18861\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18796\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_45_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(45),
datain => \GRFPC0.N_18862\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18797\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_46_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(46),
datain => \GRFPC0.N_18863\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18798\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_47_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(47),
datain => \GRFPC0.N_18864\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18799\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_48_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(48),
datain => \GRFPC0.N_18865\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18800\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_49_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(49),
datain => \GRFPC0.N_18866\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18801\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_50_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(50),
datain => \GRFPC0.N_18867\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18802\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_51_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(51),
datain => \GRFPC0.N_18868\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18803\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_52_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(52),
datain => \GRFPC0.N_18869\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18804\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_53_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(53),
datain => \GRFPC0.N_18870\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18805\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_54_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(54),
datain => \GRFPC0.N_24001\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_24000\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_55_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(55),
datain => \GRFPC0.N_18872\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18807\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_56_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(56),
datain => \GRFPC0.N_18873\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18808\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_57_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(57),
datain => \GRFPC0.N_18874\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18809\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_58_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(58),
datain => \GRFPC0.N_18875\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18810\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_59_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(59),
datain => \GRFPC0.N_18876\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18811\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_60_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(60),
datain => \GRFPC0.N_18877\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18812\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_61_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(61),
datain => \GRFPC0.N_18878\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18813\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_62_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(62),
datain => \GRFPC0.N_23938\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_23957\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_63_\: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RES\(63),
datain => \GRFPC0.N_18880\,
clk => N_62,
sload => \GRFPC0.FP_PIPELINE.UN1_HOLDN\,
adatasdata => \GRFPC0.N_18815\,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND);
\GRFPC0_R_FSR_FCC_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.FCC\(0),
datain => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_FCC_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.FCC\(1),
datain => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_RD_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RD\(0),
datain => N_50528,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_RD_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RD\(1),
datain => N_50554,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_RD_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RD\(2),
datain => N_50580,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_RD_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RD\(3),
datain => N_50606,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_RD_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.RD\(4),
datain => N_50632,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_FTT_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.FTT\(0),
datain => \GRFPC0.R.FSR.FTT_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_FTT_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.FTT\(1),
datain => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_FTT_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.FTT\(2),
datain => N_30470,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_R_FSR_AEXC_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.AEXC\(0),
datain => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(0),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_AEXC_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.AEXC\(1),
datain => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(1),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_AEXC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.AEXC\(2),
datain => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(2),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_AEXC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.AEXC\(3),
datain => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(3),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_AEXC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.AEXC\(4),
datain => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_1\(4),
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_CEXC_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.CEXC\(0),
datain => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_CEXC_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.CEXC\(1),
datain => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_CEXC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.CEXC\(2),
datain => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_CEXC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.CEXC\(3),
datain => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_FSR_CEXC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.FSR.CEXC\(4),
datain => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_INST_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(0),
datain => N_103,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(0),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(1),
datain => N_104,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(1),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(2),
datain => N_105,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(2),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(3),
datain => N_106,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(3),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(4),
datain => N_107,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(4),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(5),
datain => N_108,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(5),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(6),
datain => N_109,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(7),
datain => N_110,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(7),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(8),
datain => N_111,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(8),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(9),
datain => N_112,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(9),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(10),
datain => N_113,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(10),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(11),
datain => N_114,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(11),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(12),
datain => N_115,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(12),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(13),
datain => N_116,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(13),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(14),
datain => N_117,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(14),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(15),
datain => N_118,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(15),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(16),
datain => N_119,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(16),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(17),
datain => N_120,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(17),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(18),
datain => N_121,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(18),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(19),
datain => N_122,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(0),
datain => N_103,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(0),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(1),
datain => N_104,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(1),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(2),
datain => N_105,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(2),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(3),
datain => N_106,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(3),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(4),
datain => N_107,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(4),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(5),
datain => N_108,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(5),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(6),
datain => N_109,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1_0\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(7),
datain => N_110,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(7),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(8),
datain => N_111,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(8),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(9),
datain => N_112,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(9),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(10),
datain => N_113,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(10),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(11),
datain => N_114,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(11),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(12),
datain => N_115,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(12),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(13),
datain => N_116,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(13),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(14),
datain => N_117,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(14),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(15),
datain => N_118,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(15),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(16),
datain => N_119,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(16),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(17),
datain => N_120,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(17),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(18),
datain => N_121,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(18),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(19),
datain => N_122,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1_0\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(23),
datain => N_126,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(23),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(24),
datain => N_127,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(24),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(25),
datain => N_128,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(26),
datain => N_129,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(27),
datain => N_130,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(28),
datain => N_131,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_0_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0\(29),
datain => N_132,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0_0\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(23),
datain => N_126,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(23),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(24),
datain => N_127,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(24),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(25),
datain => N_128,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1_0\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(26),
datain => N_129,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(27),
datain => N_130,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1_0\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(28),
datain => N_131,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_1_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1\(29),
datain => N_132,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1_0\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_EX_CTRL_INST_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(1),
datain => N_52999,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(2),
datain => N_53000,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(3),
datain => N_53001,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(4),
datain => N_53002,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(5),
datain => N_53003,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(6),
datain => N_53004,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(7),
datain => N_53005,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(8),
datain => N_53006,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(9),
datain => N_53007,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(10),
datain => N_53008,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(11),
datain => N_53009,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(12),
datain => N_53010,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(13),
datain => N_53011,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(19),
datain => N_53017,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(20),
datain => N_53018,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(21),
datain => N_53019,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(22),
datain => N_53020,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(23),
datain => N_53021,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(24),
datain => N_53022,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(30),
datain => N_53028,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_INST_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.INST\(31),
datain => N_53029,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(2),
datain => N_53030,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(3),
datain => N_53031,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(4),
datain => N_53032,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(5),
datain => N_53033,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(6),
datain => N_53034,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(7),
datain => N_53035,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(8),
datain => N_53036,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(9),
datain => N_53037,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(10),
datain => N_53038,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(11),
datain => N_53039,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(12),
datain => N_53040,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(13),
datain => N_53041,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(14),
datain => N_53042,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(15),
datain => N_53043,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(16),
datain => N_53044,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(17),
datain => N_53045,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(18),
datain => N_53046,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(19),
datain => N_53047,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(20),
datain => N_53048,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(21),
datain => N_53049,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(22),
datain => N_53050,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(23),
datain => N_53051,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(24),
datain => N_53052,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(25),
datain => N_53053,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(26),
datain => N_53054,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(27),
datain => N_53055,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(28),
datain => N_53056,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(29),
datain => N_53057,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(30),
datain => N_53058,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_PC_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.PC\(31),
datain => N_53059,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_PC_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(2),
datain => N_73,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(2),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(3),
datain => N_74,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(3),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(4),
datain => N_75,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(4),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(5),
datain => N_76,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(5),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(6),
datain => N_77,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(7),
datain => N_78,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(7),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(8),
datain => N_79,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(8),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(9),
datain => N_80,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(9),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(10),
datain => N_81,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(10),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(11),
datain => N_82,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(11),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(12),
datain => N_83,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(12),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(13),
datain => N_84,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(13),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(14),
datain => N_85,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(14),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(15),
datain => N_86,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(15),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(16),
datain => N_87,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(16),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(17),
datain => N_88,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(17),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(18),
datain => N_89,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(18),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(19),
datain => N_90,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(20),
datain => N_91,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(20),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(21),
datain => N_92,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(21),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(22),
datain => N_93,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(22),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(23),
datain => N_94,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(23),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(24),
datain => N_95,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(24),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(25),
datain => N_96,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(26),
datain => N_97,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(27),
datain => N_98,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(28),
datain => N_99,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(29),
datain => N_100,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(30),
datain => N_101,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(30),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_0_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_0\(31),
datain => N_102,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.PC_0\(31),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(2),
datain => N_73,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(2),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(3),
datain => N_74,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(3),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(4),
datain => N_75,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(4),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(5),
datain => N_76,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(5),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(6),
datain => N_77,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(7),
datain => N_78,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(7),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(8),
datain => N_79,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(8),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(9),
datain => N_80,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(9),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(10),
datain => N_81,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(10),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(11),
datain => N_82,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(11),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(12),
datain => N_83,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(12),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(13),
datain => N_84,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(13),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(14),
datain => N_85,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(14),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(15),
datain => N_86,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(15),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(16),
datain => N_87,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(16),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(17),
datain => N_88,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(17),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(18),
datain => N_89,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(18),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(19),
datain => N_90,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(20),
datain => N_91,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(20),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(21),
datain => N_92,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(21),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(22),
datain => N_93,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(22),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(23),
datain => N_94,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(23),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(24),
datain => N_95,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(24),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(25),
datain => N_96,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(26),
datain => N_97,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(27),
datain => N_98,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(28),
datain => N_99,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(29),
datain => N_100,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(30),
datain => N_101,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(30),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_PC_1_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.PC_1\(31),
datain => N_102,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.PC_1\(31),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_VCNT_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_0\(0),
datain => N_53060,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_VCNT_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_0\(1),
datain => N_53061,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_VCNT_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_0\(2),
datain => \GRFPC0.FIFO.VCNT_0_0_0_2__G2\,
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_VCNT_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_1\(0),
datain => N_53062,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_VCNT_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_1\(1),
datain => N_53063,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_VCNT_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.VCNT_1\(2),
datain => \GRFPC0.FIFO.VCNT_1_0_0_2__G2\,
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(0),
datain => \GRFPC0.D.STDLCK_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(1),
datain => \GRFPC0.D.STDLCK_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(2),
datain => \GRFPC0.D.STDLCK_0_0_2__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(3),
datain => \GRFPC0.D.STDLCK_0_0_3__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(4),
datain => \GRFPC0.D.STDLCK_0_0_4__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(5),
datain => \GRFPC0.D.STDLCK_0_0_5__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(6),
datain => \GRFPC0.D.STDLCK_0_0_6__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(7),
datain => \GRFPC0.D.STDLCK_0_0_7__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(8),
datain => \GRFPC0.D.STDLCK_0_0_8__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(9),
datain => \GRFPC0.D.STDLCK_0_0_9__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(10),
datain => \GRFPC0.D.STDLCK_0_0_10__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(11),
datain => \GRFPC0.D.STDLCK_0_0_11__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(12),
datain => \GRFPC0.D.STDLCK_0_0_12__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(13),
datain => \GRFPC0.D.STDLCK_0_0_13__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(14),
datain => \GRFPC0.D.STDLCK_0_0_14__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STDLCK_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STDLCK\(15),
datain => \GRFPC0.D.STDLCK_0_0_15__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(0),
datain => \GRFPC0.D.LDLCK_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(1),
datain => \GRFPC0.D.LDLCK_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(2),
datain => \GRFPC0.D.LDLCK_0_0_2__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(3),
datain => \GRFPC0.D.LDLCK_0_0_3__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(4),
datain => \GRFPC0.D.LDLCK_0_0_4__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(5),
datain => \GRFPC0.D.LDLCK_0_0_5__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(6),
datain => \GRFPC0.D.LDLCK_0_0_6__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(7),
datain => \GRFPC0.D.LDLCK_0_0_7__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(8),
datain => \GRFPC0.D.LDLCK_0_0_8__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(9),
datain => \GRFPC0.D.LDLCK_0_0_9__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(10),
datain => \GRFPC0.D.LDLCK_0_0_10__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(11),
datain => \GRFPC0.D.LDLCK_0_0_11__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(12),
datain => \GRFPC0.D.LDLCK_0_0_12__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(13),
datain => \GRFPC0.D.LDLCK_0_0_13__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(14),
datain => \GRFPC0.D.LDLCK_0_0_14__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(15),
datain => \GRFPC0.D.LDLCK_0_0_15__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(16),
datain => \GRFPC0.D.LDLCK_0_0_16__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(17),
datain => \GRFPC0.D.LDLCK_0_0_17__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(18),
datain => \GRFPC0.D.LDLCK_0_0_18__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(19),
datain => \GRFPC0.D.LDLCK_0_0_19__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(20),
datain => \GRFPC0.D.LDLCK_0_0_20__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(21),
datain => \GRFPC0.D.LDLCK_0_0_21__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(22),
datain => \GRFPC0.D.LDLCK_0_0_22__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(23),
datain => \GRFPC0.D.LDLCK_0_0_23__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(24),
datain => \GRFPC0.D.LDLCK_0_0_24__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(25),
datain => \GRFPC0.D.LDLCK_0_0_25__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(26),
datain => \GRFPC0.D.LDLCK_0_0_26__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(27),
datain => \GRFPC0.D.LDLCK_0_0_27__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(28),
datain => \GRFPC0.D.LDLCK_0_0_28__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(29),
datain => \GRFPC0.D.LDLCK_0_0_29__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(30),
datain => \GRFPC0.D.LDLCK_0_0_30__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_LDLCK_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.LDLCK\(31),
datain => \GRFPC0.D.LDLCK_0_0_31__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(0),
datain => \GRFPC0.D.STLCK_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(1),
datain => \GRFPC0.D.STLCK_0_0_1__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(2),
datain => \GRFPC0.D.STLCK_0_0_2__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(3),
datain => \GRFPC0.D.STLCK_0_0_3__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(4),
datain => \GRFPC0.D.STLCK_0_0_4__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(5),
datain => \GRFPC0.D.STLCK_0_0_5__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(6),
datain => \GRFPC0.D.STLCK_0_0_6__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(7),
datain => \GRFPC0.D.STLCK_0_0_7__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_8_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(8),
datain => \GRFPC0.D.STLCK_0_0_8__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_9_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(9),
datain => \GRFPC0.D.STLCK_0_0_9__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_10_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(10),
datain => \GRFPC0.D.STLCK_0_0_10__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_11_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(11),
datain => \GRFPC0.D.STLCK_0_0_11__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_12_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(12),
datain => \GRFPC0.D.STLCK_0_0_12__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_13_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(13),
datain => \GRFPC0.D.STLCK_0_0_13__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_14_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(14),
datain => \GRFPC0.D.STLCK_0_0_14__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_15_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(15),
datain => \GRFPC0.D.STLCK_0_0_15__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_16_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(16),
datain => \GRFPC0.D.STLCK_0_0_16__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_17_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(17),
datain => \GRFPC0.D.STLCK_0_0_17__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_18_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(18),
datain => \GRFPC0.D.STLCK_0_0_18__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(19),
datain => \GRFPC0.D.STLCK_0_0_19__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_20_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(20),
datain => \GRFPC0.D.STLCK_0_0_20__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_21_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(21),
datain => \GRFPC0.D.STLCK_0_0_21__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_22_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(22),
datain => \GRFPC0.D.STLCK_0_0_22__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_23_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(23),
datain => \GRFPC0.D.STLCK_0_0_23__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_24_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(24),
datain => \GRFPC0.D.STLCK_0_0_24__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(25),
datain => \GRFPC0.D.STLCK_0_0_25__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(26),
datain => \GRFPC0.D.STLCK_0_0_26__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(27),
datain => \GRFPC0.D.STLCK_0_0_27__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(28),
datain => \GRFPC0.D.STLCK_0_0_28__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(29),
datain => \GRFPC0.D.STLCK_0_0_29__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_30_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(30),
datain => \GRFPC0.D.STLCK_0_0_30__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_D_STLCK_31_\: stratixii_lcell_ff port map (
regout => \GRFPC0.D.STLCK\(31),
datain => \GRFPC0.D.STLCK_0_0_31__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(4),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
datain => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\,
clk => N_62,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(0),
datain => \FPI.OPID\(0),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(1),
datain => \FPI.OPID\(1),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(2),
datain => \FPI.OPID\(2),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(3),
datain => \FPI.OPID\(3),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(4),
datain => \FPI.OPID\(4),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_EX_CTRL_ID_5_\: stratixii_lcell_ff port map (
regout => \GRFPC0.EX.CTRL.ID\(5),
datain => \FPI.OPID\(5),
clk => N_62,
sclr => RST_I,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP2_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(1),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(2),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(3),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(4),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(5),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datain => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(6),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_EXP1_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.EXP1_1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datain => \GRFPU0.GRFPU_X0.N_20890_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_11_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_13_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datain => \GRFPU0.GRFPU_X0.N_20889_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datain => \GRFPU0.GRFPU_X0.N_20886_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datain => \GRFPU0.GRFPU_X0.N_20888_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datain => \GRFPU0.GRFPU_X0.N_20893_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datain => \GRFPU0.GRFPU_X0.N_20887_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datain => \GRFPU0.GRFPU_X0.N_20891_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_R_I_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST2_REG_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datain => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(0),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(1),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(31),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(2),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(3),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(33),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(5),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(35),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(37),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(8),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(39),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(41),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(43),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(45),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(47),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(19),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(49),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__N_6\,
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datain => \GRFPU0.GRFPU_X0.ST3.REG_V_MUX2\(22),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.VST3.REG_1_SQMUXA_2\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_52_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(52),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_53_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(53),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datain => \GRFPU0.GRFPU_X0.VST3.REG_47\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(0),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_3_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(3),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_4_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(4),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_6_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(6),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_7_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(8),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_9_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(9),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_EXP_10_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datain => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(10),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_16_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(16),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(16),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_17_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(17),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(17),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_18_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(18),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(18),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_19_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(19),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(19),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_20_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(20),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(20),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_21_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(21),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(21),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_22_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(22),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(22),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_23_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(23),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(23),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_24_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(24),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(24),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_25_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(25),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(25),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_26_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(26),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(26),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_27_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(27),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(27),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_28_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(28),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(28),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_29_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(29),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(29),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_30_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(30),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(30),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_31_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(31),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(31),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_32_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(32),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(32),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_33_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(33),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(33),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_34_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(34),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(34),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_35_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(35),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(35),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_36_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(36),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(36),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_37_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(37),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(37),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_38_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(38),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(38),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_39_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(39),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(39),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_40_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(40),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(40),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_41_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(41),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(41),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_42_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(42),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(42),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_43_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(43),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(43),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_44_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(44),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(44),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_45_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(45),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(45),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_46_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(46),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(46),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_47_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(47),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(47),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_48_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(48),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(48),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_49_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(49),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(49),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_50_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(50),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(50),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_51_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(51),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(51),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_56_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(56),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(56),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_57_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(57),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(57),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_58_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(58),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(58),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_59_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(59),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(59),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_60_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(60),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(60),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_61_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(61),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(61),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_62_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(62),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(62),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(63),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_64_\: stratixii_lcell_ff port map (
regout => \GRFPU0.MULO.MRES\(64),
datain => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(64),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RNIFL4I3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff73000000")
port map (
combout => N_174882_0,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF_0_0_0__G1_E_1\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_15\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
dataa => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_4_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00cfffcf")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2_0\,
dataf => \GRFPU0.GRFPU_X0.N_19191\,
datae => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0_4\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.C\(10));
GRFPC0_VFIFO_INST_1_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3fffff")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_0_0\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6\,
datad => N_52826,
datac => N_50358,
datab => \GRFPC0.FIFO.WR\(0));
GRFPC0_FP_PIPELINE_VDIV_VALID2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.DIV.ID\(7));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_O2_RNO_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FPR.RDY\,
datad => N_63);
GRFPC0_FP_PIPELINE_UN1_HOLDN_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => N_63);
\GRFPU0_GRFPU_X0_COMB_VST4_MEXP_1_0_2__G0_0_M2_0\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(121),
datad => N_31011);
GRFPU0_GRFPU_X0_ST2_DIFFV_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datain => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FIFO_INST_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1_0\(29),
datain => N_132,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1_0\(27),
datain => N_130,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_25_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1_0\(25),
datain => N_128,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(25),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_2_29_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(29),
datain => N_132,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(29),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_28_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(28),
datain => N_131,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(28),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_2_27_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(27),
datain => N_130,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(27),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_26_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(26),
datain => N_129,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(26),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1_0\(19),
datain => N_122,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_1_0\(6),
datain => N_109,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
adatasdata => \GRFPC0.FIFO.INST_1\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_2_19_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(19),
datain => N_122,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(19),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
\GRFPC0_FIFO_INST_2_6_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.INST_0_0\(6),
datain => N_109,
clk => N_62,
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
adatasdata => \GRFPC0.FIFO.INST_0\(6),
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND);
GRFPC0_RFA_LD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.LD_0\,
datain => N_50471,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR2_CTRL_RDD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.RDD_0\,
datain => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_0\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_1\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_2_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_2\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_3_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_3\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_RD_4_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_4\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_RFA_ST_0: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA.ST_0\,
datain => N_50328,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_FIFO_WR_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.WR_0\(0),
datain => \GRFPC0.FIFO.WR_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FLOP_0\(1),
datain => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLOP_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLOP_0\(0),
datain => \FPI.FLOP\(0),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_0_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_1_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_1\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_2_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_2\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_3_5_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_3\(5),
datain => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(5),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_0_8_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datain => \GRFPU0.GRFPU_X0.N_20282_I\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(1),
datain => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_0\(0),
datain => \GRFPU0.GRFPU_X0.N_20280\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_1\(0),
datain => \GRFPU0.GRFPU_X0.N_20280\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_2_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_2\(0),
datain => \GRFPU0.GRFPU_X0.N_20280\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST1_CCSEL_3_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.CCSEL_3\(0),
datain => \GRFPU0.GRFPU_X0.N_20280\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_0_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datain => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_REG_1_63_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.REG_1\(63),
datain => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datain => \GRFPU0.GRFPU_X0.N_11244\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datain => \GRFPU0.GRFPU_X0.N_11244\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datain => \GRFPU0.GRFPU_X0.N_11243\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datain => \GRFPU0.GRFPU_X0.N_11243\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datain => \GRFPU0.GRFPU_X0.N_11242\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST4_SEL_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datain => \GRFPU0.GRFPU_X0.N_11242\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE_0\(0),
datain => \GRFPU0.GRFPU_X0.N_11291\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE_1\(0),
datain => \GRFPU0.GRFPU_X0.N_11291\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ST1_SIGN2_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST1.SIGN2_0\,
datain => \FPI.OP2\(63),
clk => N_62,
sclr => \GRFPU0.GRFPU_X0.N_80_I\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V_0\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V_1\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V_2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V_2\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V_3: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V_3\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_DIV_RD_0_4_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD_0\(4),
datain => \GRFPC0.WR2.CTRL.RD\(4),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_DIV_RD_0_3_\: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RD_0\(3),
datain => \GRFPC0.WR2.CTRL.RD\(3),
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA2_RS2SEL_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_0\(1),
datain => \GRFPC0.FPUSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_1\(1),
datain => \GRFPC0.FPUSEL_1\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_0\(1),
datain => \GRFPC0.FPUSEL_6\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_1\(1),
datain => \GRFPC0.FPUSEL_6\(1),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_0\(2),
datain => \GRFPC0.FPUSEL_6\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_1\(2),
datain => \GRFPC0.FPUSEL_6\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_0_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_0\(7),
datain => \GRFPC0.N_10169\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_1_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_1\(7),
datain => \GRFPC0.N_10169\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR2_RREG_RESV_0: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RESV_0\,
datain => \GRFPC0.N_10177\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR2_RREG_RESV_1: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RESV_1\,
datain => \GRFPC0.N_10177\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR2_RREG_RESV_2: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RESV_2\,
datain => \GRFPC0.N_10177\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_DIV_RDD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.RDD_0\,
datain => \GRFPC0.WR2.CTRL.RDD_0\,
clk => N_62,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_0_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_189\(0),
datain => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_1_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_190\(0),
datain => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_0_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_0\(1),
datain => \GRFPC0.R.STATE_0_0_1__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_1_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_1\(1),
datain => \GRFPC0.R.STATE_0_0_1__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_FLUSH0_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.FLUSH0_0\,
datain => N_91841,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_EMAXP1_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.EMAXP1_0\,
datain => N_91843,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_0_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_0\(2),
datain => \GRFPC0.FPUSEL_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS2SEL_1_2_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS2SEL_1\(2),
datain => \GRFPC0.FPUSEL_1\(2),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_0_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE_0\(12),
datain => \GRFPU0.GRFPU_X0.N_11279\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ITER_STATE_1_12_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.STATE_1\(12),
datain => \GRFPU0.GRFPU_X0.N_11279\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_0_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_1_54_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(54),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_0_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_0\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_1_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_1\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_2_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_2\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_3_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_3\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPU0_GRFPU_X0_ST3_FARRES_4_55_\: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ST3.FARRES_4\(55),
datain => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SQRT_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SQRT_0\,
datain => N_29618,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SQRT_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SQRT_1\,
datain => N_29618,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_SQRT_2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.SQRT_2\,
datain => N_29618,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPC0_WR_CTRL_RDD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.N_131_0\,
datain => \GRFPC0.N_131I\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_RDD_1: stratixii_lcell_ff port map (
regout => \GRFPC0.N_131_1\,
datain => \GRFPC0.N_131I\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_RDD_2: stratixii_lcell_ff port map (
regout => \GRFPC0.N_131_2\,
datain => \GRFPC0.N_131I\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_WR_CTRL_RDD_3: stratixii_lcell_ff port map (
regout => \GRFPC0.N_131_3\,
datain => \GRFPC0.N_131I\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_RDD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RDD_0\,
datain => \GRFPC0.MEM.CTRL.RDDI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_RDD_1: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RDD_1\,
datain => \GRFPC0.MEM.CTRL.RDDI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_MEM_CTRL_RDD_2: stratixii_lcell_ff port map (
regout => \GRFPC0.MEM.CTRL.RDD_2\,
datain => \GRFPC0.MEM.CTRL.RDDI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_0: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_0\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_1: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_1\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_2: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_2\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_3: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_3\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_4: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_4\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_ITER_DP_5: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.DP_5\,
datain => \GRFPU0.GRFPU_X0.ITER.DPI\,
clk => N_62,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_0: stratixii_lcell_ff port map (
regout => \GRFPC0.N_78_I_I_0\,
datain => N_52982,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_1: stratixii_lcell_ff port map (
regout => \GRFPC0.N_78_I_I_1\,
datain => N_52982,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_EX_CTRL_RDD_2: stratixii_lcell_ff port map (
regout => \GRFPC0.N_78_I_I_2\,
datain => N_52982,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_RFA2_RS1SEL_0_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_0\(7),
datain => \GRFPC0.FPUSEL_6\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_RFA2_RS1SEL_1_7_\: stratixii_lcell_ff port map (
regout => \GRFPC0.RFA2.RS1SEL_1\(7),
datain => \GRFPC0.FPUSEL_6\(7),
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FIFO_INST_1_RNIF9UB_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_50656_0,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_1\(0));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4227_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_VST2_REG107_0_RNIJ0PR: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20764_0\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4352_0\);
GRFPU0_GRFPU_X0_COMB_UN1_VST4_REG36_0_RNIKM2M: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_3_0__I4_I_2_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.REG36_0\,
datae => \GRFPU0.GRFPU_X0.N_4066_0\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_65_0\,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.MEM.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_VWR_RREG_RES10_0_O2_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_65_1\,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_2\,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_1\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.RES10_0_O2_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.MEM.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_0\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_VWR2_RREG_RES9_4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_4\,
dataf => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_2\,
datae => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_1\,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_3\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR.CTRL.ID\(7));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_A4_1_RNI24056_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcaafcaaffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(0),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2_0_1\(0),
datab => \GRFPU0.GRFPU_X0.N_19482\,
dataa => \GRFPU0.GRFPU_X0.L1_6\(0));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_RNIIUJL5_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcc0fccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_0\(1),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(1),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => N_124846,
datab => \GRFPU0.GRFPU_X0.L1_6\(1));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_RNICENJ5_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_0\(2),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
datab => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_RNICENJ5_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datad => \GRFPU0.GRFPU_X0.N_19472\,
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
datab => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L4_4_I_A2_2_RNIOEM91_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10710_0\,
dataf => \GRFPU0.GRFPU_X0.N_10716\,
datae => \GRFPU0.GRFPU_X0.N_10715\,
datad => \GRFPU0.GRFPU_X0.N_10717\,
datac => \GRFPU0.GRFPU_X0.L4_4_I_A2_2\(4));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_RNI0PDC7_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_0\(3),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
datac => \GRFPU0.GRFPU_X0.N_10715\,
datab => \GRFPU0.GRFPU_X0.N_10765\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_RNI0PDC7_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_10710\,
datae => \GRFPU0.GRFPU_X0.N_10716\,
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
datac => \GRFPU0.GRFPU_X0.N_10715\,
datab => \GRFPU0.GRFPU_X0.N_10765\);
GRFPU0_GRFPU_X0_VITER_NX_0_SQMUXA_1_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19502_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_VITER_NX_0_SQMUXA_1_0_O2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19502_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_COMB_VST4_REG36_RNIUHJD5: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19840_0\,
dataf => \GRFPU0.GRFPU_X0.N_4066_0\,
datae => \GRFPU0.GRFPU_X0.N_4063\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.N_6485\,
datab => \GRFPU0.GRFPU_X0.N_6484\);
GRFPU0_FPMUL0_R2_RET_159_RNIS2DI: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES_0\(120),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009);
GRFPU0_FPMUL0_R2_RET_159_RNIS2DI_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES_1\(120),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_1_SQMUXA_I_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03ff03ff03ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_20635_0\,
dataf => \GRFPU0.GRFPU_X0.N_4379\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_31_RNIFMJ61: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff0fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2_0\,
dataf => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datae => \GRFPU0.GRFPU_X0.ST3.REG_0\(63),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(50));
GRFPC0_DIVI_0_SQMUXA_4_M2_E_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000150000003f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(2),
datad => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_1\,
datac => \FPO.EXC\(0),
datab => \GRFPC0.R.FSR.TEM\(0),
dataa => \GRFPC0.R.FSR.TEM\(3));
\GRFPC0_FIFO_INST_0_RNIQ3RP_0_11_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP_0\(6),
dataf => \GRFPC0.FIFO.RD_4\(0),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_0\(11));
GRFPC0_FP_PIPELINE_V_STATE10_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ea00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.DIV.EXCT\(4),
dataa => \GRFPC0.DIV.EXCT\(5));
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_DIV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV_0\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\);
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_2_I_A3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_218_0\,
dataf => \FPI.FLOP\(7),
datae => \FPI.FLOP\(3),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA_2_I_A3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_218_1\,
dataf => \FPI.FLOP\(7),
datae => \FPI.FLOP\(3),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC_0\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.VALID\);
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_DIV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV_0\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_DIV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV_0\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_1_I_0\,
dataf => \GRFPC0.N_47\,
datae => \GRFPU0.GRFPU_X0.N_19283_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_2\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_0);
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
datae => \GRFPU0.GRFPU_X0.N_218_0\,
datad => N_49622_0);
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_DIV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV_0\,
dataf => \GRFPC0.WR2.RREG.RESV_0\,
datae => \GRFPC0.WR2.CTRL.DIV\);
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_80_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_1\,
datae => \GRFPU0.GRFPU_X0.N_157\,
datad => \GRFPU0.GRFPU_X0.COMB.VST1.V_5_IV_I_O3_0\,
datac => N_49622);
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_427_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_2_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_428_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_2_55_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_431_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2));
\GRFPU0_GRFPU_X0_RES_1_6_0_O7_0_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21448_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_O7_1_7_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_21448_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_28_0_A2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000ff030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_299_0\,
dataf => \GRFPU0.GRFPU_X0.N_9745\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(5));
\GRFPC0_RFA2_RS1SEL_RNIVDMT1_0_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.OP1_SN_N_6_0\,
dataf => \GRFPC0.RFA2.RS1SEL\(6),
datae => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_RFA2_RS1SEL_RNIVDMT1_2_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.OP1_SN_N_6_1\,
dataf => \GRFPC0.RFA2.RS1SEL\(6),
datae => \GRFPC0.RFA2.RS1SEL\(2));
\GRFPC0_FIFO_INST_1_RNIR9UB_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP_0\(1),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_1\(6));
\GRFPC0_FIFO_INST_1_RNIR9UB_2_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP_1\(1),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_1\(6));
GRFPC0_FP_PIPELINE_0_UN1_FPO_4_2_RNID6NC2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_1_0\,
dataf => \GRFPC0.N_70\,
datae => \GRFPU0.GRFPU_X0.N_19283_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_4\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_4_2\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_0_RNIPRFD1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7\,
datae => \GRFPC0.N_61\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_0\,
datac => \GRFPC0.N_131_0\,
datab => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES13\);
\GRFPU0_GRFPU_X0_RNDOP_29_IV_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0000f00000ff")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_29_IV_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.MULO.MRES\(67),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4961_0\,
dataf => \GRFPU0.GRFPU_X0.N_4373\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6));
\GRFPC0_RFA2_RS1SEL_RNI0M11_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP1_SN_N_9_0\,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
\GRFPC0_RFA2_RS1SEL_RNI0M11_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP1_SN_N_9_1\,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
GRFPU0_GRFPU_X0_COMB_VST1_V_5_IV_I_O2_3_RNI7MJB8: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000fc0000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_8197\,
datae => \GRFPU0.GRFPU_X0.N_80_0\,
datad => \FPI.FLOP_1\(1),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(5));
\GRFPC0_RFA2_RS2SEL_RNIHK61_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP2_SN_N_9_0\,
dataf => \GRFPC0.RFA2.RS2SEL\(1),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.RFA2.RS2SEL\(3));
\GRFPC0_RFA2_RS2SEL_RNIHK61_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.OP2_SN_N_9_1\,
dataf => \GRFPC0.RFA2.RS2SEL\(1),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => \GRFPC0.RFA2.RS2SEL\(3));
GRFPC0_RFA2_RS2DEP_RNIU0653: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffffffffff")
port map (
combout => N_49622_0,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => N_50504_4,
datad => \FPI.START_1\,
datac => N_50504_3,
datab => \GRFPC0.INST_1387_I_O3_1_1\,
dataa => \GRFPC0.RFA2.RS2DEP\);
GRFPC0_RFA2_RS2DEP_RNIU0653_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffffffffff")
port map (
combout => N_49622_1,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => N_50504_4,
datad => \FPI.START_1\,
datac => N_50504_3,
datab => \GRFPC0.INST_1387_I_O3_1_1\,
dataa => \GRFPC0.RFA2.RS2DEP\);
GRFPC0_RFA2_RS2DEP_RNIU0653_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffffffffff")
port map (
combout => N_49622_2,
dataf => \GRFPC0.FP_PIPELINE.FIFOV2\,
datae => N_50504_4,
datad => \FPI.START_1\,
datac => N_50504_3,
datab => \GRFPC0.INST_1387_I_O3_1_1\,
dataa => \GRFPC0.RFA2.RS2DEP\);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNIJBC71_1_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c3000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_COMB_SWAP_1_0_RNI5OBM1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1_1\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_0_46_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeffe0ff0eff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST1.ID3_0\,
dataf => \GRFPU0.GRFPU_X0.N_9745\,
datae => \GRFPU0.GRFPU_X0.N_8197\,
datad => \GRFPU0.GRFPU_X0.N_80_0\,
datac => \FPI.FLOP_1\(1),
datab => \FPI.FLOP\(6),
dataa => \FPI.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2_3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000008080000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_0\,
dataf => \FPI.FLOP_1_0\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(2),
datab => \FPI.FLOP\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1));
GRFPU0_GRFPU_X0_COMB_MULBP_1_0_A2_3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000008080000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1_0_A2_3_1\,
dataf => \FPI.FLOP_1_0\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(2),
datab => \FPI.FLOP\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1));
GRFPU0_GRFPU_X0_COMB_VST2_REG107_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000004000004040")
port map (
combout => \GRFPU0.GRFPU_X0.N_4352_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
GRFPU0_GRFPU_X0_VITER_STATE_13_SQMUXA_2_I_RNIRM3D2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003030ff30")
port map (
combout => \GRFPU0.GRFPU_X0.N_19292_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_19408\,
datae => \GRFPU0.GRFPU_X0.N_5299\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_0_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT_0\);
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP_I_O2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19499_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.RNDBIT_4\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_1_RNI6UCU3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030003000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19513_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4379\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
GRFPU0_GRFPU_X0_UN1_VITER_R_I_0_SQMUXA_1_RNI6UCU3_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030003000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19513_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_4379\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.R_I_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_O2_0_10_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15508_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_1_3\,
datad => \GRFPU0.GRFPU_X0.N_5193\,
datac => \GRFPU0.GRFPU_X0.N_19404_I\,
datab => \GRFPU0.GRFPU_X0.ITER.V_0\);
GRFPC0_OP1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300030003ff")
port map (
combout => \GRFPC0.OP1_4_0\,
dataf => \GRFPC0.V.STDATA_14\(14),
datae => \GRFPC0.RFA.RS1D\,
datad => \GRFPC0.RFA.ST_0\,
datac => N_192,
datab => N_197);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc00ceaae")
port map (
combout => \GRFPU0.GRFPU_X0.N_19496_0\,
dataf => \GRFPU0.GRFPU_X0.N_19517\,
datae => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datad => \GRFPU0.GRFPU_X0.N_51_I\,
datac => \GRFPU0.GRFPU_X0.N_77_I\,
datab => \GRFPU0.GRFPU_X0.G_672_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\);
\GRFPC0_R_STATE_2_RNITDM05_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE_2\(1),
datad => \GRFPC0.R.STATE_191\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIRHRV4_3_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIRHRV4_2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_2\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIRHRV4_1_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_3\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIRHRV4_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_4\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_63);
\GRFPC0_R_STATE_RNIRHRV4_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00000f0")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_5\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3\,
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.R.STATE\(0),
datac => N_63);
\GRFPC0_R_STATE_0_RNIMLSC5_0_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00f0000")
port map (
combout => \GRFPC0.DIV.PC_0_0_9__G2_0\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.R.STATE_189\(0));
\GRFPC0_R_STATE_0_RNIMLSC5_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f00f0000")
port map (
combout => \GRFPC0.DIV.PC_0_0_9__G2_1\,
dataf => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.R.STATE_0\(1),
datac => \GRFPC0.R.STATE_189\(0));
GRFPU0_GRFPU_X0_ITER_NORM_RNID3FS: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5221_0\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
GRFPU0_GRFPU_X0_ITER_NORM_RNID3FS_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5221_1\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_31009,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f330")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_0\,
dataf => \GRFPC0.R.STATE_1\(1),
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => \GRFPC0.FIFO.RD_1_0\(0));
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f330")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP_1\,
dataf => \GRFPC0.R.STATE_1\(1),
datae => \GRFPC0.R.STATE_190\(0),
datad => \GRFPC0.FIFO.FULL\,
datac => \GRFPC0.FIFO.WR_0\(0),
datab => \GRFPC0.FIFO.RD_1_0\(0));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNITR9G1_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNITR9G1_0_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNITR9G1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G3_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA_RNICIJJ1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19293_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4378\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
GRFPU0_GRFPU_X0_UN1_VITER_ND_I_0_SQMUXA_RNICIJJ1_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc0000cccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19293_I_1\,
dataf => \GRFPU0.GRFPU_X0.N_4227_0\,
datae => \GRFPU0.GRFPU_X0.N_4378\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2_0\(8),
datab => \GRFPU0.GRFPU_X0.ITER.V_0_0\);
GRFPC0_OP2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f000000ff")
port map (
combout => \GRFPC0.OP2_4_0\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.RFA.RS2D\,
datac => \GRFPC0.FIFO.INST_1\(0));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3e20c1d0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19600_I_I_0\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\,
datae => N_124901,
datad => \GRFPU0.GRFPU_X0.N_8376\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3e20c1d0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19600_I_I_1\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\,
datae => N_124901,
datad => \GRFPU0.GRFPU_X0.N_8376\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2_2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3e20c1d0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19600_I_I_2\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11\,
datae => N_124901,
datad => \GRFPU0.GRFPU_X0.N_8376\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI3QH51_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000f1f0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => N_184293,
datad => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.WR2.RREG.RESV_1_0\,
datab => \GRFPC0.R.STATE_2\(1),
dataa => \GRFPC0.R.STATE_191\(0));
GRFPC0_WR2_CTRL_SEQERR_0_RNIV01G4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefeeeeefffeeeee")
port map (
combout => \GRFPC0.FP_PIPELINE.PENDEXC_3_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
dataa => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_WR2_CTRL_SEQERR_0_RNIV01G4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefeeeeefffeeeee")
port map (
combout => \GRFPC0.FP_PIPELINE.PENDEXC_3_1\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
dataa => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_WR2_CTRL_SEQERR_0_RNIV01G4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefeeeeefffeeeee")
port map (
combout => \GRFPC0.FP_PIPELINE.PENDEXC_3_2\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.V.STATE10_0\,
dataa => \GRFPC0.WR2.CTRL.SEQERR_0\);
GRFPC0_DIVI_0_SQMUXA_4_M2_E_0_RNICCJU4_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0f0fffcf0f0f")
port map (
combout => CPO_EXCZ,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => N_184395,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_DIVI_0_SQMUXA_4_M2_E_0_RNICCJU4_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0f0fffcf0f0f")
port map (
combout => N_52020_1,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => N_184395,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPC0_DIVI_0_SQMUXA_4_M2_E_0_RNICCJU4: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0f0fffcf0f0f")
port map (
combout => N_52020_2,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
datad => N_184337,
datac => N_184395,
datab => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\);
GRFPU0_GRFPU_X0_ITER_STATE_RET_RNI37B11_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f3ffff33f333f3")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datae => \GRFPU0.GRFPU_X0.N_21036\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2\,
datab => N_184434);
GRFPU0_GRFPU_X0_ITER_STATE_RET_RNI37B11: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f3ffff33f333f3")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_26_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datae => \GRFPU0.GRFPU_X0.N_21036\,
datad => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_68_0_A2_1_2\,
datab => N_184434);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_O2_RNI3PJ3Q_48_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff737373ff333333")
port map (
combout => \GRFPU0.GRFPU_X0.N_20287_0\,
dataf => \GRFPU0.GRFPU_X0.N_333\,
datae => \GRFPU0.GRFPU_X0.N_20291\,
datad => \GRFPU0.GRFPU_X0.N_19767\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A2_0_0_7__G0_0_A3_0\,
datab => \GRFPU0.GRFPU_X0.N_80\,
dataa => \FPI.OP1\(51));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_O2_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000e4ee")
port map (
combout => \GRFPC0.N_21137_0\,
dataf => N_186950,
datae => \GRFPC0.VDIV.VALID_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN_1_1\,
datac => N_52020_2,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
dataa => \GRFPC0.DIV.VALID_0\);
\GRFPU0_GRFPU_X0_UN1_SGNF_1_SQMUXA_4_0_A2_1_0_A2_RNI7RT4M_0_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffefefefcfcfcfcf")
port map (
combout => \GRFPU0.GRFPU_X0.N_19712_0\,
dataf => \GRFPU0.GRFPU_X0.N_19767\,
datae => \GRFPU0.GRFPU_X0.N_327\,
datad => N_187635,
datac => \GRFPU0.GRFPU_X0.N_80_0\,
datab => \FPI.FLOP_1\(1),
dataa => \FPI.NONSTD\);
GRFPC0_RFA2_RS1SEL_RET_1_RNIUI7B2_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"aaa0000000008080")
port map (
combout => \GRFPC0.RFA2.RS1SEL_0\(4),
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\,
datae => HOLDN_RETO,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.WR2SEL4_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.FPUSEL_6_1_RETO\(7),
datag => \GRFPC0.WR.RREG.RESV_RETO\);
GRFPC0_RFA2_RS1SEL_RET_1_RNIUI7B2: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"aaa0000000008080")
port map (
combout => \GRFPC0.RFA2.RS1SEL_1\(4),
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2_RETO\,
datae => HOLDN_RETO,
datad => \GRFPC0.FP_PIPELINE.VWR2.RREG.RES9_RETO\,
datac => \GRFPC0.FP_PIPELINE.0.WR2SEL4_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.FPUSEL_6_1_RETO\(7),
datag => \GRFPC0.WR.RREG.RESV_RETO\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI3QH51_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000f1f0")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3_0_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => N_184293,
datad => \GRFPC0.FPR.RDY\,
datac => \GRFPC0.WR2.RREG.RESV_1_0\,
datab => \GRFPC0.R.STATE_2\(1),
dataa => \GRFPC0.R.STATE_191\(0));
\GRFPC0_FIFO_INST_1_RNIR9UB_1_6_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP_1_0\(1),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_1\(6));
GRFPC0_WR2_RREG_RESV_3: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.RREG.RESV_1_0\,
datain => \GRFPC0.N_10177\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
GRFPU0_GRFPU_X0_ITER_V_4: stratixii_lcell_ff port map (
regout => \GRFPU0.GRFPU_X0.ITER.V_0_0\,
datain => \GRFPU0.GRFPU_X0.N_11255\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_FIFO_RD_5_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.FIFO.RD_1_0\(0),
datain => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_0_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_2_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_3_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_3_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.SQRT_0_0_G3_0_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPC0_WR2_CTRL_SEQERR_0: stratixii_lcell_ff port map (
regout => \GRFPC0.WR2.CTRL.SEQERR_0\,
datain => N_50070,
clk => N_62,
ena => N_63,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND);
GRFPC0_DIV_VALID_0: stratixii_lcell_ff port map (
regout => \GRFPC0.DIV.VALID_0\,
datain => \GRFPC0.N_10175\,
clk => N_62,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sclr => GND,
	sload => GND,
	adatasdata => GND,
	ena => VCC);
\GRFPC0_R_STATE_2_0_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_191\(0),
datain => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
\GRFPC0_R_STATE_2_1_\: stratixii_lcell_ff port map (
regout => \GRFPC0.R.STATE_2\(1),
datain => \GRFPC0.R.STATE_0_0_1__G2\,
clk => N_62,
sclr => RST_I,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
	devpor => devpor,
	devclrn => devclrn,
	aclr => GND,
	aload => GND,
	sload => GND,
	adatasdata => GND);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_X2_RNI3B6T3: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0ccccccfc")
port map (
combout => N_174935_0,
dataf => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datae => \GRFPU0.GRFPU_X0.N_77_I\,
datad => \GRFPU0.GRFPU_X0.N_51_I\,
datac => \GRFPU0.GRFPU_X0.G_672_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.G_672_0_A2_0_2\);
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_270_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_270\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(6),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(8),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(7));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_390_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_390\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(40),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(43),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(45),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(38),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(37));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_393_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffd951c840")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_393\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(41),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_39_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfcfcfcfcfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_39\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_390\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_270\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_393\,
datab => VCC);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_1_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0fffff0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1_RETI\,
dataf => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
datae => \GRFPU0.GRFPU_X0.N_11253\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_490_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_490\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(23),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(22),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(19),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(20),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(33));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_491_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_491\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(28),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(21),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(30));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_49_18_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fffff0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_490\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_491\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_42\(18),
datac => VCC);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNI4TIH1_40_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1_E0_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38));
\GRFPU0_GRFPU_X0_L4_4_I_A2_2_RNIU6JI4_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10710\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1_0_33__G1_E0_0\,
datae => \GRFPU0.GRFPU_X0.N_10715\,
datad => \GRFPU0.GRFPU_X0.N_10717\,
datac => \GRFPU0.GRFPU_X0.L4_4_I_A2_2\(4),
datab => \GRFPU0.GRFPU_X0.N_10765\,
dataa => \GRFPU0.GRFPU_X0.N_10728\);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_0_RNO_0: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc00fcff0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
datac => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0));
GRFPU0_GRFPU_X0_ST3_FARRES_RET_0_RNO_1: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0fffff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_0_RNO: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U0\,
datae => \GRFPU0.GRFPU_X0.COMB.G_DP_1_U1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(54));
\GRFPU0_GRFPU_X0_L2_0_30_0_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_30_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPU0_GRFPU_X0_L2_0_3_4_\: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10716\,
dataf => \GRFPU0.GRFPU_X0.L2_0_30_0\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datac => \GRFPU0.GRFPU_X0.N_10728\,
datab => \GRFPU0.GRFPU_X0.N_10741\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_2_031: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0000000cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_031\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(0),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(1),
datad => \GRFPU0.GRFPU_X0.L4_4_0\(3),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_2_032: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_032\,
dataf => \GRFPU0.GRFPU_X0.L4_4_0\(2),
datae => \GRFPU0.GRFPU_X0.L4_4_0\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_2_03: stratixii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_031\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_032\);
N_61 <= RST_INTERNAL;
N_62 <= CLK_INTERNAL;
N_63 <= HOLDN_INTERNAL;
N_64 <= CPI_FLUSH_INTERNAL;
N_65 <= CPI_EXACK_INTERNAL;
N_66 <= CPI_A_RS1_INTERNAL;
N_67 <= CPI_A_RS1_INTERNAL_0;
N_68 <= CPI_A_RS1_INTERNAL_1;
N_69 <= CPI_A_RS1_INTERNAL_2;
N_70 <= CPI_A_RS1_INTERNAL_3;
N_71 <= CPI_D_PC_INTERNAL;
N_72 <= CPI_D_PC_INTERNAL_0;
N_73 <= CPI_D_PC_INTERNAL_1;
N_74 <= CPI_D_PC_INTERNAL_2;
N_75 <= CPI_D_PC_INTERNAL_3;
N_76 <= CPI_D_PC_INTERNAL_4;
N_77 <= CPI_D_PC_INTERNAL_5;
N_78 <= CPI_D_PC_INTERNAL_6;
N_79 <= CPI_D_PC_INTERNAL_7;
N_80 <= CPI_D_PC_INTERNAL_8;
N_81 <= CPI_D_PC_INTERNAL_9;
N_82 <= CPI_D_PC_INTERNAL_10;
N_83 <= CPI_D_PC_INTERNAL_11;
N_84 <= CPI_D_PC_INTERNAL_12;
N_85 <= CPI_D_PC_INTERNAL_13;
N_86 <= CPI_D_PC_INTERNAL_14;
N_87 <= CPI_D_PC_INTERNAL_15;
N_88 <= CPI_D_PC_INTERNAL_16;
N_89 <= CPI_D_PC_INTERNAL_17;
N_90 <= CPI_D_PC_INTERNAL_18;
N_91 <= CPI_D_PC_INTERNAL_19;
N_92 <= CPI_D_PC_INTERNAL_20;
N_93 <= CPI_D_PC_INTERNAL_21;
N_94 <= CPI_D_PC_INTERNAL_22;
N_95 <= CPI_D_PC_INTERNAL_23;
N_96 <= CPI_D_PC_INTERNAL_24;
N_97 <= CPI_D_PC_INTERNAL_25;
N_98 <= CPI_D_PC_INTERNAL_26;
N_99 <= CPI_D_PC_INTERNAL_27;
N_100 <= CPI_D_PC_INTERNAL_28;
N_101 <= CPI_D_PC_INTERNAL_29;
N_102 <= CPI_D_PC_INTERNAL_30;
N_103 <= CPI_D_INST_INTERNAL;
N_104 <= CPI_D_INST_INTERNAL_0;
N_105 <= CPI_D_INST_INTERNAL_1;
N_106 <= CPI_D_INST_INTERNAL_2;
N_107 <= CPI_D_INST_INTERNAL_3;
N_108 <= CPI_D_INST_INTERNAL_4;
N_109 <= CPI_D_INST_INTERNAL_5;
N_110 <= CPI_D_INST_INTERNAL_6;
N_111 <= CPI_D_INST_INTERNAL_7;
N_112 <= CPI_D_INST_INTERNAL_8;
N_113 <= CPI_D_INST_INTERNAL_9;
N_114 <= CPI_D_INST_INTERNAL_10;
N_115 <= CPI_D_INST_INTERNAL_11;
N_116 <= CPI_D_INST_INTERNAL_12;
N_117 <= CPI_D_INST_INTERNAL_13;
N_118 <= CPI_D_INST_INTERNAL_14;
N_119 <= CPI_D_INST_INTERNAL_15;
N_120 <= CPI_D_INST_INTERNAL_16;
N_121 <= CPI_D_INST_INTERNAL_17;
N_122 <= CPI_D_INST_INTERNAL_18;
N_123 <= CPI_D_INST_INTERNAL_19;
N_124 <= CPI_D_INST_INTERNAL_20;
N_125 <= CPI_D_INST_INTERNAL_21;
N_126 <= CPI_D_INST_INTERNAL_22;
N_127 <= CPI_D_INST_INTERNAL_23;
N_128 <= CPI_D_INST_INTERNAL_24;
N_129 <= CPI_D_INST_INTERNAL_25;
N_130 <= CPI_D_INST_INTERNAL_26;
N_131 <= CPI_D_INST_INTERNAL_27;
N_132 <= CPI_D_INST_INTERNAL_28;
N_133 <= CPI_D_INST_INTERNAL_29;
N_134 <= CPI_D_INST_INTERNAL_30;
N_135 <= CPI_D_CNT_INTERNAL;
N_136 <= CPI_D_CNT_INTERNAL_0;
N_137 <= CPI_D_TRAP_INTERNAL;
N_138 <= CPI_D_ANNUL_INTERNAL;
N_139 <= CPI_D_PV_INTERNAL;
N_140 <= CPI_A_PC_INTERNAL;
N_141 <= CPI_A_PC_INTERNAL_0;
N_142 <= CPI_A_PC_INTERNAL_1;
N_143 <= CPI_A_PC_INTERNAL_2;
N_144 <= CPI_A_PC_INTERNAL_3;
N_145 <= CPI_A_PC_INTERNAL_4;
N_146 <= CPI_A_PC_INTERNAL_5;
N_147 <= CPI_A_PC_INTERNAL_6;
N_148 <= CPI_A_PC_INTERNAL_7;
N_149 <= CPI_A_PC_INTERNAL_8;
N_150 <= CPI_A_PC_INTERNAL_9;
N_151 <= CPI_A_PC_INTERNAL_10;
N_152 <= CPI_A_PC_INTERNAL_11;
N_153 <= CPI_A_PC_INTERNAL_12;
N_154 <= CPI_A_PC_INTERNAL_13;
N_155 <= CPI_A_PC_INTERNAL_14;
N_156 <= CPI_A_PC_INTERNAL_15;
N_157 <= CPI_A_PC_INTERNAL_16;
N_158 <= CPI_A_PC_INTERNAL_17;
N_159 <= CPI_A_PC_INTERNAL_18;
N_160 <= CPI_A_PC_INTERNAL_19;
N_161 <= CPI_A_PC_INTERNAL_20;
N_162 <= CPI_A_PC_INTERNAL_21;
N_163 <= CPI_A_PC_INTERNAL_22;
N_164 <= CPI_A_PC_INTERNAL_23;
N_165 <= CPI_A_PC_INTERNAL_24;
N_166 <= CPI_A_PC_INTERNAL_25;
N_167 <= CPI_A_PC_INTERNAL_26;
N_168 <= CPI_A_PC_INTERNAL_27;
N_169 <= CPI_A_PC_INTERNAL_28;
N_170 <= CPI_A_PC_INTERNAL_29;
N_171 <= CPI_A_PC_INTERNAL_30;
N_172 <= CPI_A_INST_INTERNAL;
N_173 <= CPI_A_INST_INTERNAL_0;
N_174 <= CPI_A_INST_INTERNAL_1;
N_175 <= CPI_A_INST_INTERNAL_2;
N_176 <= CPI_A_INST_INTERNAL_3;
N_177 <= CPI_A_INST_INTERNAL_4;
N_178 <= CPI_A_INST_INTERNAL_5;
N_179 <= CPI_A_INST_INTERNAL_6;
N_180 <= CPI_A_INST_INTERNAL_7;
N_181 <= CPI_A_INST_INTERNAL_8;
N_182 <= CPI_A_INST_INTERNAL_9;
N_183 <= CPI_A_INST_INTERNAL_10;
N_184 <= CPI_A_INST_INTERNAL_11;
N_185 <= CPI_A_INST_INTERNAL_12;
N_186 <= CPI_A_INST_INTERNAL_13;
N_187 <= CPI_A_INST_INTERNAL_14;
N_188 <= CPI_A_INST_INTERNAL_15;
N_189 <= CPI_A_INST_INTERNAL_16;
N_190 <= CPI_A_INST_INTERNAL_17;
N_191 <= CPI_A_INST_INTERNAL_18;
N_192 <= CPI_A_INST_INTERNAL_19;
N_193 <= CPI_A_INST_INTERNAL_20;
N_194 <= CPI_A_INST_INTERNAL_21;
N_195 <= CPI_A_INST_INTERNAL_22;
N_196 <= CPI_A_INST_INTERNAL_23;
N_197 <= CPI_A_INST_INTERNAL_24;
N_198 <= CPI_A_INST_INTERNAL_25;
N_199 <= CPI_A_INST_INTERNAL_26;
N_200 <= CPI_A_INST_INTERNAL_27;
N_201 <= CPI_A_INST_INTERNAL_28;
N_202 <= CPI_A_INST_INTERNAL_29;
N_203 <= CPI_A_INST_INTERNAL_30;
N_204 <= CPI_A_CNT_INTERNAL;
N_205 <= CPI_A_CNT_INTERNAL_0;
N_206 <= CPI_A_TRAP_INTERNAL;
N_207 <= CPI_A_ANNUL_INTERNAL;
N_208 <= CPI_A_PV_INTERNAL;
N_209 <= CPI_E_PC_INTERNAL;
N_210 <= CPI_E_PC_INTERNAL_0;
N_211 <= CPI_E_PC_INTERNAL_1;
N_212 <= CPI_E_PC_INTERNAL_2;
N_213 <= CPI_E_PC_INTERNAL_3;
N_214 <= CPI_E_PC_INTERNAL_4;
N_215 <= CPI_E_PC_INTERNAL_5;
N_216 <= CPI_E_PC_INTERNAL_6;
N_217 <= CPI_E_PC_INTERNAL_7;
N_218 <= CPI_E_PC_INTERNAL_8;
N_219 <= CPI_E_PC_INTERNAL_9;
N_220 <= CPI_E_PC_INTERNAL_10;
N_221 <= CPI_E_PC_INTERNAL_11;
N_222 <= CPI_E_PC_INTERNAL_12;
N_223 <= CPI_E_PC_INTERNAL_13;
N_224 <= CPI_E_PC_INTERNAL_14;
N_225 <= CPI_E_PC_INTERNAL_15;
N_226 <= CPI_E_PC_INTERNAL_16;
N_227 <= CPI_E_PC_INTERNAL_17;
N_228 <= CPI_E_PC_INTERNAL_18;
N_229 <= CPI_E_PC_INTERNAL_19;
N_230 <= CPI_E_PC_INTERNAL_20;
N_231 <= CPI_E_PC_INTERNAL_21;
N_232 <= CPI_E_PC_INTERNAL_22;
N_233 <= CPI_E_PC_INTERNAL_23;
N_234 <= CPI_E_PC_INTERNAL_24;
N_235 <= CPI_E_PC_INTERNAL_25;
N_236 <= CPI_E_PC_INTERNAL_26;
N_237 <= CPI_E_PC_INTERNAL_27;
N_238 <= CPI_E_PC_INTERNAL_28;
N_239 <= CPI_E_PC_INTERNAL_29;
N_240 <= CPI_E_PC_INTERNAL_30;
N_241 <= CPI_E_INST_INTERNAL;
N_242 <= CPI_E_INST_INTERNAL_0;
N_243 <= CPI_E_INST_INTERNAL_1;
N_244 <= CPI_E_INST_INTERNAL_2;
N_245 <= CPI_E_INST_INTERNAL_3;
N_246 <= CPI_E_INST_INTERNAL_4;
N_247 <= CPI_E_INST_INTERNAL_5;
N_248 <= CPI_E_INST_INTERNAL_6;
N_249 <= CPI_E_INST_INTERNAL_7;
N_250 <= CPI_E_INST_INTERNAL_8;
N_251 <= CPI_E_INST_INTERNAL_9;
N_252 <= CPI_E_INST_INTERNAL_10;
N_253 <= CPI_E_INST_INTERNAL_11;
N_254 <= CPI_E_INST_INTERNAL_12;
N_255 <= CPI_E_INST_INTERNAL_13;
N_256 <= CPI_E_INST_INTERNAL_14;
N_257 <= CPI_E_INST_INTERNAL_15;
N_258 <= CPI_E_INST_INTERNAL_16;
N_259 <= CPI_E_INST_INTERNAL_17;
N_260 <= CPI_E_INST_INTERNAL_18;
N_261 <= CPI_E_INST_INTERNAL_19;
N_262 <= CPI_E_INST_INTERNAL_20;
N_263 <= CPI_E_INST_INTERNAL_21;
N_264 <= CPI_E_INST_INTERNAL_22;
N_265 <= CPI_E_INST_INTERNAL_23;
N_266 <= CPI_E_INST_INTERNAL_24;
N_267 <= CPI_E_INST_INTERNAL_25;
N_268 <= CPI_E_INST_INTERNAL_26;
N_269 <= CPI_E_INST_INTERNAL_27;
N_270 <= CPI_E_INST_INTERNAL_28;
N_271 <= CPI_E_INST_INTERNAL_29;
N_272 <= CPI_E_INST_INTERNAL_30;
N_273 <= CPI_E_CNT_INTERNAL;
N_274 <= CPI_E_CNT_INTERNAL_0;
N_275 <= CPI_E_TRAP_INTERNAL;
N_276 <= CPI_E_ANNUL_INTERNAL;
N_277 <= CPI_E_PV_INTERNAL;
N_278 <= CPI_M_PC_INTERNAL;
N_279 <= CPI_M_PC_INTERNAL_0;
N_280 <= CPI_M_PC_INTERNAL_1;
N_281 <= CPI_M_PC_INTERNAL_2;
N_282 <= CPI_M_PC_INTERNAL_3;
N_283 <= CPI_M_PC_INTERNAL_4;
N_284 <= CPI_M_PC_INTERNAL_5;
N_285 <= CPI_M_PC_INTERNAL_6;
N_286 <= CPI_M_PC_INTERNAL_7;
N_287 <= CPI_M_PC_INTERNAL_8;
N_288 <= CPI_M_PC_INTERNAL_9;
N_289 <= CPI_M_PC_INTERNAL_10;
N_290 <= CPI_M_PC_INTERNAL_11;
N_291 <= CPI_M_PC_INTERNAL_12;
N_292 <= CPI_M_PC_INTERNAL_13;
N_293 <= CPI_M_PC_INTERNAL_14;
N_294 <= CPI_M_PC_INTERNAL_15;
N_295 <= CPI_M_PC_INTERNAL_16;
N_296 <= CPI_M_PC_INTERNAL_17;
N_297 <= CPI_M_PC_INTERNAL_18;
N_298 <= CPI_M_PC_INTERNAL_19;
N_299 <= CPI_M_PC_INTERNAL_20;
N_300 <= CPI_M_PC_INTERNAL_21;
N_301 <= CPI_M_PC_INTERNAL_22;
N_302 <= CPI_M_PC_INTERNAL_23;
N_303 <= CPI_M_PC_INTERNAL_24;
N_304 <= CPI_M_PC_INTERNAL_25;
N_305 <= CPI_M_PC_INTERNAL_26;
N_306 <= CPI_M_PC_INTERNAL_27;
N_307 <= CPI_M_PC_INTERNAL_28;
N_308 <= CPI_M_PC_INTERNAL_29;
N_309 <= CPI_M_PC_INTERNAL_30;
N_310 <= CPI_M_INST_INTERNAL;
N_311 <= CPI_M_INST_INTERNAL_0;
N_312 <= CPI_M_INST_INTERNAL_1;
N_313 <= CPI_M_INST_INTERNAL_2;
N_314 <= CPI_M_INST_INTERNAL_3;
N_315 <= CPI_M_INST_INTERNAL_4;
N_316 <= CPI_M_INST_INTERNAL_5;
N_317 <= CPI_M_INST_INTERNAL_6;
N_318 <= CPI_M_INST_INTERNAL_7;
N_319 <= CPI_M_INST_INTERNAL_8;
N_320 <= CPI_M_INST_INTERNAL_9;
N_321 <= CPI_M_INST_INTERNAL_10;
N_322 <= CPI_M_INST_INTERNAL_11;
N_323 <= CPI_M_INST_INTERNAL_12;
N_324 <= CPI_M_INST_INTERNAL_13;
N_325 <= CPI_M_INST_INTERNAL_14;
N_326 <= CPI_M_INST_INTERNAL_15;
N_327 <= CPI_M_INST_INTERNAL_16;
N_328 <= CPI_M_INST_INTERNAL_17;
N_329 <= CPI_M_INST_INTERNAL_18;
N_330 <= CPI_M_INST_INTERNAL_19;
N_331 <= CPI_M_INST_INTERNAL_20;
N_332 <= CPI_M_INST_INTERNAL_21;
N_333 <= CPI_M_INST_INTERNAL_22;
N_334 <= CPI_M_INST_INTERNAL_23;
N_335 <= CPI_M_INST_INTERNAL_24;
N_336 <= CPI_M_INST_INTERNAL_25;
N_337 <= CPI_M_INST_INTERNAL_26;
N_338 <= CPI_M_INST_INTERNAL_27;
N_339 <= CPI_M_INST_INTERNAL_28;
N_340 <= CPI_M_INST_INTERNAL_29;
N_341 <= CPI_M_INST_INTERNAL_30;
N_342 <= CPI_M_CNT_INTERNAL;
N_343 <= CPI_M_CNT_INTERNAL_0;
N_344 <= CPI_M_TRAP_INTERNAL;
N_345 <= CPI_M_ANNUL_INTERNAL;
N_346 <= CPI_M_PV_INTERNAL;
N_347 <= CPI_X_PC_INTERNAL;
N_348 <= CPI_X_PC_INTERNAL_0;
N_349 <= CPI_X_PC_INTERNAL_1;
N_350 <= CPI_X_PC_INTERNAL_2;
N_351 <= CPI_X_PC_INTERNAL_3;
N_352 <= CPI_X_PC_INTERNAL_4;
N_353 <= CPI_X_PC_INTERNAL_5;
N_354 <= CPI_X_PC_INTERNAL_6;
N_355 <= CPI_X_PC_INTERNAL_7;
N_356 <= CPI_X_PC_INTERNAL_8;
N_357 <= CPI_X_PC_INTERNAL_9;
N_358 <= CPI_X_PC_INTERNAL_10;
N_359 <= CPI_X_PC_INTERNAL_11;
N_360 <= CPI_X_PC_INTERNAL_12;
N_361 <= CPI_X_PC_INTERNAL_13;
N_362 <= CPI_X_PC_INTERNAL_14;
N_363 <= CPI_X_PC_INTERNAL_15;
N_364 <= CPI_X_PC_INTERNAL_16;
N_365 <= CPI_X_PC_INTERNAL_17;
N_366 <= CPI_X_PC_INTERNAL_18;
N_367 <= CPI_X_PC_INTERNAL_19;
N_368 <= CPI_X_PC_INTERNAL_20;
N_369 <= CPI_X_PC_INTERNAL_21;
N_370 <= CPI_X_PC_INTERNAL_22;
N_371 <= CPI_X_PC_INTERNAL_23;
N_372 <= CPI_X_PC_INTERNAL_24;
N_373 <= CPI_X_PC_INTERNAL_25;
N_374 <= CPI_X_PC_INTERNAL_26;
N_375 <= CPI_X_PC_INTERNAL_27;
N_376 <= CPI_X_PC_INTERNAL_28;
N_377 <= CPI_X_PC_INTERNAL_29;
N_378 <= CPI_X_PC_INTERNAL_30;
N_379 <= CPI_X_INST_INTERNAL;
N_380 <= CPI_X_INST_INTERNAL_0;
N_381 <= CPI_X_INST_INTERNAL_1;
N_382 <= CPI_X_INST_INTERNAL_2;
N_383 <= CPI_X_INST_INTERNAL_3;
N_384 <= CPI_X_INST_INTERNAL_4;
N_385 <= CPI_X_INST_INTERNAL_5;
N_386 <= CPI_X_INST_INTERNAL_6;
N_387 <= CPI_X_INST_INTERNAL_7;
N_388 <= CPI_X_INST_INTERNAL_8;
N_389 <= CPI_X_INST_INTERNAL_9;
N_390 <= CPI_X_INST_INTERNAL_10;
N_391 <= CPI_X_INST_INTERNAL_11;
N_392 <= CPI_X_INST_INTERNAL_12;
N_393 <= CPI_X_INST_INTERNAL_13;
N_394 <= CPI_X_INST_INTERNAL_14;
N_395 <= CPI_X_INST_INTERNAL_15;
N_396 <= CPI_X_INST_INTERNAL_16;
N_397 <= CPI_X_INST_INTERNAL_17;
N_398 <= CPI_X_INST_INTERNAL_18;
N_399 <= CPI_X_INST_INTERNAL_19;
N_400 <= CPI_X_INST_INTERNAL_20;
N_401 <= CPI_X_INST_INTERNAL_21;
N_402 <= CPI_X_INST_INTERNAL_22;
N_403 <= CPI_X_INST_INTERNAL_23;
N_404 <= CPI_X_INST_INTERNAL_24;
N_405 <= CPI_X_INST_INTERNAL_25;
N_406 <= CPI_X_INST_INTERNAL_26;
N_407 <= CPI_X_INST_INTERNAL_27;
N_408 <= CPI_X_INST_INTERNAL_28;
N_409 <= CPI_X_INST_INTERNAL_29;
N_410 <= CPI_X_INST_INTERNAL_30;
N_411 <= CPI_X_CNT_INTERNAL;
N_412 <= CPI_X_CNT_INTERNAL_0;
N_413 <= CPI_X_TRAP_INTERNAL;
N_414 <= CPI_X_ANNUL_INTERNAL;
N_415 <= CPI_X_PV_INTERNAL;
N_416 <= CPI_LDDATA_INTERNAL;
N_417 <= CPI_LDDATA_INTERNAL_0;
N_418 <= CPI_LDDATA_INTERNAL_1;
N_419 <= CPI_LDDATA_INTERNAL_2;
N_420 <= CPI_LDDATA_INTERNAL_3;
N_421 <= CPI_LDDATA_INTERNAL_4;
N_422 <= CPI_LDDATA_INTERNAL_5;
N_423 <= CPI_LDDATA_INTERNAL_6;
N_424 <= CPI_LDDATA_INTERNAL_7;
N_425 <= CPI_LDDATA_INTERNAL_8;
N_426 <= CPI_LDDATA_INTERNAL_9;
N_427 <= CPI_LDDATA_INTERNAL_10;
N_428 <= CPI_LDDATA_INTERNAL_11;
N_429 <= CPI_LDDATA_INTERNAL_12;
N_430 <= CPI_LDDATA_INTERNAL_13;
N_431 <= CPI_LDDATA_INTERNAL_14;
N_432 <= CPI_LDDATA_INTERNAL_15;
N_433 <= CPI_LDDATA_INTERNAL_16;
N_434 <= CPI_LDDATA_INTERNAL_17;
N_435 <= CPI_LDDATA_INTERNAL_18;
N_436 <= CPI_LDDATA_INTERNAL_19;
N_437 <= CPI_LDDATA_INTERNAL_20;
N_438 <= CPI_LDDATA_INTERNAL_21;
N_439 <= CPI_LDDATA_INTERNAL_22;
N_440 <= CPI_LDDATA_INTERNAL_23;
N_441 <= CPI_LDDATA_INTERNAL_24;
N_442 <= CPI_LDDATA_INTERNAL_25;
N_443 <= CPI_LDDATA_INTERNAL_26;
N_444 <= CPI_LDDATA_INTERNAL_27;
N_445 <= CPI_LDDATA_INTERNAL_28;
N_446 <= CPI_LDDATA_INTERNAL_29;
N_447 <= CPI_LDDATA_INTERNAL_30;
N_448 <= CPI_DBG_ENABLE_INTERNAL;
N_449 <= CPI_DBG_WRITE_INTERNAL;
N_450 <= CPI_DBG_FSR_INTERNAL;
N_451 <= CPI_DBG_ADDR_INTERNAL;
N_452 <= CPI_DBG_ADDR_INTERNAL_0;
N_453 <= CPI_DBG_ADDR_INTERNAL_1;
N_454 <= CPI_DBG_ADDR_INTERNAL_2;
N_455 <= CPI_DBG_ADDR_INTERNAL_3;
N_456 <= CPI_DBG_DATA_INTERNAL;
N_457 <= CPI_DBG_DATA_INTERNAL_0;
N_458 <= CPI_DBG_DATA_INTERNAL_1;
N_459 <= CPI_DBG_DATA_INTERNAL_2;
N_460 <= CPI_DBG_DATA_INTERNAL_3;
N_461 <= CPI_DBG_DATA_INTERNAL_4;
N_462 <= CPI_DBG_DATA_INTERNAL_5;
N_463 <= CPI_DBG_DATA_INTERNAL_6;
N_464 <= CPI_DBG_DATA_INTERNAL_7;
N_465 <= CPI_DBG_DATA_INTERNAL_8;
N_466 <= CPI_DBG_DATA_INTERNAL_9;
N_467 <= CPI_DBG_DATA_INTERNAL_10;
N_468 <= CPI_DBG_DATA_INTERNAL_11;
N_469 <= CPI_DBG_DATA_INTERNAL_12;
N_470 <= CPI_DBG_DATA_INTERNAL_13;
N_471 <= CPI_DBG_DATA_INTERNAL_14;
N_472 <= CPI_DBG_DATA_INTERNAL_15;
N_473 <= CPI_DBG_DATA_INTERNAL_16;
N_474 <= CPI_DBG_DATA_INTERNAL_17;
N_475 <= CPI_DBG_DATA_INTERNAL_18;
N_476 <= CPI_DBG_DATA_INTERNAL_19;
N_477 <= CPI_DBG_DATA_INTERNAL_20;
N_478 <= CPI_DBG_DATA_INTERNAL_21;
N_479 <= CPI_DBG_DATA_INTERNAL_22;
N_480 <= CPI_DBG_DATA_INTERNAL_23;
N_481 <= CPI_DBG_DATA_INTERNAL_24;
N_482 <= CPI_DBG_DATA_INTERNAL_25;
N_483 <= CPI_DBG_DATA_INTERNAL_26;
N_484 <= CPI_DBG_DATA_INTERNAL_27;
N_485 <= CPI_DBG_DATA_INTERNAL_28;
N_486 <= CPI_DBG_DATA_INTERNAL_29;
N_487 <= CPI_DBG_DATA_INTERNAL_30;
N_0 <= CPO_DATAZ(0);
N_1_32 <= CPO_DATAZ(1);
N_2_0 <= CPO_DATAZ(2);
N_3_0 <= CPO_DATAZ(3);
N_4_1 <= CPO_DATAZ(4);
N_5_0 <= CPO_DATAZ(5);
N_6_0 <= CPO_DATAZ(6);
N_7_0 <= CPO_DATAZ(7);
N_8_0 <= CPO_DATAZ(8);
N_9_0 <= CPO_DATAZ(9);
N_10_0 <= CPO_DATAZ(10);
N_11_0 <= CPO_DATAZ(11);
N_12_0 <= CPO_DATAZ(12);
N_13_1 <= CPO_DATAZ(13);
N_14_0 <= CPO_DATAZ(14);
N_15_0 <= CPO_DATAZ(15);
N_16_0 <= CPO_DATAZ(16);
N_17_0 <= CPO_DATAZ(17);
N_18_0 <= CPO_DATAZ(18);
N_19_0 <= CPO_DATAZ(19);
N_20_0 <= CPO_DATAZ(20);
N_21_1 <= CPO_DATAZ(21);
N_22_0 <= CPO_DATAZ(22);
N_23_0 <= CPO_DATAZ(23);
N_24_0 <= CPO_DATAZ(24);
N_25_0 <= CPO_DATAZ(25);
N_26_0 <= CPO_DATAZ(26);
N_27_0 <= CPO_DATAZ(27);
N_28_0 <= CPO_DATAZ(28);
N_29_0 <= CPO_DATAZ(29);
N_30_0 <= CPO_DATAZ(30);
N_31_0 <= CPO_DATAZ(31);
N_32_0 <= CPO_EXCZ;
N_33_0 <= CPO_CCZ(0);
N_34_0 <= CPO_CCZ(1);
N_35_0 <= CPO_CCVZ;
N_36_0 <= CPO_LDLOCKZ;
N_37_0 <= VCC;
N_38_0 <= CPO_DBG_DATAZ(0);
N_39_0 <= CPO_DBG_DATAZ(1);
N_40_0 <= CPO_DBG_DATAZ(2);
N_41_0 <= CPO_DBG_DATAZ(3);
N_42_0 <= CPO_DBG_DATAZ(4);
N_43_0 <= CPO_DBG_DATAZ(5);
N_44_0 <= CPO_DBG_DATAZ(6);
N_45_0 <= CPO_DBG_DATAZ(7);
N_46_0 <= CPO_DBG_DATAZ(8);
N_47_0 <= CPO_DBG_DATAZ(9);
N_48_0 <= CPO_DBG_DATAZ(10);
N_49_0 <= CPO_DBG_DATAZ(11);
N_50_0 <= CPO_DBG_DATAZ(12);
N_51_0 <= CPO_DBG_DATAZ(13);
N_52_0 <= CPO_DBG_DATAZ(14);
N_53_0 <= CPO_DBG_DATAZ(15);
N_54_0 <= CPO_DBG_DATAZ(16);
N_55_0 <= CPO_DBG_DATAZ(17);
N_56_0 <= CPO_DBG_DATAZ(18);
N_57_0 <= CPO_DBG_DATAZ(19);
N_58_0 <= CPO_DBG_DATAZ(20);
N_59_0 <= CPO_DBG_DATAZ(21);
N_60_0 <= CPO_DBG_DATAZ(22);
N_61_0 <= CPO_DBG_DATAZ(23);
N_62_0 <= CPO_DBG_DATAZ(24);
N_63_0 <= CPO_DBG_DATAZ(25);
N_64_0 <= CPO_DBG_DATAZ(26);
N_65_0 <= CPO_DBG_DATAZ(27);
N_66_0 <= CPO_DBG_DATAZ(28);
N_67_0 <= CPO_DBG_DATAZ(29);
N_68_0 <= CPO_DBG_DATAZ(30);
N_69_0 <= CPO_DBG_DATAZ(31);
N_70_0 <= RFI2_RD1ADDRZ(0);
N_71_0 <= RFI2_RD1ADDRZ(1);
N_72_0 <= RFI2_RD1ADDRZ(2);
N_73_0 <= RFI2_RD1ADDRZ(3);
N_74_0 <= RFI2_RD2ADDRZ(0);
N_75_0 <= RFI2_RD2ADDRZ(1);
N_76_0 <= RFI2_RD2ADDRZ(2);
N_77_0 <= RFI2_RD2ADDRZ(3);
N_78_0 <= RFI2_WRADDRZ(0);
N_79_0 <= RFI2_WRADDRZ(1);
N_80_0 <= RFI2_WRADDRZ(2);
N_81_0 <= RFI2_WRADDRZ(3);
N_82_0 <= RFI1_WRDATAZ(0);
N_83_0 <= RFI1_WRDATAZ(1);
N_84_0 <= RFI1_WRDATAZ(2);
N_85_0 <= RFI1_WRDATAZ(3);
N_86_0 <= RFI1_WRDATAZ(4);
N_87_0 <= RFI1_WRDATAZ(5);
N_88_0 <= RFI1_WRDATAZ(6);
N_89_0 <= RFI1_WRDATAZ(7);
N_90_0 <= RFI1_WRDATAZ(8);
N_91_0 <= RFI1_WRDATAZ(9);
N_92_0 <= RFI1_WRDATAZ(10);
N_93_0 <= RFI1_WRDATAZ(11);
N_94_0 <= RFI1_WRDATAZ(12);
N_95_0 <= RFI1_WRDATAZ(13);
N_96_0 <= RFI1_WRDATAZ(14);
N_97_0 <= RFI1_WRDATAZ(15);
N_98_0 <= RFI1_WRDATAZ(16);
N_99_0 <= RFI1_WRDATAZ(17);
N_100_0 <= RFI1_WRDATAZ(18);
N_101_0 <= RFI1_WRDATAZ(19);
N_102_0 <= RFI1_WRDATAZ(20);
N_103_0 <= RFI1_WRDATAZ(21);
N_104_0 <= RFI1_WRDATAZ(22);
N_105_0 <= RFI1_WRDATAZ(23);
N_106_0 <= RFI1_WRDATAZ(24);
N_107_0 <= RFI1_WRDATAZ(25);
N_108_0 <= RFI1_WRDATAZ(26);
N_109_0 <= RFI1_WRDATAZ(27);
N_110_0 <= RFI1_WRDATAZ(28);
N_111_0 <= RFI1_WRDATAZ(29);
N_112_0 <= RFI1_WRDATAZ(30);
N_113_0 <= RFI1_WRDATAZ(31);
N_114_0 <= RFI1_REN1Z;
N_115_0 <= RFI1_REN2Z;
N_116_0 <= RFI1_WRENZ;
N_117_0 <= RFI2_RD1ADDRZ(0);
N_118_0 <= RFI2_RD1ADDRZ(1);
N_119_0 <= RFI2_RD1ADDRZ(2);
N_120_0 <= RFI2_RD1ADDRZ(3);
N_121_0 <= RFI2_RD2ADDRZ(0);
N_122_0 <= RFI2_RD2ADDRZ(1);
N_123_0 <= RFI2_RD2ADDRZ(2);
N_124_0 <= RFI2_RD2ADDRZ(3);
N_125_0 <= RFI2_WRADDRZ(0);
N_126_0 <= RFI2_WRADDRZ(1);
N_127_0 <= RFI2_WRADDRZ(2);
N_128_0 <= RFI2_WRADDRZ(3);
N_129_0 <= RFI2_WRDATAZ(0);
N_130_0 <= RFI2_WRDATAZ(1);
N_131_0 <= RFI2_WRDATAZ(2);
N_132_0 <= RFI2_WRDATAZ(3);
N_133_0 <= RFI2_WRDATAZ(4);
N_134_0 <= RFI2_WRDATAZ(5);
N_135_0 <= RFI2_WRDATAZ(6);
N_136_0 <= RFI2_WRDATAZ(7);
N_137_0 <= RFI2_WRDATAZ(8);
N_138_0 <= RFI2_WRDATAZ(9);
N_139_0 <= RFI2_WRDATAZ(10);
N_140_0 <= RFI2_WRDATAZ(11);
N_141_0 <= RFI2_WRDATAZ(12);
N_142_0 <= RFI2_WRDATAZ(13);
N_143_0 <= RFI2_WRDATAZ(14);
N_144_0 <= RFI2_WRDATAZ(15);
N_145_0 <= RFI2_WRDATAZ(16);
N_146_0 <= RFI2_WRDATAZ(17);
N_147_0 <= RFI2_WRDATAZ(18);
N_148_0 <= RFI2_WRDATAZ(19);
N_149_0 <= RFI2_WRDATAZ(20);
N_150_0 <= RFI2_WRDATAZ(21);
N_151_0 <= RFI2_WRDATAZ(22);
N_152_0 <= RFI2_WRDATAZ(23);
N_153_0 <= RFI2_WRDATAZ(24);
N_154_0 <= RFI2_WRDATAZ(25);
N_155_0 <= RFI2_WRDATAZ(26);
N_156_0 <= RFI2_WRDATAZ(27);
N_157_0 <= RFI2_WRDATAZ(28);
N_158_0 <= RFI2_WRDATAZ(29);
N_159_0 <= RFI2_WRDATAZ(30);
N_160_0 <= RFI2_WRDATAZ(31);
N_161_0 <= RFI2_REN1Z;
N_162_0 <= RFI2_REN2Z;
N_163_0 <= RFI2_WRENZ;
N_652 <= RFO1_DATA1_INTERNAL;
N_653 <= RFO1_DATA1_INTERNAL_0;
N_654 <= RFO1_DATA1_INTERNAL_1;
N_655 <= RFO1_DATA1_INTERNAL_2;
N_656 <= RFO1_DATA1_INTERNAL_3;
N_657 <= RFO1_DATA1_INTERNAL_4;
N_658 <= RFO1_DATA1_INTERNAL_5;
N_659 <= RFO1_DATA1_INTERNAL_6;
N_660 <= RFO1_DATA1_INTERNAL_7;
N_661 <= RFO1_DATA1_INTERNAL_8;
N_662 <= RFO1_DATA1_INTERNAL_9;
N_663 <= RFO1_DATA1_INTERNAL_10;
N_664 <= RFO1_DATA1_INTERNAL_11;
N_665 <= RFO1_DATA1_INTERNAL_12;
N_666 <= RFO1_DATA1_INTERNAL_13;
N_667 <= RFO1_DATA1_INTERNAL_14;
N_668 <= RFO1_DATA1_INTERNAL_15;
N_669 <= RFO1_DATA1_INTERNAL_16;
N_670 <= RFO1_DATA1_INTERNAL_17;
N_671 <= RFO1_DATA1_INTERNAL_18;
N_672 <= RFO1_DATA1_INTERNAL_19;
N_673 <= RFO1_DATA1_INTERNAL_20;
N_674 <= RFO1_DATA1_INTERNAL_21;
N_675 <= RFO1_DATA1_INTERNAL_22;
N_676 <= RFO1_DATA1_INTERNAL_23;
N_677 <= RFO1_DATA1_INTERNAL_24;
N_678 <= RFO1_DATA1_INTERNAL_25;
N_679 <= RFO1_DATA1_INTERNAL_26;
N_680 <= RFO1_DATA1_INTERNAL_27;
N_681 <= RFO1_DATA1_INTERNAL_28;
N_682 <= RFO1_DATA1_INTERNAL_29;
N_683 <= RFO1_DATA1_INTERNAL_30;
N_684 <= RFO1_DATA2_INTERNAL;
N_685 <= RFO1_DATA2_INTERNAL_0;
N_686 <= RFO1_DATA2_INTERNAL_1;
N_687 <= RFO1_DATA2_INTERNAL_2;
N_688 <= RFO1_DATA2_INTERNAL_3;
N_689 <= RFO1_DATA2_INTERNAL_4;
N_690 <= RFO1_DATA2_INTERNAL_5;
N_691 <= RFO1_DATA2_INTERNAL_6;
N_692 <= RFO1_DATA2_INTERNAL_7;
N_693 <= RFO1_DATA2_INTERNAL_8;
N_694 <= RFO1_DATA2_INTERNAL_9;
N_695 <= RFO1_DATA2_INTERNAL_10;
N_696 <= RFO1_DATA2_INTERNAL_11;
N_697 <= RFO1_DATA2_INTERNAL_12;
N_698 <= RFO1_DATA2_INTERNAL_13;
N_699 <= RFO1_DATA2_INTERNAL_14;
N_700 <= RFO1_DATA2_INTERNAL_15;
N_701 <= RFO1_DATA2_INTERNAL_16;
N_702 <= RFO1_DATA2_INTERNAL_17;
N_703 <= RFO1_DATA2_INTERNAL_18;
N_704 <= RFO1_DATA2_INTERNAL_19;
N_705 <= RFO1_DATA2_INTERNAL_20;
N_706 <= RFO1_DATA2_INTERNAL_21;
N_707 <= RFO1_DATA2_INTERNAL_22;
N_708 <= RFO1_DATA2_INTERNAL_23;
N_709 <= RFO1_DATA2_INTERNAL_24;
N_710 <= RFO1_DATA2_INTERNAL_25;
N_711 <= RFO1_DATA2_INTERNAL_26;
N_712 <= RFO1_DATA2_INTERNAL_27;
N_713 <= RFO1_DATA2_INTERNAL_28;
N_714 <= RFO1_DATA2_INTERNAL_29;
N_715 <= RFO1_DATA2_INTERNAL_30;
N_716 <= RFO2_DATA1_INTERNAL;
N_717 <= RFO2_DATA1_INTERNAL_0;
N_718 <= RFO2_DATA1_INTERNAL_1;
N_719 <= RFO2_DATA1_INTERNAL_2;
N_720 <= RFO2_DATA1_INTERNAL_3;
N_721 <= RFO2_DATA1_INTERNAL_4;
N_722 <= RFO2_DATA1_INTERNAL_5;
N_723 <= RFO2_DATA1_INTERNAL_6;
N_724 <= RFO2_DATA1_INTERNAL_7;
N_725 <= RFO2_DATA1_INTERNAL_8;
N_726 <= RFO2_DATA1_INTERNAL_9;
N_727 <= RFO2_DATA1_INTERNAL_10;
N_728 <= RFO2_DATA1_INTERNAL_11;
N_729 <= RFO2_DATA1_INTERNAL_12;
N_730 <= RFO2_DATA1_INTERNAL_13;
N_731 <= RFO2_DATA1_INTERNAL_14;
N_732 <= RFO2_DATA1_INTERNAL_15;
N_733 <= RFO2_DATA1_INTERNAL_16;
N_734 <= RFO2_DATA1_INTERNAL_17;
N_735 <= RFO2_DATA1_INTERNAL_18;
N_736 <= RFO2_DATA1_INTERNAL_19;
N_737 <= RFO2_DATA1_INTERNAL_20;
N_738 <= RFO2_DATA1_INTERNAL_21;
N_739 <= RFO2_DATA1_INTERNAL_22;
N_740 <= RFO2_DATA1_INTERNAL_23;
N_741 <= RFO2_DATA1_INTERNAL_24;
N_742 <= RFO2_DATA1_INTERNAL_25;
N_743 <= RFO2_DATA1_INTERNAL_26;
N_744 <= RFO2_DATA1_INTERNAL_27;
N_745 <= RFO2_DATA1_INTERNAL_28;
N_746 <= RFO2_DATA1_INTERNAL_29;
N_747 <= RFO2_DATA1_INTERNAL_30;
N_748 <= RFO2_DATA2_INTERNAL;
N_749 <= RFO2_DATA2_INTERNAL_0;
N_750 <= RFO2_DATA2_INTERNAL_1;
N_751 <= RFO2_DATA2_INTERNAL_2;
N_752 <= RFO2_DATA2_INTERNAL_3;
N_753 <= RFO2_DATA2_INTERNAL_4;
N_754 <= RFO2_DATA2_INTERNAL_5;
N_755 <= RFO2_DATA2_INTERNAL_6;
N_756 <= RFO2_DATA2_INTERNAL_7;
N_757 <= RFO2_DATA2_INTERNAL_8;
N_758 <= RFO2_DATA2_INTERNAL_9;
N_759 <= RFO2_DATA2_INTERNAL_10;
N_760 <= RFO2_DATA2_INTERNAL_11;
N_761 <= RFO2_DATA2_INTERNAL_12;
N_762 <= RFO2_DATA2_INTERNAL_13;
N_763 <= RFO2_DATA2_INTERNAL_14;
N_764 <= RFO2_DATA2_INTERNAL_15;
N_765 <= RFO2_DATA2_INTERNAL_16;
N_766 <= RFO2_DATA2_INTERNAL_17;
N_767 <= RFO2_DATA2_INTERNAL_18;
N_768 <= RFO2_DATA2_INTERNAL_19;
N_769 <= RFO2_DATA2_INTERNAL_20;
N_770 <= RFO2_DATA2_INTERNAL_21;
N_771 <= RFO2_DATA2_INTERNAL_22;
N_772 <= RFO2_DATA2_INTERNAL_23;
N_773 <= RFO2_DATA2_INTERNAL_24;
N_774 <= RFO2_DATA2_INTERNAL_25;
N_775 <= RFO2_DATA2_INTERNAL_26;
N_776 <= RFO2_DATA2_INTERNAL_27;
N_777 <= RFO2_DATA2_INTERNAL_28;
N_778 <= RFO2_DATA2_INTERNAL_29;
N_779 <= RFO2_DATA2_INTERNAL_30;
cpo_data(0) <= N_0;
cpo_data(1) <= N_1_32;
cpo_data(2) <= N_2_0;
cpo_data(3) <= N_3_0;
cpo_data(4) <= N_4_1;
cpo_data(5) <= N_5_0;
cpo_data(6) <= N_6_0;
cpo_data(7) <= N_7_0;
cpo_data(8) <= N_8_0;
cpo_data(9) <= N_9_0;
cpo_data(10) <= N_10_0;
cpo_data(11) <= N_11_0;
cpo_data(12) <= N_12_0;
cpo_data(13) <= N_13_1;
cpo_data(14) <= N_14_0;
cpo_data(15) <= N_15_0;
cpo_data(16) <= N_16_0;
cpo_data(17) <= N_17_0;
cpo_data(18) <= N_18_0;
cpo_data(19) <= N_19_0;
cpo_data(20) <= N_20_0;
cpo_data(21) <= N_21_1;
cpo_data(22) <= N_22_0;
cpo_data(23) <= N_23_0;
cpo_data(24) <= N_24_0;
cpo_data(25) <= N_25_0;
cpo_data(26) <= N_26_0;
cpo_data(27) <= N_27_0;
cpo_data(28) <= N_28_0;
cpo_data(29) <= N_29_0;
cpo_data(30) <= N_30_0;
cpo_data(31) <= N_31_0;
cpo_exc <= N_32_0;
cpo_cc(0) <= N_33_0;
cpo_cc(1) <= N_34_0;
cpo_ccv <= N_35_0;
cpo_ldlock <= N_36_0;
cpo_holdn <= N_37_0;
cpo_dbg_data(0) <= N_38_0;
cpo_dbg_data(1) <= N_39_0;
cpo_dbg_data(2) <= N_40_0;
cpo_dbg_data(3) <= N_41_0;
cpo_dbg_data(4) <= N_42_0;
cpo_dbg_data(5) <= N_43_0;
cpo_dbg_data(6) <= N_44_0;
cpo_dbg_data(7) <= N_45_0;
cpo_dbg_data(8) <= N_46_0;
cpo_dbg_data(9) <= N_47_0;
cpo_dbg_data(10) <= N_48_0;
cpo_dbg_data(11) <= N_49_0;
cpo_dbg_data(12) <= N_50_0;
cpo_dbg_data(13) <= N_51_0;
cpo_dbg_data(14) <= N_52_0;
cpo_dbg_data(15) <= N_53_0;
cpo_dbg_data(16) <= N_54_0;
cpo_dbg_data(17) <= N_55_0;
cpo_dbg_data(18) <= N_56_0;
cpo_dbg_data(19) <= N_57_0;
cpo_dbg_data(20) <= N_58_0;
cpo_dbg_data(21) <= N_59_0;
cpo_dbg_data(22) <= N_60_0;
cpo_dbg_data(23) <= N_61_0;
cpo_dbg_data(24) <= N_62_0;
cpo_dbg_data(25) <= N_63_0;
cpo_dbg_data(26) <= N_64_0;
cpo_dbg_data(27) <= N_65_0;
cpo_dbg_data(28) <= N_66_0;
cpo_dbg_data(29) <= N_67_0;
cpo_dbg_data(30) <= N_68_0;
cpo_dbg_data(31) <= N_69_0;
rfi1_rd1addr(0) <= N_70_0;
rfi1_rd1addr(1) <= N_71_0;
rfi1_rd1addr(2) <= N_72_0;
rfi1_rd1addr(3) <= N_73_0;
rfi1_rd2addr(0) <= N_74_0;
rfi1_rd2addr(1) <= N_75_0;
rfi1_rd2addr(2) <= N_76_0;
rfi1_rd2addr(3) <= N_77_0;
rfi1_wraddr(0) <= N_78_0;
rfi1_wraddr(1) <= N_79_0;
rfi1_wraddr(2) <= N_80_0;
rfi1_wraddr(3) <= N_81_0;
rfi1_wrdata(0) <= N_82_0;
rfi1_wrdata(1) <= N_83_0;
rfi1_wrdata(2) <= N_84_0;
rfi1_wrdata(3) <= N_85_0;
rfi1_wrdata(4) <= N_86_0;
rfi1_wrdata(5) <= N_87_0;
rfi1_wrdata(6) <= N_88_0;
rfi1_wrdata(7) <= N_89_0;
rfi1_wrdata(8) <= N_90_0;
rfi1_wrdata(9) <= N_91_0;
rfi1_wrdata(10) <= N_92_0;
rfi1_wrdata(11) <= N_93_0;
rfi1_wrdata(12) <= N_94_0;
rfi1_wrdata(13) <= N_95_0;
rfi1_wrdata(14) <= N_96_0;
rfi1_wrdata(15) <= N_97_0;
rfi1_wrdata(16) <= N_98_0;
rfi1_wrdata(17) <= N_99_0;
rfi1_wrdata(18) <= N_100_0;
rfi1_wrdata(19) <= N_101_0;
rfi1_wrdata(20) <= N_102_0;
rfi1_wrdata(21) <= N_103_0;
rfi1_wrdata(22) <= N_104_0;
rfi1_wrdata(23) <= N_105_0;
rfi1_wrdata(24) <= N_106_0;
rfi1_wrdata(25) <= N_107_0;
rfi1_wrdata(26) <= N_108_0;
rfi1_wrdata(27) <= N_109_0;
rfi1_wrdata(28) <= N_110_0;
rfi1_wrdata(29) <= N_111_0;
rfi1_wrdata(30) <= N_112_0;
rfi1_wrdata(31) <= N_113_0;
rfi1_ren1 <= N_114_0;
rfi1_ren2 <= N_115_0;
rfi1_wren <= N_116_0;
rfi2_rd1addr(0) <= N_117_0;
rfi2_rd1addr(1) <= N_118_0;
rfi2_rd1addr(2) <= N_119_0;
rfi2_rd1addr(3) <= N_120_0;
rfi2_rd2addr(0) <= N_121_0;
rfi2_rd2addr(1) <= N_122_0;
rfi2_rd2addr(2) <= N_123_0;
rfi2_rd2addr(3) <= N_124_0;
rfi2_wraddr(0) <= N_125_0;
rfi2_wraddr(1) <= N_126_0;
rfi2_wraddr(2) <= N_127_0;
rfi2_wraddr(3) <= N_128_0;
rfi2_wrdata(0) <= N_129_0;
rfi2_wrdata(1) <= N_130_0;
rfi2_wrdata(2) <= N_131_0;
rfi2_wrdata(3) <= N_132_0;
rfi2_wrdata(4) <= N_133_0;
rfi2_wrdata(5) <= N_134_0;
rfi2_wrdata(6) <= N_135_0;
rfi2_wrdata(7) <= N_136_0;
rfi2_wrdata(8) <= N_137_0;
rfi2_wrdata(9) <= N_138_0;
rfi2_wrdata(10) <= N_139_0;
rfi2_wrdata(11) <= N_140_0;
rfi2_wrdata(12) <= N_141_0;
rfi2_wrdata(13) <= N_142_0;
rfi2_wrdata(14) <= N_143_0;
rfi2_wrdata(15) <= N_144_0;
rfi2_wrdata(16) <= N_145_0;
rfi2_wrdata(17) <= N_146_0;
rfi2_wrdata(18) <= N_147_0;
rfi2_wrdata(19) <= N_148_0;
rfi2_wrdata(20) <= N_149_0;
rfi2_wrdata(21) <= N_150_0;
rfi2_wrdata(22) <= N_151_0;
rfi2_wrdata(23) <= N_152_0;
rfi2_wrdata(24) <= N_153_0;
rfi2_wrdata(25) <= N_154_0;
rfi2_wrdata(26) <= N_155_0;
rfi2_wrdata(27) <= N_156_0;
rfi2_wrdata(28) <= N_157_0;
rfi2_wrdata(29) <= N_158_0;
rfi2_wrdata(30) <= N_159_0;
rfi2_wrdata(31) <= N_160_0;
rfi2_ren1 <= N_161_0;
rfi2_ren2 <= N_162_0;
rfi2_wren <= N_163_0;
RST_INTERNAL <= rst;
CLK_INTERNAL <= clk;
HOLDN_INTERNAL <= holdn;
CPI_FLUSH_INTERNAL <= cpi_flush;
CPI_EXACK_INTERNAL <= cpi_exack;
CPI_A_RS1_INTERNAL <= cpi_a_rs1(0);
CPI_A_RS1_INTERNAL_0 <= cpi_a_rs1(1);
CPI_A_RS1_INTERNAL_1 <= cpi_a_rs1(2);
CPI_A_RS1_INTERNAL_2 <= cpi_a_rs1(3);
CPI_A_RS1_INTERNAL_3 <= cpi_a_rs1(4);
CPI_D_PC_INTERNAL <= cpi_d_pc(0);
CPI_D_PC_INTERNAL_0 <= cpi_d_pc(1);
CPI_D_PC_INTERNAL_1 <= cpi_d_pc(2);
CPI_D_PC_INTERNAL_2 <= cpi_d_pc(3);
CPI_D_PC_INTERNAL_3 <= cpi_d_pc(4);
CPI_D_PC_INTERNAL_4 <= cpi_d_pc(5);
CPI_D_PC_INTERNAL_5 <= cpi_d_pc(6);
CPI_D_PC_INTERNAL_6 <= cpi_d_pc(7);
CPI_D_PC_INTERNAL_7 <= cpi_d_pc(8);
CPI_D_PC_INTERNAL_8 <= cpi_d_pc(9);
CPI_D_PC_INTERNAL_9 <= cpi_d_pc(10);
CPI_D_PC_INTERNAL_10 <= cpi_d_pc(11);
CPI_D_PC_INTERNAL_11 <= cpi_d_pc(12);
CPI_D_PC_INTERNAL_12 <= cpi_d_pc(13);
CPI_D_PC_INTERNAL_13 <= cpi_d_pc(14);
CPI_D_PC_INTERNAL_14 <= cpi_d_pc(15);
CPI_D_PC_INTERNAL_15 <= cpi_d_pc(16);
CPI_D_PC_INTERNAL_16 <= cpi_d_pc(17);
CPI_D_PC_INTERNAL_17 <= cpi_d_pc(18);
CPI_D_PC_INTERNAL_18 <= cpi_d_pc(19);
CPI_D_PC_INTERNAL_19 <= cpi_d_pc(20);
CPI_D_PC_INTERNAL_20 <= cpi_d_pc(21);
CPI_D_PC_INTERNAL_21 <= cpi_d_pc(22);
CPI_D_PC_INTERNAL_22 <= cpi_d_pc(23);
CPI_D_PC_INTERNAL_23 <= cpi_d_pc(24);
CPI_D_PC_INTERNAL_24 <= cpi_d_pc(25);
CPI_D_PC_INTERNAL_25 <= cpi_d_pc(26);
CPI_D_PC_INTERNAL_26 <= cpi_d_pc(27);
CPI_D_PC_INTERNAL_27 <= cpi_d_pc(28);
CPI_D_PC_INTERNAL_28 <= cpi_d_pc(29);
CPI_D_PC_INTERNAL_29 <= cpi_d_pc(30);
CPI_D_PC_INTERNAL_30 <= cpi_d_pc(31);
CPI_D_INST_INTERNAL <= cpi_d_inst(0);
CPI_D_INST_INTERNAL_0 <= cpi_d_inst(1);
CPI_D_INST_INTERNAL_1 <= cpi_d_inst(2);
CPI_D_INST_INTERNAL_2 <= cpi_d_inst(3);
CPI_D_INST_INTERNAL_3 <= cpi_d_inst(4);
CPI_D_INST_INTERNAL_4 <= cpi_d_inst(5);
CPI_D_INST_INTERNAL_5 <= cpi_d_inst(6);
CPI_D_INST_INTERNAL_6 <= cpi_d_inst(7);
CPI_D_INST_INTERNAL_7 <= cpi_d_inst(8);
CPI_D_INST_INTERNAL_8 <= cpi_d_inst(9);
CPI_D_INST_INTERNAL_9 <= cpi_d_inst(10);
CPI_D_INST_INTERNAL_10 <= cpi_d_inst(11);
CPI_D_INST_INTERNAL_11 <= cpi_d_inst(12);
CPI_D_INST_INTERNAL_12 <= cpi_d_inst(13);
CPI_D_INST_INTERNAL_13 <= cpi_d_inst(14);
CPI_D_INST_INTERNAL_14 <= cpi_d_inst(15);
CPI_D_INST_INTERNAL_15 <= cpi_d_inst(16);
CPI_D_INST_INTERNAL_16 <= cpi_d_inst(17);
CPI_D_INST_INTERNAL_17 <= cpi_d_inst(18);
CPI_D_INST_INTERNAL_18 <= cpi_d_inst(19);
CPI_D_INST_INTERNAL_19 <= cpi_d_inst(20);
CPI_D_INST_INTERNAL_20 <= cpi_d_inst(21);
CPI_D_INST_INTERNAL_21 <= cpi_d_inst(22);
CPI_D_INST_INTERNAL_22 <= cpi_d_inst(23);
CPI_D_INST_INTERNAL_23 <= cpi_d_inst(24);
CPI_D_INST_INTERNAL_24 <= cpi_d_inst(25);
CPI_D_INST_INTERNAL_25 <= cpi_d_inst(26);
CPI_D_INST_INTERNAL_26 <= cpi_d_inst(27);
CPI_D_INST_INTERNAL_27 <= cpi_d_inst(28);
CPI_D_INST_INTERNAL_28 <= cpi_d_inst(29);
CPI_D_INST_INTERNAL_29 <= cpi_d_inst(30);
CPI_D_INST_INTERNAL_30 <= cpi_d_inst(31);
CPI_D_CNT_INTERNAL <= cpi_d_cnt(0);
CPI_D_CNT_INTERNAL_0 <= cpi_d_cnt(1);
CPI_D_TRAP_INTERNAL <= cpi_d_trap;
CPI_D_ANNUL_INTERNAL <= cpi_d_annul;
CPI_D_PV_INTERNAL <= cpi_d_pv;
CPI_A_PC_INTERNAL <= cpi_a_pc(0);
CPI_A_PC_INTERNAL_0 <= cpi_a_pc(1);
CPI_A_PC_INTERNAL_1 <= cpi_a_pc(2);
CPI_A_PC_INTERNAL_2 <= cpi_a_pc(3);
CPI_A_PC_INTERNAL_3 <= cpi_a_pc(4);
CPI_A_PC_INTERNAL_4 <= cpi_a_pc(5);
CPI_A_PC_INTERNAL_5 <= cpi_a_pc(6);
CPI_A_PC_INTERNAL_6 <= cpi_a_pc(7);
CPI_A_PC_INTERNAL_7 <= cpi_a_pc(8);
CPI_A_PC_INTERNAL_8 <= cpi_a_pc(9);
CPI_A_PC_INTERNAL_9 <= cpi_a_pc(10);
CPI_A_PC_INTERNAL_10 <= cpi_a_pc(11);
CPI_A_PC_INTERNAL_11 <= cpi_a_pc(12);
CPI_A_PC_INTERNAL_12 <= cpi_a_pc(13);
CPI_A_PC_INTERNAL_13 <= cpi_a_pc(14);
CPI_A_PC_INTERNAL_14 <= cpi_a_pc(15);
CPI_A_PC_INTERNAL_15 <= cpi_a_pc(16);
CPI_A_PC_INTERNAL_16 <= cpi_a_pc(17);
CPI_A_PC_INTERNAL_17 <= cpi_a_pc(18);
CPI_A_PC_INTERNAL_18 <= cpi_a_pc(19);
CPI_A_PC_INTERNAL_19 <= cpi_a_pc(20);
CPI_A_PC_INTERNAL_20 <= cpi_a_pc(21);
CPI_A_PC_INTERNAL_21 <= cpi_a_pc(22);
CPI_A_PC_INTERNAL_22 <= cpi_a_pc(23);
CPI_A_PC_INTERNAL_23 <= cpi_a_pc(24);
CPI_A_PC_INTERNAL_24 <= cpi_a_pc(25);
CPI_A_PC_INTERNAL_25 <= cpi_a_pc(26);
CPI_A_PC_INTERNAL_26 <= cpi_a_pc(27);
CPI_A_PC_INTERNAL_27 <= cpi_a_pc(28);
CPI_A_PC_INTERNAL_28 <= cpi_a_pc(29);
CPI_A_PC_INTERNAL_29 <= cpi_a_pc(30);
CPI_A_PC_INTERNAL_30 <= cpi_a_pc(31);
CPI_A_INST_INTERNAL <= cpi_a_inst(0);
CPI_A_INST_INTERNAL_0 <= cpi_a_inst(1);
CPI_A_INST_INTERNAL_1 <= cpi_a_inst(2);
CPI_A_INST_INTERNAL_2 <= cpi_a_inst(3);
CPI_A_INST_INTERNAL_3 <= cpi_a_inst(4);
CPI_A_INST_INTERNAL_4 <= cpi_a_inst(5);
CPI_A_INST_INTERNAL_5 <= cpi_a_inst(6);
CPI_A_INST_INTERNAL_6 <= cpi_a_inst(7);
CPI_A_INST_INTERNAL_7 <= cpi_a_inst(8);
CPI_A_INST_INTERNAL_8 <= cpi_a_inst(9);
CPI_A_INST_INTERNAL_9 <= cpi_a_inst(10);
CPI_A_INST_INTERNAL_10 <= cpi_a_inst(11);
CPI_A_INST_INTERNAL_11 <= cpi_a_inst(12);
CPI_A_INST_INTERNAL_12 <= cpi_a_inst(13);
CPI_A_INST_INTERNAL_13 <= cpi_a_inst(14);
CPI_A_INST_INTERNAL_14 <= cpi_a_inst(15);
CPI_A_INST_INTERNAL_15 <= cpi_a_inst(16);
CPI_A_INST_INTERNAL_16 <= cpi_a_inst(17);
CPI_A_INST_INTERNAL_17 <= cpi_a_inst(18);
CPI_A_INST_INTERNAL_18 <= cpi_a_inst(19);
CPI_A_INST_INTERNAL_19 <= cpi_a_inst(20);
CPI_A_INST_INTERNAL_20 <= cpi_a_inst(21);
CPI_A_INST_INTERNAL_21 <= cpi_a_inst(22);
CPI_A_INST_INTERNAL_22 <= cpi_a_inst(23);
CPI_A_INST_INTERNAL_23 <= cpi_a_inst(24);
CPI_A_INST_INTERNAL_24 <= cpi_a_inst(25);
CPI_A_INST_INTERNAL_25 <= cpi_a_inst(26);
CPI_A_INST_INTERNAL_26 <= cpi_a_inst(27);
CPI_A_INST_INTERNAL_27 <= cpi_a_inst(28);
CPI_A_INST_INTERNAL_28 <= cpi_a_inst(29);
CPI_A_INST_INTERNAL_29 <= cpi_a_inst(30);
CPI_A_INST_INTERNAL_30 <= cpi_a_inst(31);
CPI_A_CNT_INTERNAL <= cpi_a_cnt(0);
CPI_A_CNT_INTERNAL_0 <= cpi_a_cnt(1);
CPI_A_TRAP_INTERNAL <= cpi_a_trap;
CPI_A_ANNUL_INTERNAL <= cpi_a_annul;
CPI_A_PV_INTERNAL <= cpi_a_pv;
CPI_E_PC_INTERNAL <= cpi_e_pc(0);
CPI_E_PC_INTERNAL_0 <= cpi_e_pc(1);
CPI_E_PC_INTERNAL_1 <= cpi_e_pc(2);
CPI_E_PC_INTERNAL_2 <= cpi_e_pc(3);
CPI_E_PC_INTERNAL_3 <= cpi_e_pc(4);
CPI_E_PC_INTERNAL_4 <= cpi_e_pc(5);
CPI_E_PC_INTERNAL_5 <= cpi_e_pc(6);
CPI_E_PC_INTERNAL_6 <= cpi_e_pc(7);
CPI_E_PC_INTERNAL_7 <= cpi_e_pc(8);
CPI_E_PC_INTERNAL_8 <= cpi_e_pc(9);
CPI_E_PC_INTERNAL_9 <= cpi_e_pc(10);
CPI_E_PC_INTERNAL_10 <= cpi_e_pc(11);
CPI_E_PC_INTERNAL_11 <= cpi_e_pc(12);
CPI_E_PC_INTERNAL_12 <= cpi_e_pc(13);
CPI_E_PC_INTERNAL_13 <= cpi_e_pc(14);
CPI_E_PC_INTERNAL_14 <= cpi_e_pc(15);
CPI_E_PC_INTERNAL_15 <= cpi_e_pc(16);
CPI_E_PC_INTERNAL_16 <= cpi_e_pc(17);
CPI_E_PC_INTERNAL_17 <= cpi_e_pc(18);
CPI_E_PC_INTERNAL_18 <= cpi_e_pc(19);
CPI_E_PC_INTERNAL_19 <= cpi_e_pc(20);
CPI_E_PC_INTERNAL_20 <= cpi_e_pc(21);
CPI_E_PC_INTERNAL_21 <= cpi_e_pc(22);
CPI_E_PC_INTERNAL_22 <= cpi_e_pc(23);
CPI_E_PC_INTERNAL_23 <= cpi_e_pc(24);
CPI_E_PC_INTERNAL_24 <= cpi_e_pc(25);
CPI_E_PC_INTERNAL_25 <= cpi_e_pc(26);
CPI_E_PC_INTERNAL_26 <= cpi_e_pc(27);
CPI_E_PC_INTERNAL_27 <= cpi_e_pc(28);
CPI_E_PC_INTERNAL_28 <= cpi_e_pc(29);
CPI_E_PC_INTERNAL_29 <= cpi_e_pc(30);
CPI_E_PC_INTERNAL_30 <= cpi_e_pc(31);
CPI_E_INST_INTERNAL <= cpi_e_inst(0);
CPI_E_INST_INTERNAL_0 <= cpi_e_inst(1);
CPI_E_INST_INTERNAL_1 <= cpi_e_inst(2);
CPI_E_INST_INTERNAL_2 <= cpi_e_inst(3);
CPI_E_INST_INTERNAL_3 <= cpi_e_inst(4);
CPI_E_INST_INTERNAL_4 <= cpi_e_inst(5);
CPI_E_INST_INTERNAL_5 <= cpi_e_inst(6);
CPI_E_INST_INTERNAL_6 <= cpi_e_inst(7);
CPI_E_INST_INTERNAL_7 <= cpi_e_inst(8);
CPI_E_INST_INTERNAL_8 <= cpi_e_inst(9);
CPI_E_INST_INTERNAL_9 <= cpi_e_inst(10);
CPI_E_INST_INTERNAL_10 <= cpi_e_inst(11);
CPI_E_INST_INTERNAL_11 <= cpi_e_inst(12);
CPI_E_INST_INTERNAL_12 <= cpi_e_inst(13);
CPI_E_INST_INTERNAL_13 <= cpi_e_inst(14);
CPI_E_INST_INTERNAL_14 <= cpi_e_inst(15);
CPI_E_INST_INTERNAL_15 <= cpi_e_inst(16);
CPI_E_INST_INTERNAL_16 <= cpi_e_inst(17);
CPI_E_INST_INTERNAL_17 <= cpi_e_inst(18);
CPI_E_INST_INTERNAL_18 <= cpi_e_inst(19);
CPI_E_INST_INTERNAL_19 <= cpi_e_inst(20);
CPI_E_INST_INTERNAL_20 <= cpi_e_inst(21);
CPI_E_INST_INTERNAL_21 <= cpi_e_inst(22);
CPI_E_INST_INTERNAL_22 <= cpi_e_inst(23);
CPI_E_INST_INTERNAL_23 <= cpi_e_inst(24);
CPI_E_INST_INTERNAL_24 <= cpi_e_inst(25);
CPI_E_INST_INTERNAL_25 <= cpi_e_inst(26);
CPI_E_INST_INTERNAL_26 <= cpi_e_inst(27);
CPI_E_INST_INTERNAL_27 <= cpi_e_inst(28);
CPI_E_INST_INTERNAL_28 <= cpi_e_inst(29);
CPI_E_INST_INTERNAL_29 <= cpi_e_inst(30);
CPI_E_INST_INTERNAL_30 <= cpi_e_inst(31);
CPI_E_CNT_INTERNAL <= cpi_e_cnt(0);
CPI_E_CNT_INTERNAL_0 <= cpi_e_cnt(1);
CPI_E_TRAP_INTERNAL <= cpi_e_trap;
CPI_E_ANNUL_INTERNAL <= cpi_e_annul;
CPI_E_PV_INTERNAL <= cpi_e_pv;
CPI_M_PC_INTERNAL <= cpi_m_pc(0);
CPI_M_PC_INTERNAL_0 <= cpi_m_pc(1);
CPI_M_PC_INTERNAL_1 <= cpi_m_pc(2);
CPI_M_PC_INTERNAL_2 <= cpi_m_pc(3);
CPI_M_PC_INTERNAL_3 <= cpi_m_pc(4);
CPI_M_PC_INTERNAL_4 <= cpi_m_pc(5);
CPI_M_PC_INTERNAL_5 <= cpi_m_pc(6);
CPI_M_PC_INTERNAL_6 <= cpi_m_pc(7);
CPI_M_PC_INTERNAL_7 <= cpi_m_pc(8);
CPI_M_PC_INTERNAL_8 <= cpi_m_pc(9);
CPI_M_PC_INTERNAL_9 <= cpi_m_pc(10);
CPI_M_PC_INTERNAL_10 <= cpi_m_pc(11);
CPI_M_PC_INTERNAL_11 <= cpi_m_pc(12);
CPI_M_PC_INTERNAL_12 <= cpi_m_pc(13);
CPI_M_PC_INTERNAL_13 <= cpi_m_pc(14);
CPI_M_PC_INTERNAL_14 <= cpi_m_pc(15);
CPI_M_PC_INTERNAL_15 <= cpi_m_pc(16);
CPI_M_PC_INTERNAL_16 <= cpi_m_pc(17);
CPI_M_PC_INTERNAL_17 <= cpi_m_pc(18);
CPI_M_PC_INTERNAL_18 <= cpi_m_pc(19);
CPI_M_PC_INTERNAL_19 <= cpi_m_pc(20);
CPI_M_PC_INTERNAL_20 <= cpi_m_pc(21);
CPI_M_PC_INTERNAL_21 <= cpi_m_pc(22);
CPI_M_PC_INTERNAL_22 <= cpi_m_pc(23);
CPI_M_PC_INTERNAL_23 <= cpi_m_pc(24);
CPI_M_PC_INTERNAL_24 <= cpi_m_pc(25);
CPI_M_PC_INTERNAL_25 <= cpi_m_pc(26);
CPI_M_PC_INTERNAL_26 <= cpi_m_pc(27);
CPI_M_PC_INTERNAL_27 <= cpi_m_pc(28);
CPI_M_PC_INTERNAL_28 <= cpi_m_pc(29);
CPI_M_PC_INTERNAL_29 <= cpi_m_pc(30);
CPI_M_PC_INTERNAL_30 <= cpi_m_pc(31);
CPI_M_INST_INTERNAL <= cpi_m_inst(0);
CPI_M_INST_INTERNAL_0 <= cpi_m_inst(1);
CPI_M_INST_INTERNAL_1 <= cpi_m_inst(2);
CPI_M_INST_INTERNAL_2 <= cpi_m_inst(3);
CPI_M_INST_INTERNAL_3 <= cpi_m_inst(4);
CPI_M_INST_INTERNAL_4 <= cpi_m_inst(5);
CPI_M_INST_INTERNAL_5 <= cpi_m_inst(6);
CPI_M_INST_INTERNAL_6 <= cpi_m_inst(7);
CPI_M_INST_INTERNAL_7 <= cpi_m_inst(8);
CPI_M_INST_INTERNAL_8 <= cpi_m_inst(9);
CPI_M_INST_INTERNAL_9 <= cpi_m_inst(10);
CPI_M_INST_INTERNAL_10 <= cpi_m_inst(11);
CPI_M_INST_INTERNAL_11 <= cpi_m_inst(12);
CPI_M_INST_INTERNAL_12 <= cpi_m_inst(13);
CPI_M_INST_INTERNAL_13 <= cpi_m_inst(14);
CPI_M_INST_INTERNAL_14 <= cpi_m_inst(15);
CPI_M_INST_INTERNAL_15 <= cpi_m_inst(16);
CPI_M_INST_INTERNAL_16 <= cpi_m_inst(17);
CPI_M_INST_INTERNAL_17 <= cpi_m_inst(18);
CPI_M_INST_INTERNAL_18 <= cpi_m_inst(19);
CPI_M_INST_INTERNAL_19 <= cpi_m_inst(20);
CPI_M_INST_INTERNAL_20 <= cpi_m_inst(21);
CPI_M_INST_INTERNAL_21 <= cpi_m_inst(22);
CPI_M_INST_INTERNAL_22 <= cpi_m_inst(23);
CPI_M_INST_INTERNAL_23 <= cpi_m_inst(24);
CPI_M_INST_INTERNAL_24 <= cpi_m_inst(25);
CPI_M_INST_INTERNAL_25 <= cpi_m_inst(26);
CPI_M_INST_INTERNAL_26 <= cpi_m_inst(27);
CPI_M_INST_INTERNAL_27 <= cpi_m_inst(28);
CPI_M_INST_INTERNAL_28 <= cpi_m_inst(29);
CPI_M_INST_INTERNAL_29 <= cpi_m_inst(30);
CPI_M_INST_INTERNAL_30 <= cpi_m_inst(31);
CPI_M_CNT_INTERNAL <= cpi_m_cnt(0);
CPI_M_CNT_INTERNAL_0 <= cpi_m_cnt(1);
CPI_M_TRAP_INTERNAL <= cpi_m_trap;
CPI_M_ANNUL_INTERNAL <= cpi_m_annul;
CPI_M_PV_INTERNAL <= cpi_m_pv;
CPI_X_PC_INTERNAL <= cpi_x_pc(0);
CPI_X_PC_INTERNAL_0 <= cpi_x_pc(1);
CPI_X_PC_INTERNAL_1 <= cpi_x_pc(2);
CPI_X_PC_INTERNAL_2 <= cpi_x_pc(3);
CPI_X_PC_INTERNAL_3 <= cpi_x_pc(4);
CPI_X_PC_INTERNAL_4 <= cpi_x_pc(5);
CPI_X_PC_INTERNAL_5 <= cpi_x_pc(6);
CPI_X_PC_INTERNAL_6 <= cpi_x_pc(7);
CPI_X_PC_INTERNAL_7 <= cpi_x_pc(8);
CPI_X_PC_INTERNAL_8 <= cpi_x_pc(9);
CPI_X_PC_INTERNAL_9 <= cpi_x_pc(10);
CPI_X_PC_INTERNAL_10 <= cpi_x_pc(11);
CPI_X_PC_INTERNAL_11 <= cpi_x_pc(12);
CPI_X_PC_INTERNAL_12 <= cpi_x_pc(13);
CPI_X_PC_INTERNAL_13 <= cpi_x_pc(14);
CPI_X_PC_INTERNAL_14 <= cpi_x_pc(15);
CPI_X_PC_INTERNAL_15 <= cpi_x_pc(16);
CPI_X_PC_INTERNAL_16 <= cpi_x_pc(17);
CPI_X_PC_INTERNAL_17 <= cpi_x_pc(18);
CPI_X_PC_INTERNAL_18 <= cpi_x_pc(19);
CPI_X_PC_INTERNAL_19 <= cpi_x_pc(20);
CPI_X_PC_INTERNAL_20 <= cpi_x_pc(21);
CPI_X_PC_INTERNAL_21 <= cpi_x_pc(22);
CPI_X_PC_INTERNAL_22 <= cpi_x_pc(23);
CPI_X_PC_INTERNAL_23 <= cpi_x_pc(24);
CPI_X_PC_INTERNAL_24 <= cpi_x_pc(25);
CPI_X_PC_INTERNAL_25 <= cpi_x_pc(26);
CPI_X_PC_INTERNAL_26 <= cpi_x_pc(27);
CPI_X_PC_INTERNAL_27 <= cpi_x_pc(28);
CPI_X_PC_INTERNAL_28 <= cpi_x_pc(29);
CPI_X_PC_INTERNAL_29 <= cpi_x_pc(30);
CPI_X_PC_INTERNAL_30 <= cpi_x_pc(31);
CPI_X_INST_INTERNAL <= cpi_x_inst(0);
CPI_X_INST_INTERNAL_0 <= cpi_x_inst(1);
CPI_X_INST_INTERNAL_1 <= cpi_x_inst(2);
CPI_X_INST_INTERNAL_2 <= cpi_x_inst(3);
CPI_X_INST_INTERNAL_3 <= cpi_x_inst(4);
CPI_X_INST_INTERNAL_4 <= cpi_x_inst(5);
CPI_X_INST_INTERNAL_5 <= cpi_x_inst(6);
CPI_X_INST_INTERNAL_6 <= cpi_x_inst(7);
CPI_X_INST_INTERNAL_7 <= cpi_x_inst(8);
CPI_X_INST_INTERNAL_8 <= cpi_x_inst(9);
CPI_X_INST_INTERNAL_9 <= cpi_x_inst(10);
CPI_X_INST_INTERNAL_10 <= cpi_x_inst(11);
CPI_X_INST_INTERNAL_11 <= cpi_x_inst(12);
CPI_X_INST_INTERNAL_12 <= cpi_x_inst(13);
CPI_X_INST_INTERNAL_13 <= cpi_x_inst(14);
CPI_X_INST_INTERNAL_14 <= cpi_x_inst(15);
CPI_X_INST_INTERNAL_15 <= cpi_x_inst(16);
CPI_X_INST_INTERNAL_16 <= cpi_x_inst(17);
CPI_X_INST_INTERNAL_17 <= cpi_x_inst(18);
CPI_X_INST_INTERNAL_18 <= cpi_x_inst(19);
CPI_X_INST_INTERNAL_19 <= cpi_x_inst(20);
CPI_X_INST_INTERNAL_20 <= cpi_x_inst(21);
CPI_X_INST_INTERNAL_21 <= cpi_x_inst(22);
CPI_X_INST_INTERNAL_22 <= cpi_x_inst(23);
CPI_X_INST_INTERNAL_23 <= cpi_x_inst(24);
CPI_X_INST_INTERNAL_24 <= cpi_x_inst(25);
CPI_X_INST_INTERNAL_25 <= cpi_x_inst(26);
CPI_X_INST_INTERNAL_26 <= cpi_x_inst(27);
CPI_X_INST_INTERNAL_27 <= cpi_x_inst(28);
CPI_X_INST_INTERNAL_28 <= cpi_x_inst(29);
CPI_X_INST_INTERNAL_29 <= cpi_x_inst(30);
CPI_X_INST_INTERNAL_30 <= cpi_x_inst(31);
CPI_X_CNT_INTERNAL <= cpi_x_cnt(0);
CPI_X_CNT_INTERNAL_0 <= cpi_x_cnt(1);
CPI_X_TRAP_INTERNAL <= cpi_x_trap;
CPI_X_ANNUL_INTERNAL <= cpi_x_annul;
CPI_X_PV_INTERNAL <= cpi_x_pv;
CPI_LDDATA_INTERNAL <= cpi_lddata(0);
CPI_LDDATA_INTERNAL_0 <= cpi_lddata(1);
CPI_LDDATA_INTERNAL_1 <= cpi_lddata(2);
CPI_LDDATA_INTERNAL_2 <= cpi_lddata(3);
CPI_LDDATA_INTERNAL_3 <= cpi_lddata(4);
CPI_LDDATA_INTERNAL_4 <= cpi_lddata(5);
CPI_LDDATA_INTERNAL_5 <= cpi_lddata(6);
CPI_LDDATA_INTERNAL_6 <= cpi_lddata(7);
CPI_LDDATA_INTERNAL_7 <= cpi_lddata(8);
CPI_LDDATA_INTERNAL_8 <= cpi_lddata(9);
CPI_LDDATA_INTERNAL_9 <= cpi_lddata(10);
CPI_LDDATA_INTERNAL_10 <= cpi_lddata(11);
CPI_LDDATA_INTERNAL_11 <= cpi_lddata(12);
CPI_LDDATA_INTERNAL_12 <= cpi_lddata(13);
CPI_LDDATA_INTERNAL_13 <= cpi_lddata(14);
CPI_LDDATA_INTERNAL_14 <= cpi_lddata(15);
CPI_LDDATA_INTERNAL_15 <= cpi_lddata(16);
CPI_LDDATA_INTERNAL_16 <= cpi_lddata(17);
CPI_LDDATA_INTERNAL_17 <= cpi_lddata(18);
CPI_LDDATA_INTERNAL_18 <= cpi_lddata(19);
CPI_LDDATA_INTERNAL_19 <= cpi_lddata(20);
CPI_LDDATA_INTERNAL_20 <= cpi_lddata(21);
CPI_LDDATA_INTERNAL_21 <= cpi_lddata(22);
CPI_LDDATA_INTERNAL_22 <= cpi_lddata(23);
CPI_LDDATA_INTERNAL_23 <= cpi_lddata(24);
CPI_LDDATA_INTERNAL_24 <= cpi_lddata(25);
CPI_LDDATA_INTERNAL_25 <= cpi_lddata(26);
CPI_LDDATA_INTERNAL_26 <= cpi_lddata(27);
CPI_LDDATA_INTERNAL_27 <= cpi_lddata(28);
CPI_LDDATA_INTERNAL_28 <= cpi_lddata(29);
CPI_LDDATA_INTERNAL_29 <= cpi_lddata(30);
CPI_LDDATA_INTERNAL_30 <= cpi_lddata(31);
CPI_DBG_ENABLE_INTERNAL <= cpi_dbg_enable;
CPI_DBG_WRITE_INTERNAL <= cpi_dbg_write;
CPI_DBG_FSR_INTERNAL <= cpi_dbg_fsr;
CPI_DBG_ADDR_INTERNAL <= cpi_dbg_addr(0);
CPI_DBG_ADDR_INTERNAL_0 <= cpi_dbg_addr(1);
CPI_DBG_ADDR_INTERNAL_1 <= cpi_dbg_addr(2);
CPI_DBG_ADDR_INTERNAL_2 <= cpi_dbg_addr(3);
CPI_DBG_ADDR_INTERNAL_3 <= cpi_dbg_addr(4);
CPI_DBG_DATA_INTERNAL <= cpi_dbg_data(0);
CPI_DBG_DATA_INTERNAL_0 <= cpi_dbg_data(1);
CPI_DBG_DATA_INTERNAL_1 <= cpi_dbg_data(2);
CPI_DBG_DATA_INTERNAL_2 <= cpi_dbg_data(3);
CPI_DBG_DATA_INTERNAL_3 <= cpi_dbg_data(4);
CPI_DBG_DATA_INTERNAL_4 <= cpi_dbg_data(5);
CPI_DBG_DATA_INTERNAL_5 <= cpi_dbg_data(6);
CPI_DBG_DATA_INTERNAL_6 <= cpi_dbg_data(7);
CPI_DBG_DATA_INTERNAL_7 <= cpi_dbg_data(8);
CPI_DBG_DATA_INTERNAL_8 <= cpi_dbg_data(9);
CPI_DBG_DATA_INTERNAL_9 <= cpi_dbg_data(10);
CPI_DBG_DATA_INTERNAL_10 <= cpi_dbg_data(11);
CPI_DBG_DATA_INTERNAL_11 <= cpi_dbg_data(12);
CPI_DBG_DATA_INTERNAL_12 <= cpi_dbg_data(13);
CPI_DBG_DATA_INTERNAL_13 <= cpi_dbg_data(14);
CPI_DBG_DATA_INTERNAL_14 <= cpi_dbg_data(15);
CPI_DBG_DATA_INTERNAL_15 <= cpi_dbg_data(16);
CPI_DBG_DATA_INTERNAL_16 <= cpi_dbg_data(17);
CPI_DBG_DATA_INTERNAL_17 <= cpi_dbg_data(18);
CPI_DBG_DATA_INTERNAL_18 <= cpi_dbg_data(19);
CPI_DBG_DATA_INTERNAL_19 <= cpi_dbg_data(20);
CPI_DBG_DATA_INTERNAL_20 <= cpi_dbg_data(21);
CPI_DBG_DATA_INTERNAL_21 <= cpi_dbg_data(22);
CPI_DBG_DATA_INTERNAL_22 <= cpi_dbg_data(23);
CPI_DBG_DATA_INTERNAL_23 <= cpi_dbg_data(24);
CPI_DBG_DATA_INTERNAL_24 <= cpi_dbg_data(25);
CPI_DBG_DATA_INTERNAL_25 <= cpi_dbg_data(26);
CPI_DBG_DATA_INTERNAL_26 <= cpi_dbg_data(27);
CPI_DBG_DATA_INTERNAL_27 <= cpi_dbg_data(28);
CPI_DBG_DATA_INTERNAL_28 <= cpi_dbg_data(29);
CPI_DBG_DATA_INTERNAL_29 <= cpi_dbg_data(30);
CPI_DBG_DATA_INTERNAL_30 <= cpi_dbg_data(31);
RFO1_DATA1_INTERNAL <= rfo1_data1(0);
RFO1_DATA1_INTERNAL_0 <= rfo1_data1(1);
RFO1_DATA1_INTERNAL_1 <= rfo1_data1(2);
RFO1_DATA1_INTERNAL_2 <= rfo1_data1(3);
RFO1_DATA1_INTERNAL_3 <= rfo1_data1(4);
RFO1_DATA1_INTERNAL_4 <= rfo1_data1(5);
RFO1_DATA1_INTERNAL_5 <= rfo1_data1(6);
RFO1_DATA1_INTERNAL_6 <= rfo1_data1(7);
RFO1_DATA1_INTERNAL_7 <= rfo1_data1(8);
RFO1_DATA1_INTERNAL_8 <= rfo1_data1(9);
RFO1_DATA1_INTERNAL_9 <= rfo1_data1(10);
RFO1_DATA1_INTERNAL_10 <= rfo1_data1(11);
RFO1_DATA1_INTERNAL_11 <= rfo1_data1(12);
RFO1_DATA1_INTERNAL_12 <= rfo1_data1(13);
RFO1_DATA1_INTERNAL_13 <= rfo1_data1(14);
RFO1_DATA1_INTERNAL_14 <= rfo1_data1(15);
RFO1_DATA1_INTERNAL_15 <= rfo1_data1(16);
RFO1_DATA1_INTERNAL_16 <= rfo1_data1(17);
RFO1_DATA1_INTERNAL_17 <= rfo1_data1(18);
RFO1_DATA1_INTERNAL_18 <= rfo1_data1(19);
RFO1_DATA1_INTERNAL_19 <= rfo1_data1(20);
RFO1_DATA1_INTERNAL_20 <= rfo1_data1(21);
RFO1_DATA1_INTERNAL_21 <= rfo1_data1(22);
RFO1_DATA1_INTERNAL_22 <= rfo1_data1(23);
RFO1_DATA1_INTERNAL_23 <= rfo1_data1(24);
RFO1_DATA1_INTERNAL_24 <= rfo1_data1(25);
RFO1_DATA1_INTERNAL_25 <= rfo1_data1(26);
RFO1_DATA1_INTERNAL_26 <= rfo1_data1(27);
RFO1_DATA1_INTERNAL_27 <= rfo1_data1(28);
RFO1_DATA1_INTERNAL_28 <= rfo1_data1(29);
RFO1_DATA1_INTERNAL_29 <= rfo1_data1(30);
RFO1_DATA1_INTERNAL_30 <= rfo1_data1(31);
RFO1_DATA2_INTERNAL <= rfo1_data2(0);
RFO1_DATA2_INTERNAL_0 <= rfo1_data2(1);
RFO1_DATA2_INTERNAL_1 <= rfo1_data2(2);
RFO1_DATA2_INTERNAL_2 <= rfo1_data2(3);
RFO1_DATA2_INTERNAL_3 <= rfo1_data2(4);
RFO1_DATA2_INTERNAL_4 <= rfo1_data2(5);
RFO1_DATA2_INTERNAL_5 <= rfo1_data2(6);
RFO1_DATA2_INTERNAL_6 <= rfo1_data2(7);
RFO1_DATA2_INTERNAL_7 <= rfo1_data2(8);
RFO1_DATA2_INTERNAL_8 <= rfo1_data2(9);
RFO1_DATA2_INTERNAL_9 <= rfo1_data2(10);
RFO1_DATA2_INTERNAL_10 <= rfo1_data2(11);
RFO1_DATA2_INTERNAL_11 <= rfo1_data2(12);
RFO1_DATA2_INTERNAL_12 <= rfo1_data2(13);
RFO1_DATA2_INTERNAL_13 <= rfo1_data2(14);
RFO1_DATA2_INTERNAL_14 <= rfo1_data2(15);
RFO1_DATA2_INTERNAL_15 <= rfo1_data2(16);
RFO1_DATA2_INTERNAL_16 <= rfo1_data2(17);
RFO1_DATA2_INTERNAL_17 <= rfo1_data2(18);
RFO1_DATA2_INTERNAL_18 <= rfo1_data2(19);
RFO1_DATA2_INTERNAL_19 <= rfo1_data2(20);
RFO1_DATA2_INTERNAL_20 <= rfo1_data2(21);
RFO1_DATA2_INTERNAL_21 <= rfo1_data2(22);
RFO1_DATA2_INTERNAL_22 <= rfo1_data2(23);
RFO1_DATA2_INTERNAL_23 <= rfo1_data2(24);
RFO1_DATA2_INTERNAL_24 <= rfo1_data2(25);
RFO1_DATA2_INTERNAL_25 <= rfo1_data2(26);
RFO1_DATA2_INTERNAL_26 <= rfo1_data2(27);
RFO1_DATA2_INTERNAL_27 <= rfo1_data2(28);
RFO1_DATA2_INTERNAL_28 <= rfo1_data2(29);
RFO1_DATA2_INTERNAL_29 <= rfo1_data2(30);
RFO1_DATA2_INTERNAL_30 <= rfo1_data2(31);
RFO2_DATA1_INTERNAL <= rfo2_data1(0);
RFO2_DATA1_INTERNAL_0 <= rfo2_data1(1);
RFO2_DATA1_INTERNAL_1 <= rfo2_data1(2);
RFO2_DATA1_INTERNAL_2 <= rfo2_data1(3);
RFO2_DATA1_INTERNAL_3 <= rfo2_data1(4);
RFO2_DATA1_INTERNAL_4 <= rfo2_data1(5);
RFO2_DATA1_INTERNAL_5 <= rfo2_data1(6);
RFO2_DATA1_INTERNAL_6 <= rfo2_data1(7);
RFO2_DATA1_INTERNAL_7 <= rfo2_data1(8);
RFO2_DATA1_INTERNAL_8 <= rfo2_data1(9);
RFO2_DATA1_INTERNAL_9 <= rfo2_data1(10);
RFO2_DATA1_INTERNAL_10 <= rfo2_data1(11);
RFO2_DATA1_INTERNAL_11 <= rfo2_data1(12);
RFO2_DATA1_INTERNAL_12 <= rfo2_data1(13);
RFO2_DATA1_INTERNAL_13 <= rfo2_data1(14);
RFO2_DATA1_INTERNAL_14 <= rfo2_data1(15);
RFO2_DATA1_INTERNAL_15 <= rfo2_data1(16);
RFO2_DATA1_INTERNAL_16 <= rfo2_data1(17);
RFO2_DATA1_INTERNAL_17 <= rfo2_data1(18);
RFO2_DATA1_INTERNAL_18 <= rfo2_data1(19);
RFO2_DATA1_INTERNAL_19 <= rfo2_data1(20);
RFO2_DATA1_INTERNAL_20 <= rfo2_data1(21);
RFO2_DATA1_INTERNAL_21 <= rfo2_data1(22);
RFO2_DATA1_INTERNAL_22 <= rfo2_data1(23);
RFO2_DATA1_INTERNAL_23 <= rfo2_data1(24);
RFO2_DATA1_INTERNAL_24 <= rfo2_data1(25);
RFO2_DATA1_INTERNAL_25 <= rfo2_data1(26);
RFO2_DATA1_INTERNAL_26 <= rfo2_data1(27);
RFO2_DATA1_INTERNAL_27 <= rfo2_data1(28);
RFO2_DATA1_INTERNAL_28 <= rfo2_data1(29);
RFO2_DATA1_INTERNAL_29 <= rfo2_data1(30);
RFO2_DATA1_INTERNAL_30 <= rfo2_data1(31);
RFO2_DATA2_INTERNAL <= rfo2_data2(0);
RFO2_DATA2_INTERNAL_0 <= rfo2_data2(1);
RFO2_DATA2_INTERNAL_1 <= rfo2_data2(2);
RFO2_DATA2_INTERNAL_2 <= rfo2_data2(3);
RFO2_DATA2_INTERNAL_3 <= rfo2_data2(4);
RFO2_DATA2_INTERNAL_4 <= rfo2_data2(5);
RFO2_DATA2_INTERNAL_5 <= rfo2_data2(6);
RFO2_DATA2_INTERNAL_6 <= rfo2_data2(7);
RFO2_DATA2_INTERNAL_7 <= rfo2_data2(8);
RFO2_DATA2_INTERNAL_8 <= rfo2_data2(9);
RFO2_DATA2_INTERNAL_9 <= rfo2_data2(10);
RFO2_DATA2_INTERNAL_10 <= rfo2_data2(11);
RFO2_DATA2_INTERNAL_11 <= rfo2_data2(12);
RFO2_DATA2_INTERNAL_12 <= rfo2_data2(13);
RFO2_DATA2_INTERNAL_13 <= rfo2_data2(14);
RFO2_DATA2_INTERNAL_14 <= rfo2_data2(15);
RFO2_DATA2_INTERNAL_15 <= rfo2_data2(16);
RFO2_DATA2_INTERNAL_16 <= rfo2_data2(17);
RFO2_DATA2_INTERNAL_17 <= rfo2_data2(18);
RFO2_DATA2_INTERNAL_18 <= rfo2_data2(19);
RFO2_DATA2_INTERNAL_19 <= rfo2_data2(20);
RFO2_DATA2_INTERNAL_20 <= rfo2_data2(21);
RFO2_DATA2_INTERNAL_21 <= rfo2_data2(22);
RFO2_DATA2_INTERNAL_22 <= rfo2_data2(23);
RFO2_DATA2_INTERNAL_23 <= rfo2_data2(24);
RFO2_DATA2_INTERNAL_24 <= rfo2_data2(25);
RFO2_DATA2_INTERNAL_25 <= rfo2_data2(26);
RFO2_DATA2_INTERNAL_26 <= rfo2_data2(27);
RFO2_DATA2_INTERNAL_27 <= rfo2_data2(28);
RFO2_DATA2_INTERNAL_28 <= rfo2_data2(29);
RFO2_DATA2_INTERNAL_29 <= rfo2_data2(30);
RFO2_DATA2_INTERNAL_30 <= rfo2_data2(31);
end beh;

